/*
Configuration page for the Korganizer To-do Summary
*/

/********************************************************************************
** Form generated from reading UI file 'todosummaryconfig_base.ui'
**
** Created by: Qt User Interface Compiler version 6.11.2
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef UI_TODOSUMMARYCONFIG_BASE_H
#define UI_TODOSUMMARYCONFIG_BASE_H

#include <QtCore/QVariant>
#include <QtWidgets/QApplication>
#include <QtWidgets/QCheckBox>
#include <QtWidgets/QGroupBox>
#include <QtWidgets/QHBoxLayout>
#include <QtWidgets/QRadioButton>
#include <QtWidgets/QSpacerItem>
#include <QtWidgets/QSpinBox>
#include <QtWidgets/QVBoxLayout>
#include <QtWidgets/QWidget>
#include <klocalizedstring.h>

QT_BEGIN_NAMESPACE

class Ui_TodoSummaryConfig_Base
{
public:
    QVBoxLayout *verticalLayout_4;
    QGroupBox *mDaysGroup;
    QVBoxLayout *verticalLayout;
    QRadioButton *mDateTodayButton;
    QRadioButton *mDateMonthButton;
    QHBoxLayout *horizontalLayout;
    QRadioButton *mDateRangeButton;
    QSpinBox *mCustomDays;
    QSpacerItem *horizontalSpacer;
    QGroupBox *mHideGroup;
    QVBoxLayout *verticalLayout_2;
    QCheckBox *mHideCompletedBox;
    QCheckBox *mHideOpenEndedBox;
    QCheckBox *mHideUnstartedBox;
    QCheckBox *mHideInProgressBox;
    QCheckBox *mHideOverdueBox;
    QSpacerItem *verticalSpacer;

    void setupUi(QWidget *TodoSummaryConfig_Base)
    {
        if (TodoSummaryConfig_Base->objectName().isEmpty())
            TodoSummaryConfig_Base->setObjectName("TodoSummaryConfig_Base");
        TodoSummaryConfig_Base->resize(360, 424);
        verticalLayout_4 = new QVBoxLayout(TodoSummaryConfig_Base);
        verticalLayout_4->setObjectName("verticalLayout_4");
        mDaysGroup = new QGroupBox(TodoSummaryConfig_Base);
        mDaysGroup->setObjectName("mDaysGroup");
        verticalLayout = new QVBoxLayout(mDaysGroup);
        verticalLayout->setObjectName("verticalLayout");
        mDateTodayButton = new QRadioButton(mDaysGroup);
        mDateTodayButton->setObjectName("mDateTodayButton");
        mDateTodayButton->setChecked(true);

        verticalLayout->addWidget(mDateTodayButton);

        mDateMonthButton = new QRadioButton(mDaysGroup);
        mDateMonthButton->setObjectName("mDateMonthButton");
        mDateMonthButton->setChecked(false);

        verticalLayout->addWidget(mDateMonthButton);

        horizontalLayout = new QHBoxLayout();
        horizontalLayout->setObjectName("horizontalLayout");
        mDateRangeButton = new QRadioButton(mDaysGroup);
        mDateRangeButton->setObjectName("mDateRangeButton");
        mDateRangeButton->setEnabled(true);
        mDateRangeButton->setChecked(false);

        horizontalLayout->addWidget(mDateRangeButton);

        mCustomDays = new QSpinBox(mDaysGroup);
        mCustomDays->setObjectName("mCustomDays");
        mCustomDays->setEnabled(false);
        mCustomDays->setMinimum(1);
        mCustomDays->setMaximum(365);
        mCustomDays->setSingleStep(1);
        mCustomDays->setValue(7);

        horizontalLayout->addWidget(mCustomDays);

        horizontalSpacer = new QSpacerItem(1, 0, QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Minimum);

        horizontalLayout->addItem(horizontalSpacer);


        verticalLayout->addLayout(horizontalLayout);


        verticalLayout_4->addWidget(mDaysGroup);

        mHideGroup = new QGroupBox(TodoSummaryConfig_Base);
        mHideGroup->setObjectName("mHideGroup");
        verticalLayout_2 = new QVBoxLayout(mHideGroup);
        verticalLayout_2->setObjectName("verticalLayout_2");
        mHideCompletedBox = new QCheckBox(mHideGroup);
        mHideCompletedBox->setObjectName("mHideCompletedBox");
        mHideCompletedBox->setChecked(true);

        verticalLayout_2->addWidget(mHideCompletedBox);

        mHideOpenEndedBox = new QCheckBox(mHideGroup);
        mHideOpenEndedBox->setObjectName("mHideOpenEndedBox");
        mHideOpenEndedBox->setChecked(false);

        verticalLayout_2->addWidget(mHideOpenEndedBox);

        mHideUnstartedBox = new QCheckBox(mHideGroup);
        mHideUnstartedBox->setObjectName("mHideUnstartedBox");

        verticalLayout_2->addWidget(mHideUnstartedBox);

        mHideInProgressBox = new QCheckBox(mHideGroup);
        mHideInProgressBox->setObjectName("mHideInProgressBox");

        verticalLayout_2->addWidget(mHideInProgressBox);

        mHideOverdueBox = new QCheckBox(mHideGroup);
        mHideOverdueBox->setObjectName("mHideOverdueBox");

        verticalLayout_2->addWidget(mHideOverdueBox);


        verticalLayout_4->addWidget(mHideGroup);

        verticalSpacer = new QSpacerItem(0, 1, QSizePolicy::Policy::Minimum, QSizePolicy::Policy::Expanding);

        verticalLayout_4->addItem(verticalSpacer);


        retranslateUi(TodoSummaryConfig_Base);
        QObject::connect(mDateRangeButton, &QRadioButton::toggled, mCustomDays, &QSpinBox::setEnabled);

        QMetaObject::connectSlotsByName(TodoSummaryConfig_Base);
    } // setupUi

    void retranslateUi(QWidget *TodoSummaryConfig_Base)
    {
        TodoSummaryConfig_Base->setWindowTitle(tr2i18n("To-do Summary Configuration", nullptr));
        mDaysGroup->setTitle(tr2i18n("Show To-dos Due", nullptr));
#if QT_CONFIG(tooltip)
        mDateTodayButton->setToolTip(tr2i18n("Show To-dos due today only", nullptr));
#endif // QT_CONFIG(tooltip)
#if QT_CONFIG(whatsthis)
        mDateTodayButton->setWhatsThis(tr2i18n("Check this box if you want to see To-dos due on this date only.", nullptr));
#endif // QT_CONFIG(whatsthis)
        mDateTodayButton->setText(tr2i18n("&Today only", nullptr));
#if QT_CONFIG(tooltip)
        mDateMonthButton->setToolTip(tr2i18n("Show To-dos due within the next month", nullptr));
#endif // QT_CONFIG(tooltip)
#if QT_CONFIG(whatsthis)
        mDateMonthButton->setWhatsThis(tr2i18n("Check this box if you want to see To-dos that are due sometime during the next 31 days.", nullptr));
#endif // QT_CONFIG(whatsthis)
        mDateMonthButton->setText(tr2i18n("Within the next &month (31 days)", nullptr));
#if QT_CONFIG(tooltip)
        mDateRangeButton->setToolTip(tr2i18n("Select the days for showing pending To-dos", nullptr));
#endif // QT_CONFIG(tooltip)
#if QT_CONFIG(statustip)
        mDateRangeButton->setStatusTip(QString());
#endif // QT_CONFIG(statustip)
#if QT_CONFIG(whatsthis)
        mDateRangeButton->setWhatsThis(tr2i18n("Check this box if you want specify the number of days in the future for pending To-dos.", nullptr));
#endif // QT_CONFIG(whatsthis)
        mDateRangeButton->setText(tr2i18n("Within the &next:", nullptr));
#if QT_CONFIG(tooltip)
        mCustomDays->setToolTip(tr2i18n("Set the number of days to show pending To-dos", nullptr));
#endif // QT_CONFIG(tooltip)
#if QT_CONFIG(whatsthis)
        mCustomDays->setWhatsThis(tr2i18n("Use this spinbox to set the number of days to show pending To-dos up to 1 year in the future.", nullptr));
#endif // QT_CONFIG(whatsthis)
        mCustomDays->setSpecialValueText(tr2i18n("1 day", nullptr));
        mCustomDays->setSuffix(tr2i18n(" days", "days to show in summary"));
        mHideGroup->setTitle(tr2i18n("Hide Following To-do Types", nullptr));
#if QT_CONFIG(tooltip)
        mHideCompletedBox->setToolTip(tr2i18n("Hide completed To-dos", nullptr));
#endif // QT_CONFIG(tooltip)
#if QT_CONFIG(whatsthis)
        mHideCompletedBox->setWhatsThis(tr2i18n("Check this box if you do not want to see To-dos that have already been completed.", nullptr));
#endif // QT_CONFIG(whatsthis)
        mHideCompletedBox->setText(tr2i18n("&Completed", nullptr));
#if QT_CONFIG(tooltip)
        mHideOpenEndedBox->setToolTip(tr2i18n("Hide To-dos without a due date", nullptr));
#endif // QT_CONFIG(tooltip)
#if QT_CONFIG(whatsthis)
        mHideOpenEndedBox->setWhatsThis(tr2i18n("Check this box if you do not want to see open-ended To-dos.", nullptr));
#endif // QT_CONFIG(whatsthis)
        mHideOpenEndedBox->setText(tr2i18n("&Open-ended (no due date)", nullptr));
#if QT_CONFIG(tooltip)
        mHideUnstartedBox->setToolTip(tr2i18n("Hide unstarted To-dos", nullptr));
#endif // QT_CONFIG(tooltip)
#if QT_CONFIG(whatsthis)
        mHideUnstartedBox->setWhatsThis(tr2i18n("Check this box if you do not want to see To-dos with a start date in the future.", nullptr));
#endif // QT_CONFIG(whatsthis)
        mHideUnstartedBox->setText(tr2i18n("&Unstarted (start date is in the future)", nullptr));
#if QT_CONFIG(tooltip)
        mHideInProgressBox->setToolTip(tr2i18n("Hide in-progress To-dos", nullptr));
#endif // QT_CONFIG(tooltip)
#if QT_CONFIG(whatsthis)
        mHideInProgressBox->setWhatsThis(tr2i18n("Check this box if you do not want to see To-dos that have been started but are not yet completed.", nullptr));
#endif // QT_CONFIG(whatsthis)
        mHideInProgressBox->setText(tr2i18n("&In-progress (started but not completed)", nullptr));
#if QT_CONFIG(tooltip)
        mHideOverdueBox->setToolTip(tr2i18n("Hide overdue To-dos", nullptr));
#endif // QT_CONFIG(tooltip)
#if QT_CONFIG(statustip)
        mHideOverdueBox->setStatusTip(QString());
#endif // QT_CONFIG(statustip)
#if QT_CONFIG(whatsthis)
        mHideOverdueBox->setWhatsThis(tr2i18n("Check this box if you do not want to see To-dos that are past their due date but have not yet been completed.", nullptr));
#endif // QT_CONFIG(whatsthis)
        mHideOverdueBox->setText(tr2i18n("Over&due (not completed and beyond due-date)", nullptr));
    } // retranslateUi

};

namespace Ui {
    class TodoSummaryConfig_Base: public Ui_TodoSummaryConfig_Base {};
} // namespace Ui

QT_END_NAMESPACE

#endif // TODOSUMMARYCONFIG_BASE_H

