/****************************************************************************
** Meta object code from reading C++ file 'koeventview.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.11.2)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../../korganizer-26.08.0/src/koeventview.h"
#include <QtCore/qmetatype.h>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'koeventview.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.11.2. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN11KOEventViewE_t {};
} // unnamed namespace

template <> constexpr inline auto KOEventView::qt_create_metaobjectdata<qt_meta_tag_ZN11KOEventViewE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "KOEventView",
        "datesSelected",
        "",
        "KCalendarCore::DateList",
        "shiftedEvent",
        "focusChanged",
        "QWidget*",
        "popupShow",
        "popupEdit",
        "popupDelete",
        "popupCut",
        "popupCopy",
        "showNewEventPopup"
    };

    QtMocHelpers::UintData qt_methods {
        // Signal 'datesSelected'
        QtMocHelpers::SignalData<void(const KCalendarCore::DateList)>(1, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 3, 2 },
        }}),
        // Signal 'shiftedEvent'
        QtMocHelpers::SignalData<void(const QDate &, const QDate &)>(4, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QDate, 2 }, { QMetaType::QDate, 2 },
        }}),
        // Slot 'focusChanged'
        QtMocHelpers::SlotData<void(QWidget *, QWidget *)>(5, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 6, 2 }, { 0x80000000 | 6, 2 },
        }}),
        // Slot 'popupShow'
        QtMocHelpers::SlotData<void()>(7, 2, QMC::AccessProtected, QMetaType::Void),
        // Slot 'popupEdit'
        QtMocHelpers::SlotData<void()>(8, 2, QMC::AccessProtected, QMetaType::Void),
        // Slot 'popupDelete'
        QtMocHelpers::SlotData<void()>(9, 2, QMC::AccessProtected, QMetaType::Void),
        // Slot 'popupCut'
        QtMocHelpers::SlotData<void()>(10, 2, QMC::AccessProtected, QMetaType::Void),
        // Slot 'popupCopy'
        QtMocHelpers::SlotData<void()>(11, 2, QMC::AccessProtected, QMetaType::Void),
        // Slot 'showNewEventPopup'
        QtMocHelpers::SlotData<void()>(12, 2, QMC::AccessProtected, QMetaType::Void),
    };
    QtMocHelpers::UintData qt_properties {
    };
    QtMocHelpers::UintData qt_enums {
    };
    return QtMocHelpers::metaObjectData<KOEventView, qt_meta_tag_ZN11KOEventViewE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject KOEventView::staticMetaObject = { {
    QMetaObject::SuperData::link<KOrg::BaseView::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN11KOEventViewE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN11KOEventViewE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN11KOEventViewE_t>.metaTypes,
    nullptr
} };

void KOEventView::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<KOEventView *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->datesSelected((*reinterpret_cast<std::add_pointer_t<KCalendarCore::DateList>>(_a[1]))); break;
        case 1: _t->shiftedEvent((*reinterpret_cast<std::add_pointer_t<QDate>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QDate>>(_a[2]))); break;
        case 2: _t->focusChanged((*reinterpret_cast<std::add_pointer_t<QWidget*>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QWidget*>>(_a[2]))); break;
        case 3: _t->popupShow(); break;
        case 4: _t->popupEdit(); break;
        case 5: _t->popupDelete(); break;
        case 6: _t->popupCut(); break;
        case 7: _t->popupCopy(); break;
        case 8: _t->showNewEventPopup(); break;
        default: ;
        }
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        switch (_id) {
        default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
        case 2:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 1:
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< QWidget* >(); break;
            }
            break;
        }
    }
    if (_c == QMetaObject::IndexOfMethod) {
        if (QtMocHelpers::indexOfMethod<void (KOEventView::*)(const KCalendarCore::DateList )>(_a, &KOEventView::datesSelected, 0))
            return;
        if (QtMocHelpers::indexOfMethod<void (KOEventView::*)(const QDate & , const QDate & )>(_a, &KOEventView::shiftedEvent, 1))
            return;
    }
}

const QMetaObject *KOEventView::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *KOEventView::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN11KOEventViewE_t>.strings))
        return static_cast<void*>(this);
    return KOrg::BaseView::qt_metacast(_clname);
}

int KOEventView::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = KOrg::BaseView::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 9)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 9;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 9)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 9;
    }
    return _id;
}

// SIGNAL 0
void KOEventView::datesSelected(const KCalendarCore::DateList _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 0, nullptr, _t1);
}

// SIGNAL 1
void KOEventView::shiftedEvent(const QDate & _t1, const QDate & _t2)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 1, nullptr, _t1, _t2);
}
QT_WARNING_POP
