/****************************************************************************
** Meta object code from reading C++ file 'navigatorbar.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.11.2)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../../korganizer-26.08.0/src/widgets/navigatorbar.h"
#include <QtCore/qmetatype.h>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'navigatorbar.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.11.2. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN12NavigatorBarE_t {};
} // unnamed namespace

template <> constexpr inline auto NavigatorBar::qt_create_metaobjectdata<qt_meta_tag_ZN12NavigatorBarE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "NavigatorBar",
        "fullWindowClicked",
        "",
        "todayClicked",
        "nextWeekClicked",
        "prevWeekClicked",
        "nextMonthClicked",
        "prevMonthClicked",
        "nextYearClicked",
        "prevYearClicked",
        "monthSelected",
        "yearSelected",
        "selectDates",
        "KCalendarCore::DateList"
    };

    QtMocHelpers::UintData qt_methods {
        // Signal 'fullWindowClicked'
        QtMocHelpers::SignalData<void()>(1, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'todayClicked'
        QtMocHelpers::SignalData<void()>(3, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'nextWeekClicked'
        QtMocHelpers::SignalData<void()>(4, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'prevWeekClicked'
        QtMocHelpers::SignalData<void()>(5, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'nextMonthClicked'
        QtMocHelpers::SignalData<void()>(6, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'prevMonthClicked'
        QtMocHelpers::SignalData<void()>(7, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'nextYearClicked'
        QtMocHelpers::SignalData<void()>(8, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'prevYearClicked'
        QtMocHelpers::SignalData<void()>(9, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'monthSelected'
        QtMocHelpers::SignalData<void(int)>(10, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Int, 2 },
        }}),
        // Signal 'yearSelected'
        QtMocHelpers::SignalData<void(int)>(11, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Int, 2 },
        }}),
        // Slot 'selectDates'
        QtMocHelpers::SlotData<void(const KCalendarCore::DateList &)>(12, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 13, 2 },
        }}),
    };
    QtMocHelpers::UintData qt_properties {
    };
    QtMocHelpers::UintData qt_enums {
    };
    return QtMocHelpers::metaObjectData<NavigatorBar, qt_meta_tag_ZN12NavigatorBarE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject NavigatorBar::staticMetaObject = { {
    QMetaObject::SuperData::link<QWidget::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN12NavigatorBarE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN12NavigatorBarE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN12NavigatorBarE_t>.metaTypes,
    nullptr
} };

void NavigatorBar::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<NavigatorBar *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->fullWindowClicked(); break;
        case 1: _t->todayClicked(); break;
        case 2: _t->nextWeekClicked(); break;
        case 3: _t->prevWeekClicked(); break;
        case 4: _t->nextMonthClicked(); break;
        case 5: _t->prevMonthClicked(); break;
        case 6: _t->nextYearClicked(); break;
        case 7: _t->prevYearClicked(); break;
        case 8: _t->monthSelected((*reinterpret_cast<std::add_pointer_t<int>>(_a[1]))); break;
        case 9: _t->yearSelected((*reinterpret_cast<std::add_pointer_t<int>>(_a[1]))); break;
        case 10: _t->selectDates((*reinterpret_cast<std::add_pointer_t<KCalendarCore::DateList>>(_a[1]))); break;
        default: ;
        }
    }
    if (_c == QMetaObject::IndexOfMethod) {
        if (QtMocHelpers::indexOfMethod<void (NavigatorBar::*)()>(_a, &NavigatorBar::fullWindowClicked, 0))
            return;
        if (QtMocHelpers::indexOfMethod<void (NavigatorBar::*)()>(_a, &NavigatorBar::todayClicked, 1))
            return;
        if (QtMocHelpers::indexOfMethod<void (NavigatorBar::*)()>(_a, &NavigatorBar::nextWeekClicked, 2))
            return;
        if (QtMocHelpers::indexOfMethod<void (NavigatorBar::*)()>(_a, &NavigatorBar::prevWeekClicked, 3))
            return;
        if (QtMocHelpers::indexOfMethod<void (NavigatorBar::*)()>(_a, &NavigatorBar::nextMonthClicked, 4))
            return;
        if (QtMocHelpers::indexOfMethod<void (NavigatorBar::*)()>(_a, &NavigatorBar::prevMonthClicked, 5))
            return;
        if (QtMocHelpers::indexOfMethod<void (NavigatorBar::*)()>(_a, &NavigatorBar::nextYearClicked, 6))
            return;
        if (QtMocHelpers::indexOfMethod<void (NavigatorBar::*)()>(_a, &NavigatorBar::prevYearClicked, 7))
            return;
        if (QtMocHelpers::indexOfMethod<void (NavigatorBar::*)(int )>(_a, &NavigatorBar::monthSelected, 8))
            return;
        if (QtMocHelpers::indexOfMethod<void (NavigatorBar::*)(int )>(_a, &NavigatorBar::yearSelected, 9))
            return;
    }
}

const QMetaObject *NavigatorBar::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *NavigatorBar::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN12NavigatorBarE_t>.strings))
        return static_cast<void*>(this);
    return QWidget::qt_metacast(_clname);
}

int NavigatorBar::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QWidget::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 11)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 11;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 11)
            *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType();
        _id -= 11;
    }
    return _id;
}

// SIGNAL 0
void NavigatorBar::fullWindowClicked()
{
    QMetaObject::activate(this, &staticMetaObject, 0, nullptr);
}

// SIGNAL 1
void NavigatorBar::todayClicked()
{
    QMetaObject::activate(this, &staticMetaObject, 1, nullptr);
}

// SIGNAL 2
void NavigatorBar::nextWeekClicked()
{
    QMetaObject::activate(this, &staticMetaObject, 2, nullptr);
}

// SIGNAL 3
void NavigatorBar::prevWeekClicked()
{
    QMetaObject::activate(this, &staticMetaObject, 3, nullptr);
}

// SIGNAL 4
void NavigatorBar::nextMonthClicked()
{
    QMetaObject::activate(this, &staticMetaObject, 4, nullptr);
}

// SIGNAL 5
void NavigatorBar::prevMonthClicked()
{
    QMetaObject::activate(this, &staticMetaObject, 5, nullptr);
}

// SIGNAL 6
void NavigatorBar::nextYearClicked()
{
    QMetaObject::activate(this, &staticMetaObject, 6, nullptr);
}

// SIGNAL 7
void NavigatorBar::prevYearClicked()
{
    QMetaObject::activate(this, &staticMetaObject, 7, nullptr);
}

// SIGNAL 8
void NavigatorBar::monthSelected(int _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 8, nullptr, _t1);
}

// SIGNAL 9
void NavigatorBar::yearSelected(int _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 9, nullptr, _t1);
}
QT_WARNING_POP
