/****************************************************************************
** Meta object code from reading C++ file 'kprefsdialog.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.11.2)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../../korganizer-26.08.0/src/prefs/kprefsdialog.h"
#include <QtGui/qtextcursor.h>
#include <QtCore/qmetatype.h>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'kprefsdialog.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.11.2. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN10Korganizer9KPrefsWidE_t {};
} // unnamed namespace

template <> constexpr inline auto Korganizer::KPrefsWid::qt_create_metaobjectdata<qt_meta_tag_ZN10Korganizer9KPrefsWidE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "Korganizer::KPrefsWid",
        "changed",
        ""
    };

    QtMocHelpers::UintData qt_methods {
        // Signal 'changed'
        QtMocHelpers::SignalData<void()>(1, 2, QMC::AccessPublic, QMetaType::Void),
    };
    QtMocHelpers::UintData qt_properties {
    };
    QtMocHelpers::UintData qt_enums {
    };
    return QtMocHelpers::metaObjectData<KPrefsWid, qt_meta_tag_ZN10Korganizer9KPrefsWidE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject Korganizer::KPrefsWid::staticMetaObject = { {
    QMetaObject::SuperData::link<QObject::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN10Korganizer9KPrefsWidE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN10Korganizer9KPrefsWidE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN10Korganizer9KPrefsWidE_t>.metaTypes,
    nullptr
} };

void Korganizer::KPrefsWid::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<KPrefsWid *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->changed(); break;
        default: ;
        }
    }
    if (_c == QMetaObject::IndexOfMethod) {
        if (QtMocHelpers::indexOfMethod<void (KPrefsWid::*)()>(_a, &KPrefsWid::changed, 0))
            return;
    }
}

const QMetaObject *Korganizer::KPrefsWid::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *Korganizer::KPrefsWid::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN10Korganizer9KPrefsWidE_t>.strings))
        return static_cast<void*>(this);
    return QObject::qt_metacast(_clname);
}

int Korganizer::KPrefsWid::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QObject::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 1)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 1;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 1)
            *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType();
        _id -= 1;
    }
    return _id;
}

// SIGNAL 0
void Korganizer::KPrefsWid::changed()
{
    QMetaObject::activate(this, &staticMetaObject, 0, nullptr);
}
namespace {
struct qt_meta_tag_ZN10Korganizer13KPrefsWidBoolE_t {};
} // unnamed namespace

template <> constexpr inline auto Korganizer::KPrefsWidBool::qt_create_metaobjectdata<qt_meta_tag_ZN10Korganizer13KPrefsWidBoolE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "Korganizer::KPrefsWidBool"
    };

    QtMocHelpers::UintData qt_methods {
    };
    QtMocHelpers::UintData qt_properties {
    };
    QtMocHelpers::UintData qt_enums {
    };
    return QtMocHelpers::metaObjectData<KPrefsWidBool, qt_meta_tag_ZN10Korganizer13KPrefsWidBoolE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject Korganizer::KPrefsWidBool::staticMetaObject = { {
    QMetaObject::SuperData::link<KPrefsWid::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN10Korganizer13KPrefsWidBoolE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN10Korganizer13KPrefsWidBoolE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN10Korganizer13KPrefsWidBoolE_t>.metaTypes,
    nullptr
} };

void Korganizer::KPrefsWidBool::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<KPrefsWidBool *>(_o);
    (void)_t;
    (void)_c;
    (void)_id;
    (void)_a;
}

const QMetaObject *Korganizer::KPrefsWidBool::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *Korganizer::KPrefsWidBool::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN10Korganizer13KPrefsWidBoolE_t>.strings))
        return static_cast<void*>(this);
    return KPrefsWid::qt_metacast(_clname);
}

int Korganizer::KPrefsWidBool::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = KPrefsWid::qt_metacall(_c, _id, _a);
    return _id;
}
namespace {
struct qt_meta_tag_ZN10Korganizer12KPrefsWidIntE_t {};
} // unnamed namespace

template <> constexpr inline auto Korganizer::KPrefsWidInt::qt_create_metaobjectdata<qt_meta_tag_ZN10Korganizer12KPrefsWidIntE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "Korganizer::KPrefsWidInt"
    };

    QtMocHelpers::UintData qt_methods {
    };
    QtMocHelpers::UintData qt_properties {
    };
    QtMocHelpers::UintData qt_enums {
    };
    return QtMocHelpers::metaObjectData<KPrefsWidInt, qt_meta_tag_ZN10Korganizer12KPrefsWidIntE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject Korganizer::KPrefsWidInt::staticMetaObject = { {
    QMetaObject::SuperData::link<KPrefsWid::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN10Korganizer12KPrefsWidIntE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN10Korganizer12KPrefsWidIntE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN10Korganizer12KPrefsWidIntE_t>.metaTypes,
    nullptr
} };

void Korganizer::KPrefsWidInt::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<KPrefsWidInt *>(_o);
    (void)_t;
    (void)_c;
    (void)_id;
    (void)_a;
}

const QMetaObject *Korganizer::KPrefsWidInt::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *Korganizer::KPrefsWidInt::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN10Korganizer12KPrefsWidIntE_t>.strings))
        return static_cast<void*>(this);
    return KPrefsWid::qt_metacast(_clname);
}

int Korganizer::KPrefsWidInt::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = KPrefsWid::qt_metacall(_c, _id, _a);
    return _id;
}
namespace {
struct qt_meta_tag_ZN10Korganizer13KPrefsWidTimeE_t {};
} // unnamed namespace

template <> constexpr inline auto Korganizer::KPrefsWidTime::qt_create_metaobjectdata<qt_meta_tag_ZN10Korganizer13KPrefsWidTimeE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "Korganizer::KPrefsWidTime"
    };

    QtMocHelpers::UintData qt_methods {
    };
    QtMocHelpers::UintData qt_properties {
    };
    QtMocHelpers::UintData qt_enums {
    };
    return QtMocHelpers::metaObjectData<KPrefsWidTime, qt_meta_tag_ZN10Korganizer13KPrefsWidTimeE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject Korganizer::KPrefsWidTime::staticMetaObject = { {
    QMetaObject::SuperData::link<KPrefsWid::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN10Korganizer13KPrefsWidTimeE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN10Korganizer13KPrefsWidTimeE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN10Korganizer13KPrefsWidTimeE_t>.metaTypes,
    nullptr
} };

void Korganizer::KPrefsWidTime::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<KPrefsWidTime *>(_o);
    (void)_t;
    (void)_c;
    (void)_id;
    (void)_a;
}

const QMetaObject *Korganizer::KPrefsWidTime::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *Korganizer::KPrefsWidTime::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN10Korganizer13KPrefsWidTimeE_t>.strings))
        return static_cast<void*>(this);
    return KPrefsWid::qt_metacast(_clname);
}

int Korganizer::KPrefsWidTime::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = KPrefsWid::qt_metacall(_c, _id, _a);
    return _id;
}
namespace {
struct qt_meta_tag_ZN10Korganizer17KPrefsWidDurationE_t {};
} // unnamed namespace

template <> constexpr inline auto Korganizer::KPrefsWidDuration::qt_create_metaobjectdata<qt_meta_tag_ZN10Korganizer17KPrefsWidDurationE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "Korganizer::KPrefsWidDuration"
    };

    QtMocHelpers::UintData qt_methods {
    };
    QtMocHelpers::UintData qt_properties {
    };
    QtMocHelpers::UintData qt_enums {
    };
    return QtMocHelpers::metaObjectData<KPrefsWidDuration, qt_meta_tag_ZN10Korganizer17KPrefsWidDurationE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject Korganizer::KPrefsWidDuration::staticMetaObject = { {
    QMetaObject::SuperData::link<KPrefsWid::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN10Korganizer17KPrefsWidDurationE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN10Korganizer17KPrefsWidDurationE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN10Korganizer17KPrefsWidDurationE_t>.metaTypes,
    nullptr
} };

void Korganizer::KPrefsWidDuration::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<KPrefsWidDuration *>(_o);
    (void)_t;
    (void)_c;
    (void)_id;
    (void)_a;
}

const QMetaObject *Korganizer::KPrefsWidDuration::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *Korganizer::KPrefsWidDuration::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN10Korganizer17KPrefsWidDurationE_t>.strings))
        return static_cast<void*>(this);
    return KPrefsWid::qt_metacast(_clname);
}

int Korganizer::KPrefsWidDuration::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = KPrefsWid::qt_metacall(_c, _id, _a);
    return _id;
}
namespace {
struct qt_meta_tag_ZN10Korganizer13KPrefsWidDateE_t {};
} // unnamed namespace

template <> constexpr inline auto Korganizer::KPrefsWidDate::qt_create_metaobjectdata<qt_meta_tag_ZN10Korganizer13KPrefsWidDateE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "Korganizer::KPrefsWidDate"
    };

    QtMocHelpers::UintData qt_methods {
    };
    QtMocHelpers::UintData qt_properties {
    };
    QtMocHelpers::UintData qt_enums {
    };
    return QtMocHelpers::metaObjectData<KPrefsWidDate, qt_meta_tag_ZN10Korganizer13KPrefsWidDateE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject Korganizer::KPrefsWidDate::staticMetaObject = { {
    QMetaObject::SuperData::link<KPrefsWid::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN10Korganizer13KPrefsWidDateE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN10Korganizer13KPrefsWidDateE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN10Korganizer13KPrefsWidDateE_t>.metaTypes,
    nullptr
} };

void Korganizer::KPrefsWidDate::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<KPrefsWidDate *>(_o);
    (void)_t;
    (void)_c;
    (void)_id;
    (void)_a;
}

const QMetaObject *Korganizer::KPrefsWidDate::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *Korganizer::KPrefsWidDate::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN10Korganizer13KPrefsWidDateE_t>.strings))
        return static_cast<void*>(this);
    return KPrefsWid::qt_metacast(_clname);
}

int Korganizer::KPrefsWidDate::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = KPrefsWid::qt_metacall(_c, _id, _a);
    return _id;
}
namespace {
struct qt_meta_tag_ZN10Korganizer14KPrefsWidColorE_t {};
} // unnamed namespace

template <> constexpr inline auto Korganizer::KPrefsWidColor::qt_create_metaobjectdata<qt_meta_tag_ZN10Korganizer14KPrefsWidColorE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "Korganizer::KPrefsWidColor"
    };

    QtMocHelpers::UintData qt_methods {
    };
    QtMocHelpers::UintData qt_properties {
    };
    QtMocHelpers::UintData qt_enums {
    };
    return QtMocHelpers::metaObjectData<KPrefsWidColor, qt_meta_tag_ZN10Korganizer14KPrefsWidColorE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject Korganizer::KPrefsWidColor::staticMetaObject = { {
    QMetaObject::SuperData::link<KPrefsWid::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN10Korganizer14KPrefsWidColorE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN10Korganizer14KPrefsWidColorE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN10Korganizer14KPrefsWidColorE_t>.metaTypes,
    nullptr
} };

void Korganizer::KPrefsWidColor::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<KPrefsWidColor *>(_o);
    (void)_t;
    (void)_c;
    (void)_id;
    (void)_a;
}

const QMetaObject *Korganizer::KPrefsWidColor::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *Korganizer::KPrefsWidColor::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN10Korganizer14KPrefsWidColorE_t>.strings))
        return static_cast<void*>(this);
    return KPrefsWid::qt_metacast(_clname);
}

int Korganizer::KPrefsWidColor::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = KPrefsWid::qt_metacall(_c, _id, _a);
    return _id;
}
namespace {
struct qt_meta_tag_ZN10Korganizer13KPrefsWidFontE_t {};
} // unnamed namespace

template <> constexpr inline auto Korganizer::KPrefsWidFont::qt_create_metaobjectdata<qt_meta_tag_ZN10Korganizer13KPrefsWidFontE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "Korganizer::KPrefsWidFont",
        "selectFont",
        ""
    };

    QtMocHelpers::UintData qt_methods {
        // Slot 'selectFont'
        QtMocHelpers::SlotData<void()>(1, 2, QMC::AccessProtected, QMetaType::Void),
    };
    QtMocHelpers::UintData qt_properties {
    };
    QtMocHelpers::UintData qt_enums {
    };
    return QtMocHelpers::metaObjectData<KPrefsWidFont, qt_meta_tag_ZN10Korganizer13KPrefsWidFontE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject Korganizer::KPrefsWidFont::staticMetaObject = { {
    QMetaObject::SuperData::link<KPrefsWid::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN10Korganizer13KPrefsWidFontE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN10Korganizer13KPrefsWidFontE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN10Korganizer13KPrefsWidFontE_t>.metaTypes,
    nullptr
} };

void Korganizer::KPrefsWidFont::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<KPrefsWidFont *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->selectFont(); break;
        default: ;
        }
    }
    (void)_a;
}

const QMetaObject *Korganizer::KPrefsWidFont::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *Korganizer::KPrefsWidFont::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN10Korganizer13KPrefsWidFontE_t>.strings))
        return static_cast<void*>(this);
    return KPrefsWid::qt_metacast(_clname);
}

int Korganizer::KPrefsWidFont::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = KPrefsWid::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 1)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 1;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 1)
            *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType();
        _id -= 1;
    }
    return _id;
}
namespace {
struct qt_meta_tag_ZN10Korganizer15KPrefsWidRadiosE_t {};
} // unnamed namespace

template <> constexpr inline auto Korganizer::KPrefsWidRadios::qt_create_metaobjectdata<qt_meta_tag_ZN10Korganizer15KPrefsWidRadiosE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "Korganizer::KPrefsWidRadios"
    };

    QtMocHelpers::UintData qt_methods {
    };
    QtMocHelpers::UintData qt_properties {
    };
    QtMocHelpers::UintData qt_enums {
    };
    return QtMocHelpers::metaObjectData<KPrefsWidRadios, qt_meta_tag_ZN10Korganizer15KPrefsWidRadiosE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject Korganizer::KPrefsWidRadios::staticMetaObject = { {
    QMetaObject::SuperData::link<KPrefsWid::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN10Korganizer15KPrefsWidRadiosE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN10Korganizer15KPrefsWidRadiosE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN10Korganizer15KPrefsWidRadiosE_t>.metaTypes,
    nullptr
} };

void Korganizer::KPrefsWidRadios::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<KPrefsWidRadios *>(_o);
    (void)_t;
    (void)_c;
    (void)_id;
    (void)_a;
}

const QMetaObject *Korganizer::KPrefsWidRadios::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *Korganizer::KPrefsWidRadios::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN10Korganizer15KPrefsWidRadiosE_t>.strings))
        return static_cast<void*>(this);
    return KPrefsWid::qt_metacast(_clname);
}

int Korganizer::KPrefsWidRadios::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = KPrefsWid::qt_metacall(_c, _id, _a);
    return _id;
}
namespace {
struct qt_meta_tag_ZN10Korganizer14KPrefsWidComboE_t {};
} // unnamed namespace

template <> constexpr inline auto Korganizer::KPrefsWidCombo::qt_create_metaobjectdata<qt_meta_tag_ZN10Korganizer14KPrefsWidComboE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "Korganizer::KPrefsWidCombo"
    };

    QtMocHelpers::UintData qt_methods {
    };
    QtMocHelpers::UintData qt_properties {
    };
    QtMocHelpers::UintData qt_enums {
    };
    return QtMocHelpers::metaObjectData<KPrefsWidCombo, qt_meta_tag_ZN10Korganizer14KPrefsWidComboE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject Korganizer::KPrefsWidCombo::staticMetaObject = { {
    QMetaObject::SuperData::link<KPrefsWid::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN10Korganizer14KPrefsWidComboE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN10Korganizer14KPrefsWidComboE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN10Korganizer14KPrefsWidComboE_t>.metaTypes,
    nullptr
} };

void Korganizer::KPrefsWidCombo::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<KPrefsWidCombo *>(_o);
    (void)_t;
    (void)_c;
    (void)_id;
    (void)_a;
}

const QMetaObject *Korganizer::KPrefsWidCombo::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *Korganizer::KPrefsWidCombo::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN10Korganizer14KPrefsWidComboE_t>.strings))
        return static_cast<void*>(this);
    return KPrefsWid::qt_metacast(_clname);
}

int Korganizer::KPrefsWidCombo::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = KPrefsWid::qt_metacall(_c, _id, _a);
    return _id;
}
namespace {
struct qt_meta_tag_ZN10Korganizer15KPrefsWidStringE_t {};
} // unnamed namespace

template <> constexpr inline auto Korganizer::KPrefsWidString::qt_create_metaobjectdata<qt_meta_tag_ZN10Korganizer15KPrefsWidStringE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "Korganizer::KPrefsWidString"
    };

    QtMocHelpers::UintData qt_methods {
    };
    QtMocHelpers::UintData qt_properties {
    };
    QtMocHelpers::UintData qt_enums {
    };
    return QtMocHelpers::metaObjectData<KPrefsWidString, qt_meta_tag_ZN10Korganizer15KPrefsWidStringE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject Korganizer::KPrefsWidString::staticMetaObject = { {
    QMetaObject::SuperData::link<KPrefsWid::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN10Korganizer15KPrefsWidStringE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN10Korganizer15KPrefsWidStringE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN10Korganizer15KPrefsWidStringE_t>.metaTypes,
    nullptr
} };

void Korganizer::KPrefsWidString::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<KPrefsWidString *>(_o);
    (void)_t;
    (void)_c;
    (void)_id;
    (void)_a;
}

const QMetaObject *Korganizer::KPrefsWidString::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *Korganizer::KPrefsWidString::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN10Korganizer15KPrefsWidStringE_t>.strings))
        return static_cast<void*>(this);
    return KPrefsWid::qt_metacast(_clname);
}

int Korganizer::KPrefsWidString::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = KPrefsWid::qt_metacall(_c, _id, _a);
    return _id;
}
namespace {
struct qt_meta_tag_ZN10Korganizer13KPrefsWidPathE_t {};
} // unnamed namespace

template <> constexpr inline auto Korganizer::KPrefsWidPath::qt_create_metaobjectdata<qt_meta_tag_ZN10Korganizer13KPrefsWidPathE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "Korganizer::KPrefsWidPath"
    };

    QtMocHelpers::UintData qt_methods {
    };
    QtMocHelpers::UintData qt_properties {
    };
    QtMocHelpers::UintData qt_enums {
    };
    return QtMocHelpers::metaObjectData<KPrefsWidPath, qt_meta_tag_ZN10Korganizer13KPrefsWidPathE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject Korganizer::KPrefsWidPath::staticMetaObject = { {
    QMetaObject::SuperData::link<KPrefsWid::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN10Korganizer13KPrefsWidPathE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN10Korganizer13KPrefsWidPathE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN10Korganizer13KPrefsWidPathE_t>.metaTypes,
    nullptr
} };

void Korganizer::KPrefsWidPath::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<KPrefsWidPath *>(_o);
    (void)_t;
    (void)_c;
    (void)_id;
    (void)_a;
}

const QMetaObject *Korganizer::KPrefsWidPath::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *Korganizer::KPrefsWidPath::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN10Korganizer13KPrefsWidPathE_t>.strings))
        return static_cast<void*>(this);
    return KPrefsWid::qt_metacast(_clname);
}

int Korganizer::KPrefsWidPath::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = KPrefsWid::qt_metacall(_c, _id, _a);
    return _id;
}
namespace {
struct qt_meta_tag_ZN10Korganizer12KPrefsDialogE_t {};
} // unnamed namespace

template <> constexpr inline auto Korganizer::KPrefsDialog::qt_create_metaobjectdata<qt_meta_tag_ZN10Korganizer12KPrefsDialogE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "Korganizer::KPrefsDialog",
        "configChanged",
        "",
        "setDefaults",
        "readConfig",
        "writeConfig",
        "slotApply",
        "slotOk",
        "slotDefault"
    };

    QtMocHelpers::UintData qt_methods {
        // Signal 'configChanged'
        QtMocHelpers::SignalData<void()>(1, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'setDefaults'
        QtMocHelpers::SlotData<void()>(3, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'readConfig'
        QtMocHelpers::SlotData<void()>(4, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'writeConfig'
        QtMocHelpers::SlotData<void()>(5, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'slotApply'
        QtMocHelpers::SlotData<void()>(6, 2, QMC::AccessProtected, QMetaType::Void),
        // Slot 'slotOk'
        QtMocHelpers::SlotData<void()>(7, 2, QMC::AccessProtected, QMetaType::Void),
        // Slot 'slotDefault'
        QtMocHelpers::SlotData<void()>(8, 2, QMC::AccessProtected, QMetaType::Void),
    };
    QtMocHelpers::UintData qt_properties {
    };
    QtMocHelpers::UintData qt_enums {
    };
    return QtMocHelpers::metaObjectData<KPrefsDialog, qt_meta_tag_ZN10Korganizer12KPrefsDialogE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject Korganizer::KPrefsDialog::staticMetaObject = { {
    QMetaObject::SuperData::link<KPageDialog::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN10Korganizer12KPrefsDialogE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN10Korganizer12KPrefsDialogE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN10Korganizer12KPrefsDialogE_t>.metaTypes,
    nullptr
} };

void Korganizer::KPrefsDialog::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<KPrefsDialog *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->configChanged(); break;
        case 1: _t->setDefaults(); break;
        case 2: _t->readConfig(); break;
        case 3: _t->writeConfig(); break;
        case 4: _t->slotApply(); break;
        case 5: _t->slotOk(); break;
        case 6: _t->slotDefault(); break;
        default: ;
        }
    }
    if (_c == QMetaObject::IndexOfMethod) {
        if (QtMocHelpers::indexOfMethod<void (KPrefsDialog::*)()>(_a, &KPrefsDialog::configChanged, 0))
            return;
    }
}

const QMetaObject *Korganizer::KPrefsDialog::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *Korganizer::KPrefsDialog::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN10Korganizer12KPrefsDialogE_t>.strings))
        return static_cast<void*>(this);
    if (!strcmp(_clname, "KPrefsWidManager"))
        return static_cast< KPrefsWidManager*>(this);
    return KPageDialog::qt_metacast(_clname);
}

int Korganizer::KPrefsDialog::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = KPageDialog::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 7)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 7;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 7)
            *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType();
        _id -= 7;
    }
    return _id;
}

// SIGNAL 0
void Korganizer::KPrefsDialog::configChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 0, nullptr);
}
namespace {
struct qt_meta_tag_ZN10Korganizer12KPrefsModuleE_t {};
} // unnamed namespace

template <> constexpr inline auto Korganizer::KPrefsModule::qt_create_metaobjectdata<qt_meta_tag_ZN10Korganizer12KPrefsModuleE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "Korganizer::KPrefsModule",
        "slotWidChanged",
        ""
    };

    QtMocHelpers::UintData qt_methods {
        // Slot 'slotWidChanged'
        QtMocHelpers::SlotData<void()>(1, 2, QMC::AccessPublic, QMetaType::Void),
    };
    QtMocHelpers::UintData qt_properties {
    };
    QtMocHelpers::UintData qt_enums {
    };
    return QtMocHelpers::metaObjectData<KPrefsModule, qt_meta_tag_ZN10Korganizer12KPrefsModuleE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject Korganizer::KPrefsModule::staticMetaObject = { {
    QMetaObject::SuperData::link<KCModule::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN10Korganizer12KPrefsModuleE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN10Korganizer12KPrefsModuleE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN10Korganizer12KPrefsModuleE_t>.metaTypes,
    nullptr
} };

void Korganizer::KPrefsModule::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<KPrefsModule *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->slotWidChanged(); break;
        default: ;
        }
    }
    (void)_a;
}

const QMetaObject *Korganizer::KPrefsModule::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *Korganizer::KPrefsModule::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN10Korganizer12KPrefsModuleE_t>.strings))
        return static_cast<void*>(this);
    if (!strcmp(_clname, "KPrefsWidManager"))
        return static_cast< KPrefsWidManager*>(this);
    return KCModule::qt_metacast(_clname);
}

int Korganizer::KPrefsModule::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = KCModule::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 1)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 1;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 1)
            *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType();
        _id -= 1;
    }
    return _id;
}
QT_WARNING_POP
