/********************************************************************************
** Form generated from reading UI file 'multiagendaviewconfigwidget.ui'
**
** Created by: Qt User Interface Compiler version 6.11.2
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef UI_MULTIAGENDAVIEWCONFIGWIDGET_H
#define UI_MULTIAGENDAVIEWCONFIGWIDGET_H

#include <QtCore/QVariant>
#include <QtWidgets/QApplication>
#include <QtWidgets/QGridLayout>
#include <QtWidgets/QHBoxLayout>
#include <QtWidgets/QLabel>
#include <QtWidgets/QLineEdit>
#include <QtWidgets/QListView>
#include <QtWidgets/QRadioButton>
#include <QtWidgets/QSpacerItem>
#include <QtWidgets/QSpinBox>
#include <QtWidgets/QStackedWidget>
#include <QtWidgets/QVBoxLayout>
#include <QtWidgets/QWidget>
#include <klocalizedstring.h>

QT_BEGIN_NAMESPACE

class Ui_MultiAgendaViewConfigWidget
{
public:
    QGridLayout *gridLayout;
    QRadioButton *useDefaultRB;
    QRadioButton *useCustomRB;
    QHBoxLayout *horizontalLayout;
    QLabel *columnNumberLabel;
    QSpinBox *columnNumberSB;
    QSpacerItem *horizontalSpacer;
    QHBoxLayout *horizontalLayout_3;
    QListView *columnList;
    QVBoxLayout *verticalLayout;
    QHBoxLayout *horizontalLayout_2;
    QLabel *titleLabel;
    QLineEdit *titleLE;
    QLabel *selectedCalendarsLabel;
    QStackedWidget *selectionStack;

    void setupUi(QWidget *MultiAgendaViewConfigWidget)
    {
        if (MultiAgendaViewConfigWidget->objectName().isEmpty())
            MultiAgendaViewConfigWidget->setObjectName("MultiAgendaViewConfigWidget");
        MultiAgendaViewConfigWidget->resize(602, 481);
        gridLayout = new QGridLayout(MultiAgendaViewConfigWidget);
        gridLayout->setObjectName("gridLayout");
        useDefaultRB = new QRadioButton(MultiAgendaViewConfigWidget);
        useDefaultRB->setObjectName("useDefaultRB");
        useDefaultRB->setChecked(true);

        gridLayout->addWidget(useDefaultRB, 0, 0, 1, 1);

        useCustomRB = new QRadioButton(MultiAgendaViewConfigWidget);
        useCustomRB->setObjectName("useCustomRB");

        gridLayout->addWidget(useCustomRB, 1, 0, 1, 1);

        horizontalLayout = new QHBoxLayout();
        horizontalLayout->setObjectName("horizontalLayout");
        columnNumberLabel = new QLabel(MultiAgendaViewConfigWidget);
        columnNumberLabel->setObjectName("columnNumberLabel");

        horizontalLayout->addWidget(columnNumberLabel);

        columnNumberSB = new QSpinBox(MultiAgendaViewConfigWidget);
        columnNumberSB->setObjectName("columnNumberSB");
        columnNumberSB->setMinimum(1);
        columnNumberSB->setValue(2);

        horizontalLayout->addWidget(columnNumberSB);

        horizontalSpacer = new QSpacerItem(40, 20, QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Minimum);

        horizontalLayout->addItem(horizontalSpacer);


        gridLayout->addLayout(horizontalLayout, 2, 0, 1, 1);

        horizontalLayout_3 = new QHBoxLayout();
        horizontalLayout_3->setObjectName("horizontalLayout_3");
        columnList = new QListView(MultiAgendaViewConfigWidget);
        columnList->setObjectName("columnList");
        QSizePolicy sizePolicy(QSizePolicy::Policy::Preferred, QSizePolicy::Policy::Expanding);
        sizePolicy.setHorizontalStretch(0);
        sizePolicy.setVerticalStretch(0);
        sizePolicy.setHeightForWidth(columnList->sizePolicy().hasHeightForWidth());
        columnList->setSizePolicy(sizePolicy);

        horizontalLayout_3->addWidget(columnList);

        verticalLayout = new QVBoxLayout();
        verticalLayout->setObjectName("verticalLayout");
        horizontalLayout_2 = new QHBoxLayout();
        horizontalLayout_2->setObjectName("horizontalLayout_2");
        titleLabel = new QLabel(MultiAgendaViewConfigWidget);
        titleLabel->setObjectName("titleLabel");

        horizontalLayout_2->addWidget(titleLabel);

        titleLE = new QLineEdit(MultiAgendaViewConfigWidget);
        titleLE->setObjectName("titleLE");

        horizontalLayout_2->addWidget(titleLE);


        verticalLayout->addLayout(horizontalLayout_2);

        selectedCalendarsLabel = new QLabel(MultiAgendaViewConfigWidget);
        selectedCalendarsLabel->setObjectName("selectedCalendarsLabel");
        QSizePolicy sizePolicy1(QSizePolicy::Policy::MinimumExpanding, QSizePolicy::Policy::Preferred);
        sizePolicy1.setHorizontalStretch(0);
        sizePolicy1.setVerticalStretch(0);
        sizePolicy1.setHeightForWidth(selectedCalendarsLabel->sizePolicy().hasHeightForWidth());
        selectedCalendarsLabel->setSizePolicy(sizePolicy1);

        verticalLayout->addWidget(selectedCalendarsLabel);

        selectionStack = new QStackedWidget(MultiAgendaViewConfigWidget);
        selectionStack->setObjectName("selectionStack");
        QSizePolicy sizePolicy2(QSizePolicy::Policy::MinimumExpanding, QSizePolicy::Policy::MinimumExpanding);
        sizePolicy2.setHorizontalStretch(1);
        sizePolicy2.setVerticalStretch(1);
        sizePolicy2.setHeightForWidth(selectionStack->sizePolicy().hasHeightForWidth());
        selectionStack->setSizePolicy(sizePolicy2);

        verticalLayout->addWidget(selectionStack);


        horizontalLayout_3->addLayout(verticalLayout);


        gridLayout->addLayout(horizontalLayout_3, 3, 0, 1, 1);


        retranslateUi(MultiAgendaViewConfigWidget);

        selectionStack->setCurrentIndex(-1);


        QMetaObject::connectSlotsByName(MultiAgendaViewConfigWidget);
    } // setupUi

    void retranslateUi(QWidget *MultiAgendaViewConfigWidget)
    {
        useDefaultRB->setText(tr2i18n("Show one calendar per agenda column", nullptr));
        useCustomRB->setText(tr2i18n("Use custom calendar setup", nullptr));
        columnNumberLabel->setText(tr2i18n("Number of columns", nullptr));
        titleLabel->setText(tr2i18n("Title", "Agenda title"));
        selectedCalendarsLabel->setText(tr2i18n("Selected Calendars", nullptr));
        (void)MultiAgendaViewConfigWidget;
    } // retranslateUi

};

namespace Ui {
    class MultiAgendaViewConfigWidget: public Ui_MultiAgendaViewConfigWidget {};
} // namespace Ui

QT_END_NAMESPACE

#endif // MULTIAGENDAVIEWCONFIGWIDGET_H

