/*
 * This file was generated by qdbusxml2cpp version 0.8
 * Source file was org.kde.korganizer.Korganizer.xml
 *
 * qdbusxml2cpp is Copyright (C) The Qt Company Ltd. and other contributors.
 *
 * This is an auto-generated file.
 * Do not edit! All changes made to it will be lost.
 */

#include "korganizeradaptor.h"
#include <QtCore/QMetaObject>
#include <QtCore/QByteArray>
#include <QtCore/QList>
#include <QtCore/QMap>
#include <QtCore/QString>
#include <QtCore/QStringList>
#include <QtCore/QVariant>

/*
 * Implementation of adaptor class KorganizerAdaptor
 */

KorganizerAdaptor::KorganizerAdaptor(KOrganizerIfaceImpl *parent)
    : QDBusAbstractAdaptor(parent)
{
    // constructor
    setAutoRelaySignals(true);
}

KorganizerAdaptor::~KorganizerAdaptor()
{
    // destructor
}

bool KorganizerAdaptor::addIncidence(const QString &ical)
{
    // handle method call org.kde.korganizer.Korganizer.addIncidence
    return parent()->addIncidence(ical);
}

bool KorganizerAdaptor::deleteIncidence(const QString &url, bool force)
{
    // handle method call org.kde.korganizer.Korganizer.deleteIncidence
    return parent()->deleteIncidence(url, force);
}

bool KorganizerAdaptor::deleteIncidence(const QString &url)
{
    // handle method call org.kde.korganizer.Korganizer.deleteIncidence
    return parent()->deleteIncidence(url);
}

bool KorganizerAdaptor::editIncidence(const QString &url)
{
    // handle method call org.kde.korganizer.Korganizer.editIncidence
    return parent()->editIncidence(url);
}

QString KorganizerAdaptor::getCurrentURLasString()
{
    // handle method call org.kde.korganizer.Korganizer.getCurrentURLasString
    return parent()->getCurrentURLasString();
}

bool KorganizerAdaptor::handleCommandLine(const QStringList &args)
{
    // handle method call org.kde.korganizer.Korganizer.handleCommandLine
    return parent()->handleCommandLine(args);
}

bool KorganizerAdaptor::mergeURL(const QString &url)
{
    // handle method call org.kde.korganizer.Korganizer.mergeURL
    return parent()->mergeURL(url);
}

bool KorganizerAdaptor::openURL(const QString &url)
{
    // handle method call org.kde.korganizer.Korganizer.openURL
    return parent()->openURL(url);
}

bool KorganizerAdaptor::saveAsURL(const QString &url)
{
    // handle method call org.kde.korganizer.Korganizer.saveAsURL
    return parent()->saveAsURL(url);
}

bool KorganizerAdaptor::saveURL()
{
    // handle method call org.kde.korganizer.Korganizer.saveURL
    return parent()->saveURL();
}

bool KorganizerAdaptor::showIncidence(const QString &url)
{
    // handle method call org.kde.korganizer.Korganizer.showIncidence
    return parent()->showIncidence(url);
}

bool KorganizerAdaptor::showIncidenceContext(const QString &url)
{
    // handle method call org.kde.korganizer.Korganizer.showIncidenceContext
    return parent()->showIncidenceContext(url);
}


#include "moc_korganizeradaptor.cpp"
