/****************************************************************************
** Meta object code from reading C++ file 'koviewmanager.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.11.2)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../../korganizer-26.08.0/src/koviewmanager.h"
#include <QtCore/qmetatype.h>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'koviewmanager.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.11.2. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN13KOViewManagerE_t {};
} // unnamed namespace

template <> constexpr inline auto KOViewManager::qt_create_metaobjectdata<qt_meta_tag_ZN13KOViewManagerE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "KOViewManager",
        "configChanged",
        "",
        "datesSelected",
        "KCalendarCore::DateList",
        "showWhatsNextView",
        "showListView",
        "showAgendaView",
        "showTodoView",
        "showTimeLineView",
        "showMonthView",
        "showJournalView",
        "showEventView",
        "selectDay",
        "selectWorkWeek",
        "selectWeek",
        "selectNextX",
        "connectTodoView",
        "KOTodoView*",
        "todoView",
        "zoomInHorizontally",
        "zoomOutHorizontally",
        "zoomInVertically",
        "zoomOutVertically",
        "addChange",
        "EventViews::EventView::Change",
        "change",
        "currentAgendaViewTabChanged",
        "index",
        "addCalendar",
        "Akonadi::CollectionCalendar::Ptr",
        "calendar",
        "removeCalendar"
    };

    QtMocHelpers::UintData qt_methods {
        // Signal 'configChanged'
        QtMocHelpers::SignalData<void()>(1, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'datesSelected'
        QtMocHelpers::SignalData<void(const KCalendarCore::DateList &)>(3, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 4, 2 },
        }}),
        // Slot 'showWhatsNextView'
        QtMocHelpers::SlotData<void()>(5, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'showListView'
        QtMocHelpers::SlotData<void()>(6, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'showAgendaView'
        QtMocHelpers::SlotData<void()>(7, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'showTodoView'
        QtMocHelpers::SlotData<void()>(8, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'showTimeLineView'
        QtMocHelpers::SlotData<void()>(9, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'showMonthView'
        QtMocHelpers::SlotData<void()>(10, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'showJournalView'
        QtMocHelpers::SlotData<void()>(11, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'showEventView'
        QtMocHelpers::SlotData<void()>(12, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'selectDay'
        QtMocHelpers::SlotData<void()>(13, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'selectWorkWeek'
        QtMocHelpers::SlotData<void()>(14, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'selectWeek'
        QtMocHelpers::SlotData<void()>(15, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'selectNextX'
        QtMocHelpers::SlotData<void()>(16, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'connectTodoView'
        QtMocHelpers::SlotData<void(KOTodoView *)>(17, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 18, 19 },
        }}),
        // Slot 'zoomInHorizontally'
        QtMocHelpers::SlotData<void()>(20, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'zoomOutHorizontally'
        QtMocHelpers::SlotData<void()>(21, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'zoomInVertically'
        QtMocHelpers::SlotData<void()>(22, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'zoomOutVertically'
        QtMocHelpers::SlotData<void()>(23, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'addChange'
        QtMocHelpers::SlotData<void(EventViews::EventView::Change)>(24, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 25, 26 },
        }}),
        // Slot 'currentAgendaViewTabChanged'
        QtMocHelpers::SlotData<void(int)>(27, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::Int, 28 },
        }}),
        // Slot 'addCalendar'
        QtMocHelpers::SlotData<void(const Akonadi::CollectionCalendar::Ptr &)>(29, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { 0x80000000 | 30, 31 },
        }}),
        // Slot 'removeCalendar'
        QtMocHelpers::SlotData<void(const Akonadi::CollectionCalendar::Ptr &)>(32, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { 0x80000000 | 30, 31 },
        }}),
    };
    QtMocHelpers::UintData qt_properties {
    };
    QtMocHelpers::UintData qt_enums {
    };
    return QtMocHelpers::metaObjectData<KOViewManager, qt_meta_tag_ZN13KOViewManagerE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject KOViewManager::staticMetaObject = { {
    QMetaObject::SuperData::link<QObject::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN13KOViewManagerE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN13KOViewManagerE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN13KOViewManagerE_t>.metaTypes,
    nullptr
} };

void KOViewManager::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<KOViewManager *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->configChanged(); break;
        case 1: _t->datesSelected((*reinterpret_cast<std::add_pointer_t<KCalendarCore::DateList>>(_a[1]))); break;
        case 2: _t->showWhatsNextView(); break;
        case 3: _t->showListView(); break;
        case 4: _t->showAgendaView(); break;
        case 5: _t->showTodoView(); break;
        case 6: _t->showTimeLineView(); break;
        case 7: _t->showMonthView(); break;
        case 8: _t->showJournalView(); break;
        case 9: _t->showEventView(); break;
        case 10: _t->selectDay(); break;
        case 11: _t->selectWorkWeek(); break;
        case 12: _t->selectWeek(); break;
        case 13: _t->selectNextX(); break;
        case 14: _t->connectTodoView((*reinterpret_cast<std::add_pointer_t<KOTodoView*>>(_a[1]))); break;
        case 15: _t->zoomInHorizontally(); break;
        case 16: _t->zoomOutHorizontally(); break;
        case 17: _t->zoomInVertically(); break;
        case 18: _t->zoomOutVertically(); break;
        case 19: _t->addChange((*reinterpret_cast<std::add_pointer_t<EventViews::EventView::Change>>(_a[1]))); break;
        case 20: _t->currentAgendaViewTabChanged((*reinterpret_cast<std::add_pointer_t<int>>(_a[1]))); break;
        case 21: _t->addCalendar((*reinterpret_cast<std::add_pointer_t<Akonadi::CollectionCalendar::Ptr>>(_a[1]))); break;
        case 22: _t->removeCalendar((*reinterpret_cast<std::add_pointer_t<Akonadi::CollectionCalendar::Ptr>>(_a[1]))); break;
        default: ;
        }
    }
    if (_c == QMetaObject::IndexOfMethod) {
        if (QtMocHelpers::indexOfMethod<void (KOViewManager::*)()>(_a, &KOViewManager::configChanged, 0))
            return;
        if (QtMocHelpers::indexOfMethod<void (KOViewManager::*)(const KCalendarCore::DateList & )>(_a, &KOViewManager::datesSelected, 1))
            return;
    }
}

const QMetaObject *KOViewManager::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *KOViewManager::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN13KOViewManagerE_t>.strings))
        return static_cast<void*>(this);
    return QObject::qt_metacast(_clname);
}

int KOViewManager::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QObject::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 23)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 23;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 23)
            *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType();
        _id -= 23;
    }
    return _id;
}

// SIGNAL 0
void KOViewManager::configChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 0, nullptr);
}

// SIGNAL 1
void KOViewManager::datesSelected(const KCalendarCore::DateList & _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 1, nullptr, _t1);
}
QT_WARNING_POP
