/****************************************************************************
** Meta object code from reading C++ file 'baseview.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.11.2)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../../../../korganizer-26.08.0/src/interfaces/korganizer/baseview.h"
#include <QtCore/qmetatype.h>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'baseview.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.11.2. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN4KOrg8BaseViewE_t {};
} // unnamed namespace

template <> constexpr inline auto KOrg::BaseView::qt_create_metaobjectdata<qt_meta_tag_ZN4KOrg8BaseViewE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "KOrg::BaseView",
        "incidenceSelected",
        "",
        "Akonadi::Item",
        "showIncidenceSignal",
        "showOccurrenceSignal",
        "editIncidenceSignal",
        "deleteIncidenceSignal",
        "cutIncidenceSignal",
        "copyIncidenceSignal",
        "pasteIncidenceSignal",
        "toggleAlarmSignal",
        "toggleTodoCompletedSignal",
        "toggleOccurrenceCompletedSignal",
        "copyIncidenceToResourceSignal",
        "Akonadi::Collection",
        "moveIncidenceToResourceSignal",
        "dissociateOccurrencesSignal",
        "startMultiModify",
        "endMultiModify",
        "newEventSignal",
        "newTodoSignal",
        "newSubTodoSignal",
        "newJournalSignal",
        "showIncidences",
        "Akonadi::Item::List",
        "incidenceList",
        "date",
        "updateView",
        "dayPassed",
        "setIncidenceChanger",
        "Akonadi::IncidenceChanger*",
        "changer",
        "flushView",
        "changeIncidenceDisplay",
        "Akonadi::IncidenceChanger::ChangeType",
        "updateConfig",
        "clearSelection",
        "eventDurationHint",
        "QDateTime&",
        "startDt",
        "endDt",
        "bool&",
        "allDay",
        "calendarAdded",
        "Akonadi::CollectionCalendar::Ptr",
        "calendar",
        "calendarRemoved",
        "calendarReset"
    };

    QtMocHelpers::UintData qt_methods {
        // Signal 'incidenceSelected'
        QtMocHelpers::SignalData<void(const Akonadi::Item &, const QDate)>(1, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 3, 2 }, { QMetaType::QDate, 2 },
        }}),
        // Signal 'showIncidenceSignal'
        QtMocHelpers::SignalData<void(const Akonadi::Item &)>(4, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 3, 2 },
        }}),
        // Signal 'showOccurrenceSignal'
        QtMocHelpers::SignalData<void(const Akonadi::Item &, const QDate &)>(5, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 3, 2 }, { QMetaType::QDate, 2 },
        }}),
        // Signal 'editIncidenceSignal'
        QtMocHelpers::SignalData<void(const Akonadi::Item &)>(6, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 3, 2 },
        }}),
        // Signal 'deleteIncidenceSignal'
        QtMocHelpers::SignalData<void(const Akonadi::Item &)>(7, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 3, 2 },
        }}),
        // Signal 'cutIncidenceSignal'
        QtMocHelpers::SignalData<void(const Akonadi::Item &)>(8, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 3, 2 },
        }}),
        // Signal 'copyIncidenceSignal'
        QtMocHelpers::SignalData<void(const Akonadi::Item &)>(9, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 3, 2 },
        }}),
        // Signal 'pasteIncidenceSignal'
        QtMocHelpers::SignalData<void()>(10, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'toggleAlarmSignal'
        QtMocHelpers::SignalData<void(const Akonadi::Item &)>(11, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 3, 2 },
        }}),
        // Signal 'toggleTodoCompletedSignal'
        QtMocHelpers::SignalData<void(const Akonadi::Item &)>(12, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 3, 2 },
        }}),
        // Signal 'toggleOccurrenceCompletedSignal'
        QtMocHelpers::SignalData<void(const Akonadi::Item &, const QDate &)>(13, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 3, 2 }, { QMetaType::QDate, 2 },
        }}),
        // Signal 'copyIncidenceToResourceSignal'
        QtMocHelpers::SignalData<void(const Akonadi::Item &, const Akonadi::Collection &)>(14, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 3, 2 }, { 0x80000000 | 15, 2 },
        }}),
        // Signal 'moveIncidenceToResourceSignal'
        QtMocHelpers::SignalData<void(const Akonadi::Item &, const Akonadi::Collection &)>(16, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 3, 2 }, { 0x80000000 | 15, 2 },
        }}),
        // Signal 'dissociateOccurrencesSignal'
        QtMocHelpers::SignalData<void(const Akonadi::Item &, const QDate &)>(17, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 3, 2 }, { QMetaType::QDate, 2 },
        }}),
        // Signal 'startMultiModify'
        QtMocHelpers::SignalData<void(const QString &)>(18, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 2 },
        }}),
        // Signal 'endMultiModify'
        QtMocHelpers::SignalData<void()>(19, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'newEventSignal'
        QtMocHelpers::SignalData<void()>(20, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'newEventSignal'
        QtMocHelpers::SignalData<void(const QDate &)>(20, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QDate, 2 },
        }}),
        // Signal 'newEventSignal'
        QtMocHelpers::SignalData<void(const QDateTime &)>(20, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QDateTime, 2 },
        }}),
        // Signal 'newEventSignal'
        QtMocHelpers::SignalData<void(const QDateTime &, const QDateTime &)>(20, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QDateTime, 2 }, { QMetaType::QDateTime, 2 },
        }}),
        // Signal 'newTodoSignal'
        QtMocHelpers::SignalData<void(const QDate &)>(21, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QDate, 2 },
        }}),
        // Signal 'newSubTodoSignal'
        QtMocHelpers::SignalData<void(const Akonadi::Item &)>(22, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 3, 2 },
        }}),
        // Signal 'newJournalSignal'
        QtMocHelpers::SignalData<void(const QDate &)>(23, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QDate, 2 },
        }}),
        // Slot 'showIncidences'
        QtMocHelpers::SlotData<void(const Akonadi::Item::List &, const QDate &)>(24, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 25, 26 }, { QMetaType::QDate, 27 },
        }}),
        // Slot 'updateView'
        QtMocHelpers::SlotData<void()>(28, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'dayPassed'
        QtMocHelpers::SlotData<void(const QDate &)>(29, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QDate, 2 },
        }}),
        // Slot 'setIncidenceChanger'
        QtMocHelpers::SlotData<void(Akonadi::IncidenceChanger *)>(30, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 31, 32 },
        }}),
        // Slot 'flushView'
        QtMocHelpers::SlotData<void()>(33, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'changeIncidenceDisplay'
        QtMocHelpers::SlotData<void(const Akonadi::Item &, Akonadi::IncidenceChanger::ChangeType)>(34, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 3, 2 }, { 0x80000000 | 35, 2 },
        }}),
        // Slot 'updateConfig'
        QtMocHelpers::SlotData<void()>(36, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'clearSelection'
        QtMocHelpers::SlotData<void()>(37, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'eventDurationHint'
        QtMocHelpers::SlotData<bool(QDateTime &, QDateTime &, bool &)>(38, 2, QMC::AccessPublic, QMetaType::Bool, {{
            { 0x80000000 | 39, 40 }, { 0x80000000 | 39, 41 }, { 0x80000000 | 42, 43 },
        }}),
        // Slot 'calendarAdded'
        QtMocHelpers::SlotData<void(const Akonadi::CollectionCalendar::Ptr &)>(44, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 45, 46 },
        }}),
        // Slot 'calendarRemoved'
        QtMocHelpers::SlotData<void(const Akonadi::CollectionCalendar::Ptr &)>(47, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 45, 46 },
        }}),
        // Slot 'calendarReset'
        QtMocHelpers::SlotData<void()>(48, 2, QMC::AccessProtected, QMetaType::Void),
    };
    QtMocHelpers::UintData qt_properties {
    };
    QtMocHelpers::UintData qt_enums {
    };
    return QtMocHelpers::metaObjectData<BaseView, qt_meta_tag_ZN4KOrg8BaseViewE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject KOrg::BaseView::staticMetaObject = { {
    QMetaObject::SuperData::link<QWidget::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN4KOrg8BaseViewE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN4KOrg8BaseViewE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN4KOrg8BaseViewE_t>.metaTypes,
    nullptr
} };

void KOrg::BaseView::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<BaseView *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->incidenceSelected((*reinterpret_cast<std::add_pointer_t<Akonadi::Item>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QDate>>(_a[2]))); break;
        case 1: _t->showIncidenceSignal((*reinterpret_cast<std::add_pointer_t<Akonadi::Item>>(_a[1]))); break;
        case 2: _t->showOccurrenceSignal((*reinterpret_cast<std::add_pointer_t<Akonadi::Item>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QDate>>(_a[2]))); break;
        case 3: _t->editIncidenceSignal((*reinterpret_cast<std::add_pointer_t<Akonadi::Item>>(_a[1]))); break;
        case 4: _t->deleteIncidenceSignal((*reinterpret_cast<std::add_pointer_t<Akonadi::Item>>(_a[1]))); break;
        case 5: _t->cutIncidenceSignal((*reinterpret_cast<std::add_pointer_t<Akonadi::Item>>(_a[1]))); break;
        case 6: _t->copyIncidenceSignal((*reinterpret_cast<std::add_pointer_t<Akonadi::Item>>(_a[1]))); break;
        case 7: _t->pasteIncidenceSignal(); break;
        case 8: _t->toggleAlarmSignal((*reinterpret_cast<std::add_pointer_t<Akonadi::Item>>(_a[1]))); break;
        case 9: _t->toggleTodoCompletedSignal((*reinterpret_cast<std::add_pointer_t<Akonadi::Item>>(_a[1]))); break;
        case 10: _t->toggleOccurrenceCompletedSignal((*reinterpret_cast<std::add_pointer_t<Akonadi::Item>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QDate>>(_a[2]))); break;
        case 11: _t->copyIncidenceToResourceSignal((*reinterpret_cast<std::add_pointer_t<Akonadi::Item>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<Akonadi::Collection>>(_a[2]))); break;
        case 12: _t->moveIncidenceToResourceSignal((*reinterpret_cast<std::add_pointer_t<Akonadi::Item>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<Akonadi::Collection>>(_a[2]))); break;
        case 13: _t->dissociateOccurrencesSignal((*reinterpret_cast<std::add_pointer_t<Akonadi::Item>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QDate>>(_a[2]))); break;
        case 14: _t->startMultiModify((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 15: _t->endMultiModify(); break;
        case 16: _t->newEventSignal(); break;
        case 17: _t->newEventSignal((*reinterpret_cast<std::add_pointer_t<QDate>>(_a[1]))); break;
        case 18: _t->newEventSignal((*reinterpret_cast<std::add_pointer_t<QDateTime>>(_a[1]))); break;
        case 19: _t->newEventSignal((*reinterpret_cast<std::add_pointer_t<QDateTime>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QDateTime>>(_a[2]))); break;
        case 20: _t->newTodoSignal((*reinterpret_cast<std::add_pointer_t<QDate>>(_a[1]))); break;
        case 21: _t->newSubTodoSignal((*reinterpret_cast<std::add_pointer_t<Akonadi::Item>>(_a[1]))); break;
        case 22: _t->newJournalSignal((*reinterpret_cast<std::add_pointer_t<QDate>>(_a[1]))); break;
        case 23: _t->showIncidences((*reinterpret_cast<std::add_pointer_t<Akonadi::Item::List>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QDate>>(_a[2]))); break;
        case 24: _t->updateView(); break;
        case 25: _t->dayPassed((*reinterpret_cast<std::add_pointer_t<QDate>>(_a[1]))); break;
        case 26: _t->setIncidenceChanger((*reinterpret_cast<std::add_pointer_t<Akonadi::IncidenceChanger*>>(_a[1]))); break;
        case 27: _t->flushView(); break;
        case 28: _t->changeIncidenceDisplay((*reinterpret_cast<std::add_pointer_t<Akonadi::Item>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<Akonadi::IncidenceChanger::ChangeType>>(_a[2]))); break;
        case 29: _t->updateConfig(); break;
        case 30: _t->clearSelection(); break;
        case 31: { bool _r = _t->eventDurationHint((*reinterpret_cast<std::add_pointer_t<QDateTime&>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QDateTime&>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<bool&>>(_a[3])));
            if (_a[0]) *reinterpret_cast<bool*>(_a[0]) = std::move(_r); }  break;
        case 32: _t->calendarAdded((*reinterpret_cast<std::add_pointer_t<Akonadi::CollectionCalendar::Ptr>>(_a[1]))); break;
        case 33: _t->calendarRemoved((*reinterpret_cast<std::add_pointer_t<Akonadi::CollectionCalendar::Ptr>>(_a[1]))); break;
        case 34: _t->calendarReset(); break;
        default: ;
        }
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        switch (_id) {
        default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
        case 0:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< Akonadi::Item >(); break;
            }
            break;
        case 1:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< Akonadi::Item >(); break;
            }
            break;
        case 2:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< Akonadi::Item >(); break;
            }
            break;
        case 3:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< Akonadi::Item >(); break;
            }
            break;
        case 4:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< Akonadi::Item >(); break;
            }
            break;
        case 5:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< Akonadi::Item >(); break;
            }
            break;
        case 6:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< Akonadi::Item >(); break;
            }
            break;
        case 8:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< Akonadi::Item >(); break;
            }
            break;
        case 9:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< Akonadi::Item >(); break;
            }
            break;
        case 10:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< Akonadi::Item >(); break;
            }
            break;
        case 11:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< Akonadi::Item >(); break;
            }
            break;
        case 12:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< Akonadi::Item >(); break;
            }
            break;
        case 13:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< Akonadi::Item >(); break;
            }
            break;
        case 21:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< Akonadi::Item >(); break;
            }
            break;
        case 23:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< Akonadi::Item::List >(); break;
            }
            break;
        case 26:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< Akonadi::IncidenceChanger* >(); break;
            }
            break;
        case 28:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 1:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< Akonadi::IncidenceChanger::ChangeType >(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< Akonadi::Item >(); break;
            }
            break;
        }
    }
    if (_c == QMetaObject::IndexOfMethod) {
        if (QtMocHelpers::indexOfMethod<void (BaseView::*)(const Akonadi::Item & , const QDate )>(_a, &BaseView::incidenceSelected, 0))
            return;
        if (QtMocHelpers::indexOfMethod<void (BaseView::*)(const Akonadi::Item & )>(_a, &BaseView::showIncidenceSignal, 1))
            return;
        if (QtMocHelpers::indexOfMethod<void (BaseView::*)(const Akonadi::Item & , const QDate & )>(_a, &BaseView::showOccurrenceSignal, 2))
            return;
        if (QtMocHelpers::indexOfMethod<void (BaseView::*)(const Akonadi::Item & )>(_a, &BaseView::editIncidenceSignal, 3))
            return;
        if (QtMocHelpers::indexOfMethod<void (BaseView::*)(const Akonadi::Item & )>(_a, &BaseView::deleteIncidenceSignal, 4))
            return;
        if (QtMocHelpers::indexOfMethod<void (BaseView::*)(const Akonadi::Item & )>(_a, &BaseView::cutIncidenceSignal, 5))
            return;
        if (QtMocHelpers::indexOfMethod<void (BaseView::*)(const Akonadi::Item & )>(_a, &BaseView::copyIncidenceSignal, 6))
            return;
        if (QtMocHelpers::indexOfMethod<void (BaseView::*)()>(_a, &BaseView::pasteIncidenceSignal, 7))
            return;
        if (QtMocHelpers::indexOfMethod<void (BaseView::*)(const Akonadi::Item & )>(_a, &BaseView::toggleAlarmSignal, 8))
            return;
        if (QtMocHelpers::indexOfMethod<void (BaseView::*)(const Akonadi::Item & )>(_a, &BaseView::toggleTodoCompletedSignal, 9))
            return;
        if (QtMocHelpers::indexOfMethod<void (BaseView::*)(const Akonadi::Item & , const QDate & )>(_a, &BaseView::toggleOccurrenceCompletedSignal, 10))
            return;
        if (QtMocHelpers::indexOfMethod<void (BaseView::*)(const Akonadi::Item & , const Akonadi::Collection & )>(_a, &BaseView::copyIncidenceToResourceSignal, 11))
            return;
        if (QtMocHelpers::indexOfMethod<void (BaseView::*)(const Akonadi::Item & , const Akonadi::Collection & )>(_a, &BaseView::moveIncidenceToResourceSignal, 12))
            return;
        if (QtMocHelpers::indexOfMethod<void (BaseView::*)(const Akonadi::Item & , const QDate & )>(_a, &BaseView::dissociateOccurrencesSignal, 13))
            return;
        if (QtMocHelpers::indexOfMethod<void (BaseView::*)(const QString & )>(_a, &BaseView::startMultiModify, 14))
            return;
        if (QtMocHelpers::indexOfMethod<void (BaseView::*)()>(_a, &BaseView::endMultiModify, 15))
            return;
        if (QtMocHelpers::indexOfMethod<void (BaseView::*)()>(_a, &BaseView::newEventSignal, 16))
            return;
        if (QtMocHelpers::indexOfMethod<void (BaseView::*)(const QDate & )>(_a, &BaseView::newEventSignal, 17))
            return;
        if (QtMocHelpers::indexOfMethod<void (BaseView::*)(const QDateTime & )>(_a, &BaseView::newEventSignal, 18))
            return;
        if (QtMocHelpers::indexOfMethod<void (BaseView::*)(const QDateTime & , const QDateTime & )>(_a, &BaseView::newEventSignal, 19))
            return;
        if (QtMocHelpers::indexOfMethod<void (BaseView::*)(const QDate & )>(_a, &BaseView::newTodoSignal, 20))
            return;
        if (QtMocHelpers::indexOfMethod<void (BaseView::*)(const Akonadi::Item & )>(_a, &BaseView::newSubTodoSignal, 21))
            return;
        if (QtMocHelpers::indexOfMethod<void (BaseView::*)(const QDate & )>(_a, &BaseView::newJournalSignal, 22))
            return;
    }
}

const QMetaObject *KOrg::BaseView::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *KOrg::BaseView::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN4KOrg8BaseViewE_t>.strings))
        return static_cast<void*>(this);
    return QWidget::qt_metacast(_clname);
}

int KOrg::BaseView::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QWidget::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 35)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 35;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 35)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 35;
    }
    return _id;
}

// SIGNAL 0
void KOrg::BaseView::incidenceSelected(const Akonadi::Item & _t1, const QDate _t2)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 0, nullptr, _t1, _t2);
}

// SIGNAL 1
void KOrg::BaseView::showIncidenceSignal(const Akonadi::Item & _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 1, nullptr, _t1);
}

// SIGNAL 2
void KOrg::BaseView::showOccurrenceSignal(const Akonadi::Item & _t1, const QDate & _t2)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 2, nullptr, _t1, _t2);
}

// SIGNAL 3
void KOrg::BaseView::editIncidenceSignal(const Akonadi::Item & _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 3, nullptr, _t1);
}

// SIGNAL 4
void KOrg::BaseView::deleteIncidenceSignal(const Akonadi::Item & _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 4, nullptr, _t1);
}

// SIGNAL 5
void KOrg::BaseView::cutIncidenceSignal(const Akonadi::Item & _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 5, nullptr, _t1);
}

// SIGNAL 6
void KOrg::BaseView::copyIncidenceSignal(const Akonadi::Item & _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 6, nullptr, _t1);
}

// SIGNAL 7
void KOrg::BaseView::pasteIncidenceSignal()
{
    QMetaObject::activate(this, &staticMetaObject, 7, nullptr);
}

// SIGNAL 8
void KOrg::BaseView::toggleAlarmSignal(const Akonadi::Item & _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 8, nullptr, _t1);
}

// SIGNAL 9
void KOrg::BaseView::toggleTodoCompletedSignal(const Akonadi::Item & _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 9, nullptr, _t1);
}

// SIGNAL 10
void KOrg::BaseView::toggleOccurrenceCompletedSignal(const Akonadi::Item & _t1, const QDate & _t2)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 10, nullptr, _t1, _t2);
}

// SIGNAL 11
void KOrg::BaseView::copyIncidenceToResourceSignal(const Akonadi::Item & _t1, const Akonadi::Collection & _t2)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 11, nullptr, _t1, _t2);
}

// SIGNAL 12
void KOrg::BaseView::moveIncidenceToResourceSignal(const Akonadi::Item & _t1, const Akonadi::Collection & _t2)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 12, nullptr, _t1, _t2);
}

// SIGNAL 13
void KOrg::BaseView::dissociateOccurrencesSignal(const Akonadi::Item & _t1, const QDate & _t2)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 13, nullptr, _t1, _t2);
}

// SIGNAL 14
void KOrg::BaseView::startMultiModify(const QString & _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 14, nullptr, _t1);
}

// SIGNAL 15
void KOrg::BaseView::endMultiModify()
{
    QMetaObject::activate(this, &staticMetaObject, 15, nullptr);
}

// SIGNAL 16
void KOrg::BaseView::newEventSignal()
{
    QMetaObject::activate(this, &staticMetaObject, 16, nullptr);
}

// SIGNAL 17
void KOrg::BaseView::newEventSignal(const QDate & _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 17, nullptr, _t1);
}

// SIGNAL 18
void KOrg::BaseView::newEventSignal(const QDateTime & _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 18, nullptr, _t1);
}

// SIGNAL 19
void KOrg::BaseView::newEventSignal(const QDateTime & _t1, const QDateTime & _t2)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 19, nullptr, _t1, _t2);
}

// SIGNAL 20
void KOrg::BaseView::newTodoSignal(const QDate & _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 20, nullptr, _t1);
}

// SIGNAL 21
void KOrg::BaseView::newSubTodoSignal(const Akonadi::Item & _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 21, nullptr, _t1);
}

// SIGNAL 22
void KOrg::BaseView::newJournalSignal(const QDate & _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 22, nullptr, _t1);
}
QT_WARNING_POP
