/********************************************************************************
** Form generated from reading UI file 'filteredit_base.ui'
**
** Created by: Qt User Interface Compiler version 6.11.2
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef UI_FILTEREDIT_BASE_H
#define UI_FILTEREDIT_BASE_H

#include <QtCore/QVariant>
#include <QtWidgets/QApplication>
#include <QtWidgets/QCheckBox>
#include <QtWidgets/QGridLayout>
#include <QtWidgets/QGroupBox>
#include <QtWidgets/QHBoxLayout>
#include <QtWidgets/QLabel>
#include <QtWidgets/QLineEdit>
#include <QtWidgets/QListWidget>
#include <QtWidgets/QPushButton>
#include <QtWidgets/QRadioButton>
#include <QtWidgets/QSpacerItem>
#include <QtWidgets/QSpinBox>
#include <QtWidgets/QVBoxLayout>
#include <QtWidgets/QWidget>
#include <klocalizedstring.h>
#include "klistwidgetsearchline.h"

QT_BEGIN_NAMESPACE

class Ui_FilterEdit_base
{
public:
    QVBoxLayout *verticalLayout_3;
    QHBoxLayout *horizontalLayout_2;
    QVBoxLayout *verticalLayout_2;
    QVBoxLayout *verticalLayout;
    KListWidgetSearchLine *searchline;
    QListWidget *mRulesList;
    QHBoxLayout *horizontalLayout;
    QPushButton *mNewButton;
    QPushButton *mDeleteButton;
    QGroupBox *mDetailsFrame;
    QGridLayout *gridLayout;
    QHBoxLayout *hboxLayout;
    QLabel *textLabel1;
    QLineEdit *mNameLineEdit;
    QCheckBox *mRecurringCheck;
    QCheckBox *mCompletedCheck;
    QHBoxLayout *hboxLayout1;
    QSpacerItem *spacerItem;
    QLabel *mCompletedTimeSpanLabel;
    QSpinBox *mCompletedTimeSpan;
    QSpacerItem *spacerItem1;
    QCheckBox *mHideInactiveTodosCheck;
    QGroupBox *mCategoriesButtonGroup;
    QGridLayout *gridLayout1;
    QListWidget *mCatList;
    QSpacerItem *spacerItem2;
    QRadioButton *mCatHideCheck;
    QRadioButton *mCatShowCheck;
    QPushButton *mCatEditButton;
    QCheckBox *mHideTodosNotAssignedToMeCheck;

    void setupUi(QWidget *FilterEdit_base)
    {
        if (FilterEdit_base->objectName().isEmpty())
            FilterEdit_base->setObjectName("FilterEdit_base");
        FilterEdit_base->resize(549, 443);
        verticalLayout_3 = new QVBoxLayout(FilterEdit_base);
        verticalLayout_3->setObjectName("verticalLayout_3");
        verticalLayout_3->setContentsMargins(0, 0, 0, 0);
        horizontalLayout_2 = new QHBoxLayout();
        horizontalLayout_2->setObjectName("horizontalLayout_2");
        verticalLayout_2 = new QVBoxLayout();
        verticalLayout_2->setObjectName("verticalLayout_2");
        verticalLayout = new QVBoxLayout();
        verticalLayout->setObjectName("verticalLayout");
        searchline = new KListWidgetSearchLine(FilterEdit_base);
        searchline->setObjectName("searchline");

        verticalLayout->addWidget(searchline);

        mRulesList = new QListWidget(FilterEdit_base);
        mRulesList->setObjectName("mRulesList");

        verticalLayout->addWidget(mRulesList);


        verticalLayout_2->addLayout(verticalLayout);

        horizontalLayout = new QHBoxLayout();
        horizontalLayout->setObjectName("horizontalLayout");
        mNewButton = new QPushButton(FilterEdit_base);
        mNewButton->setObjectName("mNewButton");

        horizontalLayout->addWidget(mNewButton);

        mDeleteButton = new QPushButton(FilterEdit_base);
        mDeleteButton->setObjectName("mDeleteButton");

        horizontalLayout->addWidget(mDeleteButton);


        verticalLayout_2->addLayout(horizontalLayout);


        horizontalLayout_2->addLayout(verticalLayout_2);

        mDetailsFrame = new QGroupBox(FilterEdit_base);
        mDetailsFrame->setObjectName("mDetailsFrame");
        gridLayout = new QGridLayout(mDetailsFrame);
        gridLayout->setSpacing(6);
        gridLayout->setObjectName("gridLayout");
        gridLayout->setContentsMargins(11, 11, 11, 11);
        hboxLayout = new QHBoxLayout();
        hboxLayout->setSpacing(6);
        hboxLayout->setObjectName("hboxLayout");
        hboxLayout->setContentsMargins(0, 0, 0, 0);
        textLabel1 = new QLabel(mDetailsFrame);
        textLabel1->setObjectName("textLabel1");

        hboxLayout->addWidget(textLabel1);

        mNameLineEdit = new QLineEdit(mDetailsFrame);
        mNameLineEdit->setObjectName("mNameLineEdit");

        hboxLayout->addWidget(mNameLineEdit);


        gridLayout->addLayout(hboxLayout, 0, 0, 1, 1);

        mRecurringCheck = new QCheckBox(mDetailsFrame);
        mRecurringCheck->setObjectName("mRecurringCheck");

        gridLayout->addWidget(mRecurringCheck, 1, 0, 1, 1);

        mCompletedCheck = new QCheckBox(mDetailsFrame);
        mCompletedCheck->setObjectName("mCompletedCheck");

        gridLayout->addWidget(mCompletedCheck, 2, 0, 1, 1);

        hboxLayout1 = new QHBoxLayout();
        hboxLayout1->setSpacing(6);
        hboxLayout1->setObjectName("hboxLayout1");
        hboxLayout1->setContentsMargins(0, 0, 0, 0);
        spacerItem = new QSpacerItem(15, 20, QSizePolicy::Policy::Fixed, QSizePolicy::Policy::Minimum);

        hboxLayout1->addItem(spacerItem);

        mCompletedTimeSpanLabel = new QLabel(mDetailsFrame);
        mCompletedTimeSpanLabel->setObjectName("mCompletedTimeSpanLabel");
        mCompletedTimeSpanLabel->setEnabled(false);

        hboxLayout1->addWidget(mCompletedTimeSpanLabel);

        mCompletedTimeSpan = new QSpinBox(mDetailsFrame);
        mCompletedTimeSpan->setObjectName("mCompletedTimeSpan");
        mCompletedTimeSpan->setEnabled(false);

        hboxLayout1->addWidget(mCompletedTimeSpan);

        spacerItem1 = new QSpacerItem(16, 21, QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Minimum);

        hboxLayout1->addItem(spacerItem1);


        gridLayout->addLayout(hboxLayout1, 3, 0, 1, 1);

        mHideInactiveTodosCheck = new QCheckBox(mDetailsFrame);
        mHideInactiveTodosCheck->setObjectName("mHideInactiveTodosCheck");

        gridLayout->addWidget(mHideInactiveTodosCheck, 4, 0, 1, 1);

        mCategoriesButtonGroup = new QGroupBox(mDetailsFrame);
        mCategoriesButtonGroup->setObjectName("mCategoriesButtonGroup");
        gridLayout1 = new QGridLayout(mCategoriesButtonGroup);
        gridLayout1->setSpacing(6);
        gridLayout1->setObjectName("gridLayout1");
        gridLayout1->setContentsMargins(11, 11, 11, 11);
        mCatList = new QListWidget(mCategoriesButtonGroup);
        mCatList->setObjectName("mCatList");
        mCatList->setSelectionMode(QAbstractItemView::NoSelection);

        gridLayout1->addWidget(mCatList, 2, 0, 2, 1);

        spacerItem2 = new QSpacerItem(20, 110, QSizePolicy::Policy::Minimum, QSizePolicy::Policy::Expanding);

        gridLayout1->addItem(spacerItem2, 3, 1, 1, 1);

        mCatHideCheck = new QRadioButton(mCategoriesButtonGroup);
        mCatHideCheck->setObjectName("mCatHideCheck");
        mCatHideCheck->setChecked(true);

        gridLayout1->addWidget(mCatHideCheck, 1, 0, 1, 2);

        mCatShowCheck = new QRadioButton(mCategoriesButtonGroup);
        mCatShowCheck->setObjectName("mCatShowCheck");

        gridLayout1->addWidget(mCatShowCheck, 0, 0, 1, 2);

        mCatEditButton = new QPushButton(mCategoriesButtonGroup);
        mCatEditButton->setObjectName("mCatEditButton");

        gridLayout1->addWidget(mCatEditButton, 2, 1, 1, 1);


        gridLayout->addWidget(mCategoriesButtonGroup, 6, 0, 1, 1);

        mHideTodosNotAssignedToMeCheck = new QCheckBox(mDetailsFrame);
        mHideTodosNotAssignedToMeCheck->setObjectName("mHideTodosNotAssignedToMeCheck");

        gridLayout->addWidget(mHideTodosNotAssignedToMeCheck, 5, 0, 1, 1);


        horizontalLayout_2->addWidget(mDetailsFrame);


        verticalLayout_3->addLayout(horizontalLayout_2);

#if QT_CONFIG(shortcut)
        textLabel1->setBuddy(mNameLineEdit);
        mCompletedTimeSpanLabel->setBuddy(mCompletedTimeSpan);
#endif // QT_CONFIG(shortcut)
        QWidget::setTabOrder(searchline, mRulesList);
        QWidget::setTabOrder(mRulesList, mNewButton);
        QWidget::setTabOrder(mNewButton, mDeleteButton);
        QWidget::setTabOrder(mDeleteButton, mNameLineEdit);
        QWidget::setTabOrder(mNameLineEdit, mRecurringCheck);
        QWidget::setTabOrder(mRecurringCheck, mCompletedCheck);
        QWidget::setTabOrder(mCompletedCheck, mCompletedTimeSpan);
        QWidget::setTabOrder(mCompletedTimeSpan, mHideInactiveTodosCheck);
        QWidget::setTabOrder(mHideInactiveTodosCheck, mHideTodosNotAssignedToMeCheck);
        QWidget::setTabOrder(mHideTodosNotAssignedToMeCheck, mCatShowCheck);
        QWidget::setTabOrder(mCatShowCheck, mCatHideCheck);
        QWidget::setTabOrder(mCatHideCheck, mCatList);
        QWidget::setTabOrder(mCatList, mCatEditButton);

        retranslateUi(FilterEdit_base);

        QMetaObject::connectSlotsByName(FilterEdit_base);
    } // setupUi

    void retranslateUi(QWidget *FilterEdit_base)
    {
        searchline->setPlaceholderText(tr2i18n("Search", "Displayed grayed-out inside the textbox, verb to search"));
        mNewButton->setText(tr2i18n("&New", nullptr));
        mDeleteButton->setText(tr2i18n("&Delete", nullptr));
        mDetailsFrame->setTitle(tr2i18n("Filter Details", nullptr));
        textLabel1->setText(tr2i18n("Name:", "filter name"));
#if QT_CONFIG(whatsthis)
        mRecurringCheck->setWhatsThis(tr2i18n("Select this option if you do not want to show recurring events and to-dos in your views. Daily and weekly recurring items may take a lot of space, so it might be handy to hide them.", nullptr));
#endif // QT_CONFIG(whatsthis)
        mRecurringCheck->setText(tr2i18n("Hide &recurring events and to-dos", nullptr));
#if QT_CONFIG(whatsthis)
        mCompletedCheck->setWhatsThis(tr2i18n("If this box is checked, the filter will hide all to-do items from the list, that have been completed. Optionally, only items that have been completed a given number of days are hidden.", nullptr));
#endif // QT_CONFIG(whatsthis)
        mCompletedCheck->setText(tr2i18n("Hide co&mpleted to-dos", nullptr));
#if QT_CONFIG(whatsthis)
        mCompletedTimeSpanLabel->setWhatsThis(tr2i18n("This option will allow you to select which completed to-dos should be hidden. When you choose <i>Immediately</i>, it will hide the to-do as soon as you check it. You can increase or decrease the number of days in the spinbox.", nullptr));
#endif // QT_CONFIG(whatsthis)
        mCompletedTimeSpanLabel->setText(tr2i18n("Da&ys after completion:", nullptr));
#if QT_CONFIG(whatsthis)
        mCompletedTimeSpan->setWhatsThis(tr2i18n("Here you can give the number of days a to-do item has to be completed to be hidden from the to-do list. If you select \"Immediately\", all completed to-dos will be hidden. If you, for example, choose a value of 1, all to-do items will be hidden, that have been marked finished longer than 24 hours ago.", nullptr));
#endif // QT_CONFIG(whatsthis)
#if QT_CONFIG(whatsthis)
        mHideInactiveTodosCheck->setWhatsThis(tr2i18n("This option hides all to-dos from your list, where the start date has not been reached. (Note that the start date is not the due date of the to-do item.)", nullptr));
#endif // QT_CONFIG(whatsthis)
        mHideInactiveTodosCheck->setText(tr2i18n("Hide &inactive to-dos", nullptr));
        mCategoriesButtonGroup->setTitle(tr2i18n("Tags", nullptr));
#if QT_CONFIG(whatsthis)
        mCatHideCheck->setWhatsThis(tr2i18n("When this option is chosen, this filter will show all items which do <i>not</i> contain any of the selected tags.", nullptr));
#endif // QT_CONFIG(whatsthis)
        mCatHideCheck->setText(tr2i18n("Show all except selected", nullptr));
#if QT_CONFIG(shortcut)
        mCatHideCheck->setShortcut(QString());
#endif // QT_CONFIG(shortcut)
#if QT_CONFIG(whatsthis)
        mCatShowCheck->setWhatsThis(tr2i18n("When this option is chosen, this filter will show all items containing any of the selected tags.", nullptr));
#endif // QT_CONFIG(whatsthis)
        mCatShowCheck->setText(tr2i18n("Show only selected", nullptr));
#if QT_CONFIG(shortcut)
        mCatShowCheck->setShortcut(QString());
#endif // QT_CONFIG(shortcut)
        mCatEditButton->setText(tr2i18n("Change\342\200\246", nullptr));
#if QT_CONFIG(shortcut)
        mCatEditButton->setShortcut(QString());
#endif // QT_CONFIG(shortcut)
#if QT_CONFIG(whatsthis)
        mHideTodosNotAssignedToMeCheck->setWhatsThis(tr2i18n("This option hides all to-dos from your list which are assigned to someone else.<br>\n"
"Only to-dos which have least one attendee will be checked.  If you are not in the list of attendees the to-do will be hidden.", nullptr));
#endif // QT_CONFIG(whatsthis)
        mHideTodosNotAssignedToMeCheck->setText(tr2i18n("Hide to-dos not assigned to me", nullptr));
#if QT_CONFIG(shortcut)
        mHideTodosNotAssignedToMeCheck->setShortcut(QString());
#endif // QT_CONFIG(shortcut)
        (void)FilterEdit_base;
    } // retranslateUi

};

namespace Ui {
    class FilterEdit_base: public Ui_FilterEdit_base {};
} // namespace Ui

QT_END_NAMESPACE

#endif // FILTEREDIT_BASE_H

