/****************************************************************************
** Meta object code from reading C++ file 'datenavigator.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.11.2)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../../korganizer-26.08.0/src/datenavigator.h"
#include <QtCore/qmetatype.h>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'datenavigator.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.11.2. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN13DateNavigatorE_t {};
} // unnamed namespace

template <> constexpr inline auto DateNavigator::qt_create_metaobjectdata<qt_meta_tag_ZN13DateNavigatorE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "DateNavigator",
        "datesSelected",
        "",
        "KCalendarCore::DateList",
        "selectDates",
        "preferredMonth",
        "selectDate",
        "count",
        "selectWeek",
        "selectWorkWeek",
        "selectWeekByDay",
        "weekDay",
        "selectADate",
        "d",
        "selectToday",
        "selectPreviousYear",
        "selectPreviousMonth",
        "currentMonth",
        "selectionLowerLimit",
        "selectionUpperLimit",
        "selectPreviousWeek",
        "selectNextWeek",
        "selectNextMonth",
        "selectNextYear",
        "selectPrevious",
        "selectNext",
        "selectMonth",
        "month",
        "selectYear",
        "year"
    };

    QtMocHelpers::UintData qt_methods {
        // Signal 'datesSelected'
        QtMocHelpers::SignalData<void(const KCalendarCore::DateList &, const QDate &)>(1, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 3, 2 }, { QMetaType::QDate, 2 },
        }}),
        // Slot 'selectDates'
        QtMocHelpers::SlotData<void(const KCalendarCore::DateList &, QDate)>(4, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 3, 2 }, { QMetaType::QDate, 5 },
        }}),
        // Slot 'selectDates'
        QtMocHelpers::SlotData<void(const KCalendarCore::DateList &)>(4, 2, QMC::AccessPublic | QMC::MethodCloned, QMetaType::Void, {{
            { 0x80000000 | 3, 2 },
        }}),
        // Slot 'selectDate'
        QtMocHelpers::SlotData<void(QDate)>(6, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QDate, 2 },
        }}),
        // Slot 'selectDates'
        QtMocHelpers::SlotData<void(int)>(4, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Int, 7 },
        }}),
        // Slot 'selectDates'
        QtMocHelpers::SlotData<void(const QDate &, int, const QDate &)>(4, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QDate, 2 }, { QMetaType::Int, 7 }, { QMetaType::QDate, 5 },
        }}),
        // Slot 'selectDates'
        QtMocHelpers::SlotData<void(const QDate &, int)>(4, 2, QMC::AccessPublic | QMC::MethodCloned, QMetaType::Void, {{
            { QMetaType::QDate, 2 }, { QMetaType::Int, 7 },
        }}),
        // Slot 'selectWeek'
        QtMocHelpers::SlotData<void()>(8, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'selectWeek'
        QtMocHelpers::SlotData<void(const QDate &, const QDate &)>(8, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QDate, 2 }, { QMetaType::QDate, 5 },
        }}),
        // Slot 'selectWeek'
        QtMocHelpers::SlotData<void(const QDate &)>(8, 2, QMC::AccessPublic | QMC::MethodCloned, QMetaType::Void, {{
            { QMetaType::QDate, 2 },
        }}),
        // Slot 'selectWorkWeek'
        QtMocHelpers::SlotData<void()>(9, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'selectWorkWeek'
        QtMocHelpers::SlotData<void(QDate)>(9, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QDate, 2 },
        }}),
        // Slot 'selectWeekByDay'
        QtMocHelpers::SlotData<void(int, QDate, QDate)>(10, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Int, 11 }, { QMetaType::QDate, 2 }, { QMetaType::QDate, 5 },
        }}),
        // Slot 'selectWeekByDay'
        QtMocHelpers::SlotData<void(int, QDate)>(10, 2, QMC::AccessPublic | QMC::MethodCloned, QMetaType::Void, {{
            { QMetaType::Int, 11 }, { QMetaType::QDate, 2 },
        }}),
        // Slot 'selectADate'
        QtMocHelpers::SlotData<void(QDate)>(12, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QDate, 13 },
        }}),
        // Slot 'selectToday'
        QtMocHelpers::SlotData<void()>(14, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'selectPreviousYear'
        QtMocHelpers::SlotData<void()>(15, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'selectPreviousMonth'
        QtMocHelpers::SlotData<void(const QDate &, const QDate &, const QDate &)>(16, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QDate, 17 }, { QMetaType::QDate, 18 }, { QMetaType::QDate, 19 },
        }}),
        // Slot 'selectPreviousMonth'
        QtMocHelpers::SlotData<void(const QDate &, const QDate &)>(16, 2, QMC::AccessPublic | QMC::MethodCloned, QMetaType::Void, {{
            { QMetaType::QDate, 17 }, { QMetaType::QDate, 18 },
        }}),
        // Slot 'selectPreviousMonth'
        QtMocHelpers::SlotData<void(const QDate &)>(16, 2, QMC::AccessPublic | QMC::MethodCloned, QMetaType::Void, {{
            { QMetaType::QDate, 17 },
        }}),
        // Slot 'selectPreviousMonth'
        QtMocHelpers::SlotData<void()>(16, 2, QMC::AccessPublic | QMC::MethodCloned, QMetaType::Void),
        // Slot 'selectPreviousWeek'
        QtMocHelpers::SlotData<void()>(20, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'selectNextWeek'
        QtMocHelpers::SlotData<void()>(21, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'selectNextMonth'
        QtMocHelpers::SlotData<void(const QDate &, const QDate &, const QDate &)>(22, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QDate, 17 }, { QMetaType::QDate, 18 }, { QMetaType::QDate, 19 },
        }}),
        // Slot 'selectNextMonth'
        QtMocHelpers::SlotData<void(const QDate &, const QDate &)>(22, 2, QMC::AccessPublic | QMC::MethodCloned, QMetaType::Void, {{
            { QMetaType::QDate, 17 }, { QMetaType::QDate, 18 },
        }}),
        // Slot 'selectNextMonth'
        QtMocHelpers::SlotData<void(const QDate &)>(22, 2, QMC::AccessPublic | QMC::MethodCloned, QMetaType::Void, {{
            { QMetaType::QDate, 17 },
        }}),
        // Slot 'selectNextMonth'
        QtMocHelpers::SlotData<void()>(22, 2, QMC::AccessPublic | QMC::MethodCloned, QMetaType::Void),
        // Slot 'selectNextYear'
        QtMocHelpers::SlotData<void()>(23, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'selectPrevious'
        QtMocHelpers::SlotData<void()>(24, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'selectNext'
        QtMocHelpers::SlotData<void()>(25, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'selectMonth'
        QtMocHelpers::SlotData<void(int)>(26, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Int, 27 },
        }}),
        // Slot 'selectYear'
        QtMocHelpers::SlotData<void(int)>(28, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Int, 29 },
        }}),
    };
    QtMocHelpers::UintData qt_properties {
    };
    QtMocHelpers::UintData qt_enums {
    };
    return QtMocHelpers::metaObjectData<DateNavigator, qt_meta_tag_ZN13DateNavigatorE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject DateNavigator::staticMetaObject = { {
    QMetaObject::SuperData::link<QObject::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN13DateNavigatorE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN13DateNavigatorE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN13DateNavigatorE_t>.metaTypes,
    nullptr
} };

void DateNavigator::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<DateNavigator *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->datesSelected((*reinterpret_cast<std::add_pointer_t<KCalendarCore::DateList>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QDate>>(_a[2]))); break;
        case 1: _t->selectDates((*reinterpret_cast<std::add_pointer_t<KCalendarCore::DateList>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QDate>>(_a[2]))); break;
        case 2: _t->selectDates((*reinterpret_cast<std::add_pointer_t<KCalendarCore::DateList>>(_a[1]))); break;
        case 3: _t->selectDate((*reinterpret_cast<std::add_pointer_t<QDate>>(_a[1]))); break;
        case 4: _t->selectDates((*reinterpret_cast<std::add_pointer_t<int>>(_a[1]))); break;
        case 5: _t->selectDates((*reinterpret_cast<std::add_pointer_t<QDate>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<QDate>>(_a[3]))); break;
        case 6: _t->selectDates((*reinterpret_cast<std::add_pointer_t<QDate>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[2]))); break;
        case 7: _t->selectWeek(); break;
        case 8: _t->selectWeek((*reinterpret_cast<std::add_pointer_t<QDate>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QDate>>(_a[2]))); break;
        case 9: _t->selectWeek((*reinterpret_cast<std::add_pointer_t<QDate>>(_a[1]))); break;
        case 10: _t->selectWorkWeek(); break;
        case 11: _t->selectWorkWeek((*reinterpret_cast<std::add_pointer_t<QDate>>(_a[1]))); break;
        case 12: _t->selectWeekByDay((*reinterpret_cast<std::add_pointer_t<int>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QDate>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<QDate>>(_a[3]))); break;
        case 13: _t->selectWeekByDay((*reinterpret_cast<std::add_pointer_t<int>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QDate>>(_a[2]))); break;
        case 14: _t->selectADate((*reinterpret_cast<std::add_pointer_t<QDate>>(_a[1]))); break;
        case 15: _t->selectToday(); break;
        case 16: _t->selectPreviousYear(); break;
        case 17: _t->selectPreviousMonth((*reinterpret_cast<std::add_pointer_t<QDate>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QDate>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<QDate>>(_a[3]))); break;
        case 18: _t->selectPreviousMonth((*reinterpret_cast<std::add_pointer_t<QDate>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QDate>>(_a[2]))); break;
        case 19: _t->selectPreviousMonth((*reinterpret_cast<std::add_pointer_t<QDate>>(_a[1]))); break;
        case 20: _t->selectPreviousMonth(); break;
        case 21: _t->selectPreviousWeek(); break;
        case 22: _t->selectNextWeek(); break;
        case 23: _t->selectNextMonth((*reinterpret_cast<std::add_pointer_t<QDate>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QDate>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<QDate>>(_a[3]))); break;
        case 24: _t->selectNextMonth((*reinterpret_cast<std::add_pointer_t<QDate>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QDate>>(_a[2]))); break;
        case 25: _t->selectNextMonth((*reinterpret_cast<std::add_pointer_t<QDate>>(_a[1]))); break;
        case 26: _t->selectNextMonth(); break;
        case 27: _t->selectNextYear(); break;
        case 28: _t->selectPrevious(); break;
        case 29: _t->selectNext(); break;
        case 30: _t->selectMonth((*reinterpret_cast<std::add_pointer_t<int>>(_a[1]))); break;
        case 31: _t->selectYear((*reinterpret_cast<std::add_pointer_t<int>>(_a[1]))); break;
        default: ;
        }
    }
    if (_c == QMetaObject::IndexOfMethod) {
        if (QtMocHelpers::indexOfMethod<void (DateNavigator::*)(const KCalendarCore::DateList & , const QDate & )>(_a, &DateNavigator::datesSelected, 0))
            return;
    }
}

const QMetaObject *DateNavigator::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *DateNavigator::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN13DateNavigatorE_t>.strings))
        return static_cast<void*>(this);
    return QObject::qt_metacast(_clname);
}

int DateNavigator::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QObject::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 32)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 32;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 32)
            *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType();
        _id -= 32;
    }
    return _id;
}

// SIGNAL 0
void DateNavigator::datesSelected(const KCalendarCore::DateList & _t1, const QDate & _t2)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 0, nullptr, _t1, _t2);
}
QT_WARNING_POP
