/*
This is a comment
*/

/********************************************************************************
** Form generated from reading UI file 'searchdialog_base.ui'
**
** Created by: Qt User Interface Compiler version 6.11.2
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef UI_SEARCHDIALOG_BASE_H
#define UI_SEARCHDIALOG_BASE_H

#include <QtCore/QVariant>
#include <QtWidgets/QApplication>
#include <QtWidgets/QCheckBox>
#include <QtWidgets/QFormLayout>
#include <QtWidgets/QFrame>
#include <QtWidgets/QGridLayout>
#include <QtWidgets/QGroupBox>
#include <QtWidgets/QHBoxLayout>
#include <QtWidgets/QLabel>
#include <QtWidgets/QLineEdit>
#include <QtWidgets/QVBoxLayout>
#include <QtWidgets/QWidget>
#include <klocalizedstring.h>
#include "kdatecombobox.h"

QT_BEGIN_NAMESPACE

class Ui_SearchDialog
{
public:
    QGridLayout *gridLayout_2;
    QHBoxLayout *horizontalLayout_4;
    QLabel *searchLabel;
    QLineEdit *searchEdit;
    QGroupBox *searchTypeGroup;
    QVBoxLayout *verticalLayout;
    QCheckBox *eventsCheck;
    QCheckBox *journalsCheck;
    QCheckBox *todosCheck;
    QGroupBox *searchGroup;
    QGridLayout *gridLayout;
    QCheckBox *categoryCheck;
    QCheckBox *locationCheck;
    QCheckBox *descriptionCheck;
    QCheckBox *summaryCheck;
    QCheckBox *attendeeCheck;
    QGroupBox *dateRangeGroup;
    QFormLayout *formLayout;
    QCheckBox *dateRangeCheckbox;
    QHBoxLayout *horizontalLayout_2;
    QLabel *startDateLabel;
    KDateComboBox *startDate;
    QHBoxLayout *horizontalLayout_3;
    QLabel *endDateLabel;
    KDateComboBox *endDate;
    QCheckBox *inclusiveCheck;
    QCheckBox *includeUndatedTodos;
    QCheckBox *unfiltered;
    QLabel *numItems;
    QFrame *listViewFrame;

    void setupUi(QWidget *SearchDialog)
    {
        if (SearchDialog->objectName().isEmpty())
            SearchDialog->setObjectName("SearchDialog");
        SearchDialog->resize(401, 831);
        gridLayout_2 = new QGridLayout(SearchDialog);
        gridLayout_2->setObjectName("gridLayout_2");
        gridLayout_2->setHorizontalSpacing(6);
        gridLayout_2->setContentsMargins(0, 0, 0, 0);
        horizontalLayout_4 = new QHBoxLayout();
        horizontalLayout_4->setObjectName("horizontalLayout_4");
        searchLabel = new QLabel(SearchDialog);
        searchLabel->setObjectName("searchLabel");
        searchLabel->setWordWrap(false);

        horizontalLayout_4->addWidget(searchLabel);

        searchEdit = new QLineEdit(SearchDialog);
        searchEdit->setObjectName("searchEdit");
        searchEdit->setClearButtonEnabled(true);

        horizontalLayout_4->addWidget(searchEdit);


        gridLayout_2->addLayout(horizontalLayout_4, 0, 0, 1, 2);

        searchTypeGroup = new QGroupBox(SearchDialog);
        searchTypeGroup->setObjectName("searchTypeGroup");
        verticalLayout = new QVBoxLayout(searchTypeGroup);
        verticalLayout->setObjectName("verticalLayout");
        eventsCheck = new QCheckBox(searchTypeGroup);
        eventsCheck->setObjectName("eventsCheck");
        eventsCheck->setChecked(true);

        verticalLayout->addWidget(eventsCheck);

        journalsCheck = new QCheckBox(searchTypeGroup);
        journalsCheck->setObjectName("journalsCheck");

        verticalLayout->addWidget(journalsCheck);

        todosCheck = new QCheckBox(searchTypeGroup);
        todosCheck->setObjectName("todosCheck");
        todosCheck->setChecked(true);

        verticalLayout->addWidget(todosCheck);


        gridLayout_2->addWidget(searchTypeGroup, 1, 0, 1, 1);

        searchGroup = new QGroupBox(SearchDialog);
        searchGroup->setObjectName("searchGroup");
        gridLayout = new QGridLayout(searchGroup);
        gridLayout->setObjectName("gridLayout");
        categoryCheck = new QCheckBox(searchGroup);
        categoryCheck->setObjectName("categoryCheck");

        gridLayout->addWidget(categoryCheck, 0, 0, 1, 1);

        locationCheck = new QCheckBox(searchGroup);
        locationCheck->setObjectName("locationCheck");

        gridLayout->addWidget(locationCheck, 0, 1, 1, 1);

        descriptionCheck = new QCheckBox(searchGroup);
        descriptionCheck->setObjectName("descriptionCheck");

        gridLayout->addWidget(descriptionCheck, 1, 0, 1, 1);

        summaryCheck = new QCheckBox(searchGroup);
        summaryCheck->setObjectName("summaryCheck");
        summaryCheck->setChecked(true);

        gridLayout->addWidget(summaryCheck, 1, 1, 1, 1);

        attendeeCheck = new QCheckBox(searchGroup);
        attendeeCheck->setObjectName("attendeeCheck");

        gridLayout->addWidget(attendeeCheck, 2, 1, 1, 1);


        gridLayout_2->addWidget(searchGroup, 1, 1, 1, 1);

        dateRangeGroup = new QGroupBox(SearchDialog);
        dateRangeGroup->setObjectName("dateRangeGroup");
        formLayout = new QFormLayout(dateRangeGroup);
        formLayout->setObjectName("formLayout");
        dateRangeCheckbox = new QCheckBox(dateRangeGroup);
        dateRangeCheckbox->setObjectName("dateRangeCheckbox");
        dateRangeCheckbox->setChecked(true);

        formLayout->setWidget(0, QFormLayout::ItemRole::SpanningRole, dateRangeCheckbox);

        horizontalLayout_2 = new QHBoxLayout();
        horizontalLayout_2->setObjectName("horizontalLayout_2");
        startDateLabel = new QLabel(dateRangeGroup);
        startDateLabel->setObjectName("startDateLabel");
        startDateLabel->setWordWrap(false);

        horizontalLayout_2->addWidget(startDateLabel);

        startDate = new KDateComboBox(dateRangeGroup);
        startDate->addItem(QString());
        startDate->setObjectName("startDate");
        QSizePolicy sizePolicy(QSizePolicy::Policy::Preferred, QSizePolicy::Policy::Fixed);
        sizePolicy.setHorizontalStretch(1);
        sizePolicy.setVerticalStretch(0);
        sizePolicy.setHeightForWidth(startDate->sizePolicy().hasHeightForWidth());
        startDate->setSizePolicy(sizePolicy);

        horizontalLayout_2->addWidget(startDate);


        formLayout->setLayout(1, QFormLayout::ItemRole::LabelRole, horizontalLayout_2);

        horizontalLayout_3 = new QHBoxLayout();
        horizontalLayout_3->setObjectName("horizontalLayout_3");
        endDateLabel = new QLabel(dateRangeGroup);
        endDateLabel->setObjectName("endDateLabel");
        endDateLabel->setWordWrap(false);

        horizontalLayout_3->addWidget(endDateLabel);

        endDate = new KDateComboBox(dateRangeGroup);
        endDate->addItem(QString());
        endDate->setObjectName("endDate");
        sizePolicy.setHeightForWidth(endDate->sizePolicy().hasHeightForWidth());
        endDate->setSizePolicy(sizePolicy);

        horizontalLayout_3->addWidget(endDate);


        formLayout->setLayout(1, QFormLayout::ItemRole::FieldRole, horizontalLayout_3);

        inclusiveCheck = new QCheckBox(dateRangeGroup);
        inclusiveCheck->setObjectName("inclusiveCheck");

        formLayout->setWidget(2, QFormLayout::ItemRole::SpanningRole, inclusiveCheck);

        includeUndatedTodos = new QCheckBox(dateRangeGroup);
        includeUndatedTodos->setObjectName("includeUndatedTodos");
        includeUndatedTodos->setChecked(true);

        formLayout->setWidget(3, QFormLayout::ItemRole::SpanningRole, includeUndatedTodos);

        unfiltered = new QCheckBox(dateRangeGroup);
        unfiltered->setObjectName("unfiltered");
        unfiltered->setChecked(true);

        formLayout->setWidget(4, QFormLayout::ItemRole::SpanningRole, unfiltered);


        gridLayout_2->addWidget(dateRangeGroup, 2, 0, 1, 2);

        numItems = new QLabel(SearchDialog);
        numItems->setObjectName("numItems");

        gridLayout_2->addWidget(numItems, 4, 0, 1, 1);

        listViewFrame = new QFrame(SearchDialog);
        listViewFrame->setObjectName("listViewFrame");
        QSizePolicy sizePolicy1(QSizePolicy::Policy::Preferred, QSizePolicy::Policy::MinimumExpanding);
        sizePolicy1.setHorizontalStretch(0);
        sizePolicy1.setVerticalStretch(0);
        sizePolicy1.setHeightForWidth(listViewFrame->sizePolicy().hasHeightForWidth());
        listViewFrame->setSizePolicy(sizePolicy1);
        listViewFrame->setFrameShape(QFrame::Shape::StyledPanel);
        listViewFrame->setFrameShadow(QFrame::Shadow::Raised);

        gridLayout_2->addWidget(listViewFrame, 3, 0, 1, 2);

        gridLayout_2->setRowStretch(3, 1);
#if QT_CONFIG(shortcut)
        searchLabel->setBuddy(searchEdit);
        startDateLabel->setBuddy(startDate);
        endDateLabel->setBuddy(endDate);
#endif // QT_CONFIG(shortcut)
        QWidget::setTabOrder(searchEdit, eventsCheck);
        QWidget::setTabOrder(eventsCheck, journalsCheck);
        QWidget::setTabOrder(journalsCheck, todosCheck);
        QWidget::setTabOrder(todosCheck, startDate);
        QWidget::setTabOrder(startDate, endDate);
        QWidget::setTabOrder(endDate, inclusiveCheck);
        QWidget::setTabOrder(inclusiveCheck, includeUndatedTodos);
        QWidget::setTabOrder(includeUndatedTodos, categoryCheck);
        QWidget::setTabOrder(categoryCheck, locationCheck);
        QWidget::setTabOrder(locationCheck, descriptionCheck);
        QWidget::setTabOrder(descriptionCheck, summaryCheck);

        retranslateUi(SearchDialog);

        QMetaObject::connectSlotsByName(SearchDialog);
    } // setupUi

    void retranslateUi(QWidget *SearchDialog)
    {
        searchLabel->setText(tr2i18n("&Search for:", nullptr));
#if QT_CONFIG(tooltip)
        searchEdit->setToolTip(tr2i18n("Search pattern. Use wildcards \342\200\234*\342\200\235 and \342\200\234?\342\200\235 as desired.", nullptr));
#endif // QT_CONFIG(tooltip)
#if QT_CONFIG(whatsthis)
        searchEdit->setWhatsThis(tr2i18n("Examine various fields to see if they contain the search pattern: The pattern \342\200\234meet\342\200\235 would match \342\200\234kick-off meeting\342\200\235. Wildcards \342\200\234*\342\200\235 (matches any number of characters) and \342\200\234?\342\200\235 (matches any single character) are supported.  For example, the search pattern \342\200\234meet*boss\342\200\235 matches \342\200\234Meeting with boss\342\200\235. The pattern \342\200\234c?t\342\200\235 would match \342\200\234cat\342\200\235, \342\200\234cot\342\200\235, and so on.", nullptr));
#endif // QT_CONFIG(whatsthis)
        searchEdit->setText(tr2i18n("*", nullptr));
        searchTypeGroup->setTitle(tr2i18n("Search For", nullptr));
#if QT_CONFIG(tooltip)
        eventsCheck->setToolTip(tr2i18n("Search for events with matching criteria.", nullptr));
#endif // QT_CONFIG(tooltip)
#if QT_CONFIG(whatsthis)
        eventsCheck->setWhatsThis(tr2i18n("Check this box if you want to search for events that match the search pattern and have start dates or end dates in the given date range.", nullptr));
#endif // QT_CONFIG(whatsthis)
        eventsCheck->setText(tr2i18n("&Events", nullptr));
#if QT_CONFIG(tooltip)
        journalsCheck->setToolTip(tr2i18n("Search for journal entries with matching criteria.", nullptr));
#endif // QT_CONFIG(tooltip)
#if QT_CONFIG(whatsthis)
        journalsCheck->setWhatsThis(tr2i18n("Check this box if you want to search for journal entries that match the search pattern and have start dates in the given date range.", nullptr));
#endif // QT_CONFIG(whatsthis)
        journalsCheck->setText(tr2i18n("&Journals", nullptr));
#if QT_CONFIG(tooltip)
        todosCheck->setToolTip(tr2i18n("Search for to-dos with matching criteria.", nullptr));
#endif // QT_CONFIG(tooltip)
#if QT_CONFIG(whatsthis)
        todosCheck->setWhatsThis(tr2i18n("Check this box if you want to search for to-dos that match the search pattern and have due dates in the given date range.", nullptr));
#endif // QT_CONFIG(whatsthis)
        todosCheck->setText(tr2i18n("To-&dos", nullptr));
        searchGroup->setTitle(tr2i18n("Search In", nullptr));
#if QT_CONFIG(tooltip)
        categoryCheck->setToolTip(tr2i18n("Include tags in your search.", nullptr));
#endif // QT_CONFIG(tooltip)
#if QT_CONFIG(whatsthis)
        categoryCheck->setWhatsThis(tr2i18n("Check this box if you want to match tags against your search pattern.", nullptr));
#endif // QT_CONFIG(whatsthis)
        categoryCheck->setText(tr2i18n("Ta&gs", nullptr));
#if QT_CONFIG(tooltip)
        locationCheck->setToolTip(tr2i18n("Include locations in your search.", nullptr));
#endif // QT_CONFIG(tooltip)
#if QT_CONFIG(whatsthis)
        locationCheck->setWhatsThis(tr2i18n("Check this box if you want to match locations against your search pattern.", nullptr));
#endif // QT_CONFIG(whatsthis)
        locationCheck->setText(tr2i18n("Locations", nullptr));
#if QT_CONFIG(tooltip)
        descriptionCheck->setToolTip(tr2i18n("Include descriptions in your search.", nullptr));
#endif // QT_CONFIG(tooltip)
#if QT_CONFIG(whatsthis)
        descriptionCheck->setWhatsThis(tr2i18n("Check this box if you want to match descriptions against your search pattern.", nullptr));
#endif // QT_CONFIG(whatsthis)
        descriptionCheck->setText(tr2i18n("Desc&riptions", nullptr));
#if QT_CONFIG(tooltip)
        summaryCheck->setToolTip(tr2i18n("Include summaries in your search.", nullptr));
#endif // QT_CONFIG(tooltip)
#if QT_CONFIG(whatsthis)
        summaryCheck->setWhatsThis(tr2i18n("Check this box if you want to match summaries against your search pattern.", nullptr));
#endif // QT_CONFIG(whatsthis)
        summaryCheck->setText(tr2i18n("Su&mmaries", nullptr));
#if QT_CONFIG(tooltip)
        attendeeCheck->setToolTip(tr2i18n("Include attendees in your search.", nullptr));
#endif // QT_CONFIG(tooltip)
#if QT_CONFIG(whatsthis)
        attendeeCheck->setWhatsThis(tr2i18n("Check this box if you want to match attendees against your search pattern.", nullptr));
#endif // QT_CONFIG(whatsthis)
        attendeeCheck->setText(tr2i18n("Attendees", nullptr));
        dateRangeGroup->setTitle(tr2i18n("Date Range", nullptr));
#if QT_CONFIG(tooltip)
        dateRangeCheckbox->setToolTip(tr2i18n("When checked, the search will be limited to the specified date range.", nullptr));
#endif // QT_CONFIG(tooltip)
#if QT_CONFIG(whatsthis)
        dateRangeCheckbox->setWhatsThis(tr2i18n("Check this box to search for events within a specified date range. If the box is unchecked, all events will be searched.", nullptr));
#endif // QT_CONFIG(whatsthis)
        dateRangeCheckbox->setText(tr2i18n("Limit search to specified date range", nullptr));
        startDateLabel->setText(tr2i18n("Fr&om:", nullptr));
        startDate->setItemText(0, tr2i18n("2008-08-18", nullptr));

#if QT_CONFIG(tooltip)
        startDate->setToolTip(tr2i18n("The starting date of the period to search.", nullptr));
#endif // QT_CONFIG(tooltip)
#if QT_CONFIG(whatsthis)
        startDate->setWhatsThis(tr2i18n("Search for items in the time period starting at the date given here.", nullptr));
#endif // QT_CONFIG(whatsthis)
        endDateLabel->setText(tr2i18n("&To:", nullptr));
        endDate->setItemText(0, tr2i18n("2008-08-18", nullptr));

#if QT_CONFIG(tooltip)
        endDate->setToolTip(tr2i18n("The ending date of the period to search.", nullptr));
#endif // QT_CONFIG(tooltip)
#if QT_CONFIG(whatsthis)
        endDate->setWhatsThis(tr2i18n("Search for items in the time period ending at the date given here.", nullptr));
#endif // QT_CONFIG(whatsthis)
#if QT_CONFIG(tooltip)
        inclusiveCheck->setToolTip(tr2i18n("Display events only if their start date and end date are both in the date range specified.", nullptr));
#endif // QT_CONFIG(tooltip)
#if QT_CONFIG(whatsthis)
        inclusiveCheck->setWhatsThis(tr2i18n("Check this box if you only want to find events that occur entirely within the date range specified.  Events that start during the date range but end after it, or end during the date range but start before it, will be excluded from the search results.", nullptr));
#endif // QT_CONFIG(whatsthis)
        inclusiveCheck->setText(tr2i18n("Exclude e&vents that extend outside the specified date range", nullptr));
#if QT_CONFIG(tooltip)
        includeUndatedTodos->setToolTip(tr2i18n("Include to-dos that have a start date, due date,  or completion date in the date range specified, or have neither a start date nor an end date.", nullptr));
#endif // QT_CONFIG(tooltip)
#if QT_CONFIG(whatsthis)
        includeUndatedTodos->setWhatsThis(tr2i18n("Check this box to search for to-dos that have a start date, due date, or completion date in the date range specified, or have neither a start date nor an end date.  If the box is unchecked, only to-dos that have a due date in the date range will be displayed.", nullptr));
#endif // QT_CONFIG(whatsthis)
        includeUndatedTodos->setText(tr2i18n("Include all to-dos &within the specified date range", nullptr));
#if QT_CONFIG(tooltip)
        unfiltered->setToolTip(tr2i18n("Uncheck this box to skip incidences matching the currently selected view filter", nullptr));
#endif // QT_CONFIG(tooltip)
#if QT_CONFIG(whatsthis)
        unfiltered->setWhatsThis(tr2i18n("When this box is checked all incidences will be considered in the search, even those that aren't displayed according the currently selected view filter", nullptr));
#endif // QT_CONFIG(whatsthis)
        unfiltered->setText(tr2i18n("Include all incidences matched by view filter", nullptr));
        numItems->setText(QString());
        (void)SearchDialog;
    } // retranslateUi

};

namespace Ui {
    class SearchDialog: public Ui_SearchDialog {};
} // namespace Ui

QT_END_NAMESPACE

#endif // SEARCHDIALOG_BASE_H

