/*
 * This file was generated by qdbusxml2cpp version 0.8
 * Source file was org.kde.Korganizer.Calendar.xml
 *
 * qdbusxml2cpp is Copyright (C) The Qt Company Ltd. and other contributors.
 *
 * This is an auto-generated file.
 * Do not edit! All changes made to it will be lost.
 */

#include "calendaradaptor.h"
#include <QtCore/QMetaObject>
#include <QtCore/QByteArray>
#include <QtCore/QList>
#include <QtCore/QMap>
#include <QtCore/QString>
#include <QtCore/QStringList>
#include <QtCore/QVariant>

/*
 * Implementation of adaptor class KOrgCalendarAdaptor
 */

KOrgCalendarAdaptor::KOrgCalendarAdaptor(ActionManager *parent)
    : QDBusAbstractAdaptor(parent)
{
    // constructor
    setAutoRelaySignals(true);
}

KOrgCalendarAdaptor::~KOrgCalendarAdaptor()
{
    // destructor
}

void KOrgCalendarAdaptor::goDate(const QString &date)
{
    // handle method call org.kde.Korganizer.Calendar.goDate
    parent()->goDate(date);
}

void KOrgCalendarAdaptor::goDate(const QDate &date)
{
    // handle method call org.kde.Korganizer.Calendar.goDate
    parent()->goDate(date);
}

void KOrgCalendarAdaptor::openEventEditor(const QString &summary, const QString &description, const QStringList &attachmentUris, const QStringList &attendees, const QStringList &attachmentMimetypes, bool attachmentIsInline)
{
    // handle method call org.kde.Korganizer.Calendar.openEventEditor
    parent()->openEventEditor(summary, description, attachmentUris, attendees, attachmentMimetypes, attachmentIsInline);
}

void KOrgCalendarAdaptor::openEventEditor(const QString &summary, const QString &description, const QStringList &attachments, const QStringList &attendees)
{
    // handle method call org.kde.Korganizer.Calendar.openEventEditor
    parent()->openEventEditor(summary, description, attachments, attendees);
}

void KOrgCalendarAdaptor::openEventEditor(const QString &summary, const QString &description, const QString &uri, const QString &file, const QStringList &attendees, const QString &attachmentMimetype)
{
    // handle method call org.kde.Korganizer.Calendar.openEventEditor
    parent()->openEventEditor(summary, description, uri, file, attendees, attachmentMimetype);
}

void KOrgCalendarAdaptor::openEventEditor(const QString &summary, const QString &description, const QStringList &attachments)
{
    // handle method call org.kde.Korganizer.Calendar.openEventEditor
    parent()->openEventEditor(summary, description, attachments);
}

void KOrgCalendarAdaptor::openEventEditor(const QString &text)
{
    // handle method call org.kde.Korganizer.Calendar.openEventEditor
    parent()->openEventEditor(text);
}

void KOrgCalendarAdaptor::openEventEditor()
{
    // handle method call org.kde.Korganizer.Calendar.openEventEditor
    parent()->openEventEditor();
}

void KOrgCalendarAdaptor::openJournalEditor(const QString &text)
{
    // handle method call org.kde.Korganizer.Calendar.openJournalEditor
    parent()->openJournalEditor(text);
}

void KOrgCalendarAdaptor::openJournalEditor(const QString &text, const QDate &date)
{
    // handle method call org.kde.Korganizer.Calendar.openJournalEditor
    parent()->openJournalEditor(text, date);
}

void KOrgCalendarAdaptor::openJournalEditor(const QDate &date)
{
    // handle method call org.kde.Korganizer.Calendar.openJournalEditor
    parent()->openJournalEditor(date);
}

void KOrgCalendarAdaptor::openTodoEditor(const QString &summary, const QString &description, const QStringList &attachmentUris, const QStringList &attendees, const QStringList &attachmentMimetypes, bool attachmentIsInline)
{
    // handle method call org.kde.Korganizer.Calendar.openTodoEditor
    parent()->openTodoEditor(summary, description, attachmentUris, attendees, attachmentMimetypes, attachmentIsInline);
}

void KOrgCalendarAdaptor::openTodoEditor(const QString &summary, const QString &description, const QString &uri, const QString &file, const QStringList &attendees, const QString &attachmentMimetype)
{
    // handle method call org.kde.Korganizer.Calendar.openTodoEditor
    parent()->openTodoEditor(summary, description, uri, file, attendees, attachmentMimetype);
}

void KOrgCalendarAdaptor::openTodoEditor(const QString &summary, const QString &description, const QStringList &attachments, const QStringList &attendees)
{
    // handle method call org.kde.Korganizer.Calendar.openTodoEditor
    parent()->openTodoEditor(summary, description, attachments, attendees);
}

void KOrgCalendarAdaptor::openTodoEditor(const QString &summary, const QString &description, const QStringList &attachments)
{
    // handle method call org.kde.Korganizer.Calendar.openTodoEditor
    parent()->openTodoEditor(summary, description, attachments);
}

void KOrgCalendarAdaptor::openTodoEditor(const QString &text)
{
    // handle method call org.kde.Korganizer.Calendar.openTodoEditor
    parent()->openTodoEditor(text);
}

void KOrgCalendarAdaptor::showDate(const QDate &date)
{
    // handle method call org.kde.Korganizer.Calendar.showDate
    parent()->showDate(date);
}

void KOrgCalendarAdaptor::showEventView()
{
    // handle method call org.kde.Korganizer.Calendar.showEventView
    parent()->showEventView();
}

void KOrgCalendarAdaptor::showJournalView()
{
    // handle method call org.kde.Korganizer.Calendar.showJournalView
    parent()->showJournalView();
}

void KOrgCalendarAdaptor::showTodoView()
{
    // handle method call org.kde.Korganizer.Calendar.showTodoView
    parent()->showTodoView();
}


#include "moc_calendaradaptor.cpp"
