/*
 * This file was generated by qdbusxml2cpp version 0.8
 * Source file was org.kde.korganizer.Korganizer.xml
 *
 * qdbusxml2cpp is Copyright (C) The Qt Company Ltd. and other contributors.
 *
 * This is an auto-generated file.
 * This file may have been hand-edited. Look for HAND-EDIT comments
 * before re-generating it.
 */

#ifndef KORGANIZERADAPTOR_H
#define KORGANIZERADAPTOR_H

#include <QtCore/QObject>
#include <QtDBus/QtDBus>
#include "impl/korganizerifaceimpl.h"
#include <QtCore/qcontainerfwd.h>

/*
 * Adaptor class for interface org.kde.korganizer.Korganizer
 */
class KorganizerAdaptor: public QDBusAbstractAdaptor
{
    Q_OBJECT
    Q_CLASSINFO("D-Bus Interface", "org.kde.korganizer.Korganizer")
    Q_CLASSINFO("D-Bus Introspection", ""
"  <interface name=\"org.kde.korganizer.Korganizer\">\n"
"    <method name=\"openURL\">\n"
"      <arg direction=\"in\" type=\"s\" name=\"url\"/>\n"
"      <arg direction=\"out\" type=\"b\"/>\n"
"    </method>\n"
"    <method name=\"mergeURL\">\n"
"      <arg direction=\"in\" type=\"s\" name=\"url\"/>\n"
"      <arg direction=\"out\" type=\"b\"/>\n"
"    </method>\n"
"    <method name=\"saveURL\">\n"
"      <arg direction=\"out\" type=\"b\"/>\n"
"    </method>\n"
"    <method name=\"saveAsURL\">\n"
"      <arg direction=\"in\" type=\"s\" name=\"url\"/>\n"
"      <arg direction=\"out\" type=\"b\"/>\n"
"    </method>\n"
"    <method name=\"getCurrentURLasString\">\n"
"      <arg direction=\"out\" type=\"s\"/>\n"
"    </method>\n"
"    <method name=\"editIncidence\">\n"
"      <arg direction=\"in\" type=\"s\" name=\"url\"/>\n"
"      <arg direction=\"out\" type=\"b\"/>\n"
"    </method>\n"
"    <method name=\"deleteIncidence\">\n"
"      <arg direction=\"in\" type=\"s\" name=\"url\"/>\n"
"      <arg direction=\"out\" type=\"b\"/>\n"
"    </method>\n"
"    <method name=\"deleteIncidence\">\n"
"      <arg direction=\"in\" type=\"s\" name=\"url\"/>\n"
"      <arg direction=\"in\" type=\"b\" name=\"force\"/>\n"
"      <arg direction=\"out\" type=\"b\"/>\n"
"    </method>\n"
"    <method name=\"addIncidence\">\n"
"      <arg direction=\"in\" type=\"s\" name=\"ical\"/>\n"
"      <arg direction=\"out\" type=\"b\"/>\n"
"    </method>\n"
"    <method name=\"showIncidence\">\n"
"      <arg direction=\"in\" type=\"s\" name=\"url\"/>\n"
"      <arg direction=\"out\" type=\"b\"/>\n"
"    </method>\n"
"    <method name=\"showIncidenceContext\">\n"
"      <arg direction=\"in\" type=\"s\" name=\"url\"/>\n"
"      <arg direction=\"out\" type=\"b\"/>\n"
"    </method>\n"
"    <method name=\"handleCommandLine\">\n"
"      <arg direction=\"out\" type=\"b\"/>\n"
"      <arg direction=\"in\" type=\"as\" name=\"args\"/>\n"
"    </method>\n"
"  </interface>\n"
        "")
public:
    KorganizerAdaptor(KOrganizerIfaceImpl *parent);
    ~KorganizerAdaptor() override;

    inline KOrganizerIfaceImpl *parent() const
    { return static_cast<KOrganizerIfaceImpl *>(QObject::parent()); }

public: // PROPERTIES
public Q_SLOTS: // METHODS
    bool addIncidence(const QString &ical);
    bool deleteIncidence(const QString &url, bool force);
    bool deleteIncidence(const QString &url);
    bool editIncidence(const QString &url);
    QString getCurrentURLasString();
    bool handleCommandLine(const QStringList &args);
    bool mergeURL(const QString &url);
    bool openURL(const QString &url);
    bool saveAsURL(const QString &url);
    bool saveURL();
    bool showIncidence(const QString &url);
    bool showIncidenceContext(const QString &url);
Q_SIGNALS: // SIGNALS
};

#endif
