/****************************************************************************
** Meta object code from reading C++ file 'datenavigatorcontainer.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.11.2)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../../korganizer-26.08.0/src/datenavigatorcontainer.h"
#include <QtCore/qmetatype.h>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'datenavigatorcontainer.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.11.2. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN22DateNavigatorContainerE_t {};
} // unnamed namespace

template <> constexpr inline auto DateNavigatorContainer::qt_create_metaobjectdata<qt_meta_tag_ZN22DateNavigatorContainerE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "DateNavigatorContainer",
        "datesSelected",
        "",
        "KCalendarCore::DateList",
        "incidenceDropped",
        "Akonadi::Item",
        "incidenceDroppedMove",
        "newEventSignal",
        "newTodoSignal",
        "newJournalSignal",
        "weekClicked",
        "goPrevious",
        "goNext",
        "fullWindowClicked",
        "todayClicked",
        "nextYearClicked",
        "prevYearClicked",
        "nextWeekClicked",
        "prevWeekClicked",
        "prevMonthClicked",
        "nextMonthClicked",
        "monthSelected",
        "yearSelected",
        "selectDates",
        "preferredMonth",
        "updateView",
        "updateConfig",
        "updateDayMatrix",
        "updateToday",
        "goPrevWeek",
        "goNextWeek",
        "goPrevMonth",
        "goNextMonth",
        "resizeAllContents",
        "handleDatesSelectedSignal",
        "handleWeekClickedSignal"
    };

    QtMocHelpers::UintData qt_methods {
        // Signal 'datesSelected'
        QtMocHelpers::SignalData<void(const KCalendarCore::DateList &, const QDate &)>(1, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 3, 2 }, { QMetaType::QDate, 2 },
        }}),
        // Signal 'incidenceDropped'
        QtMocHelpers::SignalData<void(const Akonadi::Item &, const QDate &)>(4, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 5, 2 }, { QMetaType::QDate, 2 },
        }}),
        // Signal 'incidenceDroppedMove'
        QtMocHelpers::SignalData<void(const Akonadi::Item &, const QDate &)>(6, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 5, 2 }, { QMetaType::QDate, 2 },
        }}),
        // Signal 'newEventSignal'
        QtMocHelpers::SignalData<void(const QDate &)>(7, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QDate, 2 },
        }}),
        // Signal 'newTodoSignal'
        QtMocHelpers::SignalData<void(const QDate &)>(8, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QDate, 2 },
        }}),
        // Signal 'newJournalSignal'
        QtMocHelpers::SignalData<void(const QDate &)>(9, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QDate, 2 },
        }}),
        // Signal 'weekClicked'
        QtMocHelpers::SignalData<void(const QDate &, const QDate &)>(10, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QDate, 2 }, { QMetaType::QDate, 2 },
        }}),
        // Signal 'goPrevious'
        QtMocHelpers::SignalData<void()>(11, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'goNext'
        QtMocHelpers::SignalData<void()>(12, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'fullWindowClicked'
        QtMocHelpers::SignalData<void()>(13, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'todayClicked'
        QtMocHelpers::SignalData<void()>(14, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'nextYearClicked'
        QtMocHelpers::SignalData<void()>(15, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'prevYearClicked'
        QtMocHelpers::SignalData<void()>(16, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'nextWeekClicked'
        QtMocHelpers::SignalData<void()>(17, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'prevWeekClicked'
        QtMocHelpers::SignalData<void()>(18, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'prevMonthClicked'
        QtMocHelpers::SignalData<void(const QDate &, const QDate &, const QDate &)>(19, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QDate, 2 }, { QMetaType::QDate, 2 }, { QMetaType::QDate, 2 },
        }}),
        // Signal 'nextMonthClicked'
        QtMocHelpers::SignalData<void(const QDate &, const QDate &, const QDate &)>(20, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QDate, 2 }, { QMetaType::QDate, 2 }, { QMetaType::QDate, 2 },
        }}),
        // Signal 'monthSelected'
        QtMocHelpers::SignalData<void(int)>(21, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Int, 2 },
        }}),
        // Signal 'yearSelected'
        QtMocHelpers::SignalData<void(int)>(22, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Int, 2 },
        }}),
        // Slot 'selectDates'
        QtMocHelpers::SlotData<void(const KCalendarCore::DateList &, const QDate &)>(23, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 3, 2 }, { QMetaType::QDate, 24 },
        }}),
        // Slot 'selectDates'
        QtMocHelpers::SlotData<void(const KCalendarCore::DateList &)>(23, 2, QMC::AccessPublic | QMC::MethodCloned, QMetaType::Void, {{
            { 0x80000000 | 3, 2 },
        }}),
        // Slot 'updateView'
        QtMocHelpers::SlotData<void()>(25, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'updateConfig'
        QtMocHelpers::SlotData<void()>(26, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'updateDayMatrix'
        QtMocHelpers::SlotData<void()>(27, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'updateToday'
        QtMocHelpers::SlotData<void()>(28, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'goPrevWeek'
        QtMocHelpers::SlotData<void()>(29, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'goNextWeek'
        QtMocHelpers::SlotData<void()>(30, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'goPrevMonth'
        QtMocHelpers::SlotData<void()>(31, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'goNextMonth'
        QtMocHelpers::SlotData<void()>(32, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'resizeAllContents'
        QtMocHelpers::SlotData<void()>(33, 2, QMC::AccessProtected, QMetaType::Void),
        // Slot 'handleDatesSelectedSignal'
        QtMocHelpers::SlotData<void(const KCalendarCore::DateList &)>(34, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { 0x80000000 | 3, 2 },
        }}),
        // Slot 'handleWeekClickedSignal'
        QtMocHelpers::SlotData<void(const QDate &, const QDate &)>(35, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::QDate, 2 }, { QMetaType::QDate, 2 },
        }}),
    };
    QtMocHelpers::UintData qt_properties {
    };
    QtMocHelpers::UintData qt_enums {
    };
    return QtMocHelpers::metaObjectData<DateNavigatorContainer, qt_meta_tag_ZN22DateNavigatorContainerE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject DateNavigatorContainer::staticMetaObject = { {
    QMetaObject::SuperData::link<QFrame::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN22DateNavigatorContainerE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN22DateNavigatorContainerE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN22DateNavigatorContainerE_t>.metaTypes,
    nullptr
} };

void DateNavigatorContainer::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<DateNavigatorContainer *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->datesSelected((*reinterpret_cast<std::add_pointer_t<KCalendarCore::DateList>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QDate>>(_a[2]))); break;
        case 1: _t->incidenceDropped((*reinterpret_cast<std::add_pointer_t<Akonadi::Item>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QDate>>(_a[2]))); break;
        case 2: _t->incidenceDroppedMove((*reinterpret_cast<std::add_pointer_t<Akonadi::Item>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QDate>>(_a[2]))); break;
        case 3: _t->newEventSignal((*reinterpret_cast<std::add_pointer_t<QDate>>(_a[1]))); break;
        case 4: _t->newTodoSignal((*reinterpret_cast<std::add_pointer_t<QDate>>(_a[1]))); break;
        case 5: _t->newJournalSignal((*reinterpret_cast<std::add_pointer_t<QDate>>(_a[1]))); break;
        case 6: _t->weekClicked((*reinterpret_cast<std::add_pointer_t<QDate>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QDate>>(_a[2]))); break;
        case 7: _t->goPrevious(); break;
        case 8: _t->goNext(); break;
        case 9: _t->fullWindowClicked(); break;
        case 10: _t->todayClicked(); break;
        case 11: _t->nextYearClicked(); break;
        case 12: _t->prevYearClicked(); break;
        case 13: _t->nextWeekClicked(); break;
        case 14: _t->prevWeekClicked(); break;
        case 15: _t->prevMonthClicked((*reinterpret_cast<std::add_pointer_t<QDate>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QDate>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<QDate>>(_a[3]))); break;
        case 16: _t->nextMonthClicked((*reinterpret_cast<std::add_pointer_t<QDate>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QDate>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<QDate>>(_a[3]))); break;
        case 17: _t->monthSelected((*reinterpret_cast<std::add_pointer_t<int>>(_a[1]))); break;
        case 18: _t->yearSelected((*reinterpret_cast<std::add_pointer_t<int>>(_a[1]))); break;
        case 19: _t->selectDates((*reinterpret_cast<std::add_pointer_t<KCalendarCore::DateList>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QDate>>(_a[2]))); break;
        case 20: _t->selectDates((*reinterpret_cast<std::add_pointer_t<KCalendarCore::DateList>>(_a[1]))); break;
        case 21: _t->updateView(); break;
        case 22: _t->updateConfig(); break;
        case 23: _t->updateDayMatrix(); break;
        case 24: _t->updateToday(); break;
        case 25: _t->goPrevWeek(); break;
        case 26: _t->goNextWeek(); break;
        case 27: _t->goPrevMonth(); break;
        case 28: _t->goNextMonth(); break;
        case 29: _t->resizeAllContents(); break;
        case 30: _t->handleDatesSelectedSignal((*reinterpret_cast<std::add_pointer_t<KCalendarCore::DateList>>(_a[1]))); break;
        case 31: _t->handleWeekClickedSignal((*reinterpret_cast<std::add_pointer_t<QDate>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QDate>>(_a[2]))); break;
        default: ;
        }
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        switch (_id) {
        default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
        case 1:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< Akonadi::Item >(); break;
            }
            break;
        case 2:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< Akonadi::Item >(); break;
            }
            break;
        }
    }
    if (_c == QMetaObject::IndexOfMethod) {
        if (QtMocHelpers::indexOfMethod<void (DateNavigatorContainer::*)(const KCalendarCore::DateList & , const QDate & )>(_a, &DateNavigatorContainer::datesSelected, 0))
            return;
        if (QtMocHelpers::indexOfMethod<void (DateNavigatorContainer::*)(const Akonadi::Item & , const QDate & )>(_a, &DateNavigatorContainer::incidenceDropped, 1))
            return;
        if (QtMocHelpers::indexOfMethod<void (DateNavigatorContainer::*)(const Akonadi::Item & , const QDate & )>(_a, &DateNavigatorContainer::incidenceDroppedMove, 2))
            return;
        if (QtMocHelpers::indexOfMethod<void (DateNavigatorContainer::*)(const QDate & )>(_a, &DateNavigatorContainer::newEventSignal, 3))
            return;
        if (QtMocHelpers::indexOfMethod<void (DateNavigatorContainer::*)(const QDate & )>(_a, &DateNavigatorContainer::newTodoSignal, 4))
            return;
        if (QtMocHelpers::indexOfMethod<void (DateNavigatorContainer::*)(const QDate & )>(_a, &DateNavigatorContainer::newJournalSignal, 5))
            return;
        if (QtMocHelpers::indexOfMethod<void (DateNavigatorContainer::*)(const QDate & , const QDate & )>(_a, &DateNavigatorContainer::weekClicked, 6))
            return;
        if (QtMocHelpers::indexOfMethod<void (DateNavigatorContainer::*)()>(_a, &DateNavigatorContainer::goPrevious, 7))
            return;
        if (QtMocHelpers::indexOfMethod<void (DateNavigatorContainer::*)()>(_a, &DateNavigatorContainer::goNext, 8))
            return;
        if (QtMocHelpers::indexOfMethod<void (DateNavigatorContainer::*)()>(_a, &DateNavigatorContainer::fullWindowClicked, 9))
            return;
        if (QtMocHelpers::indexOfMethod<void (DateNavigatorContainer::*)()>(_a, &DateNavigatorContainer::todayClicked, 10))
            return;
        if (QtMocHelpers::indexOfMethod<void (DateNavigatorContainer::*)()>(_a, &DateNavigatorContainer::nextYearClicked, 11))
            return;
        if (QtMocHelpers::indexOfMethod<void (DateNavigatorContainer::*)()>(_a, &DateNavigatorContainer::prevYearClicked, 12))
            return;
        if (QtMocHelpers::indexOfMethod<void (DateNavigatorContainer::*)()>(_a, &DateNavigatorContainer::nextWeekClicked, 13))
            return;
        if (QtMocHelpers::indexOfMethod<void (DateNavigatorContainer::*)()>(_a, &DateNavigatorContainer::prevWeekClicked, 14))
            return;
        if (QtMocHelpers::indexOfMethod<void (DateNavigatorContainer::*)(const QDate & , const QDate & , const QDate & )>(_a, &DateNavigatorContainer::prevMonthClicked, 15))
            return;
        if (QtMocHelpers::indexOfMethod<void (DateNavigatorContainer::*)(const QDate & , const QDate & , const QDate & )>(_a, &DateNavigatorContainer::nextMonthClicked, 16))
            return;
        if (QtMocHelpers::indexOfMethod<void (DateNavigatorContainer::*)(int )>(_a, &DateNavigatorContainer::monthSelected, 17))
            return;
        if (QtMocHelpers::indexOfMethod<void (DateNavigatorContainer::*)(int )>(_a, &DateNavigatorContainer::yearSelected, 18))
            return;
    }
}

const QMetaObject *DateNavigatorContainer::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *DateNavigatorContainer::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN22DateNavigatorContainerE_t>.strings))
        return static_cast<void*>(this);
    return QFrame::qt_metacast(_clname);
}

int DateNavigatorContainer::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QFrame::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 32)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 32;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 32)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 32;
    }
    return _id;
}

// SIGNAL 0
void DateNavigatorContainer::datesSelected(const KCalendarCore::DateList & _t1, const QDate & _t2)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 0, nullptr, _t1, _t2);
}

// SIGNAL 1
void DateNavigatorContainer::incidenceDropped(const Akonadi::Item & _t1, const QDate & _t2)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 1, nullptr, _t1, _t2);
}

// SIGNAL 2
void DateNavigatorContainer::incidenceDroppedMove(const Akonadi::Item & _t1, const QDate & _t2)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 2, nullptr, _t1, _t2);
}

// SIGNAL 3
void DateNavigatorContainer::newEventSignal(const QDate & _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 3, nullptr, _t1);
}

// SIGNAL 4
void DateNavigatorContainer::newTodoSignal(const QDate & _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 4, nullptr, _t1);
}

// SIGNAL 5
void DateNavigatorContainer::newJournalSignal(const QDate & _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 5, nullptr, _t1);
}

// SIGNAL 6
void DateNavigatorContainer::weekClicked(const QDate & _t1, const QDate & _t2)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 6, nullptr, _t1, _t2);
}

// SIGNAL 7
void DateNavigatorContainer::goPrevious()
{
    QMetaObject::activate(this, &staticMetaObject, 7, nullptr);
}

// SIGNAL 8
void DateNavigatorContainer::goNext()
{
    QMetaObject::activate(this, &staticMetaObject, 8, nullptr);
}

// SIGNAL 9
void DateNavigatorContainer::fullWindowClicked()
{
    QMetaObject::activate(this, &staticMetaObject, 9, nullptr);
}

// SIGNAL 10
void DateNavigatorContainer::todayClicked()
{
    QMetaObject::activate(this, &staticMetaObject, 10, nullptr);
}

// SIGNAL 11
void DateNavigatorContainer::nextYearClicked()
{
    QMetaObject::activate(this, &staticMetaObject, 11, nullptr);
}

// SIGNAL 12
void DateNavigatorContainer::prevYearClicked()
{
    QMetaObject::activate(this, &staticMetaObject, 12, nullptr);
}

// SIGNAL 13
void DateNavigatorContainer::nextWeekClicked()
{
    QMetaObject::activate(this, &staticMetaObject, 13, nullptr);
}

// SIGNAL 14
void DateNavigatorContainer::prevWeekClicked()
{
    QMetaObject::activate(this, &staticMetaObject, 14, nullptr);
}

// SIGNAL 15
void DateNavigatorContainer::prevMonthClicked(const QDate & _t1, const QDate & _t2, const QDate & _t3)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 15, nullptr, _t1, _t2, _t3);
}

// SIGNAL 16
void DateNavigatorContainer::nextMonthClicked(const QDate & _t1, const QDate & _t2, const QDate & _t3)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 16, nullptr, _t1, _t2, _t3);
}

// SIGNAL 17
void DateNavigatorContainer::monthSelected(int _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 17, nullptr, _t1);
}

// SIGNAL 18
void DateNavigatorContainer::yearSelected(int _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 18, nullptr, _t1);
}
QT_WARNING_POP
