// This file is generated by kconfig_compiler_kf6 from korganizer.kcfg.
// All changes you do to this file will be lost.
#ifndef KOPREFSBASE_H
#define KOPREFSBASE_H

#include <korganizer_debug.h>

#include <qglobal.h>
#include <kconfigskeleton.h>
#include <QCoreApplication>
#include <QDebug>

class KOPrefsBase : public KConfigSkeleton
{
  public:
    enum EnumDestination { standardDestination, askDestination };
    enum EnumAgendaViewColors { CategoryInsideResourceOutside, ResourceInsideCategoryOutside, CategoryOnly, ResourceOnly };
    enum EnumAgendaViewCalendarDisplay { CalendarsMerged, CalendarsSideBySide, AllCalendarViews };
    enum EnumMonthViewColors { MonthItemCategoryInsideResourceOutside, MonthItemResourceInsideCategoryOutside, MonthItemCategoryOnly, MonthItemResourceOnly };
    enum EnumDefaultTodoAttachMethod { TodoAttachAsk, TodoAttachLink, TodoAttachInlineFull };

    KOPrefsBase( );
    ~KOPrefsBase() override;

    /**
      Set Confirm deletes
    */
    void setConfirm( bool v )
    {
      if (!isConfirmImmutable())
        mConfirm = v;
    }

    /**
      Get Confirm deletes
    */
    bool confirm() const
    {
      return mConfirm;
    }

    /**
      Is Confirm deletes Immutable
    */
    bool isConfirmImmutable() const
    {
      return isImmutable( QStringLiteral( "Confirm" ) );
    }

    /**
      Get Item object corresponding to Confirm()
    */
    ItemBool *confirmItem()
    {
      return mConfirmItem;
    }

    /**
      Set New Events, To-dos and Journal Entries Should
    */
    void setDestination( int v )
    {
      if (!isDestinationImmutable())
        mDestination = v;
    }

    /**
      Get New Events, To-dos and Journal Entries Should
    */
    int destination() const
    {
      return mDestination;
    }

    /**
      Is New Events, To-dos and Journal Entries Should Immutable
    */
    bool isDestinationImmutable() const
    {
      return isImmutable( QStringLiteral( "Destination" ) );
    }

    /**
      Get Item object corresponding to Destination()
    */
    ItemEnum *destinationItem()
    {
      return mDestinationItem;
    }

    /**
      Set TimeZoneId
    */
    void setTimeZoneId( const QString & v )
    {
      if (!isTimeZoneIdImmutable())
        mTimeZoneId = v;
    }

    /**
      Get TimeZoneId
    */
    QString timeZoneId() const
    {
      return mTimeZoneId;
    }

    /**
      Is TimeZoneId Immutable
    */
    bool isTimeZoneIdImmutable() const
    {
      return isImmutable( QStringLiteral( "TimeZoneId" ) );
    }

    /**
      Get Item object corresponding to TimeZoneId()
    */
    ItemString *timeZoneIdItem()
    {
      return mTimeZoneIdItem;
    }

    /**
      Set Weekly start day:
    */
    void setWeekStartDay( int v )
    {
      if (!isWeekStartDayImmutable())
        mWeekStartDay = v;
    }

    /**
      Get Weekly start day:
    */
    int weekStartDay() const
    {
      return mWeekStartDay;
    }

    /**
      Is Weekly start day: Immutable
    */
    bool isWeekStartDayImmutable() const
    {
      return isImmutable( QStringLiteral( "WeekStartDay" ) );
    }

    /**
      Get Item object corresponding to WeekStartDay()
    */
    ItemEnum *weekStartDayItem()
    {
      return mWeekStartDayItem;
    }

    /**
      Set Daily starting hour
    */
    void setWorkingHoursStart( const QDateTime & v )
    {
      if (!isWorkingHoursStartImmutable())
        mWorkingHoursStart = v;
    }

    /**
      Get Daily starting hour
    */
    QDateTime workingHoursStart() const
    {
      return mWorkingHoursStart;
    }

    /**
      Is Daily starting hour Immutable
    */
    bool isWorkingHoursStartImmutable() const
    {
      return isImmutable( QStringLiteral( "WorkingHoursStart" ) );
    }

    /**
      Get Item object corresponding to WorkingHoursStart()
    */
    ItemDateTime *workingHoursStartItem()
    {
      return mWorkingHoursStartItem;
    }

    /**
      Set Daily ending hour
    */
    void setWorkingHoursEnd( const QDateTime & v )
    {
      if (!isWorkingHoursEndImmutable())
        mWorkingHoursEnd = v;
    }

    /**
      Get Daily ending hour
    */
    QDateTime workingHoursEnd() const
    {
      return mWorkingHoursEnd;
    }

    /**
      Is Daily ending hour Immutable
    */
    bool isWorkingHoursEndImmutable() const
    {
      return isImmutable( QStringLiteral( "WorkingHoursEnd" ) );
    }

    /**
      Get Item object corresponding to WorkingHoursEnd()
    */
    ItemDateTime *workingHoursEndItem()
    {
      return mWorkingHoursEndItem;
    }

    /**
      Set Color busy days with a different background color
    */
    void setColorMonthBusyDaysEnabled( bool v )
    {
      if (!isColorMonthBusyDaysEnabledImmutable())
        mColorMonthBusyDaysEnabled = v;
    }

    /**
      Get Color busy days with a different background color
    */
    bool colorMonthBusyDaysEnabled() const
    {
      return mColorMonthBusyDaysEnabled;
    }

    /**
      Is Color busy days with a different background color Immutable
    */
    bool isColorMonthBusyDaysEnabledImmutable() const
    {
      return isImmutable( QStringLiteral( "ColorMonthBusyDaysEnabled" ) );
    }

    /**
      Get Item object corresponding to ColorMonthBusyDaysEnabled()
    */
    ItemBool *colorMonthBusyDaysEnabledItem()
    {
      return mColorMonthBusyDaysEnabledItem;
    }

    /**
      Set Enable tooltips for displaying summaries
    */
    void setEnableToolTips( bool v )
    {
      if (!isEnableToolTipsImmutable())
        mEnableToolTips = v;
    }

    /**
      Get Enable tooltips for displaying summaries
    */
    bool enableToolTips() const
    {
      return mEnableToolTips;
    }

    /**
      Is Enable tooltips for displaying summaries Immutable
    */
    bool isEnableToolTipsImmutable() const
    {
      return isImmutable( QStringLiteral( "EnableToolTips" ) );
    }

    /**
      Get Item object corresponding to EnableToolTips()
    */
    ItemBool *enableToolTipsItem()
    {
      return mEnableToolTipsItem;
    }

    /**
      Set To-dos use tag colors
    */
    void setTodosUseCategoryColors( bool v )
    {
      if (!isTodosUseCategoryColorsImmutable())
        mTodosUseCategoryColors = v;
    }

    /**
      Get To-dos use tag colors
    */
    bool todosUseCategoryColors() const
    {
      return mTodosUseCategoryColors;
    }

    /**
      Is To-dos use tag colors Immutable
    */
    bool isTodosUseCategoryColorsImmutable() const
    {
      return isImmutable( QStringLiteral( "TodosUseCategoryColors" ) );
    }

    /**
      Get Item object corresponding to TodosUseCategoryColors()
    */
    ItemBool *todosUseCategoryColorsItem()
    {
      return mTodosUseCategoryColorsItem;
    }

    /**
      Set Next x days
    */
    void setNextXDays( int v )
    {
      if (!isNextXDaysImmutable())
        mNextXDays = v;
    }

    /**
      Get Next x days
    */
    int nextXDays() const
    {
      return mNextXDays;
    }

    /**
      Is Next x days Immutable
    */
    bool isNextXDaysImmutable() const
    {
      return isImmutable( QStringLiteral( "NextXDays" ) );
    }

    /**
      Get Item object corresponding to NextXDays()
    */
    ItemInt *nextXDaysItem()
    {
      return mNextXDaysItem;
    }

    /**
      Set Show items that recur daily
    */
    void setDailyRecur( bool v )
    {
      if (!isDailyRecurImmutable())
        mDailyRecur = v;
    }

    /**
      Get Show items that recur daily
    */
    bool dailyRecur() const
    {
      return mDailyRecur;
    }

    /**
      Is Show items that recur daily Immutable
    */
    bool isDailyRecurImmutable() const
    {
      return isImmutable( QStringLiteral( "DailyRecur" ) );
    }

    /**
      Get Item object corresponding to DailyRecur()
    */
    ItemBool *dailyRecurItem()
    {
      return mDailyRecurItem;
    }

    /**
      Set Show items that recur weekly
    */
    void setWeeklyRecur( bool v )
    {
      if (!isWeeklyRecurImmutable())
        mWeeklyRecur = v;
    }

    /**
      Get Show items that recur weekly
    */
    bool weeklyRecur() const
    {
      return mWeeklyRecur;
    }

    /**
      Is Show items that recur weekly Immutable
    */
    bool isWeeklyRecurImmutable() const
    {
      return isImmutable( QStringLiteral( "WeeklyRecur" ) );
    }

    /**
      Get Item object corresponding to WeeklyRecur()
    */
    ItemBool *weeklyRecurItem()
    {
      return mWeeklyRecurItem;
    }

    /**
      Set Show to-dos instead of events when in Todo View
    */
    void setHighlightTodos( bool v )
    {
      if (!isHighlightTodosImmutable())
        mHighlightTodos = v;
    }

    /**
      Get Show to-dos instead of events when in Todo View
    */
    bool highlightTodos() const
    {
      return mHighlightTodos;
    }

    /**
      Is Show to-dos instead of events when in Todo View Immutable
    */
    bool isHighlightTodosImmutable() const
    {
      return isImmutable( QStringLiteral( "HighlightTodos" ) );
    }

    /**
      Get Item object corresponding to HighlightTodos()
    */
    ItemBool *highlightTodosItem()
    {
      return mHighlightTodosItem;
    }

    /**
      Set Show journals instead of events when in Journal View
    */
    void setHighlightJournals( bool v )
    {
      if (!isHighlightJournalsImmutable())
        mHighlightJournals = v;
    }

    /**
      Get Show journals instead of events when in Journal View
    */
    bool highlightJournals() const
    {
      return mHighlightJournals;
    }

    /**
      Is Show journals instead of events when in Journal View Immutable
    */
    bool isHighlightJournalsImmutable() const
    {
      return isImmutable( QStringLiteral( "HighlightJournals" ) );
    }

    /**
      Get Item object corresponding to HighlightJournals()
    */
    ItemBool *highlightJournalsItem()
    {
      return mHighlightJournalsItem;
    }

    /**
      Set Show week numbers
    */
    void setWeekNumbersShow( bool v )
    {
      if (!isWeekNumbersShowImmutable())
        mWeekNumbersShow = v;
    }

    /**
      Get Show week numbers
    */
    bool weekNumbersShow() const
    {
      return mWeekNumbersShow;
    }

    /**
      Is Show week numbers Immutable
    */
    bool isWeekNumbersShowImmutable() const
    {
      return isImmutable( QStringLiteral( "WeekNumbersShow" ) );
    }

    /**
      Get Item object corresponding to WeekNumbersShow()
    */
    ItemBool *weekNumbersShowItem()
    {
      return mWeekNumbersShowItem;
    }

    /**
      Set Week numbers select a work week when in work week mode
    */
    void setWeekNumbersShowWork( bool v )
    {
      if (!isWeekNumbersShowWorkImmutable())
        mWeekNumbersShowWork = v;
    }

    /**
      Get Week numbers select a work week when in work week mode
    */
    bool weekNumbersShowWork() const
    {
      return mWeekNumbersShowWork;
    }

    /**
      Is Week numbers select a work week when in work week mode Immutable
    */
    bool isWeekNumbersShowWorkImmutable() const
    {
      return isImmutable( QStringLiteral( "WeekNumbersShowWork" ) );
    }

    /**
      Get Item object corresponding to WeekNumbersShowWork()
    */
    ItemBool *weekNumbersShowWorkItem()
    {
      return mWeekNumbersShowWorkItem;
    }

    /**
      Set Hour size
    */
    void setHourSize( int v )
    {
      if (v < 4)
      {
        qCDebug(KORGANIZER_LOG) << "setHourSize: value " << v << " is less than the minimum value of 4";
        v = 4;
      }

      if (v > 30)
      {
        qCDebug(KORGANIZER_LOG) << "setHourSize: value " << v << " is greater than the maximum value of 30";
        v = 30;
      }

      if (!isHourSizeImmutable())
        mHourSize = v;
    }

    /**
      Get Hour size
    */
    int hourSize() const
    {
      return mHourSize;
    }

    /**
      Is Hour size Immutable
    */
    bool isHourSizeImmutable() const
    {
      return isImmutable( QStringLiteral( "HourSize" ) );
    }

    /**
      Get Item object corresponding to HourSize()
    */
    ItemInt *hourSizeItem()
    {
      return mHourSizeItem;
    }

    /**
      Set Show icons in agenda view items
    */
    void setEnableAgendaItemIcons( bool v )
    {
      if (!isEnableAgendaItemIconsImmutable())
        mEnableAgendaItemIcons = v;
    }

    /**
      Get Show icons in agenda view items
    */
    bool enableAgendaItemIcons() const
    {
      return mEnableAgendaItemIcons;
    }

    /**
      Is Show icons in agenda view items Immutable
    */
    bool isEnableAgendaItemIconsImmutable() const
    {
      return isImmutable( QStringLiteral( "EnableAgendaItemIcons" ) );
    }

    /**
      Get Item object corresponding to EnableAgendaItemIcons()
    */
    ItemBool *enableAgendaItemIconsItem()
    {
      return mEnableAgendaItemIconsItem;
    }

    /**
      Set Draw bold horizontal grid lines for the even hours
    */
    void setEnableAgendaBoldEvenHours( bool v )
    {
      if (!isEnableAgendaBoldEvenHoursImmutable())
        mEnableAgendaBoldEvenHours = v;
    }

    /**
      Get Draw bold horizontal grid lines for the even hours
    */
    bool enableAgendaBoldEvenHours() const
    {
      return mEnableAgendaBoldEvenHours;
    }

    /**
      Is Draw bold horizontal grid lines for the even hours Immutable
    */
    bool isEnableAgendaBoldEvenHoursImmutable() const
    {
      return isImmutable( QStringLiteral( "EnableAgendaBoldEvenHours" ) );
    }

    /**
      Get Item object corresponding to EnableAgendaBoldEvenHours()
    */
    ItemBool *enableAgendaBoldEvenHoursItem()
    {
      return mEnableAgendaBoldEvenHoursItem;
    }

    /**
      Set Show incidence descriptions in agenda view items
    */
    void setEnableAgendaItemDesc( bool v )
    {
      if (!isEnableAgendaItemDescImmutable())
        mEnableAgendaItemDesc = v;
    }

    /**
      Get Show incidence descriptions in agenda view items
    */
    bool enableAgendaItemDesc() const
    {
      return mEnableAgendaItemDesc;
    }

    /**
      Is Show incidence descriptions in agenda view items Immutable
    */
    bool isEnableAgendaItemDescImmutable() const
    {
      return isImmutable( QStringLiteral( "EnableAgendaItemDesc" ) );
    }

    /**
      Get Item object corresponding to EnableAgendaItemDesc()
    */
    ItemBool *enableAgendaItemDescItem()
    {
      return mEnableAgendaItemDescItem;
    }

    /**
      Set Show incidence locations in agenda view items
    */
    void setEnableAgendaItemLocation( bool v )
    {
      if (!isEnableAgendaItemLocationImmutable())
        mEnableAgendaItemLocation = v;
    }

    /**
      Get Show incidence locations in agenda view items
    */
    bool enableAgendaItemLocation() const
    {
      return mEnableAgendaItemLocation;
    }

    /**
      Is Show incidence locations in agenda view items Immutable
    */
    bool isEnableAgendaItemLocationImmutable() const
    {
      return isImmutable( QStringLiteral( "EnableAgendaItemLocation" ) );
    }

    /**
      Get Item object corresponding to EnableAgendaItemLocation()
    */
    ItemBool *enableAgendaItemLocationItem()
    {
      return mEnableAgendaItemLocationItem;
    }

    /**
      Set Show to-dos
    */
    void setShowTodosAgendaView( bool v )
    {
      if (!isShowTodosAgendaViewImmutable())
        mShowTodosAgendaView = v;
    }

    /**
      Get Show to-dos
    */
    bool showTodosAgendaView() const
    {
      return mShowTodosAgendaView;
    }

    /**
      Is Show to-dos Immutable
    */
    bool isShowTodosAgendaViewImmutable() const
    {
      return isImmutable( QStringLiteral( "ShowTodosAgendaView" ) );
    }

    /**
      Get Item object corresponding to ShowTodosAgendaView()
    */
    ItemBool *showTodosAgendaViewItem()
    {
      return mShowTodosAgendaViewItem;
    }

    /**
      Set Show current-time (Marcus Bains) line
    */
    void setMarcusBainsEnabled( bool v )
    {
      if (!isMarcusBainsEnabledImmutable())
        mMarcusBainsEnabled = v;
    }

    /**
      Get Show current-time (Marcus Bains) line
    */
    bool marcusBainsEnabled() const
    {
      return mMarcusBainsEnabled;
    }

    /**
      Is Show current-time (Marcus Bains) line Immutable
    */
    bool isMarcusBainsEnabledImmutable() const
    {
      return isImmutable( QStringLiteral( "MarcusBainsEnabled" ) );
    }

    /**
      Get Item object corresponding to MarcusBainsEnabled()
    */
    ItemBool *marcusBainsEnabledItem()
    {
      return mMarcusBainsEnabledItem;
    }

    /**
      Set Show seconds and timezone on the current-time (Marcus Bains) line
    */
    void setMarcusBainsShowSeconds( bool v )
    {
      if (!isMarcusBainsShowSecondsImmutable())
        mMarcusBainsShowSeconds = v;
    }

    /**
      Get Show seconds and timezone on the current-time (Marcus Bains) line
    */
    bool marcusBainsShowSeconds() const
    {
      return mMarcusBainsShowSeconds;
    }

    /**
      Is Show seconds and timezone on the current-time (Marcus Bains) line Immutable
    */
    bool isMarcusBainsShowSecondsImmutable() const
    {
      return isImmutable( QStringLiteral( "MarcusBainsShowSeconds" ) );
    }

    /**
      Get Item object corresponding to MarcusBainsShowSeconds()
    */
    ItemBool *marcusBainsShowSecondsItem()
    {
      return mMarcusBainsShowSecondsItem;
    }

    /**
      Set Time range selection in agenda view starts event editor
    */
    void setSelectionStartsEditor( bool v )
    {
      if (!isSelectionStartsEditorImmutable())
        mSelectionStartsEditor = v;
    }

    /**
      Get Time range selection in agenda view starts event editor
    */
    bool selectionStartsEditor() const
    {
      return mSelectionStartsEditor;
    }

    /**
      Is Time range selection in agenda view starts event editor Immutable
    */
    bool isSelectionStartsEditorImmutable() const
    {
      return isImmutable( QStringLiteral( "SelectionStartsEditor" ) );
    }

    /**
      Get Item object corresponding to SelectionStartsEditor()
    */
    ItemBool *selectionStartsEditorItem()
    {
      return mSelectionStartsEditorItem;
    }

    /**
      Set Color Usage
    */
    void setAgendaViewColors( int v )
    {
      if (!isAgendaViewColorsImmutable())
        mAgendaViewColors = v;
    }

    /**
      Get Color Usage
    */
    int agendaViewColors() const
    {
      return mAgendaViewColors;
    }

    /**
      Is Color Usage Immutable
    */
    bool isAgendaViewColorsImmutable() const
    {
      return isImmutable( QStringLiteral( "AgendaViewColors" ) );
    }

    /**
      Get Item object corresponding to AgendaViewColors()
    */
    ItemEnum *agendaViewColorsItem()
    {
      return mAgendaViewColorsItem;
    }

    /**
      Set Color busy days with a different background color
    */
    void setColorBusyDaysEnabled( bool v )
    {
      if (!isColorBusyDaysEnabledImmutable())
        mColorBusyDaysEnabled = v;
    }

    /**
      Get Color busy days with a different background color
    */
    bool colorBusyDaysEnabled() const
    {
      return mColorBusyDaysEnabled;
    }

    /**
      Is Color busy days with a different background color Immutable
    */
    bool isColorBusyDaysEnabledImmutable() const
    {
      return isImmutable( QStringLiteral( "ColorBusyDaysEnabled" ) );
    }

    /**
      Get Item object corresponding to ColorBusyDaysEnabled()
    */
    ItemBool *colorBusyDaysEnabledItem()
    {
      return mColorBusyDaysEnabledItem;
    }

    /**
      Set Multiple Calendar Display
    */
    void setAgendaViewCalendarDisplay( int v )
    {
      if (!isAgendaViewCalendarDisplayImmutable())
        mAgendaViewCalendarDisplay = v;
    }

    /**
      Get Multiple Calendar Display
    */
    int agendaViewCalendarDisplay() const
    {
      return mAgendaViewCalendarDisplay;
    }

    /**
      Is Multiple Calendar Display Immutable
    */
    bool isAgendaViewCalendarDisplayImmutable() const
    {
      return isImmutable( QStringLiteral( "AgendaViewCalendarDisplay" ) );
    }

    /**
      Get Item object corresponding to AgendaViewCalendarDisplay()
    */
    ItemEnum *agendaViewCalendarDisplayItem()
    {
      return mAgendaViewCalendarDisplayItem;
    }

    /**
      Set Show icons in month view items
    */
    void setEnableMonthItemIcons( bool v )
    {
      if (!isEnableMonthItemIconsImmutable())
        mEnableMonthItemIcons = v;
    }

    /**
      Get Show icons in month view items
    */
    bool enableMonthItemIcons() const
    {
      return mEnableMonthItemIcons;
    }

    /**
      Is Show icons in month view items Immutable
    */
    bool isEnableMonthItemIconsImmutable() const
    {
      return isImmutable( QStringLiteral( "EnableMonthItemIcons" ) );
    }

    /**
      Get Item object corresponding to EnableMonthItemIcons()
    */
    ItemBool *enableMonthItemIconsItem()
    {
      return mEnableMonthItemIconsItem;
    }

    /**
      Set Show start-times without end-times in month view items
    */
    void setShowTimeInMonthView( bool v )
    {
      if (!isShowTimeInMonthViewImmutable())
        mShowTimeInMonthView = v;
    }

    /**
      Get Show start-times without end-times in month view items
    */
    bool showTimeInMonthView() const
    {
      return mShowTimeInMonthView;
    }

    /**
      Is Show start-times without end-times in month view items Immutable
    */
    bool isShowTimeInMonthViewImmutable() const
    {
      return isImmutable( QStringLiteral( "ShowTimeInMonthView" ) );
    }

    /**
      Get Item object corresponding to ShowTimeInMonthView()
    */
    ItemBool *showTimeInMonthViewItem()
    {
      return mShowTimeInMonthViewItem;
    }

    /**
      Set Show the start-time and the end-time in month view items
    */
    void setShowEndTimeInMonthView( bool v )
    {
      if (!isShowEndTimeInMonthViewImmutable())
        mShowEndTimeInMonthView = v;
    }

    /**
      Get Show the start-time and the end-time in month view items
    */
    bool showEndTimeInMonthView() const
    {
      return mShowEndTimeInMonthView;
    }

    /**
      Is Show the start-time and the end-time in month view items Immutable
    */
    bool isShowEndTimeInMonthViewImmutable() const
    {
      return isImmutable( QStringLiteral( "ShowEndTimeInMonthView" ) );
    }

    /**
      Get Item object corresponding to ShowEndTimeInMonthView()
    */
    ItemBool *showEndTimeInMonthViewItem()
    {
      return mShowEndTimeInMonthViewItem;
    }

    /**
      Set Show to-dos
    */
    void setShowTodosMonthView( bool v )
    {
      if (!isShowTodosMonthViewImmutable())
        mShowTodosMonthView = v;
    }

    /**
      Get Show to-dos
    */
    bool showTodosMonthView() const
    {
      return mShowTodosMonthView;
    }

    /**
      Is Show to-dos Immutable
    */
    bool isShowTodosMonthViewImmutable() const
    {
      return isImmutable( QStringLiteral( "ShowTodosMonthView" ) );
    }

    /**
      Get Item object corresponding to ShowTodosMonthView()
    */
    ItemBool *showTodosMonthViewItem()
    {
      return mShowTodosMonthViewItem;
    }

    /**
      Set Show journals
    */
    void setShowJournalsMonthView( bool v )
    {
      if (!isShowJournalsMonthViewImmutable())
        mShowJournalsMonthView = v;
    }

    /**
      Get Show journals
    */
    bool showJournalsMonthView() const
    {
      return mShowJournalsMonthView;
    }

    /**
      Is Show journals Immutable
    */
    bool isShowJournalsMonthViewImmutable() const
    {
      return isImmutable( QStringLiteral( "ShowJournalsMonthView" ) );
    }

    /**
      Get Item object corresponding to ShowJournalsMonthView()
    */
    ItemBool *showJournalsMonthViewItem()
    {
      return mShowJournalsMonthViewItem;
    }

    /**
      Set Show holidays
    */
    void setShowHolidaysMonthView( bool v )
    {
      if (!isShowHolidaysMonthViewImmutable())
        mShowHolidaysMonthView = v;
    }

    /**
      Get Show holidays
    */
    bool showHolidaysMonthView() const
    {
      return mShowHolidaysMonthView;
    }

    /**
      Is Show holidays Immutable
    */
    bool isShowHolidaysMonthViewImmutable() const
    {
      return isImmutable( QStringLiteral( "ShowHolidaysMonthView" ) );
    }

    /**
      Get Item object corresponding to ShowHolidaysMonthView()
    */
    ItemBool *showHolidaysMonthViewItem()
    {
      return mShowHolidaysMonthViewItem;
    }

    /**
      Set Use the Holiday background color when a holiday lands on the date
    */
    void setShowHolidaysBackgroundMonthView( bool v )
    {
      if (!isShowHolidaysBackgroundMonthViewImmutable())
        mShowHolidaysBackgroundMonthView = v;
    }

    /**
      Get Use the Holiday background color when a holiday lands on the date
    */
    bool showHolidaysBackgroundMonthView() const
    {
      return mShowHolidaysBackgroundMonthView;
    }

    /**
      Is Use the Holiday background color when a holiday lands on the date Immutable
    */
    bool isShowHolidaysBackgroundMonthViewImmutable() const
    {
      return isImmutable( QStringLiteral( "ShowHolidaysBackgroundMonthView" ) );
    }

    /**
      Get Item object corresponding to ShowHolidaysBackgroundMonthView()
    */
    ItemBool *showHolidaysBackgroundMonthViewItem()
    {
      return mShowHolidaysBackgroundMonthViewItem;
    }

    /**
      Set Month view uses full window
    */
    void setFullViewMonth( bool v )
    {
      if (!isFullViewMonthImmutable())
        mFullViewMonth = v;
    }

    /**
      Get Month view uses full window
    */
    bool fullViewMonth() const
    {
      return mFullViewMonth;
    }

    /**
      Is Month view uses full window Immutable
    */
    bool isFullViewMonthImmutable() const
    {
      return isImmutable( QStringLiteral( "FullViewMonth" ) );
    }

    /**
      Get Item object corresponding to FullViewMonth()
    */
    ItemBool *fullViewMonthItem()
    {
      return mFullViewMonthItem;
    }

    /**
      Set Color Usage
    */
    void setMonthViewColors( int v )
    {
      if (!isMonthViewColorsImmutable())
        mMonthViewColors = v;
    }

    /**
      Get Color Usage
    */
    int monthViewColors() const
    {
      return mMonthViewColors;
    }

    /**
      Is Color Usage Immutable
    */
    bool isMonthViewColorsImmutable() const
    {
      return isImmutable( QStringLiteral( "MonthViewColors" ) );
    }

    /**
      Get Item object corresponding to MonthViewColors()
    */
    ItemEnum *monthViewColorsItem()
    {
      return mMonthViewColorsItem;
    }

    /**
      Set Always display completed to-dos at the bottom of the list
    */
    void setSortCompletedTodosSeparately( bool v )
    {
      if (!isSortCompletedTodosSeparatelyImmutable())
        mSortCompletedTodosSeparately = v;
    }

    /**
      Get Always display completed to-dos at the bottom of the list
    */
    bool sortCompletedTodosSeparately() const
    {
      return mSortCompletedTodosSeparately;
    }

    /**
      Is Always display completed to-dos at the bottom of the list Immutable
    */
    bool isSortCompletedTodosSeparatelyImmutable() const
    {
      return isImmutable( QStringLiteral( "SortCompletedTodosSeparately" ) );
    }

    /**
      Get Item object corresponding to SortCompletedTodosSeparately()
    */
    ItemBool *sortCompletedTodosSeparatelyItem()
    {
      return mSortCompletedTodosSeparatelyItem;
    }

    /**
      Set To-do list view uses full window
    */
    void setFullViewTodo( bool v )
    {
      if (!isFullViewTodoImmutable())
        mFullViewTodo = v;
    }

    /**
      Get To-do list view uses full window
    */
    bool fullViewTodo() const
    {
      return mFullViewTodo;
    }

    /**
      Is To-do list view uses full window Immutable
    */
    bool isFullViewTodoImmutable() const
    {
      return isImmutable( QStringLiteral( "FullViewTodo" ) );
    }

    /**
      Get Item object corresponding to FullViewTodo()
    */
    ItemBool *fullViewTodoItem()
    {
      return mFullViewTodoItem;
    }

    /**
      Set Display to-dos in a flat list
    */
    void setFlatListTodo( bool v )
    {
      if (!isFlatListTodoImmutable())
        mFlatListTodo = v;
    }

    /**
      Get Display to-dos in a flat list
    */
    bool flatListTodo() const
    {
      return mFlatListTodo;
    }

    /**
      Is Display to-dos in a flat list Immutable
    */
    bool isFlatListTodoImmutable() const
    {
      return isImmutable( QStringLiteral( "FlatListTodo" ) );
    }

    /**
      Get Item object corresponding to FlatListTodo()
    */
    ItemBool *flatListTodoItem()
    {
      return mFlatListTodoItem;
    }

    /**
      Set Record completed to-dos in journal entries
    */
    void setRecordTodosInJournals( bool v )
    {
      if (!isRecordTodosInJournalsImmutable())
        mRecordTodosInJournals = v;
    }

    /**
      Get Record completed to-dos in journal entries
    */
    bool recordTodosInJournals() const
    {
      return mRecordTodosInJournals;
    }

    /**
      Is Record completed to-dos in journal entries Immutable
    */
    bool isRecordTodosInJournalsImmutable() const
    {
      return isImmutable( QStringLiteral( "RecordTodosInJournals" ) );
    }

    /**
      Get Item object corresponding to RecordTodosInJournals()
    */
    ItemBool *recordTodosInJournalsItem()
    {
      return mRecordTodosInJournalsItem;
    }

    /**
      Set Holiday color
    */
    void setHolidayColor( const QColor & v )
    {
      if (!isHolidayColorImmutable())
        mHolidayColor = v;
    }

    /**
      Get Holiday color
    */
    QColor holidayColor() const
    {
      return mHolidayColor;
    }

    /**
      Is Holiday color Immutable
    */
    bool isHolidayColorImmutable() const
    {
      return isImmutable( QStringLiteral( "HolidayColor" ) );
    }

    /**
      Get Item object corresponding to HolidayColor()
    */
    ItemColor *holidayColorItem()
    {
      return mHolidayColorItem;
    }

    /**
      Set Agenda view background color
    */
    void setAgendaBgColor( const QColor & v )
    {
      if (!isAgendaBgColorImmutable())
        mAgendaBgColor = v;
    }

    /**
      Get Agenda view background color
    */
    QColor agendaBgColor() const
    {
      return mAgendaBgColor;
    }

    /**
      Is Agenda view background color Immutable
    */
    bool isAgendaBgColorImmutable() const
    {
      return isImmutable( QStringLiteral( "AgendaBgColor" ) );
    }

    /**
      Get Item object corresponding to AgendaBgColor()
    */
    ItemColor *agendaBgColorItem()
    {
      return mAgendaBgColorItem;
    }

    /**
      Set Agenda view current-time (Marcus Bains) line color
    */
    void setAgendaMarcusBainsLineLineColor( const QColor & v )
    {
      if (!isAgendaMarcusBainsLineLineColorImmutable())
        mAgendaMarcusBainsLineLineColor = v;
    }

    /**
      Get Agenda view current-time (Marcus Bains) line color
    */
    QColor agendaMarcusBainsLineLineColor() const
    {
      return mAgendaMarcusBainsLineLineColor;
    }

    /**
      Is Agenda view current-time (Marcus Bains) line color Immutable
    */
    bool isAgendaMarcusBainsLineLineColorImmutable() const
    {
      return isImmutable( QStringLiteral( "AgendaMarcusBainsLineLineColor" ) );
    }

    /**
      Get Item object corresponding to AgendaMarcusBainsLineLineColor()
    */
    ItemColor *agendaMarcusBainsLineLineColorItem()
    {
      return mAgendaMarcusBainsLineLineColorItem;
    }

    /**
      Set Busy days background color
    */
    void setViewBgBusyColor( const QColor & v )
    {
      if (!isViewBgBusyColorImmutable())
        mViewBgBusyColor = v;
    }

    /**
      Get Busy days background color
    */
    QColor viewBgBusyColor() const
    {
      return mViewBgBusyColor;
    }

    /**
      Is Busy days background color Immutable
    */
    bool isViewBgBusyColorImmutable() const
    {
      return isImmutable( QStringLiteral( "ViewBgBusyColor" ) );
    }

    /**
      Get Item object corresponding to ViewBgBusyColor()
    */
    ItemColor *viewBgBusyColorItem()
    {
      return mViewBgBusyColorItem;
    }

    /**
      Set Working hours color
    */
    void setWorkingHoursColor( const QColor & v )
    {
      if (!isWorkingHoursColorImmutable())
        mWorkingHoursColor = v;
    }

    /**
      Get Working hours color
    */
    QColor workingHoursColor() const
    {
      return mWorkingHoursColor;
    }

    /**
      Is Working hours color Immutable
    */
    bool isWorkingHoursColorImmutable() const
    {
      return isImmutable( QStringLiteral( "WorkingHoursColor" ) );
    }

    /**
      Get Item object corresponding to WorkingHoursColor()
    */
    ItemColor *workingHoursColorItem()
    {
      return mWorkingHoursColorItem;
    }

    /**
      Set To-do due today color
    */
    void setTodoDueTodayColor( const QColor & v )
    {
      if (!isTodoDueTodayColorImmutable())
        mTodoDueTodayColor = v;
    }

    /**
      Get To-do due today color
    */
    QColor todoDueTodayColor() const
    {
      return mTodoDueTodayColor;
    }

    /**
      Is To-do due today color Immutable
    */
    bool isTodoDueTodayColorImmutable() const
    {
      return isImmutable( QStringLiteral( "TodoDueTodayColor" ) );
    }

    /**
      Get Item object corresponding to TodoDueTodayColor()
    */
    ItemColor *todoDueTodayColorItem()
    {
      return mTodoDueTodayColorItem;
    }

    /**
      Set To-do overdue color
    */
    void setTodoOverdueColor( const QColor & v )
    {
      if (!isTodoOverdueColorImmutable())
        mTodoOverdueColor = v;
    }

    /**
      Get To-do overdue color
    */
    QColor todoOverdueColor() const
    {
      return mTodoOverdueColor;
    }

    /**
      Is To-do overdue color Immutable
    */
    bool isTodoOverdueColorImmutable() const
    {
      return isImmutable( QStringLiteral( "TodoOverdueColor" ) );
    }

    /**
      Get Item object corresponding to TodoOverdueColor()
    */
    ItemColor *todoOverdueColorItem()
    {
      return mTodoOverdueColorItem;
    }

    /**
      Set Month view today background color
    */
    void setMonthTodayColor( const QColor & v )
    {
      if (!isMonthTodayColorImmutable())
        mMonthTodayColor = v;
    }

    /**
      Get Month view today background color
    */
    QColor monthTodayColor() const
    {
      return mMonthTodayColor;
    }

    /**
      Is Month view today background color Immutable
    */
    bool isMonthTodayColorImmutable() const
    {
      return isImmutable( QStringLiteral( "MonthTodayColor" ) );
    }

    /**
      Get Item object corresponding to MonthTodayColor()
    */
    ItemColor *monthTodayColorItem()
    {
      return mMonthTodayColorItem;
    }

    /**
      Set Time bar
    */
    void setAgendaTimeLabelsFont( const QFont & v )
    {
      if (!isAgendaTimeLabelsFontImmutable())
        mAgendaTimeLabelsFont = v;
    }

    /**
      Get Time bar
    */
    QFont agendaTimeLabelsFont() const
    {
      return mAgendaTimeLabelsFont;
    }

    /**
      Is Time bar Immutable
    */
    bool isAgendaTimeLabelsFontImmutable() const
    {
      return isImmutable( QStringLiteral( "AgendaTimeLabelsFont" ) );
    }

    /**
      Get Item object corresponding to AgendaTimeLabelsFont()
    */
    ItemFont *agendaTimeLabelsFontItem()
    {
      return mAgendaTimeLabelsFontItem;
    }

    /**
      Set Month view
    */
    void setMonthViewFont( const QFont & v )
    {
      if (!isMonthViewFontImmutable())
        mMonthViewFont = v;
    }

    /**
      Get Month view
    */
    QFont monthViewFont() const
    {
      return mMonthViewFont;
    }

    /**
      Is Month view Immutable
    */
    bool isMonthViewFontImmutable() const
    {
      return isImmutable( QStringLiteral( "MonthViewFont" ) );
    }

    /**
      Get Item object corresponding to MonthViewFont()
    */
    ItemFont *monthViewFontItem()
    {
      return mMonthViewFontItem;
    }

    /**
      Set Agenda view
    */
    void setAgendaViewFont( const QFont & v )
    {
      if (!isAgendaViewFontImmutable())
        mAgendaViewFont = v;
    }

    /**
      Get Agenda view
    */
    QFont agendaViewFont() const
    {
      return mAgendaViewFont;
    }

    /**
      Is Agenda view Immutable
    */
    bool isAgendaViewFontImmutable() const
    {
      return isImmutable( QStringLiteral( "AgendaViewFont" ) );
    }

    /**
      Get Item object corresponding to AgendaViewFont()
    */
    ItemFont *agendaViewFontItem()
    {
      return mAgendaViewFontItem;
    }

    /**
      Set Current-time (Marcus Bains) line
    */
    void setAgendaMarcusBainsLineFont( const QFont & v )
    {
      if (!isAgendaMarcusBainsLineFontImmutable())
        mAgendaMarcusBainsLineFont = v;
    }

    /**
      Get Current-time (Marcus Bains) line
    */
    QFont agendaMarcusBainsLineFont() const
    {
      return mAgendaMarcusBainsLineFont;
    }

    /**
      Is Current-time (Marcus Bains) line Immutable
    */
    bool isAgendaMarcusBainsLineFontImmutable() const
    {
      return isImmutable( QStringLiteral( "AgendaMarcusBainsLineFont" ) );
    }

    /**
      Get Item object corresponding to AgendaMarcusBainsLineFont()
    */
    ItemFont *agendaMarcusBainsLineFontItem()
    {
      return mAgendaMarcusBainsLineFontItem;
    }

    /**
      Set SelectedPlugins
    */
    void setSelectedPlugins( const QStringList & v )
    {
      if (!isSelectedPluginsImmutable())
        mSelectedPlugins = v;
    }

    /**
      Get SelectedPlugins
    */
    QStringList selectedPlugins() const
    {
      return mSelectedPlugins;
    }

    /**
      Is SelectedPlugins Immutable
    */
    bool isSelectedPluginsImmutable() const
    {
      return isImmutable( QStringLiteral( "SelectedPlugins" ) );
    }

    /**
      Get Item object corresponding to SelectedPlugins()
    */
    ItemStringList *selectedPluginsItem()
    {
      return mSelectedPluginsItem;
    }

    /**
      Set Quick Todo
    */
    void setEnableQuickTodo( bool v )
    {
      if (!isEnableQuickTodoImmutable())
        mEnableQuickTodo = v;
    }

    /**
      Get Quick Todo
    */
    bool enableQuickTodo() const
    {
      return mEnableQuickTodo;
    }

    /**
      Is Quick Todo Immutable
    */
    bool isEnableQuickTodoImmutable() const
    {
      return isImmutable( QStringLiteral( "EnableQuickTodo" ) );
    }

    /**
      Get Item object corresponding to EnableQuickTodo()
    */
    ItemBool *enableQuickTodoItem()
    {
      return mEnableQuickTodoItem;
    }

    /**
      Set Todo Quick Search
    */
    void setEnableTodoQuickSearch( bool v )
    {
      if (!isEnableTodoQuickSearchImmutable())
        mEnableTodoQuickSearch = v;
    }

    /**
      Get Todo Quick Search
    */
    bool enableTodoQuickSearch() const
    {
      return mEnableTodoQuickSearch;
    }

    /**
      Is Todo Quick Search Immutable
    */
    bool isEnableTodoQuickSearchImmutable() const
    {
      return isImmutable( QStringLiteral( "EnableTodoQuickSearch" ) );
    }

    /**
      Get Item object corresponding to EnableTodoQuickSearch()
    */
    ItemBool *enableTodoQuickSearchItem()
    {
      return mEnableTodoQuickSearchItem;
    }

    /**
      Set Default todo attachment method
    */
    void setDefaultTodoAttachMethod( int v )
    {
      if (!isDefaultTodoAttachMethodImmutable())
        mDefaultTodoAttachMethod = v;
    }

    /**
      Get Default todo attachment method
    */
    int defaultTodoAttachMethod() const
    {
      return mDefaultTodoAttachMethod;
    }

    /**
      Is Default todo attachment method Immutable
    */
    bool isDefaultTodoAttachMethodImmutable() const
    {
      return isImmutable( QStringLiteral( "DefaultTodoAttachMethod" ) );
    }

    /**
      Get Item object corresponding to DefaultTodoAttachMethod()
    */
    ItemEnum *defaultTodoAttachMethodItem()
    {
      return mDefaultTodoAttachMethodItem;
    }

    /**
      Set CompactDialogs
    */
    void setCompactDialogs( bool v )
    {
      if (!isCompactDialogsImmutable())
        mCompactDialogs = v;
    }

    /**
      Get CompactDialogs
    */
    bool compactDialogs() const
    {
      return mCompactDialogs;
    }

    /**
      Is CompactDialogs Immutable
    */
    bool isCompactDialogsImmutable() const
    {
      return isImmutable( QStringLiteral( "CompactDialogs" ) );
    }

    /**
      Get Item object corresponding to CompactDialogs()
    */
    ItemBool *compactDialogsItem()
    {
      return mCompactDialogsItem;
    }

    /**
      Set ShowMenuBar
    */
    void setShowMenuBar( bool v )
    {
      if (!isShowMenuBarImmutable())
        mShowMenuBar = v;
    }

    /**
      Get ShowMenuBar
    */
    bool showMenuBar() const
    {
      return mShowMenuBar;
    }

    /**
      Is ShowMenuBar Immutable
    */
    bool isShowMenuBarImmutable() const
    {
      return isImmutable( QStringLiteral( "ShowMenuBar" ) );
    }

    /**
      Get Item object corresponding to ShowMenuBar()
    */
    ItemBool *showMenuBarItem()
    {
      return mShowMenuBarItem;
    }

    /**
      Set Work Week Mask
    */
    void setWorkWeekMask( int v )
    {
      if (!isWorkWeekMaskImmutable())
        mWorkWeekMask = v;
    }

    /**
      Get Work Week Mask
    */
    int workWeekMask() const
    {
      return mWorkWeekMask;
    }

    /**
      Is Work Week Mask Immutable
    */
    bool isWorkWeekMaskImmutable() const
    {
      return isImmutable( QStringLiteral( "WorkWeekMask" ) );
    }

    /**
      Get Item object corresponding to WorkWeekMask()
    */
    ItemInt *workWeekMaskItem()
    {
      return mWorkWeekMaskItem;
    }

    /**
      Set DefaultResourceColorSeed
    */
    void setDefaultResourceColorSeed( int v )
    {
      if (!isDefaultResourceColorSeedImmutable())
        mDefaultResourceColorSeed = v;
    }

    /**
      Get DefaultResourceColorSeed
    */
    int defaultResourceColorSeed() const
    {
      return mDefaultResourceColorSeed;
    }

    /**
      Is DefaultResourceColorSeed Immutable
    */
    bool isDefaultResourceColorSeedImmutable() const
    {
      return isImmutable( QStringLiteral( "DefaultResourceColorSeed" ) );
    }

    /**
      Get Item object corresponding to DefaultResourceColorSeed()
    */
    ItemInt *defaultResourceColorSeedItem()
    {
      return mDefaultResourceColorSeedItem;
    }

    /**
      Set DefaultResourceColors
    */
    void setDefaultResourceColors( const QStringList & v )
    {
      if (!isDefaultResourceColorsImmutable())
        mDefaultResourceColors = v;
    }

    /**
      Get DefaultResourceColors
    */
    QStringList defaultResourceColors() const
    {
      return mDefaultResourceColors;
    }

    /**
      Is DefaultResourceColors Immutable
    */
    bool isDefaultResourceColorsImmutable() const
    {
      return isImmutable( QStringLiteral( "DefaultResourceColors" ) );
    }

    /**
      Get Item object corresponding to DefaultResourceColors()
    */
    ItemStringList *defaultResourceColorsItem()
    {
      return mDefaultResourceColorsItem;
    }

    /**
      Set AssignDefaultResourceColors
    */
    void setAssignDefaultResourceColors( bool v )
    {
      if (!isAssignDefaultResourceColorsImmutable())
        mAssignDefaultResourceColors = v;
    }

    /**
      Get AssignDefaultResourceColors
    */
    bool assignDefaultResourceColors() const
    {
      return mAssignDefaultResourceColors;
    }

    /**
      Is AssignDefaultResourceColors Immutable
    */
    bool isAssignDefaultResourceColorsImmutable() const
    {
      return isImmutable( QStringLiteral( "AssignDefaultResourceColors" ) );
    }

    /**
      Get Item object corresponding to AssignDefaultResourceColors()
    */
    ItemBool *assignDefaultResourceColorsItem()
    {
      return mAssignDefaultResourceColorsItem;
    }

    /**
      Set Decorations At Month View Top
    */
    void setDecorationsAtMonthViewTop( const QStringList & v )
    {
      if (!isDecorationsAtMonthViewTopImmutable())
        mDecorationsAtMonthViewTop = v;
    }

    /**
      Get Decorations At Month View Top
    */
    QStringList decorationsAtMonthViewTop() const
    {
      return mDecorationsAtMonthViewTop;
    }

    /**
      Is Decorations At Month View Top Immutable
    */
    bool isDecorationsAtMonthViewTopImmutable() const
    {
      return isImmutable( QStringLiteral( "DecorationsAtMonthViewTop" ) );
    }

    /**
      Get Item object corresponding to DecorationsAtMonthViewTop()
    */
    ItemStringList *decorationsAtMonthViewTopItem()
    {
      return mDecorationsAtMonthViewTopItem;
    }

    /**
      Set Decorations At Agenda View Top
    */
    void setDecorationsAtAgendaViewTop( const QStringList & v )
    {
      if (!isDecorationsAtAgendaViewTopImmutable())
        mDecorationsAtAgendaViewTop = v;
    }

    /**
      Get Decorations At Agenda View Top
    */
    QStringList decorationsAtAgendaViewTop() const
    {
      return mDecorationsAtAgendaViewTop;
    }

    /**
      Is Decorations At Agenda View Top Immutable
    */
    bool isDecorationsAtAgendaViewTopImmutable() const
    {
      return isImmutable( QStringLiteral( "DecorationsAtAgendaViewTop" ) );
    }

    /**
      Get Item object corresponding to DecorationsAtAgendaViewTop()
    */
    ItemStringList *decorationsAtAgendaViewTopItem()
    {
      return mDecorationsAtAgendaViewTopItem;
    }

    /**
      Set Decorations At Agenda View Bottom
    */
    void setDecorationsAtAgendaViewBottom( const QStringList & v )
    {
      if (!isDecorationsAtAgendaViewBottomImmutable())
        mDecorationsAtAgendaViewBottom = v;
    }

    /**
      Get Decorations At Agenda View Bottom
    */
    QStringList decorationsAtAgendaViewBottom() const
    {
      return mDecorationsAtAgendaViewBottom;
    }

    /**
      Is Decorations At Agenda View Bottom Immutable
    */
    bool isDecorationsAtAgendaViewBottomImmutable() const
    {
      return isImmutable( QStringLiteral( "DecorationsAtAgendaViewBottom" ) );
    }

    /**
      Get Item object corresponding to DecorationsAtAgendaViewBottom()
    */
    ItemStringList *decorationsAtAgendaViewBottomItem()
    {
      return mDecorationsAtAgendaViewBottomItem;
    }

    /**
      Set AgendaView Show Sidebar
    */
    void setAgendaViewShowSidebar( bool v )
    {
      if (!isAgendaViewShowSidebarImmutable())
        mAgendaViewShowSidebar = v;
    }

    /**
      Get AgendaView Show Sidebar
    */
    bool agendaViewShowSidebar() const
    {
      return mAgendaViewShowSidebar;
    }

    /**
      Is AgendaView Show Sidebar Immutable
    */
    bool isAgendaViewShowSidebarImmutable() const
    {
      return isImmutable( QStringLiteral( "AgendaViewShowSidebar" ) );
    }

    /**
      Get Item object corresponding to AgendaViewShowSidebar()
    */
    ItemBool *agendaViewShowSidebarItem()
    {
      return mAgendaViewShowSidebarItem;
    }

    /**
      Set JournalView Show Sidebar
    */
    void setJournalViewShowSidebar( bool v )
    {
      if (!isJournalViewShowSidebarImmutable())
        mJournalViewShowSidebar = v;
    }

    /**
      Get JournalView Show Sidebar
    */
    bool journalViewShowSidebar() const
    {
      return mJournalViewShowSidebar;
    }

    /**
      Is JournalView Show Sidebar Immutable
    */
    bool isJournalViewShowSidebarImmutable() const
    {
      return isImmutable( QStringLiteral( "JournalViewShowSidebar" ) );
    }

    /**
      Get Item object corresponding to JournalViewShowSidebar()
    */
    ItemBool *journalViewShowSidebarItem()
    {
      return mJournalViewShowSidebarItem;
    }

    /**
      Set ListView Show Sidebar
    */
    void setListViewShowSidebar( bool v )
    {
      if (!isListViewShowSidebarImmutable())
        mListViewShowSidebar = v;
    }

    /**
      Get ListView Show Sidebar
    */
    bool listViewShowSidebar() const
    {
      return mListViewShowSidebar;
    }

    /**
      Is ListView Show Sidebar Immutable
    */
    bool isListViewShowSidebarImmutable() const
    {
      return isImmutable( QStringLiteral( "ListViewShowSidebar" ) );
    }

    /**
      Get Item object corresponding to ListViewShowSidebar()
    */
    ItemBool *listViewShowSidebarItem()
    {
      return mListViewShowSidebarItem;
    }

    /**
      Set MonthView Show Sidebar
    */
    void setMonthViewShowSidebar( bool v )
    {
      if (!isMonthViewShowSidebarImmutable())
        mMonthViewShowSidebar = v;
    }

    /**
      Get MonthView Show Sidebar
    */
    bool monthViewShowSidebar() const
    {
      return mMonthViewShowSidebar;
    }

    /**
      Is MonthView Show Sidebar Immutable
    */
    bool isMonthViewShowSidebarImmutable() const
    {
      return isImmutable( QStringLiteral( "MonthViewShowSidebar" ) );
    }

    /**
      Get Item object corresponding to MonthViewShowSidebar()
    */
    ItemBool *monthViewShowSidebarItem()
    {
      return mMonthViewShowSidebarItem;
    }

    /**
      Set TimelineView Show Sidebar
    */
    void setTimelineViewShowSidebar( bool v )
    {
      if (!isTimelineViewShowSidebarImmutable())
        mTimelineViewShowSidebar = v;
    }

    /**
      Get TimelineView Show Sidebar
    */
    bool timelineViewShowSidebar() const
    {
      return mTimelineViewShowSidebar;
    }

    /**
      Is TimelineView Show Sidebar Immutable
    */
    bool isTimelineViewShowSidebarImmutable() const
    {
      return isImmutable( QStringLiteral( "TimelineViewShowSidebar" ) );
    }

    /**
      Get Item object corresponding to TimelineViewShowSidebar()
    */
    ItemBool *timelineViewShowSidebarItem()
    {
      return mTimelineViewShowSidebarItem;
    }

    /**
      Set TodoView Show Sidebar
    */
    void setTodoViewShowSidebar( bool v )
    {
      if (!isTodoViewShowSidebarImmutable())
        mTodoViewShowSidebar = v;
    }

    /**
      Get TodoView Show Sidebar
    */
    bool todoViewShowSidebar() const
    {
      return mTodoViewShowSidebar;
    }

    /**
      Is TodoView Show Sidebar Immutable
    */
    bool isTodoViewShowSidebarImmutable() const
    {
      return isImmutable( QStringLiteral( "TodoViewShowSidebar" ) );
    }

    /**
      Get Item object corresponding to TodoViewShowSidebar()
    */
    ItemBool *todoViewShowSidebarItem()
    {
      return mTodoViewShowSidebarItem;
    }

    /**
      Set WhatsNextView Show Sidebar
    */
    void setWhatsNextViewShowSidebar( bool v )
    {
      if (!isWhatsNextViewShowSidebarImmutable())
        mWhatsNextViewShowSidebar = v;
    }

    /**
      Get WhatsNextView Show Sidebar
    */
    bool whatsNextViewShowSidebar() const
    {
      return mWhatsNextViewShowSidebar;
    }

    /**
      Is WhatsNextView Show Sidebar Immutable
    */
    bool isWhatsNextViewShowSidebarImmutable() const
    {
      return isImmutable( QStringLiteral( "WhatsNextViewShowSidebar" ) );
    }

    /**
      Get Item object corresponding to WhatsNextViewShowSidebar()
    */
    ItemBool *whatsNextViewShowSidebarItem()
    {
      return mWhatsNextViewShowSidebarItem;
    }

    /**
      Set Agenda view background color
    */
    void setAgendaGridBackgroundColor( const QColor & v )
    {
      if (!isAgendaGridBackgroundColorImmutable())
        mAgendaGridBackgroundColor = v;
    }

    /**
      Get Agenda view background color
    */
    QColor agendaGridBackgroundColor() const
    {
      return mAgendaGridBackgroundColor;
    }

    /**
      Is Agenda view background color Immutable
    */
    bool isAgendaGridBackgroundColorImmutable() const
    {
      return isImmutable( QStringLiteral( "AgendaGridBackgroundColor" ) );
    }

    /**
      Get Item object corresponding to AgendaGridBackgroundColor()
    */
    ItemColor *agendaGridBackgroundColorItem()
    {
      return mAgendaGridBackgroundColorItem;
    }

    /**
      Set Agenda Grid Background Image
    */
    void setAgendaGridBackgroundImage( const QString & v )
    {
      if (!isAgendaGridBackgroundImageImmutable())
        mAgendaGridBackgroundImage = v;
    }

    /**
      Get Agenda Grid Background Image
    */
    QString agendaGridBackgroundImage() const
    {
      return mAgendaGridBackgroundImage;
    }

    /**
      Is Agenda Grid Background Image Immutable
    */
    bool isAgendaGridBackgroundImageImmutable() const
    {
      return isImmutable( QStringLiteral( "AgendaGridBackgroundImage" ) );
    }

    /**
      Get Item object corresponding to AgendaGridBackgroundImage()
    */
    ItemString *agendaGridBackgroundImageItem()
    {
      return mAgendaGridBackgroundImageItem;
    }

    /**
      Set Highlight color
    */
    void setAgendaGridHighlightColor( const QColor & v )
    {
      if (!isAgendaGridHighlightColorImmutable())
        mAgendaGridHighlightColor = v;
    }

    /**
      Get Highlight color
    */
    QColor agendaGridHighlightColor() const
    {
      return mAgendaGridHighlightColor;
    }

    /**
      Is Highlight color Immutable
    */
    bool isAgendaGridHighlightColorImmutable() const
    {
      return isImmutable( QStringLiteral( "AgendaGridHighlightColor" ) );
    }

    /**
      Get Item object corresponding to AgendaGridHighlightColor()
    */
    ItemColor *agendaGridHighlightColorItem()
    {
      return mAgendaGridHighlightColorItem;
    }

    /**
      Set Agenda Grid WorkHours Background Image
    */
    void setAgendaGridWorkHoursBackgroundImage( const QString & v )
    {
      if (!isAgendaGridWorkHoursBackgroundImageImmutable())
        mAgendaGridWorkHoursBackgroundImage = v;
    }

    /**
      Get Agenda Grid WorkHours Background Image
    */
    QString agendaGridWorkHoursBackgroundImage() const
    {
      return mAgendaGridWorkHoursBackgroundImage;
    }

    /**
      Is Agenda Grid WorkHours Background Image Immutable
    */
    bool isAgendaGridWorkHoursBackgroundImageImmutable() const
    {
      return isImmutable( QStringLiteral( "AgendaGridWorkHoursBackgroundImage" ) );
    }

    /**
      Get Item object corresponding to AgendaGridWorkHoursBackgroundImage()
    */
    ItemString *agendaGridWorkHoursBackgroundImageItem()
    {
      return mAgendaGridWorkHoursBackgroundImageItem;
    }

    /**
      Set Agenda CalendarItems Background Color
    */
    void setAgendaCalendarItemsBackgroundColor( const QColor & v )
    {
      if (!isAgendaCalendarItemsBackgroundColorImmutable())
        mAgendaCalendarItemsBackgroundColor = v;
    }

    /**
      Get Agenda CalendarItems Background Color
    */
    QColor agendaCalendarItemsBackgroundColor() const
    {
      return mAgendaCalendarItemsBackgroundColor;
    }

    /**
      Is Agenda CalendarItems Background Color Immutable
    */
    bool isAgendaCalendarItemsBackgroundColorImmutable() const
    {
      return isImmutable( QStringLiteral( "AgendaCalendarItemsBackgroundColor" ) );
    }

    /**
      Get Item object corresponding to AgendaCalendarItemsBackgroundColor()
    */
    ItemColor *agendaCalendarItemsBackgroundColorItem()
    {
      return mAgendaCalendarItemsBackgroundColorItem;
    }

    /**
      Set Agenda CalendarItems Background Image
    */
    void setAgendaCalendarItemsBackgroundImage( const QString & v )
    {
      if (!isAgendaCalendarItemsBackgroundImageImmutable())
        mAgendaCalendarItemsBackgroundImage = v;
    }

    /**
      Get Agenda CalendarItems Background Image
    */
    QString agendaCalendarItemsBackgroundImage() const
    {
      return mAgendaCalendarItemsBackgroundImage;
    }

    /**
      Is Agenda CalendarItems Background Image Immutable
    */
    bool isAgendaCalendarItemsBackgroundImageImmutable() const
    {
      return isImmutable( QStringLiteral( "AgendaCalendarItemsBackgroundImage" ) );
    }

    /**
      Get Item object corresponding to AgendaCalendarItemsBackgroundImage()
    */
    ItemString *agendaCalendarItemsBackgroundImageItem()
    {
      return mAgendaCalendarItemsBackgroundImageItem;
    }

    /**
      Set Agenda CalendarItems Font
    */
    void setAgendaCalendarItemsFont( const QFont & v )
    {
      if (!isAgendaCalendarItemsFontImmutable())
        mAgendaCalendarItemsFont = v;
    }

    /**
      Get Agenda CalendarItems Font
    */
    QFont agendaCalendarItemsFont() const
    {
      return mAgendaCalendarItemsFont;
    }

    /**
      Is Agenda CalendarItems Font Immutable
    */
    bool isAgendaCalendarItemsFontImmutable() const
    {
      return isImmutable( QStringLiteral( "AgendaCalendarItemsFont" ) );
    }

    /**
      Get Item object corresponding to AgendaCalendarItemsFont()
    */
    ItemFont *agendaCalendarItemsFontItem()
    {
      return mAgendaCalendarItemsFontItem;
    }

    /**
      Set Agenda CalendarItems Frame Color
    */
    void setAgendaCalendarItemsFrameColor( const QColor & v )
    {
      if (!isAgendaCalendarItemsFrameColorImmutable())
        mAgendaCalendarItemsFrameColor = v;
    }

    /**
      Get Agenda CalendarItems Frame Color
    */
    QColor agendaCalendarItemsFrameColor() const
    {
      return mAgendaCalendarItemsFrameColor;
    }

    /**
      Is Agenda CalendarItems Frame Color Immutable
    */
    bool isAgendaCalendarItemsFrameColorImmutable() const
    {
      return isImmutable( QStringLiteral( "AgendaCalendarItemsFrameColor" ) );
    }

    /**
      Get Item object corresponding to AgendaCalendarItemsFrameColor()
    */
    ItemColor *agendaCalendarItemsFrameColorItem()
    {
      return mAgendaCalendarItemsFrameColorItem;
    }

    /**
      Set Agenda CalendarItems Icon
    */
    void setAgendaCalendarItemsIcon( const QString & v )
    {
      if (!isAgendaCalendarItemsIconImmutable())
        mAgendaCalendarItemsIcon = v;
    }

    /**
      Get Agenda CalendarItems Icon
    */
    QString agendaCalendarItemsIcon() const
    {
      return mAgendaCalendarItemsIcon;
    }

    /**
      Is Agenda CalendarItems Icon Immutable
    */
    bool isAgendaCalendarItemsIconImmutable() const
    {
      return isImmutable( QStringLiteral( "AgendaCalendarItemsIcon" ) );
    }

    /**
      Get Item object corresponding to AgendaCalendarItemsIcon()
    */
    ItemString *agendaCalendarItemsIconItem()
    {
      return mAgendaCalendarItemsIconItem;
    }

    /**
      Set Agenda CalendarItems Events Background Image
    */
    void setAgendaCalendarItemsEventsBackgroundImage( const QString & v )
    {
      if (!isAgendaCalendarItemsEventsBackgroundImageImmutable())
        mAgendaCalendarItemsEventsBackgroundImage = v;
    }

    /**
      Get Agenda CalendarItems Events Background Image
    */
    QString agendaCalendarItemsEventsBackgroundImage() const
    {
      return mAgendaCalendarItemsEventsBackgroundImage;
    }

    /**
      Is Agenda CalendarItems Events Background Image Immutable
    */
    bool isAgendaCalendarItemsEventsBackgroundImageImmutable() const
    {
      return isImmutable( QStringLiteral( "AgendaCalendarItemsEventsBackgroundImage" ) );
    }

    /**
      Get Item object corresponding to AgendaCalendarItemsEventsBackgroundImage()
    */
    ItemString *agendaCalendarItemsEventsBackgroundImageItem()
    {
      return mAgendaCalendarItemsEventsBackgroundImageItem;
    }

    /**
      Set Agenda CalendarItems Events Font
    */
    void setAgendaCalendarItemsEventsFont( const QFont & v )
    {
      if (!isAgendaCalendarItemsEventsFontImmutable())
        mAgendaCalendarItemsEventsFont = v;
    }

    /**
      Get Agenda CalendarItems Events Font
    */
    QFont agendaCalendarItemsEventsFont() const
    {
      return mAgendaCalendarItemsEventsFont;
    }

    /**
      Is Agenda CalendarItems Events Font Immutable
    */
    bool isAgendaCalendarItemsEventsFontImmutable() const
    {
      return isImmutable( QStringLiteral( "AgendaCalendarItemsEventsFont" ) );
    }

    /**
      Get Item object corresponding to AgendaCalendarItemsEventsFont()
    */
    ItemFont *agendaCalendarItemsEventsFontItem()
    {
      return mAgendaCalendarItemsEventsFontItem;
    }

    /**
      Set Agenda CalendarItems Events Frame Color
    */
    void setAgendaCalendarItemsEventsFrameColor( const QColor & v )
    {
      if (!isAgendaCalendarItemsEventsFrameColorImmutable())
        mAgendaCalendarItemsEventsFrameColor = v;
    }

    /**
      Get Agenda CalendarItems Events Frame Color
    */
    QColor agendaCalendarItemsEventsFrameColor() const
    {
      return mAgendaCalendarItemsEventsFrameColor;
    }

    /**
      Is Agenda CalendarItems Events Frame Color Immutable
    */
    bool isAgendaCalendarItemsEventsFrameColorImmutable() const
    {
      return isImmutable( QStringLiteral( "AgendaCalendarItemsEventsFrameColor" ) );
    }

    /**
      Get Item object corresponding to AgendaCalendarItemsEventsFrameColor()
    */
    ItemColor *agendaCalendarItemsEventsFrameColorItem()
    {
      return mAgendaCalendarItemsEventsFrameColorItem;
    }

    /**
      Set Agenda CalendarItems Events Icon
    */
    void setAgendaCalendarItemsEventsIcon( const QString & v )
    {
      if (!isAgendaCalendarItemsEventsIconImmutable())
        mAgendaCalendarItemsEventsIcon = v;
    }

    /**
      Get Agenda CalendarItems Events Icon
    */
    QString agendaCalendarItemsEventsIcon() const
    {
      return mAgendaCalendarItemsEventsIcon;
    }

    /**
      Is Agenda CalendarItems Events Icon Immutable
    */
    bool isAgendaCalendarItemsEventsIconImmutable() const
    {
      return isImmutable( QStringLiteral( "AgendaCalendarItemsEventsIcon" ) );
    }

    /**
      Get Item object corresponding to AgendaCalendarItemsEventsIcon()
    */
    ItemString *agendaCalendarItemsEventsIconItem()
    {
      return mAgendaCalendarItemsEventsIconItem;
    }

    /**
      Set Agenda CalendarItems ToDos Background Color
    */
    void setAgendaCalendarItemsToDosBackgroundColor( const QColor & v )
    {
      if (!isAgendaCalendarItemsToDosBackgroundColorImmutable())
        mAgendaCalendarItemsToDosBackgroundColor = v;
    }

    /**
      Get Agenda CalendarItems ToDos Background Color
    */
    QColor agendaCalendarItemsToDosBackgroundColor() const
    {
      return mAgendaCalendarItemsToDosBackgroundColor;
    }

    /**
      Is Agenda CalendarItems ToDos Background Color Immutable
    */
    bool isAgendaCalendarItemsToDosBackgroundColorImmutable() const
    {
      return isImmutable( QStringLiteral( "AgendaCalendarItemsToDosBackgroundColor" ) );
    }

    /**
      Get Item object corresponding to AgendaCalendarItemsToDosBackgroundColor()
    */
    ItemColor *agendaCalendarItemsToDosBackgroundColorItem()
    {
      return mAgendaCalendarItemsToDosBackgroundColorItem;
    }

    /**
      Set Agenda CalendarItems ToDos Background Image
    */
    void setAgendaCalendarItemsToDosBackgroundImage( const QString & v )
    {
      if (!isAgendaCalendarItemsToDosBackgroundImageImmutable())
        mAgendaCalendarItemsToDosBackgroundImage = v;
    }

    /**
      Get Agenda CalendarItems ToDos Background Image
    */
    QString agendaCalendarItemsToDosBackgroundImage() const
    {
      return mAgendaCalendarItemsToDosBackgroundImage;
    }

    /**
      Is Agenda CalendarItems ToDos Background Image Immutable
    */
    bool isAgendaCalendarItemsToDosBackgroundImageImmutable() const
    {
      return isImmutable( QStringLiteral( "AgendaCalendarItemsToDosBackgroundImage" ) );
    }

    /**
      Get Item object corresponding to AgendaCalendarItemsToDosBackgroundImage()
    */
    ItemString *agendaCalendarItemsToDosBackgroundImageItem()
    {
      return mAgendaCalendarItemsToDosBackgroundImageItem;
    }

    /**
      Set Agenda CalendarItems ToDos Font
    */
    void setAgendaCalendarItemsToDosFont( const QFont & v )
    {
      if (!isAgendaCalendarItemsToDosFontImmutable())
        mAgendaCalendarItemsToDosFont = v;
    }

    /**
      Get Agenda CalendarItems ToDos Font
    */
    QFont agendaCalendarItemsToDosFont() const
    {
      return mAgendaCalendarItemsToDosFont;
    }

    /**
      Is Agenda CalendarItems ToDos Font Immutable
    */
    bool isAgendaCalendarItemsToDosFontImmutable() const
    {
      return isImmutable( QStringLiteral( "AgendaCalendarItemsToDosFont" ) );
    }

    /**
      Get Item object corresponding to AgendaCalendarItemsToDosFont()
    */
    ItemFont *agendaCalendarItemsToDosFontItem()
    {
      return mAgendaCalendarItemsToDosFontItem;
    }

    /**
      Set Agenda CalendarItems ToDos Frame Color
    */
    void setAgendaCalendarItemsToDosFrameColor( const QColor & v )
    {
      if (!isAgendaCalendarItemsToDosFrameColorImmutable())
        mAgendaCalendarItemsToDosFrameColor = v;
    }

    /**
      Get Agenda CalendarItems ToDos Frame Color
    */
    QColor agendaCalendarItemsToDosFrameColor() const
    {
      return mAgendaCalendarItemsToDosFrameColor;
    }

    /**
      Is Agenda CalendarItems ToDos Frame Color Immutable
    */
    bool isAgendaCalendarItemsToDosFrameColorImmutable() const
    {
      return isImmutable( QStringLiteral( "AgendaCalendarItemsToDosFrameColor" ) );
    }

    /**
      Get Item object corresponding to AgendaCalendarItemsToDosFrameColor()
    */
    ItemColor *agendaCalendarItemsToDosFrameColorItem()
    {
      return mAgendaCalendarItemsToDosFrameColorItem;
    }

    /**
      Set Agenda CalendarItems ToDos Icon
    */
    void setAgendaCalendarItemsToDosIcon( const QString & v )
    {
      if (!isAgendaCalendarItemsToDosIconImmutable())
        mAgendaCalendarItemsToDosIcon = v;
    }

    /**
      Get Agenda CalendarItems ToDos Icon
    */
    QString agendaCalendarItemsToDosIcon() const
    {
      return mAgendaCalendarItemsToDosIcon;
    }

    /**
      Is Agenda CalendarItems ToDos Icon Immutable
    */
    bool isAgendaCalendarItemsToDosIconImmutable() const
    {
      return isImmutable( QStringLiteral( "AgendaCalendarItemsToDosIcon" ) );
    }

    /**
      Get Item object corresponding to AgendaCalendarItemsToDosIcon()
    */
    ItemString *agendaCalendarItemsToDosIconItem()
    {
      return mAgendaCalendarItemsToDosIconItem;
    }

    /**
      Set Agenda CalendarItems ToDos DueToday Background Image
    */
    void setAgendaCalendarItemsToDosDueTodayBackgroundImage( const QString & v )
    {
      if (!isAgendaCalendarItemsToDosDueTodayBackgroundImageImmutable())
        mAgendaCalendarItemsToDosDueTodayBackgroundImage = v;
    }

    /**
      Get Agenda CalendarItems ToDos DueToday Background Image
    */
    QString agendaCalendarItemsToDosDueTodayBackgroundImage() const
    {
      return mAgendaCalendarItemsToDosDueTodayBackgroundImage;
    }

    /**
      Is Agenda CalendarItems ToDos DueToday Background Image Immutable
    */
    bool isAgendaCalendarItemsToDosDueTodayBackgroundImageImmutable() const
    {
      return isImmutable( QStringLiteral( "AgendaCalendarItemsToDosDueTodayBackgroundImage" ) );
    }

    /**
      Get Item object corresponding to AgendaCalendarItemsToDosDueTodayBackgroundImage()
    */
    ItemString *agendaCalendarItemsToDosDueTodayBackgroundImageItem()
    {
      return mAgendaCalendarItemsToDosDueTodayBackgroundImageItem;
    }

    /**
      Set Agenda CalendarItems ToDos DueToday Font
    */
    void setAgendaCalendarItemsToDosDueTodayFont( const QFont & v )
    {
      if (!isAgendaCalendarItemsToDosDueTodayFontImmutable())
        mAgendaCalendarItemsToDosDueTodayFont = v;
    }

    /**
      Get Agenda CalendarItems ToDos DueToday Font
    */
    QFont agendaCalendarItemsToDosDueTodayFont() const
    {
      return mAgendaCalendarItemsToDosDueTodayFont;
    }

    /**
      Is Agenda CalendarItems ToDos DueToday Font Immutable
    */
    bool isAgendaCalendarItemsToDosDueTodayFontImmutable() const
    {
      return isImmutable( QStringLiteral( "AgendaCalendarItemsToDosDueTodayFont" ) );
    }

    /**
      Get Item object corresponding to AgendaCalendarItemsToDosDueTodayFont()
    */
    ItemFont *agendaCalendarItemsToDosDueTodayFontItem()
    {
      return mAgendaCalendarItemsToDosDueTodayFontItem;
    }

    /**
      Set Agenda CalendarItems ToDos DueToday Frame Color
    */
    void setAgendaCalendarItemsToDosDueTodayFrameColor( const QColor & v )
    {
      if (!isAgendaCalendarItemsToDosDueTodayFrameColorImmutable())
        mAgendaCalendarItemsToDosDueTodayFrameColor = v;
    }

    /**
      Get Agenda CalendarItems ToDos DueToday Frame Color
    */
    QColor agendaCalendarItemsToDosDueTodayFrameColor() const
    {
      return mAgendaCalendarItemsToDosDueTodayFrameColor;
    }

    /**
      Is Agenda CalendarItems ToDos DueToday Frame Color Immutable
    */
    bool isAgendaCalendarItemsToDosDueTodayFrameColorImmutable() const
    {
      return isImmutable( QStringLiteral( "AgendaCalendarItemsToDosDueTodayFrameColor" ) );
    }

    /**
      Get Item object corresponding to AgendaCalendarItemsToDosDueTodayFrameColor()
    */
    ItemColor *agendaCalendarItemsToDosDueTodayFrameColorItem()
    {
      return mAgendaCalendarItemsToDosDueTodayFrameColorItem;
    }

    /**
      Set Agenda CalendarItems ToDos DueToday Icon
    */
    void setAgendaCalendarItemsToDosDueTodayIcon( const QString & v )
    {
      if (!isAgendaCalendarItemsToDosDueTodayIconImmutable())
        mAgendaCalendarItemsToDosDueTodayIcon = v;
    }

    /**
      Get Agenda CalendarItems ToDos DueToday Icon
    */
    QString agendaCalendarItemsToDosDueTodayIcon() const
    {
      return mAgendaCalendarItemsToDosDueTodayIcon;
    }

    /**
      Is Agenda CalendarItems ToDos DueToday Icon Immutable
    */
    bool isAgendaCalendarItemsToDosDueTodayIconImmutable() const
    {
      return isImmutable( QStringLiteral( "AgendaCalendarItemsToDosDueTodayIcon" ) );
    }

    /**
      Get Item object corresponding to AgendaCalendarItemsToDosDueTodayIcon()
    */
    ItemString *agendaCalendarItemsToDosDueTodayIconItem()
    {
      return mAgendaCalendarItemsToDosDueTodayIconItem;
    }

    /**
      Set Agenda CalendarItems ToDos Overdue Background Image
    */
    void setAgendaCalendarItemsToDosOverdueBackgroundImage( const QString & v )
    {
      if (!isAgendaCalendarItemsToDosOverdueBackgroundImageImmutable())
        mAgendaCalendarItemsToDosOverdueBackgroundImage = v;
    }

    /**
      Get Agenda CalendarItems ToDos Overdue Background Image
    */
    QString agendaCalendarItemsToDosOverdueBackgroundImage() const
    {
      return mAgendaCalendarItemsToDosOverdueBackgroundImage;
    }

    /**
      Is Agenda CalendarItems ToDos Overdue Background Image Immutable
    */
    bool isAgendaCalendarItemsToDosOverdueBackgroundImageImmutable() const
    {
      return isImmutable( QStringLiteral( "AgendaCalendarItemsToDosOverdueBackgroundImage" ) );
    }

    /**
      Get Item object corresponding to AgendaCalendarItemsToDosOverdueBackgroundImage()
    */
    ItemString *agendaCalendarItemsToDosOverdueBackgroundImageItem()
    {
      return mAgendaCalendarItemsToDosOverdueBackgroundImageItem;
    }

    /**
      Set Agenda CalendarItems ToDos Overdue Font
    */
    void setAgendaCalendarItemsToDosOverdueFont( const QFont & v )
    {
      if (!isAgendaCalendarItemsToDosOverdueFontImmutable())
        mAgendaCalendarItemsToDosOverdueFont = v;
    }

    /**
      Get Agenda CalendarItems ToDos Overdue Font
    */
    QFont agendaCalendarItemsToDosOverdueFont() const
    {
      return mAgendaCalendarItemsToDosOverdueFont;
    }

    /**
      Is Agenda CalendarItems ToDos Overdue Font Immutable
    */
    bool isAgendaCalendarItemsToDosOverdueFontImmutable() const
    {
      return isImmutable( QStringLiteral( "AgendaCalendarItemsToDosOverdueFont" ) );
    }

    /**
      Get Item object corresponding to AgendaCalendarItemsToDosOverdueFont()
    */
    ItemFont *agendaCalendarItemsToDosOverdueFontItem()
    {
      return mAgendaCalendarItemsToDosOverdueFontItem;
    }

    /**
      Set Agenda CalendarItems ToDos Overdue Frame Color
    */
    void setAgendaCalendarItemsToDosOverdueFrameColor( const QColor & v )
    {
      if (!isAgendaCalendarItemsToDosOverdueFrameColorImmutable())
        mAgendaCalendarItemsToDosOverdueFrameColor = v;
    }

    /**
      Get Agenda CalendarItems ToDos Overdue Frame Color
    */
    QColor agendaCalendarItemsToDosOverdueFrameColor() const
    {
      return mAgendaCalendarItemsToDosOverdueFrameColor;
    }

    /**
      Is Agenda CalendarItems ToDos Overdue Frame Color Immutable
    */
    bool isAgendaCalendarItemsToDosOverdueFrameColorImmutable() const
    {
      return isImmutable( QStringLiteral( "AgendaCalendarItemsToDosOverdueFrameColor" ) );
    }

    /**
      Get Item object corresponding to AgendaCalendarItemsToDosOverdueFrameColor()
    */
    ItemColor *agendaCalendarItemsToDosOverdueFrameColorItem()
    {
      return mAgendaCalendarItemsToDosOverdueFrameColorItem;
    }

    /**
      Set Agenda CalendarItems ToDos Overdue Icon
    */
    void setAgendaCalendarItemsToDosOverdueIcon( const QString & v )
    {
      if (!isAgendaCalendarItemsToDosOverdueIconImmutable())
        mAgendaCalendarItemsToDosOverdueIcon = v;
    }

    /**
      Get Agenda CalendarItems ToDos Overdue Icon
    */
    QString agendaCalendarItemsToDosOverdueIcon() const
    {
      return mAgendaCalendarItemsToDosOverdueIcon;
    }

    /**
      Is Agenda CalendarItems ToDos Overdue Icon Immutable
    */
    bool isAgendaCalendarItemsToDosOverdueIconImmutable() const
    {
      return isImmutable( QStringLiteral( "AgendaCalendarItemsToDosOverdueIcon" ) );
    }

    /**
      Get Item object corresponding to AgendaCalendarItemsToDosOverdueIcon()
    */
    ItemString *agendaCalendarItemsToDosOverdueIconItem()
    {
      return mAgendaCalendarItemsToDosOverdueIconItem;
    }

    /**
      Set Holiday color
    */
    void setAgendaHolidaysBackgroundColor( const QColor & v )
    {
      if (!isAgendaHolidaysBackgroundColorImmutable())
        mAgendaHolidaysBackgroundColor = v;
    }

    /**
      Get Holiday color
    */
    QColor agendaHolidaysBackgroundColor() const
    {
      return mAgendaHolidaysBackgroundColor;
    }

    /**
      Is Holiday color Immutable
    */
    bool isAgendaHolidaysBackgroundColorImmutable() const
    {
      return isImmutable( QStringLiteral( "AgendaHolidaysBackgroundColor" ) );
    }

    /**
      Get Item object corresponding to AgendaHolidaysBackgroundColor()
    */
    ItemColor *agendaHolidaysBackgroundColorItem()
    {
      return mAgendaHolidaysBackgroundColorItem;
    }

    /**
      Set Use system colors for some background colors
    */
    void setUseSystemColor( bool v )
    {
      if (!isUseSystemColorImmutable())
        mUseSystemColor = v;
    }

    /**
      Get Use system colors for some background colors
    */
    bool useSystemColor() const
    {
      return mUseSystemColor;
    }

    /**
      Is Use system colors for some background colors Immutable
    */
    bool isUseSystemColorImmutable() const
    {
      return isImmutable( QStringLiteral( "UseSystemColor" ) );
    }

    /**
      Get Item object corresponding to UseSystemColor()
    */
    ItemBool *useSystemColorItem()
    {
      return mUseSystemColorItem;
    }

    /**
      Set Agenda Holidays Background Image
    */
    void setAgendaHolidaysBackgroundImage( const QString & v )
    {
      if (!isAgendaHolidaysBackgroundImageImmutable())
        mAgendaHolidaysBackgroundImage = v;
    }

    /**
      Get Agenda Holidays Background Image
    */
    QString agendaHolidaysBackgroundImage() const
    {
      return mAgendaHolidaysBackgroundImage;
    }

    /**
      Is Agenda Holidays Background Image Immutable
    */
    bool isAgendaHolidaysBackgroundImageImmutable() const
    {
      return isImmutable( QStringLiteral( "AgendaHolidaysBackgroundImage" ) );
    }

    /**
      Get Item object corresponding to AgendaHolidaysBackgroundImage()
    */
    ItemString *agendaHolidaysBackgroundImageItem()
    {
      return mAgendaHolidaysBackgroundImageItem;
    }

    /**
      Set Month view background color
    */
    void setMonthGridBackgroundColor( const QColor & v )
    {
      if (!isMonthGridBackgroundColorImmutable())
        mMonthGridBackgroundColor = v;
    }

    /**
      Get Month view background color
    */
    QColor monthGridBackgroundColor() const
    {
      return mMonthGridBackgroundColor;
    }

    /**
      Is Month view background color Immutable
    */
    bool isMonthGridBackgroundColorImmutable() const
    {
      return isImmutable( QStringLiteral( "MonthGridBackgroundColor" ) );
    }

    /**
      Get Item object corresponding to MonthGridBackgroundColor()
    */
    ItemColor *monthGridBackgroundColorItem()
    {
      return mMonthGridBackgroundColorItem;
    }

    /**
      Set Month Grid Background Image
    */
    void setMonthGridBackgroundImage( const QString & v )
    {
      if (!isMonthGridBackgroundImageImmutable())
        mMonthGridBackgroundImage = v;
    }

    /**
      Get Month Grid Background Image
    */
    QString monthGridBackgroundImage() const
    {
      return mMonthGridBackgroundImage;
    }

    /**
      Is Month Grid Background Image Immutable
    */
    bool isMonthGridBackgroundImageImmutable() const
    {
      return isImmutable( QStringLiteral( "MonthGridBackgroundImage" ) );
    }

    /**
      Get Item object corresponding to MonthGridBackgroundImage()
    */
    ItemString *monthGridBackgroundImageItem()
    {
      return mMonthGridBackgroundImageItem;
    }

    /**
      Set Highlight color
    */
    void setMonthGridHighlightColor( const QColor & v )
    {
      if (!isMonthGridHighlightColorImmutable())
        mMonthGridHighlightColor = v;
    }

    /**
      Get Highlight color
    */
    QColor monthGridHighlightColor() const
    {
      return mMonthGridHighlightColor;
    }

    /**
      Is Highlight color Immutable
    */
    bool isMonthGridHighlightColorImmutable() const
    {
      return isImmutable( QStringLiteral( "MonthGridHighlightColor" ) );
    }

    /**
      Get Item object corresponding to MonthGridHighlightColor()
    */
    ItemColor *monthGridHighlightColorItem()
    {
      return mMonthGridHighlightColorItem;
    }

    /**
      Set Working hours color
    */
    void setMonthGridWorkHoursBackgroundColor( const QColor & v )
    {
      if (!isMonthGridWorkHoursBackgroundColorImmutable())
        mMonthGridWorkHoursBackgroundColor = v;
    }

    /**
      Get Working hours color
    */
    QColor monthGridWorkHoursBackgroundColor() const
    {
      return mMonthGridWorkHoursBackgroundColor;
    }

    /**
      Is Working hours color Immutable
    */
    bool isMonthGridWorkHoursBackgroundColorImmutable() const
    {
      return isImmutable( QStringLiteral( "MonthGridWorkHoursBackgroundColor" ) );
    }

    /**
      Get Item object corresponding to MonthGridWorkHoursBackgroundColor()
    */
    ItemColor *monthGridWorkHoursBackgroundColorItem()
    {
      return mMonthGridWorkHoursBackgroundColorItem;
    }

    /**
      Set Month Grid WorkHours Background Image
    */
    void setMonthGridWorkHoursBackgroundImage( const QString & v )
    {
      if (!isMonthGridWorkHoursBackgroundImageImmutable())
        mMonthGridWorkHoursBackgroundImage = v;
    }

    /**
      Get Month Grid WorkHours Background Image
    */
    QString monthGridWorkHoursBackgroundImage() const
    {
      return mMonthGridWorkHoursBackgroundImage;
    }

    /**
      Is Month Grid WorkHours Background Image Immutable
    */
    bool isMonthGridWorkHoursBackgroundImageImmutable() const
    {
      return isImmutable( QStringLiteral( "MonthGridWorkHoursBackgroundImage" ) );
    }

    /**
      Get Item object corresponding to MonthGridWorkHoursBackgroundImage()
    */
    ItemString *monthGridWorkHoursBackgroundImageItem()
    {
      return mMonthGridWorkHoursBackgroundImageItem;
    }

    /**
      Set Month CalendarItems Background Color
    */
    void setMonthCalendarItemsBackgroundColor( const QColor & v )
    {
      if (!isMonthCalendarItemsBackgroundColorImmutable())
        mMonthCalendarItemsBackgroundColor = v;
    }

    /**
      Get Month CalendarItems Background Color
    */
    QColor monthCalendarItemsBackgroundColor() const
    {
      return mMonthCalendarItemsBackgroundColor;
    }

    /**
      Is Month CalendarItems Background Color Immutable
    */
    bool isMonthCalendarItemsBackgroundColorImmutable() const
    {
      return isImmutable( QStringLiteral( "MonthCalendarItemsBackgroundColor" ) );
    }

    /**
      Get Item object corresponding to MonthCalendarItemsBackgroundColor()
    */
    ItemColor *monthCalendarItemsBackgroundColorItem()
    {
      return mMonthCalendarItemsBackgroundColorItem;
    }

    /**
      Set Month CalendarItems Background Image
    */
    void setMonthCalendarItemsBackgroundImage( const QString & v )
    {
      if (!isMonthCalendarItemsBackgroundImageImmutable())
        mMonthCalendarItemsBackgroundImage = v;
    }

    /**
      Get Month CalendarItems Background Image
    */
    QString monthCalendarItemsBackgroundImage() const
    {
      return mMonthCalendarItemsBackgroundImage;
    }

    /**
      Is Month CalendarItems Background Image Immutable
    */
    bool isMonthCalendarItemsBackgroundImageImmutable() const
    {
      return isImmutable( QStringLiteral( "MonthCalendarItemsBackgroundImage" ) );
    }

    /**
      Get Item object corresponding to MonthCalendarItemsBackgroundImage()
    */
    ItemString *monthCalendarItemsBackgroundImageItem()
    {
      return mMonthCalendarItemsBackgroundImageItem;
    }

    /**
      Set Month CalendarItems Font
    */
    void setMonthCalendarItemsFont( const QFont & v )
    {
      if (!isMonthCalendarItemsFontImmutable())
        mMonthCalendarItemsFont = v;
    }

    /**
      Get Month CalendarItems Font
    */
    QFont monthCalendarItemsFont() const
    {
      return mMonthCalendarItemsFont;
    }

    /**
      Is Month CalendarItems Font Immutable
    */
    bool isMonthCalendarItemsFontImmutable() const
    {
      return isImmutable( QStringLiteral( "MonthCalendarItemsFont" ) );
    }

    /**
      Get Item object corresponding to MonthCalendarItemsFont()
    */
    ItemFont *monthCalendarItemsFontItem()
    {
      return mMonthCalendarItemsFontItem;
    }

    /**
      Set Month CalendarItems Frame Color
    */
    void setMonthCalendarItemsFrameColor( const QColor & v )
    {
      if (!isMonthCalendarItemsFrameColorImmutable())
        mMonthCalendarItemsFrameColor = v;
    }

    /**
      Get Month CalendarItems Frame Color
    */
    QColor monthCalendarItemsFrameColor() const
    {
      return mMonthCalendarItemsFrameColor;
    }

    /**
      Is Month CalendarItems Frame Color Immutable
    */
    bool isMonthCalendarItemsFrameColorImmutable() const
    {
      return isImmutable( QStringLiteral( "MonthCalendarItemsFrameColor" ) );
    }

    /**
      Get Item object corresponding to MonthCalendarItemsFrameColor()
    */
    ItemColor *monthCalendarItemsFrameColorItem()
    {
      return mMonthCalendarItemsFrameColorItem;
    }

    /**
      Set Month CalendarItems Icon
    */
    void setMonthCalendarItemsIcon( const QString & v )
    {
      if (!isMonthCalendarItemsIconImmutable())
        mMonthCalendarItemsIcon = v;
    }

    /**
      Get Month CalendarItems Icon
    */
    QString monthCalendarItemsIcon() const
    {
      return mMonthCalendarItemsIcon;
    }

    /**
      Is Month CalendarItems Icon Immutable
    */
    bool isMonthCalendarItemsIconImmutable() const
    {
      return isImmutable( QStringLiteral( "MonthCalendarItemsIcon" ) );
    }

    /**
      Get Item object corresponding to MonthCalendarItemsIcon()
    */
    ItemString *monthCalendarItemsIconItem()
    {
      return mMonthCalendarItemsIconItem;
    }

    /**
      Set Default event color
    */
    void setMonthCalendarItemsEventsBackgroundColor( const QColor & v )
    {
      if (!isMonthCalendarItemsEventsBackgroundColorImmutable())
        mMonthCalendarItemsEventsBackgroundColor = v;
    }

    /**
      Get Default event color
    */
    QColor monthCalendarItemsEventsBackgroundColor() const
    {
      return mMonthCalendarItemsEventsBackgroundColor;
    }

    /**
      Is Default event color Immutable
    */
    bool isMonthCalendarItemsEventsBackgroundColorImmutable() const
    {
      return isImmutable( QStringLiteral( "MonthCalendarItemsEventsBackgroundColor" ) );
    }

    /**
      Get Item object corresponding to MonthCalendarItemsEventsBackgroundColor()
    */
    ItemColor *monthCalendarItemsEventsBackgroundColorItem()
    {
      return mMonthCalendarItemsEventsBackgroundColorItem;
    }

    /**
      Set Month CalendarItems Events Background Image
    */
    void setMonthCalendarItemsEventsBackgroundImage( const QString & v )
    {
      if (!isMonthCalendarItemsEventsBackgroundImageImmutable())
        mMonthCalendarItemsEventsBackgroundImage = v;
    }

    /**
      Get Month CalendarItems Events Background Image
    */
    QString monthCalendarItemsEventsBackgroundImage() const
    {
      return mMonthCalendarItemsEventsBackgroundImage;
    }

    /**
      Is Month CalendarItems Events Background Image Immutable
    */
    bool isMonthCalendarItemsEventsBackgroundImageImmutable() const
    {
      return isImmutable( QStringLiteral( "MonthCalendarItemsEventsBackgroundImage" ) );
    }

    /**
      Get Item object corresponding to MonthCalendarItemsEventsBackgroundImage()
    */
    ItemString *monthCalendarItemsEventsBackgroundImageItem()
    {
      return mMonthCalendarItemsEventsBackgroundImageItem;
    }

    /**
      Set Month CalendarItems Events Font
    */
    void setMonthCalendarItemsEventsFont( const QFont & v )
    {
      if (!isMonthCalendarItemsEventsFontImmutable())
        mMonthCalendarItemsEventsFont = v;
    }

    /**
      Get Month CalendarItems Events Font
    */
    QFont monthCalendarItemsEventsFont() const
    {
      return mMonthCalendarItemsEventsFont;
    }

    /**
      Is Month CalendarItems Events Font Immutable
    */
    bool isMonthCalendarItemsEventsFontImmutable() const
    {
      return isImmutable( QStringLiteral( "MonthCalendarItemsEventsFont" ) );
    }

    /**
      Get Item object corresponding to MonthCalendarItemsEventsFont()
    */
    ItemFont *monthCalendarItemsEventsFontItem()
    {
      return mMonthCalendarItemsEventsFontItem;
    }

    /**
      Set Month CalendarItems Events Frame Color
    */
    void setMonthCalendarItemsEventsFrameColor( const QColor & v )
    {
      if (!isMonthCalendarItemsEventsFrameColorImmutable())
        mMonthCalendarItemsEventsFrameColor = v;
    }

    /**
      Get Month CalendarItems Events Frame Color
    */
    QColor monthCalendarItemsEventsFrameColor() const
    {
      return mMonthCalendarItemsEventsFrameColor;
    }

    /**
      Is Month CalendarItems Events Frame Color Immutable
    */
    bool isMonthCalendarItemsEventsFrameColorImmutable() const
    {
      return isImmutable( QStringLiteral( "MonthCalendarItemsEventsFrameColor" ) );
    }

    /**
      Get Item object corresponding to MonthCalendarItemsEventsFrameColor()
    */
    ItemColor *monthCalendarItemsEventsFrameColorItem()
    {
      return mMonthCalendarItemsEventsFrameColorItem;
    }

    /**
      Set Month CalendarItems Events Icon
    */
    void setMonthCalendarItemsEventsIcon( const QString & v )
    {
      if (!isMonthCalendarItemsEventsIconImmutable())
        mMonthCalendarItemsEventsIcon = v;
    }

    /**
      Get Month CalendarItems Events Icon
    */
    QString monthCalendarItemsEventsIcon() const
    {
      return mMonthCalendarItemsEventsIcon;
    }

    /**
      Is Month CalendarItems Events Icon Immutable
    */
    bool isMonthCalendarItemsEventsIconImmutable() const
    {
      return isImmutable( QStringLiteral( "MonthCalendarItemsEventsIcon" ) );
    }

    /**
      Get Item object corresponding to MonthCalendarItemsEventsIcon()
    */
    ItemString *monthCalendarItemsEventsIconItem()
    {
      return mMonthCalendarItemsEventsIconItem;
    }

    /**
      Set Month CalendarItems ToDos Background Color
    */
    void setMonthCalendarItemsToDosBackgroundColor( const QColor & v )
    {
      if (!isMonthCalendarItemsToDosBackgroundColorImmutable())
        mMonthCalendarItemsToDosBackgroundColor = v;
    }

    /**
      Get Month CalendarItems ToDos Background Color
    */
    QColor monthCalendarItemsToDosBackgroundColor() const
    {
      return mMonthCalendarItemsToDosBackgroundColor;
    }

    /**
      Is Month CalendarItems ToDos Background Color Immutable
    */
    bool isMonthCalendarItemsToDosBackgroundColorImmutable() const
    {
      return isImmutable( QStringLiteral( "MonthCalendarItemsToDosBackgroundColor" ) );
    }

    /**
      Get Item object corresponding to MonthCalendarItemsToDosBackgroundColor()
    */
    ItemColor *monthCalendarItemsToDosBackgroundColorItem()
    {
      return mMonthCalendarItemsToDosBackgroundColorItem;
    }

    /**
      Set Month CalendarItems ToDos Background Image
    */
    void setMonthCalendarItemsToDosBackgroundImage( const QString & v )
    {
      if (!isMonthCalendarItemsToDosBackgroundImageImmutable())
        mMonthCalendarItemsToDosBackgroundImage = v;
    }

    /**
      Get Month CalendarItems ToDos Background Image
    */
    QString monthCalendarItemsToDosBackgroundImage() const
    {
      return mMonthCalendarItemsToDosBackgroundImage;
    }

    /**
      Is Month CalendarItems ToDos Background Image Immutable
    */
    bool isMonthCalendarItemsToDosBackgroundImageImmutable() const
    {
      return isImmutable( QStringLiteral( "MonthCalendarItemsToDosBackgroundImage" ) );
    }

    /**
      Get Item object corresponding to MonthCalendarItemsToDosBackgroundImage()
    */
    ItemString *monthCalendarItemsToDosBackgroundImageItem()
    {
      return mMonthCalendarItemsToDosBackgroundImageItem;
    }

    /**
      Set Month CalendarItems ToDos Font
    */
    void setMonthCalendarItemsToDosFont( const QFont & v )
    {
      if (!isMonthCalendarItemsToDosFontImmutable())
        mMonthCalendarItemsToDosFont = v;
    }

    /**
      Get Month CalendarItems ToDos Font
    */
    QFont monthCalendarItemsToDosFont() const
    {
      return mMonthCalendarItemsToDosFont;
    }

    /**
      Is Month CalendarItems ToDos Font Immutable
    */
    bool isMonthCalendarItemsToDosFontImmutable() const
    {
      return isImmutable( QStringLiteral( "MonthCalendarItemsToDosFont" ) );
    }

    /**
      Get Item object corresponding to MonthCalendarItemsToDosFont()
    */
    ItemFont *monthCalendarItemsToDosFontItem()
    {
      return mMonthCalendarItemsToDosFontItem;
    }

    /**
      Set Month CalendarItems ToDos Frame Color
    */
    void setMonthCalendarItemsToDosFrameColor( const QColor & v )
    {
      if (!isMonthCalendarItemsToDosFrameColorImmutable())
        mMonthCalendarItemsToDosFrameColor = v;
    }

    /**
      Get Month CalendarItems ToDos Frame Color
    */
    QColor monthCalendarItemsToDosFrameColor() const
    {
      return mMonthCalendarItemsToDosFrameColor;
    }

    /**
      Is Month CalendarItems ToDos Frame Color Immutable
    */
    bool isMonthCalendarItemsToDosFrameColorImmutable() const
    {
      return isImmutable( QStringLiteral( "MonthCalendarItemsToDosFrameColor" ) );
    }

    /**
      Get Item object corresponding to MonthCalendarItemsToDosFrameColor()
    */
    ItemColor *monthCalendarItemsToDosFrameColorItem()
    {
      return mMonthCalendarItemsToDosFrameColorItem;
    }

    /**
      Set Month CalendarItems ToDos Icon
    */
    void setMonthCalendarItemsToDosIcon( const QString & v )
    {
      if (!isMonthCalendarItemsToDosIconImmutable())
        mMonthCalendarItemsToDosIcon = v;
    }

    /**
      Get Month CalendarItems ToDos Icon
    */
    QString monthCalendarItemsToDosIcon() const
    {
      return mMonthCalendarItemsToDosIcon;
    }

    /**
      Is Month CalendarItems ToDos Icon Immutable
    */
    bool isMonthCalendarItemsToDosIconImmutable() const
    {
      return isImmutable( QStringLiteral( "MonthCalendarItemsToDosIcon" ) );
    }

    /**
      Get Item object corresponding to MonthCalendarItemsToDosIcon()
    */
    ItemString *monthCalendarItemsToDosIconItem()
    {
      return mMonthCalendarItemsToDosIconItem;
    }

    /**
      Set To-do due today color
    */
    void setMonthCalendarItemsToDosDueTodayBackgroundColor( const QColor & v )
    {
      if (!isMonthCalendarItemsToDosDueTodayBackgroundColorImmutable())
        mMonthCalendarItemsToDosDueTodayBackgroundColor = v;
    }

    /**
      Get To-do due today color
    */
    QColor monthCalendarItemsToDosDueTodayBackgroundColor() const
    {
      return mMonthCalendarItemsToDosDueTodayBackgroundColor;
    }

    /**
      Is To-do due today color Immutable
    */
    bool isMonthCalendarItemsToDosDueTodayBackgroundColorImmutable() const
    {
      return isImmutable( QStringLiteral( "MonthCalendarItemsToDosDueTodayBackgroundColor" ) );
    }

    /**
      Get Item object corresponding to MonthCalendarItemsToDosDueTodayBackgroundColor()
    */
    ItemColor *monthCalendarItemsToDosDueTodayBackgroundColorItem()
    {
      return mMonthCalendarItemsToDosDueTodayBackgroundColorItem;
    }

    /**
      Set Month CalendarItems ToDos DueToday Background Image
    */
    void setMonthCalendarItemsToDosDueTodayBackgroundImage( const QString & v )
    {
      if (!isMonthCalendarItemsToDosDueTodayBackgroundImageImmutable())
        mMonthCalendarItemsToDosDueTodayBackgroundImage = v;
    }

    /**
      Get Month CalendarItems ToDos DueToday Background Image
    */
    QString monthCalendarItemsToDosDueTodayBackgroundImage() const
    {
      return mMonthCalendarItemsToDosDueTodayBackgroundImage;
    }

    /**
      Is Month CalendarItems ToDos DueToday Background Image Immutable
    */
    bool isMonthCalendarItemsToDosDueTodayBackgroundImageImmutable() const
    {
      return isImmutable( QStringLiteral( "MonthCalendarItemsToDosDueTodayBackgroundImage" ) );
    }

    /**
      Get Item object corresponding to MonthCalendarItemsToDosDueTodayBackgroundImage()
    */
    ItemString *monthCalendarItemsToDosDueTodayBackgroundImageItem()
    {
      return mMonthCalendarItemsToDosDueTodayBackgroundImageItem;
    }

    /**
      Set Month CalendarItems ToDos DueToday Font
    */
    void setMonthCalendarItemsToDosDueTodayFont( const QFont & v )
    {
      if (!isMonthCalendarItemsToDosDueTodayFontImmutable())
        mMonthCalendarItemsToDosDueTodayFont = v;
    }

    /**
      Get Month CalendarItems ToDos DueToday Font
    */
    QFont monthCalendarItemsToDosDueTodayFont() const
    {
      return mMonthCalendarItemsToDosDueTodayFont;
    }

    /**
      Is Month CalendarItems ToDos DueToday Font Immutable
    */
    bool isMonthCalendarItemsToDosDueTodayFontImmutable() const
    {
      return isImmutable( QStringLiteral( "MonthCalendarItemsToDosDueTodayFont" ) );
    }

    /**
      Get Item object corresponding to MonthCalendarItemsToDosDueTodayFont()
    */
    ItemFont *monthCalendarItemsToDosDueTodayFontItem()
    {
      return mMonthCalendarItemsToDosDueTodayFontItem;
    }

    /**
      Set Month CalendarItems ToDos DueToday Frame Color
    */
    void setMonthCalendarItemsToDosDueTodayFrameColor( const QColor & v )
    {
      if (!isMonthCalendarItemsToDosDueTodayFrameColorImmutable())
        mMonthCalendarItemsToDosDueTodayFrameColor = v;
    }

    /**
      Get Month CalendarItems ToDos DueToday Frame Color
    */
    QColor monthCalendarItemsToDosDueTodayFrameColor() const
    {
      return mMonthCalendarItemsToDosDueTodayFrameColor;
    }

    /**
      Is Month CalendarItems ToDos DueToday Frame Color Immutable
    */
    bool isMonthCalendarItemsToDosDueTodayFrameColorImmutable() const
    {
      return isImmutable( QStringLiteral( "MonthCalendarItemsToDosDueTodayFrameColor" ) );
    }

    /**
      Get Item object corresponding to MonthCalendarItemsToDosDueTodayFrameColor()
    */
    ItemColor *monthCalendarItemsToDosDueTodayFrameColorItem()
    {
      return mMonthCalendarItemsToDosDueTodayFrameColorItem;
    }

    /**
      Set Month CalendarItems ToDos DueToday Icon
    */
    void setMonthCalendarItemsToDosDueTodayIcon( const QString & v )
    {
      if (!isMonthCalendarItemsToDosDueTodayIconImmutable())
        mMonthCalendarItemsToDosDueTodayIcon = v;
    }

    /**
      Get Month CalendarItems ToDos DueToday Icon
    */
    QString monthCalendarItemsToDosDueTodayIcon() const
    {
      return mMonthCalendarItemsToDosDueTodayIcon;
    }

    /**
      Is Month CalendarItems ToDos DueToday Icon Immutable
    */
    bool isMonthCalendarItemsToDosDueTodayIconImmutable() const
    {
      return isImmutable( QStringLiteral( "MonthCalendarItemsToDosDueTodayIcon" ) );
    }

    /**
      Get Item object corresponding to MonthCalendarItemsToDosDueTodayIcon()
    */
    ItemString *monthCalendarItemsToDosDueTodayIconItem()
    {
      return mMonthCalendarItemsToDosDueTodayIconItem;
    }

    /**
      Set To-do overdue color
    */
    void setMonthCalendarItemsToDosOverdueBackgroundColor( const QColor & v )
    {
      if (!isMonthCalendarItemsToDosOverdueBackgroundColorImmutable())
        mMonthCalendarItemsToDosOverdueBackgroundColor = v;
    }

    /**
      Get To-do overdue color
    */
    QColor monthCalendarItemsToDosOverdueBackgroundColor() const
    {
      return mMonthCalendarItemsToDosOverdueBackgroundColor;
    }

    /**
      Is To-do overdue color Immutable
    */
    bool isMonthCalendarItemsToDosOverdueBackgroundColorImmutable() const
    {
      return isImmutable( QStringLiteral( "MonthCalendarItemsToDosOverdueBackgroundColor" ) );
    }

    /**
      Get Item object corresponding to MonthCalendarItemsToDosOverdueBackgroundColor()
    */
    ItemColor *monthCalendarItemsToDosOverdueBackgroundColorItem()
    {
      return mMonthCalendarItemsToDosOverdueBackgroundColorItem;
    }

    /**
      Set Month CalendarItems ToDos Overdue Background Image
    */
    void setMonthCalendarItemsToDosOverdueBackgroundImage( const QString & v )
    {
      if (!isMonthCalendarItemsToDosOverdueBackgroundImageImmutable())
        mMonthCalendarItemsToDosOverdueBackgroundImage = v;
    }

    /**
      Get Month CalendarItems ToDos Overdue Background Image
    */
    QString monthCalendarItemsToDosOverdueBackgroundImage() const
    {
      return mMonthCalendarItemsToDosOverdueBackgroundImage;
    }

    /**
      Is Month CalendarItems ToDos Overdue Background Image Immutable
    */
    bool isMonthCalendarItemsToDosOverdueBackgroundImageImmutable() const
    {
      return isImmutable( QStringLiteral( "MonthCalendarItemsToDosOverdueBackgroundImage" ) );
    }

    /**
      Get Item object corresponding to MonthCalendarItemsToDosOverdueBackgroundImage()
    */
    ItemString *monthCalendarItemsToDosOverdueBackgroundImageItem()
    {
      return mMonthCalendarItemsToDosOverdueBackgroundImageItem;
    }

    /**
      Set Month CalendarItems ToDos Overdue Font
    */
    void setMonthCalendarItemsToDosOverdueFont( const QFont & v )
    {
      if (!isMonthCalendarItemsToDosOverdueFontImmutable())
        mMonthCalendarItemsToDosOverdueFont = v;
    }

    /**
      Get Month CalendarItems ToDos Overdue Font
    */
    QFont monthCalendarItemsToDosOverdueFont() const
    {
      return mMonthCalendarItemsToDosOverdueFont;
    }

    /**
      Is Month CalendarItems ToDos Overdue Font Immutable
    */
    bool isMonthCalendarItemsToDosOverdueFontImmutable() const
    {
      return isImmutable( QStringLiteral( "MonthCalendarItemsToDosOverdueFont" ) );
    }

    /**
      Get Item object corresponding to MonthCalendarItemsToDosOverdueFont()
    */
    ItemFont *monthCalendarItemsToDosOverdueFontItem()
    {
      return mMonthCalendarItemsToDosOverdueFontItem;
    }

    /**
      Set Month CalendarItems ToDos Overdue Frame Color
    */
    void setMonthCalendarItemsToDosOverdueFrameColor( const QColor & v )
    {
      if (!isMonthCalendarItemsToDosOverdueFrameColorImmutable())
        mMonthCalendarItemsToDosOverdueFrameColor = v;
    }

    /**
      Get Month CalendarItems ToDos Overdue Frame Color
    */
    QColor monthCalendarItemsToDosOverdueFrameColor() const
    {
      return mMonthCalendarItemsToDosOverdueFrameColor;
    }

    /**
      Is Month CalendarItems ToDos Overdue Frame Color Immutable
    */
    bool isMonthCalendarItemsToDosOverdueFrameColorImmutable() const
    {
      return isImmutable( QStringLiteral( "MonthCalendarItemsToDosOverdueFrameColor" ) );
    }

    /**
      Get Item object corresponding to MonthCalendarItemsToDosOverdueFrameColor()
    */
    ItemColor *monthCalendarItemsToDosOverdueFrameColorItem()
    {
      return mMonthCalendarItemsToDosOverdueFrameColorItem;
    }

    /**
      Set Month CalendarItems ToDos Overdue Icon
    */
    void setMonthCalendarItemsToDosOverdueIcon( const QString & v )
    {
      if (!isMonthCalendarItemsToDosOverdueIconImmutable())
        mMonthCalendarItemsToDosOverdueIcon = v;
    }

    /**
      Get Month CalendarItems ToDos Overdue Icon
    */
    QString monthCalendarItemsToDosOverdueIcon() const
    {
      return mMonthCalendarItemsToDosOverdueIcon;
    }

    /**
      Is Month CalendarItems ToDos Overdue Icon Immutable
    */
    bool isMonthCalendarItemsToDosOverdueIconImmutable() const
    {
      return isImmutable( QStringLiteral( "MonthCalendarItemsToDosOverdueIcon" ) );
    }

    /**
      Get Item object corresponding to MonthCalendarItemsToDosOverdueIcon()
    */
    ItemString *monthCalendarItemsToDosOverdueIconItem()
    {
      return mMonthCalendarItemsToDosOverdueIconItem;
    }

    /**
      Set Holiday color
    */
    void setMonthHolidaysBackgroundColor( const QColor & v )
    {
      if (!isMonthHolidaysBackgroundColorImmutable())
        mMonthHolidaysBackgroundColor = v;
    }

    /**
      Get Holiday color
    */
    QColor monthHolidaysBackgroundColor() const
    {
      return mMonthHolidaysBackgroundColor;
    }

    /**
      Is Holiday color Immutable
    */
    bool isMonthHolidaysBackgroundColorImmutable() const
    {
      return isImmutable( QStringLiteral( "MonthHolidaysBackgroundColor" ) );
    }

    /**
      Get Item object corresponding to MonthHolidaysBackgroundColor()
    */
    ItemColor *monthHolidaysBackgroundColorItem()
    {
      return mMonthHolidaysBackgroundColorItem;
    }

    /**
      Set Month Holidays Background Image
    */
    void setMonthHolidaysBackgroundImage( const QString & v )
    {
      if (!isMonthHolidaysBackgroundImageImmutable())
        mMonthHolidaysBackgroundImage = v;
    }

    /**
      Get Month Holidays Background Image
    */
    QString monthHolidaysBackgroundImage() const
    {
      return mMonthHolidaysBackgroundImage;
    }

    /**
      Is Month Holidays Background Image Immutable
    */
    bool isMonthHolidaysBackgroundImageImmutable() const
    {
      return isImmutable( QStringLiteral( "MonthHolidaysBackgroundImage" ) );
    }

    /**
      Get Item object corresponding to MonthHolidaysBackgroundImage()
    */
    ItemString *monthHolidaysBackgroundImageItem()
    {
      return mMonthHolidaysBackgroundImageItem;
    }

    /**
      Set EnabledActivities
    */
    void setEnabledActivities( bool v )
    {
      if (!isEnabledActivitiesImmutable())
        mEnabledActivities = v;
    }

    /**
      Get EnabledActivities
    */
    bool enabledActivities() const
    {
      return mEnabledActivities;
    }

    /**
      Is EnabledActivities Immutable
    */
    bool isEnabledActivitiesImmutable() const
    {
      return isImmutable( QStringLiteral( "EnabledActivities" ) );
    }

    /**
      Get Item object corresponding to EnabledActivities()
    */
    ItemBool *enabledActivitiesItem()
    {
      return mEnabledActivitiesItem;
    }

    /**
      Set PreviousNewFeaturesMD5
    */
    void setPreviousNewFeaturesMD5( const QString & v )
    {
      if (!isPreviousNewFeaturesMD5Immutable())
        mPreviousNewFeaturesMD5 = v;
    }

    /**
      Get PreviousNewFeaturesMD5
    */
    QString previousNewFeaturesMD5() const
    {
      return mPreviousNewFeaturesMD5;
    }

    /**
      Is PreviousNewFeaturesMD5 Immutable
    */
    bool isPreviousNewFeaturesMD5Immutable() const
    {
      return isImmutable( QStringLiteral( "PreviousNewFeaturesMD5" ) );
    }

    /**
      Get Item object corresponding to PreviousNewFeaturesMD5()
    */
    ItemString *previousNewFeaturesMD5Item()
    {
      return mPreviousNewFeaturesMD5Item;
    }

  protected:
  public:

    // Save Settings
    bool mConfirm;
    int mDestination;

    // Time & Date
    QString mTimeZoneId;
    int mWeekStartDay;
    QDateTime mWorkingHoursStart;
    QDateTime mWorkingHoursEnd;
    bool mColorMonthBusyDaysEnabled;

    // General View
    bool mEnableToolTips;
    bool mTodosUseCategoryColors;
    int mNextXDays;
    bool mDailyRecur;
    bool mWeeklyRecur;
    bool mHighlightTodos;
    bool mHighlightJournals;
    bool mWeekNumbersShow;
    bool mWeekNumbersShowWork;

    // Agenda View
    int mHourSize;
    bool mEnableAgendaItemIcons;
    bool mEnableAgendaBoldEvenHours;
    bool mEnableAgendaItemDesc;
    bool mEnableAgendaItemLocation;
    bool mShowTodosAgendaView;
    bool mMarcusBainsEnabled;
    bool mMarcusBainsShowSeconds;
    bool mSelectionStartsEditor;
    int mAgendaViewColors;
    bool mColorBusyDaysEnabled;
    int mAgendaViewCalendarDisplay;

    // Month View
    bool mEnableMonthItemIcons;
    bool mShowTimeInMonthView;
    bool mShowEndTimeInMonthView;
    bool mShowTodosMonthView;
    bool mShowJournalsMonthView;
    bool mShowHolidaysMonthView;
    bool mShowHolidaysBackgroundMonthView;
    bool mFullViewMonth;
    int mMonthViewColors;

    // Todo View
    bool mSortCompletedTodosSeparately;
    bool mFullViewTodo;
    bool mFlatListTodo;
    bool mRecordTodosInJournals;

    // Colors
    QColor mHolidayColor;
    QColor mAgendaBgColor;
    QColor mAgendaMarcusBainsLineLineColor;
    QColor mViewBgBusyColor;
    QColor mWorkingHoursColor;
    QColor mTodoDueTodayColor;
    QColor mTodoOverdueColor;
    QColor mMonthTodayColor;

    // Fonts
    QFont mAgendaTimeLabelsFont;
    QFont mMonthViewFont;
    QFont mAgendaViewFont;
    QFont mAgendaMarcusBainsLineFont;

    // KOrganizer Plugins
    QStringList mSelectedPlugins;

    // Hidden Options
    bool mEnableQuickTodo;
    bool mEnableTodoQuickSearch;
    int mDefaultTodoAttachMethod;
    bool mCompactDialogs;
    bool mShowMenuBar;

    // Internal Settings
    int mWorkWeekMask;
    int mDefaultResourceColorSeed;
    QStringList mDefaultResourceColors;
    bool mAssignDefaultResourceColors;
    QStringList mDecorationsAtMonthViewTop;
    QStringList mDecorationsAtAgendaViewTop;
    QStringList mDecorationsAtAgendaViewBottom;
    bool mAgendaViewShowSidebar;
    bool mJournalViewShowSidebar;
    bool mListViewShowSidebar;
    bool mMonthViewShowSidebar;
    bool mTimelineViewShowSidebar;
    bool mTodoViewShowSidebar;
    bool mWhatsNextViewShowSidebar;

    // Theming
    QColor mAgendaGridBackgroundColor;
    QString mAgendaGridBackgroundImage;
    QColor mAgendaGridHighlightColor;
    QString mAgendaGridWorkHoursBackgroundImage;
    QColor mAgendaCalendarItemsBackgroundColor;
    QString mAgendaCalendarItemsBackgroundImage;
    QFont mAgendaCalendarItemsFont;
    QColor mAgendaCalendarItemsFrameColor;
    QString mAgendaCalendarItemsIcon;
    QString mAgendaCalendarItemsEventsBackgroundImage;
    QFont mAgendaCalendarItemsEventsFont;
    QColor mAgendaCalendarItemsEventsFrameColor;
    QString mAgendaCalendarItemsEventsIcon;
    QColor mAgendaCalendarItemsToDosBackgroundColor;
    QString mAgendaCalendarItemsToDosBackgroundImage;
    QFont mAgendaCalendarItemsToDosFont;
    QColor mAgendaCalendarItemsToDosFrameColor;
    QString mAgendaCalendarItemsToDosIcon;
    QString mAgendaCalendarItemsToDosDueTodayBackgroundImage;
    QFont mAgendaCalendarItemsToDosDueTodayFont;
    QColor mAgendaCalendarItemsToDosDueTodayFrameColor;
    QString mAgendaCalendarItemsToDosDueTodayIcon;
    QString mAgendaCalendarItemsToDosOverdueBackgroundImage;
    QFont mAgendaCalendarItemsToDosOverdueFont;
    QColor mAgendaCalendarItemsToDosOverdueFrameColor;
    QString mAgendaCalendarItemsToDosOverdueIcon;
    QColor mAgendaHolidaysBackgroundColor;
    bool mUseSystemColor;
    QString mAgendaHolidaysBackgroundImage;

    // Theme/Month view
    QColor mMonthGridBackgroundColor;
    QString mMonthGridBackgroundImage;
    QColor mMonthGridHighlightColor;
    QColor mMonthGridWorkHoursBackgroundColor;
    QString mMonthGridWorkHoursBackgroundImage;
    QColor mMonthCalendarItemsBackgroundColor;
    QString mMonthCalendarItemsBackgroundImage;
    QFont mMonthCalendarItemsFont;
    QColor mMonthCalendarItemsFrameColor;
    QString mMonthCalendarItemsIcon;
    QColor mMonthCalendarItemsEventsBackgroundColor;
    QString mMonthCalendarItemsEventsBackgroundImage;
    QFont mMonthCalendarItemsEventsFont;
    QColor mMonthCalendarItemsEventsFrameColor;
    QString mMonthCalendarItemsEventsIcon;
    QColor mMonthCalendarItemsToDosBackgroundColor;
    QString mMonthCalendarItemsToDosBackgroundImage;
    QFont mMonthCalendarItemsToDosFont;
    QColor mMonthCalendarItemsToDosFrameColor;
    QString mMonthCalendarItemsToDosIcon;
    QColor mMonthCalendarItemsToDosDueTodayBackgroundColor;
    QString mMonthCalendarItemsToDosDueTodayBackgroundImage;
    QFont mMonthCalendarItemsToDosDueTodayFont;
    QColor mMonthCalendarItemsToDosDueTodayFrameColor;
    QString mMonthCalendarItemsToDosDueTodayIcon;
    QColor mMonthCalendarItemsToDosOverdueBackgroundColor;
    QString mMonthCalendarItemsToDosOverdueBackgroundImage;
    QFont mMonthCalendarItemsToDosOverdueFont;
    QColor mMonthCalendarItemsToDosOverdueFrameColor;
    QString mMonthCalendarItemsToDosOverdueIcon;
    QColor mMonthHolidaysBackgroundColor;
    QString mMonthHolidaysBackgroundImage;

    // Activities
    bool mEnabledActivities;

    // General
    QString mPreviousNewFeaturesMD5;

  private:
    ItemBool *mConfirmItem;
    ItemEnum *mDestinationItem;
    ItemString *mTimeZoneIdItem;
    ItemEnum *mWeekStartDayItem;
    ItemDateTime *mWorkingHoursStartItem;
    ItemDateTime *mWorkingHoursEndItem;
    ItemBool *mColorMonthBusyDaysEnabledItem;
    ItemBool *mEnableToolTipsItem;
    ItemBool *mTodosUseCategoryColorsItem;
    ItemInt *mNextXDaysItem;
    ItemBool *mDailyRecurItem;
    ItemBool *mWeeklyRecurItem;
    ItemBool *mHighlightTodosItem;
    ItemBool *mHighlightJournalsItem;
    ItemBool *mWeekNumbersShowItem;
    ItemBool *mWeekNumbersShowWorkItem;
    ItemInt *mHourSizeItem;
    ItemBool *mEnableAgendaItemIconsItem;
    ItemBool *mEnableAgendaBoldEvenHoursItem;
    ItemBool *mEnableAgendaItemDescItem;
    ItemBool *mEnableAgendaItemLocationItem;
    ItemBool *mShowTodosAgendaViewItem;
    ItemBool *mMarcusBainsEnabledItem;
    ItemBool *mMarcusBainsShowSecondsItem;
    ItemBool *mSelectionStartsEditorItem;
    ItemEnum *mAgendaViewColorsItem;
    ItemBool *mColorBusyDaysEnabledItem;
    ItemEnum *mAgendaViewCalendarDisplayItem;
    ItemBool *mEnableMonthItemIconsItem;
    ItemBool *mShowTimeInMonthViewItem;
    ItemBool *mShowEndTimeInMonthViewItem;
    ItemBool *mShowTodosMonthViewItem;
    ItemBool *mShowJournalsMonthViewItem;
    ItemBool *mShowHolidaysMonthViewItem;
    ItemBool *mShowHolidaysBackgroundMonthViewItem;
    ItemBool *mFullViewMonthItem;
    ItemEnum *mMonthViewColorsItem;
    ItemBool *mSortCompletedTodosSeparatelyItem;
    ItemBool *mFullViewTodoItem;
    ItemBool *mFlatListTodoItem;
    ItemBool *mRecordTodosInJournalsItem;
    ItemColor *mHolidayColorItem;
    ItemColor *mAgendaBgColorItem;
    ItemColor *mAgendaMarcusBainsLineLineColorItem;
    ItemColor *mViewBgBusyColorItem;
    ItemColor *mWorkingHoursColorItem;
    ItemColor *mTodoDueTodayColorItem;
    ItemColor *mTodoOverdueColorItem;
    ItemColor *mMonthTodayColorItem;
    ItemFont *mAgendaTimeLabelsFontItem;
    ItemFont *mMonthViewFontItem;
    ItemFont *mAgendaViewFontItem;
    ItemFont *mAgendaMarcusBainsLineFontItem;
    ItemStringList *mSelectedPluginsItem;
    ItemBool *mEnableQuickTodoItem;
    ItemBool *mEnableTodoQuickSearchItem;
    ItemEnum *mDefaultTodoAttachMethodItem;
    ItemBool *mCompactDialogsItem;
    ItemBool *mShowMenuBarItem;
    ItemInt *mWorkWeekMaskItem;
    ItemInt *mDefaultResourceColorSeedItem;
    ItemStringList *mDefaultResourceColorsItem;
    ItemBool *mAssignDefaultResourceColorsItem;
    ItemStringList *mDecorationsAtMonthViewTopItem;
    ItemStringList *mDecorationsAtAgendaViewTopItem;
    ItemStringList *mDecorationsAtAgendaViewBottomItem;
    ItemBool *mAgendaViewShowSidebarItem;
    ItemBool *mJournalViewShowSidebarItem;
    ItemBool *mListViewShowSidebarItem;
    ItemBool *mMonthViewShowSidebarItem;
    ItemBool *mTimelineViewShowSidebarItem;
    ItemBool *mTodoViewShowSidebarItem;
    ItemBool *mWhatsNextViewShowSidebarItem;
    ItemColor *mAgendaGridBackgroundColorItem;
    ItemString *mAgendaGridBackgroundImageItem;
    ItemColor *mAgendaGridHighlightColorItem;
    ItemString *mAgendaGridWorkHoursBackgroundImageItem;
    ItemColor *mAgendaCalendarItemsBackgroundColorItem;
    ItemString *mAgendaCalendarItemsBackgroundImageItem;
    ItemFont *mAgendaCalendarItemsFontItem;
    ItemColor *mAgendaCalendarItemsFrameColorItem;
    ItemString *mAgendaCalendarItemsIconItem;
    ItemString *mAgendaCalendarItemsEventsBackgroundImageItem;
    ItemFont *mAgendaCalendarItemsEventsFontItem;
    ItemColor *mAgendaCalendarItemsEventsFrameColorItem;
    ItemString *mAgendaCalendarItemsEventsIconItem;
    ItemColor *mAgendaCalendarItemsToDosBackgroundColorItem;
    ItemString *mAgendaCalendarItemsToDosBackgroundImageItem;
    ItemFont *mAgendaCalendarItemsToDosFontItem;
    ItemColor *mAgendaCalendarItemsToDosFrameColorItem;
    ItemString *mAgendaCalendarItemsToDosIconItem;
    ItemString *mAgendaCalendarItemsToDosDueTodayBackgroundImageItem;
    ItemFont *mAgendaCalendarItemsToDosDueTodayFontItem;
    ItemColor *mAgendaCalendarItemsToDosDueTodayFrameColorItem;
    ItemString *mAgendaCalendarItemsToDosDueTodayIconItem;
    ItemString *mAgendaCalendarItemsToDosOverdueBackgroundImageItem;
    ItemFont *mAgendaCalendarItemsToDosOverdueFontItem;
    ItemColor *mAgendaCalendarItemsToDosOverdueFrameColorItem;
    ItemString *mAgendaCalendarItemsToDosOverdueIconItem;
    ItemColor *mAgendaHolidaysBackgroundColorItem;
    ItemBool *mUseSystemColorItem;
    ItemString *mAgendaHolidaysBackgroundImageItem;
    ItemColor *mMonthGridBackgroundColorItem;
    ItemString *mMonthGridBackgroundImageItem;
    ItemColor *mMonthGridHighlightColorItem;
    ItemColor *mMonthGridWorkHoursBackgroundColorItem;
    ItemString *mMonthGridWorkHoursBackgroundImageItem;
    ItemColor *mMonthCalendarItemsBackgroundColorItem;
    ItemString *mMonthCalendarItemsBackgroundImageItem;
    ItemFont *mMonthCalendarItemsFontItem;
    ItemColor *mMonthCalendarItemsFrameColorItem;
    ItemString *mMonthCalendarItemsIconItem;
    ItemColor *mMonthCalendarItemsEventsBackgroundColorItem;
    ItemString *mMonthCalendarItemsEventsBackgroundImageItem;
    ItemFont *mMonthCalendarItemsEventsFontItem;
    ItemColor *mMonthCalendarItemsEventsFrameColorItem;
    ItemString *mMonthCalendarItemsEventsIconItem;
    ItemColor *mMonthCalendarItemsToDosBackgroundColorItem;
    ItemString *mMonthCalendarItemsToDosBackgroundImageItem;
    ItemFont *mMonthCalendarItemsToDosFontItem;
    ItemColor *mMonthCalendarItemsToDosFrameColorItem;
    ItemString *mMonthCalendarItemsToDosIconItem;
    ItemColor *mMonthCalendarItemsToDosDueTodayBackgroundColorItem;
    ItemString *mMonthCalendarItemsToDosDueTodayBackgroundImageItem;
    ItemFont *mMonthCalendarItemsToDosDueTodayFontItem;
    ItemColor *mMonthCalendarItemsToDosDueTodayFrameColorItem;
    ItemString *mMonthCalendarItemsToDosDueTodayIconItem;
    ItemColor *mMonthCalendarItemsToDosOverdueBackgroundColorItem;
    ItemString *mMonthCalendarItemsToDosOverdueBackgroundImageItem;
    ItemFont *mMonthCalendarItemsToDosOverdueFontItem;
    ItemColor *mMonthCalendarItemsToDosOverdueFrameColorItem;
    ItemString *mMonthCalendarItemsToDosOverdueIconItem;
    ItemColor *mMonthHolidaysBackgroundColorItem;
    ItemString *mMonthHolidaysBackgroundImageItem;
    ItemBool *mEnabledActivitiesItem;
    ItemString *mPreviousNewFeaturesMD5Item;
};

#endif

