/*
 * This file was generated by qdbusxml2cpp version 0.8
 * Source file was org.kde.calendar.Calendar.xml
 *
 * qdbusxml2cpp is Copyright (C) The Qt Company Ltd. and other contributors.
 *
 * This is an auto-generated file.
 * This file may have been hand-edited. Look for HAND-EDIT comments
 * before re-generating it.
 */

#ifndef CALENDARINTERFACEADAPTOR_H
#define CALENDARINTERFACEADAPTOR_H

#include <QtCore/QObject>
#include <QtDBus/QtDBus>
#include "actionmanager.h"
#include <QtCore/qcontainerfwd.h>

/*
 * Adaptor class for interface org.kde.calendar.Calendar
 */
class CalendarInterfaceAdaptor: public QDBusAbstractAdaptor
{
    Q_OBJECT
    Q_CLASSINFO("D-Bus Interface", "org.kde.calendar.Calendar")
    Q_CLASSINFO("D-Bus Introspection", ""
"  <interface name=\"org.kde.calendar.Calendar\">\n"
"    <method name=\"showIncidenceByUid\">\n"
"      <arg direction=\"in\" type=\"s\" name=\"uid\"/>\n"
"      <arg direction=\"in\" type=\"((iii)(iiii)i)\" name=\"occurrence\"/>\n"
"      <arg direction=\"in\" type=\"s\" name=\"xdgActivationToken\"/>\n"
"      <annotation value=\"QDateTime\" name=\"org.qtproject.QtDBus.QtTypeName.In1\"/>\n"
"    </method>\n"
"  </interface>\n"
        "")
public:
    CalendarInterfaceAdaptor(ActionManager *parent);
    ~CalendarInterfaceAdaptor() override;

    inline ActionManager *parent() const
    { return static_cast<ActionManager *>(QObject::parent()); }

public: // PROPERTIES
public Q_SLOTS: // METHODS
    void showIncidenceByUid(const QString &uid, const QDateTime &occurrence, const QString &xdgActivationToken);
Q_SIGNALS: // SIGNALS
};

#endif
