/****************************************************************************
** Meta object code from reading C++ file 'actionmanager.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.11.2)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../../korganizer-26.08.0/src/actionmanager.h"
#include <QtCore/qmetatype.h>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'actionmanager.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.11.2. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN13ActionManagerE_t {};
} // unnamed namespace

template <> constexpr inline auto ActionManager::qt_create_metaobjectdata<qt_meta_tag_ZN13ActionManagerE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "ActionManager",
        "configChanged",
        "",
        "importURL",
        "QUrl",
        "url",
        "merge",
        "saveURL",
        "saveAsURL",
        "toggleMenubar",
        "dontShowWarning",
        "openEventEditor",
        "summary",
        "description",
        "attachments",
        "attendees",
        "uri",
        "file",
        "attachmentMimetype",
        "attachmentUris",
        "attachmentMimetypes",
        "attachmentIsInline",
        "openTodoEditor",
        "openJournalEditor",
        "date",
        "text",
        "showJournalView",
        "showTodoView",
        "showEventView",
        "goDate",
        "showDate",
        "updateConfig",
        "processIncidenceSelection",
        "Akonadi::Item",
        "item",
        "keyBindings",
        "readSettings",
        "writeSettings",
        "saveProperties",
        "KConfigGroup&",
        "readProperties",
        "KConfigGroup",
        "importCalendar",
        "setItems",
        "file_open",
        "file_import",
        "file_archive",
        "configureDateTime",
        "toggleDateNavigator",
        "toggleTodoView",
        "toggleEventViewer",
        "toggleResourceView",
        "slotAutoArchivingSettingsModified",
        "slotAutoArchive",
        "setTitle",
        "updateUndoRedoActions",
        "dumpText",
        "slotDefaultResourceChanged",
        "Akonadi::Collection",
        "slotResourcesAddedRemoved",
        "slotNewEvent",
        "slotNewTodo",
        "slotNewSubTodo",
        "slotNewJournal",
        "slotMergeFinished",
        "success",
        "total",
        "slotNewResourceFinished"
    };

    QtMocHelpers::UintData qt_methods {
        // Signal 'configChanged'
        QtMocHelpers::SignalData<void()>(1, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'importURL'
        QtMocHelpers::SlotData<bool(const QUrl &, bool)>(3, 2, QMC::AccessPublic, QMetaType::Bool, {{
            { 0x80000000 | 4, 5 }, { QMetaType::Bool, 6 },
        }}),
        // Slot 'saveURL'
        QtMocHelpers::SlotData<bool()>(7, 2, QMC::AccessPublic, QMetaType::Bool),
        // Slot 'saveAsURL'
        QtMocHelpers::SlotData<bool(const QUrl &)>(8, 2, QMC::AccessPublic, QMetaType::Bool, {{
            { 0x80000000 | 4, 4 },
        }}),
        // Slot 'toggleMenubar'
        QtMocHelpers::SlotData<void(bool)>(9, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Bool, 10 },
        }}),
        // Slot 'toggleMenubar'
        QtMocHelpers::SlotData<void()>(9, 2, QMC::AccessPublic | QMC::MethodCloned, QMetaType::Void),
        // Slot 'openEventEditor'
        QtMocHelpers::SlotData<void()>(11, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'openEventEditor'
        QtMocHelpers::SlotData<void(const QString &)>(11, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 12 },
        }}),
        // Slot 'openEventEditor'
        QtMocHelpers::SlotData<void(const QString &, const QString &, const QStringList &)>(11, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 12 }, { QMetaType::QString, 13 }, { QMetaType::QStringList, 14 },
        }}),
        // Slot 'openEventEditor'
        QtMocHelpers::SlotData<void(const QString &, const QString &, const QStringList &, const QStringList &)>(11, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 12 }, { QMetaType::QString, 13 }, { QMetaType::QStringList, 14 }, { QMetaType::QStringList, 15 },
        }}),
        // Slot 'openEventEditor'
        QtMocHelpers::SlotData<void(const QString &, const QString &, const QString &, const QString &, const QStringList &, const QString &)>(11, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 12 }, { QMetaType::QString, 13 }, { QMetaType::QString, 16 }, { QMetaType::QString, 17 },
            { QMetaType::QStringList, 15 }, { QMetaType::QString, 18 },
        }}),
        // Slot 'openEventEditor'
        QtMocHelpers::SlotData<void(const QString &, const QString &, const QStringList &, const QStringList &, const QStringList &, bool)>(11, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 12 }, { QMetaType::QString, 13 }, { QMetaType::QStringList, 19 }, { QMetaType::QStringList, 15 },
            { QMetaType::QStringList, 20 }, { QMetaType::Bool, 21 },
        }}),
        // Slot 'openTodoEditor'
        QtMocHelpers::SlotData<void(const QString &)>(22, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 2 },
        }}),
        // Slot 'openTodoEditor'
        QtMocHelpers::SlotData<void(const QString &, const QString &, const QStringList &)>(22, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 12 }, { QMetaType::QString, 13 }, { QMetaType::QStringList, 14 },
        }}),
        // Slot 'openTodoEditor'
        QtMocHelpers::SlotData<void(const QString &, const QString &, const QStringList &, const QStringList &)>(22, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 12 }, { QMetaType::QString, 13 }, { QMetaType::QStringList, 14 }, { QMetaType::QStringList, 15 },
        }}),
        // Slot 'openTodoEditor'
        QtMocHelpers::SlotData<void(const QString &, const QString &, const QString &, const QString &, const QStringList &, const QString &)>(22, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 12 }, { QMetaType::QString, 13 }, { QMetaType::QString, 16 }, { QMetaType::QString, 17 },
            { QMetaType::QStringList, 15 }, { QMetaType::QString, 18 },
        }}),
        // Slot 'openTodoEditor'
        QtMocHelpers::SlotData<void(const QString &, const QString &, const QStringList &, const QStringList &, const QStringList &, bool)>(22, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 12 }, { QMetaType::QString, 13 }, { QMetaType::QStringList, 19 }, { QMetaType::QStringList, 15 },
            { QMetaType::QStringList, 20 }, { QMetaType::Bool, 21 },
        }}),
        // Slot 'openJournalEditor'
        QtMocHelpers::SlotData<void(QDate)>(23, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QDate, 24 },
        }}),
        // Slot 'openJournalEditor'
        QtMocHelpers::SlotData<void(const QString &, QDate)>(23, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 25 }, { QMetaType::QDate, 24 },
        }}),
        // Slot 'openJournalEditor'
        QtMocHelpers::SlotData<void(const QString &)>(23, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 25 },
        }}),
        // Slot 'showJournalView'
        QtMocHelpers::SlotData<void()>(26, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'showTodoView'
        QtMocHelpers::SlotData<void()>(27, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'showEventView'
        QtMocHelpers::SlotData<void()>(28, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'goDate'
        QtMocHelpers::SlotData<void(QDate)>(29, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QDate, 2 },
        }}),
        // Slot 'goDate'
        QtMocHelpers::SlotData<void(const QString &)>(29, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 2 },
        }}),
        // Slot 'showDate'
        QtMocHelpers::SlotData<void(QDate)>(30, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QDate, 24 },
        }}),
        // Slot 'updateConfig'
        QtMocHelpers::SlotData<void()>(31, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'processIncidenceSelection'
        QtMocHelpers::SlotData<void(const Akonadi::Item &, QDate)>(32, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 33, 34 }, { QMetaType::QDate, 24 },
        }}),
        // Slot 'keyBindings'
        QtMocHelpers::SlotData<void()>(35, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'readSettings'
        QtMocHelpers::SlotData<void()>(36, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'writeSettings'
        QtMocHelpers::SlotData<void()>(37, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'saveProperties'
        QtMocHelpers::SlotData<void(KConfigGroup &)>(38, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 39, 2 },
        }}),
        // Slot 'readProperties'
        QtMocHelpers::SlotData<void(const KConfigGroup &)>(40, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 41, 2 },
        }}),
        // Slot 'importCalendar'
        QtMocHelpers::SlotData<void(const QUrl &)>(42, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 4, 5 },
        }}),
        // Slot 'setItems'
        QtMocHelpers::SlotData<void(const QStringList &, int)>(43, 2, QMC::AccessProtected, QMetaType::Void, {{
            { QMetaType::QStringList, 2 }, { QMetaType::Int, 2 },
        }}),
        // Slot 'file_open'
        QtMocHelpers::SlotData<void()>(44, 2, QMC::AccessProtected, QMetaType::Void),
        // Slot 'file_open'
        QtMocHelpers::SlotData<void(const QUrl &)>(44, 2, QMC::AccessProtected, QMetaType::Void, {{
            { 0x80000000 | 4, 5 },
        }}),
        // Slot 'file_import'
        QtMocHelpers::SlotData<void()>(45, 2, QMC::AccessProtected, QMetaType::Void),
        // Slot 'file_archive'
        QtMocHelpers::SlotData<void()>(46, 2, QMC::AccessProtected, QMetaType::Void),
        // Slot 'configureDateTime'
        QtMocHelpers::SlotData<void()>(47, 2, QMC::AccessProtected, QMetaType::Void),
        // Slot 'toggleDateNavigator'
        QtMocHelpers::SlotData<void()>(48, 2, QMC::AccessProtected, QMetaType::Void),
        // Slot 'toggleTodoView'
        QtMocHelpers::SlotData<void()>(49, 2, QMC::AccessProtected, QMetaType::Void),
        // Slot 'toggleEventViewer'
        QtMocHelpers::SlotData<void()>(50, 2, QMC::AccessProtected, QMetaType::Void),
        // Slot 'toggleResourceView'
        QtMocHelpers::SlotData<void()>(51, 2, QMC::AccessProtected, QMetaType::Void),
        // Slot 'slotAutoArchivingSettingsModified'
        QtMocHelpers::SlotData<void()>(52, 2, QMC::AccessProtected, QMetaType::Void),
        // Slot 'slotAutoArchive'
        QtMocHelpers::SlotData<void()>(53, 2, QMC::AccessProtected, QMetaType::Void),
        // Slot 'setTitle'
        QtMocHelpers::SlotData<void()>(54, 2, QMC::AccessProtected, QMetaType::Void),
        // Slot 'updateUndoRedoActions'
        QtMocHelpers::SlotData<void()>(55, 2, QMC::AccessProtected, QMetaType::Void),
        // Slot 'dumpText'
        QtMocHelpers::SlotData<void(const QString &)>(56, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::QString, 2 },
        }}),
        // Slot 'slotDefaultResourceChanged'
        QtMocHelpers::SlotData<void(const Akonadi::Collection &)>(57, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { 0x80000000 | 58, 2 },
        }}),
        // Slot 'slotResourcesAddedRemoved'
        QtMocHelpers::SlotData<void()>(59, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'slotNewEvent'
        QtMocHelpers::SlotData<void()>(60, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'slotNewTodo'
        QtMocHelpers::SlotData<void()>(61, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'slotNewSubTodo'
        QtMocHelpers::SlotData<void()>(62, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'slotNewJournal'
        QtMocHelpers::SlotData<void()>(63, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'slotMergeFinished'
        QtMocHelpers::SlotData<void(bool, int)>(64, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::Bool, 65 }, { QMetaType::Int, 66 },
        }}),
        // Slot 'slotNewResourceFinished'
        QtMocHelpers::SlotData<void(bool)>(67, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::Bool, 2 },
        }}),
    };
    QtMocHelpers::UintData qt_properties {
    };
    QtMocHelpers::UintData qt_enums {
    };
    return QtMocHelpers::metaObjectData<ActionManager, qt_meta_tag_ZN13ActionManagerE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject ActionManager::staticMetaObject = { {
    QMetaObject::SuperData::link<QObject::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN13ActionManagerE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN13ActionManagerE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN13ActionManagerE_t>.metaTypes,
    nullptr
} };

void ActionManager::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<ActionManager *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->configChanged(); break;
        case 1: { bool _r = _t->importURL((*reinterpret_cast<std::add_pointer_t<QUrl>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<bool>>(_a[2])));
            if (_a[0]) *reinterpret_cast<bool*>(_a[0]) = std::move(_r); }  break;
        case 2: { bool _r = _t->saveURL();
            if (_a[0]) *reinterpret_cast<bool*>(_a[0]) = std::move(_r); }  break;
        case 3: { bool _r = _t->saveAsURL((*reinterpret_cast<std::add_pointer_t<QUrl>>(_a[1])));
            if (_a[0]) *reinterpret_cast<bool*>(_a[0]) = std::move(_r); }  break;
        case 4: _t->toggleMenubar((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 5: _t->toggleMenubar(); break;
        case 6: _t->openEventEditor(); break;
        case 7: _t->openEventEditor((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 8: _t->openEventEditor((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<QStringList>>(_a[3]))); break;
        case 9: _t->openEventEditor((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<QStringList>>(_a[3])),(*reinterpret_cast<std::add_pointer_t<QStringList>>(_a[4]))); break;
        case 10: _t->openEventEditor((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[3])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[4])),(*reinterpret_cast<std::add_pointer_t<QStringList>>(_a[5])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[6]))); break;
        case 11: _t->openEventEditor((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<QStringList>>(_a[3])),(*reinterpret_cast<std::add_pointer_t<QStringList>>(_a[4])),(*reinterpret_cast<std::add_pointer_t<QStringList>>(_a[5])),(*reinterpret_cast<std::add_pointer_t<bool>>(_a[6]))); break;
        case 12: _t->openTodoEditor((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 13: _t->openTodoEditor((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<QStringList>>(_a[3]))); break;
        case 14: _t->openTodoEditor((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<QStringList>>(_a[3])),(*reinterpret_cast<std::add_pointer_t<QStringList>>(_a[4]))); break;
        case 15: _t->openTodoEditor((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[3])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[4])),(*reinterpret_cast<std::add_pointer_t<QStringList>>(_a[5])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[6]))); break;
        case 16: _t->openTodoEditor((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<QStringList>>(_a[3])),(*reinterpret_cast<std::add_pointer_t<QStringList>>(_a[4])),(*reinterpret_cast<std::add_pointer_t<QStringList>>(_a[5])),(*reinterpret_cast<std::add_pointer_t<bool>>(_a[6]))); break;
        case 17: _t->openJournalEditor((*reinterpret_cast<std::add_pointer_t<QDate>>(_a[1]))); break;
        case 18: _t->openJournalEditor((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QDate>>(_a[2]))); break;
        case 19: _t->openJournalEditor((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 20: _t->showJournalView(); break;
        case 21: _t->showTodoView(); break;
        case 22: _t->showEventView(); break;
        case 23: _t->goDate((*reinterpret_cast<std::add_pointer_t<QDate>>(_a[1]))); break;
        case 24: _t->goDate((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 25: _t->showDate((*reinterpret_cast<std::add_pointer_t<QDate>>(_a[1]))); break;
        case 26: _t->updateConfig(); break;
        case 27: _t->processIncidenceSelection((*reinterpret_cast<std::add_pointer_t<Akonadi::Item>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QDate>>(_a[2]))); break;
        case 28: _t->keyBindings(); break;
        case 29: _t->readSettings(); break;
        case 30: _t->writeSettings(); break;
        case 31: _t->saveProperties((*reinterpret_cast<std::add_pointer_t<KConfigGroup&>>(_a[1]))); break;
        case 32: _t->readProperties((*reinterpret_cast<std::add_pointer_t<KConfigGroup>>(_a[1]))); break;
        case 33: _t->importCalendar((*reinterpret_cast<std::add_pointer_t<QUrl>>(_a[1]))); break;
        case 34: _t->setItems((*reinterpret_cast<std::add_pointer_t<QStringList>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[2]))); break;
        case 35: _t->file_open(); break;
        case 36: _t->file_open((*reinterpret_cast<std::add_pointer_t<QUrl>>(_a[1]))); break;
        case 37: _t->file_import(); break;
        case 38: _t->file_archive(); break;
        case 39: _t->configureDateTime(); break;
        case 40: _t->toggleDateNavigator(); break;
        case 41: _t->toggleTodoView(); break;
        case 42: _t->toggleEventViewer(); break;
        case 43: _t->toggleResourceView(); break;
        case 44: _t->slotAutoArchivingSettingsModified(); break;
        case 45: _t->slotAutoArchive(); break;
        case 46: _t->setTitle(); break;
        case 47: _t->updateUndoRedoActions(); break;
        case 48: _t->dumpText((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 49: _t->slotDefaultResourceChanged((*reinterpret_cast<std::add_pointer_t<Akonadi::Collection>>(_a[1]))); break;
        case 50: _t->slotResourcesAddedRemoved(); break;
        case 51: _t->slotNewEvent(); break;
        case 52: _t->slotNewTodo(); break;
        case 53: _t->slotNewSubTodo(); break;
        case 54: _t->slotNewJournal(); break;
        case 55: _t->slotMergeFinished((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[2]))); break;
        case 56: _t->slotNewResourceFinished((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        default: ;
        }
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        switch (_id) {
        default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
        case 27:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< Akonadi::Item >(); break;
            }
            break;
        }
    }
    if (_c == QMetaObject::IndexOfMethod) {
        if (QtMocHelpers::indexOfMethod<void (ActionManager::*)()>(_a, &ActionManager::configChanged, 0))
            return;
    }
}

const QMetaObject *ActionManager::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *ActionManager::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN13ActionManagerE_t>.strings))
        return static_cast<void*>(this);
    return QObject::qt_metacast(_clname);
}

int ActionManager::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QObject::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 57)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 57;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 57)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 57;
    }
    return _id;
}

// SIGNAL 0
void ActionManager::configChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 0, nullptr);
}
QT_WARNING_POP
