/****************************************************************************
** Meta object code from reading C++ file 'korganizeradaptor.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.11.2)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "korganizeradaptor.h"
#include <QtCore/qmetatype.h>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'korganizeradaptor.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.11.2. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN17KorganizerAdaptorE_t {};
} // unnamed namespace

template <> constexpr inline auto KorganizerAdaptor::qt_create_metaobjectdata<qt_meta_tag_ZN17KorganizerAdaptorE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "KorganizerAdaptor",
        "D-Bus Interface",
        "org.kde.korganizer.Korganizer",
        "D-Bus Introspection",
        "  <interface name=\"org.kde.korganizer.Korganizer\">\n    <method "
        "name=\"openURL\">\n      <arg direction=\"in\" type=\"s\" name=\"u"
        "rl\"/>\n      <arg direction=\"out\" type=\"b\"/>\n    </method>\n"
        "    <method name=\"mergeURL\">\n      <arg direction=\"in\" type=\""
        "s\" name=\"url\"/>\n      <arg direction=\"out\" type=\"b\"/>\n   "
        " </method>\n    <method name=\"saveURL\">\n      <arg direction=\""
        "out\" type=\"b\"/>\n    </method>\n    <method name=\"saveAsURL\">"
        "\n      <arg direction=\"in\" type=\"s\" name=\"url\"/>\n      <ar"
        "g direction=\"out\" type=\"b\"/>\n    </method>\n    <method name="
        "\"getCurrentURLasString\">\n      <arg direction=\"out\" type=\"s\""
        "/>\n    </method>\n    <method name=\"editIncidence\">\n      <arg"
        " direction=\"in\" type=\"s\" name=\"url\"/>\n      <arg direction="
        "\"out\" type=\"b\"/>\n    </method>\n    <method name=\"deleteInci"
        "dence\">\n      <arg direction=\"in\" type=\"s\" name=\"url\"/>\n "
        "     <arg direction=\"out\" type=\"b\"/>\n    </method>\n    <meth"
        "od name=\"deleteIncidence\">\n      <arg direction=\"in\" type=\"s"
        "\" name=\"url\"/>\n      <arg direction=\"in\" type=\"b\" name=\"f"
        "orce\"/>\n      <arg direction=\"out\" type=\"b\"/>\n    </method>"
        "\n    <method name=\"addIncidence\">\n      <arg direction=\"in\" "
        "type=\"s\" name=\"ical\"/>\n      <arg direction=\"out\" type=\"b\""
        "/>\n    </method>\n    <method name=\"showIncidence\">\n      <arg"
        " direction=\"in\" type=\"s\" name=\"url\"/>\n      <arg direction="
        "\"out\" type=\"b\"/>\n    </method>\n    <method name=\"showIncide"
        "nceContext\">\n      <arg direction=\"in\" type=\"s\" name=\"url\""
        "/>\n      <arg direction=\"out\" type=\"b\"/>\n    </method>\n    "
        "<method name=\"handleCommandLine\">\n      <arg direction=\"out\" "
        "type=\"b\"/>\n      <arg direction=\"in\" type=\"as\" name=\"args\""
        "/>\n    </method>\n  </interface>\n",
        "addIncidence",
        "",
        "ical",
        "deleteIncidence",
        "url",
        "force",
        "editIncidence",
        "getCurrentURLasString",
        "handleCommandLine",
        "args",
        "mergeURL",
        "openURL",
        "saveAsURL",
        "saveURL",
        "showIncidence",
        "showIncidenceContext"
    };

    QtMocHelpers::UintData qt_methods {
        // Slot 'addIncidence'
        QtMocHelpers::SlotData<bool(const QString &)>(5, 6, QMC::AccessPublic, QMetaType::Bool, {{
            { QMetaType::QString, 7 },
        }}),
        // Slot 'deleteIncidence'
        QtMocHelpers::SlotData<bool(const QString &, bool)>(8, 6, QMC::AccessPublic, QMetaType::Bool, {{
            { QMetaType::QString, 9 }, { QMetaType::Bool, 10 },
        }}),
        // Slot 'deleteIncidence'
        QtMocHelpers::SlotData<bool(const QString &)>(8, 6, QMC::AccessPublic, QMetaType::Bool, {{
            { QMetaType::QString, 9 },
        }}),
        // Slot 'editIncidence'
        QtMocHelpers::SlotData<bool(const QString &)>(11, 6, QMC::AccessPublic, QMetaType::Bool, {{
            { QMetaType::QString, 9 },
        }}),
        // Slot 'getCurrentURLasString'
        QtMocHelpers::SlotData<QString()>(12, 6, QMC::AccessPublic, QMetaType::QString),
        // Slot 'handleCommandLine'
        QtMocHelpers::SlotData<bool(const QStringList &)>(13, 6, QMC::AccessPublic, QMetaType::Bool, {{
            { QMetaType::QStringList, 14 },
        }}),
        // Slot 'mergeURL'
        QtMocHelpers::SlotData<bool(const QString &)>(15, 6, QMC::AccessPublic, QMetaType::Bool, {{
            { QMetaType::QString, 9 },
        }}),
        // Slot 'openURL'
        QtMocHelpers::SlotData<bool(const QString &)>(16, 6, QMC::AccessPublic, QMetaType::Bool, {{
            { QMetaType::QString, 9 },
        }}),
        // Slot 'saveAsURL'
        QtMocHelpers::SlotData<bool(const QString &)>(17, 6, QMC::AccessPublic, QMetaType::Bool, {{
            { QMetaType::QString, 9 },
        }}),
        // Slot 'saveURL'
        QtMocHelpers::SlotData<bool()>(18, 6, QMC::AccessPublic, QMetaType::Bool),
        // Slot 'showIncidence'
        QtMocHelpers::SlotData<bool(const QString &)>(19, 6, QMC::AccessPublic, QMetaType::Bool, {{
            { QMetaType::QString, 9 },
        }}),
        // Slot 'showIncidenceContext'
        QtMocHelpers::SlotData<bool(const QString &)>(20, 6, QMC::AccessPublic, QMetaType::Bool, {{
            { QMetaType::QString, 9 },
        }}),
    };
    QtMocHelpers::UintData qt_properties {
    };
    QtMocHelpers::UintData qt_enums {
    };
    QtMocHelpers::UintData qt_constructors {};
    QtMocHelpers::ClassInfos qt_classinfo({
            {    1,    2 },
            {    3,    4 },
    });
    return QtMocHelpers::metaObjectData<KorganizerAdaptor, qt_meta_tag_ZN17KorganizerAdaptorE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums, qt_constructors, qt_classinfo);
}
Q_CONSTINIT const QMetaObject KorganizerAdaptor::staticMetaObject = { {
    QMetaObject::SuperData::link<QDBusAbstractAdaptor::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN17KorganizerAdaptorE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN17KorganizerAdaptorE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN17KorganizerAdaptorE_t>.metaTypes,
    nullptr
} };

void KorganizerAdaptor::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<KorganizerAdaptor *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: { bool _r = _t->addIncidence((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])));
            if (_a[0]) *reinterpret_cast<bool*>(_a[0]) = std::move(_r); }  break;
        case 1: { bool _r = _t->deleteIncidence((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<bool>>(_a[2])));
            if (_a[0]) *reinterpret_cast<bool*>(_a[0]) = std::move(_r); }  break;
        case 2: { bool _r = _t->deleteIncidence((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])));
            if (_a[0]) *reinterpret_cast<bool*>(_a[0]) = std::move(_r); }  break;
        case 3: { bool _r = _t->editIncidence((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])));
            if (_a[0]) *reinterpret_cast<bool*>(_a[0]) = std::move(_r); }  break;
        case 4: { QString _r = _t->getCurrentURLasString();
            if (_a[0]) *reinterpret_cast<QString*>(_a[0]) = std::move(_r); }  break;
        case 5: { bool _r = _t->handleCommandLine((*reinterpret_cast<std::add_pointer_t<QStringList>>(_a[1])));
            if (_a[0]) *reinterpret_cast<bool*>(_a[0]) = std::move(_r); }  break;
        case 6: { bool _r = _t->mergeURL((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])));
            if (_a[0]) *reinterpret_cast<bool*>(_a[0]) = std::move(_r); }  break;
        case 7: { bool _r = _t->openURL((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])));
            if (_a[0]) *reinterpret_cast<bool*>(_a[0]) = std::move(_r); }  break;
        case 8: { bool _r = _t->saveAsURL((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])));
            if (_a[0]) *reinterpret_cast<bool*>(_a[0]) = std::move(_r); }  break;
        case 9: { bool _r = _t->saveURL();
            if (_a[0]) *reinterpret_cast<bool*>(_a[0]) = std::move(_r); }  break;
        case 10: { bool _r = _t->showIncidence((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])));
            if (_a[0]) *reinterpret_cast<bool*>(_a[0]) = std::move(_r); }  break;
        case 11: { bool _r = _t->showIncidenceContext((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])));
            if (_a[0]) *reinterpret_cast<bool*>(_a[0]) = std::move(_r); }  break;
        default: ;
        }
    }
}

const QMetaObject *KorganizerAdaptor::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *KorganizerAdaptor::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN17KorganizerAdaptorE_t>.strings))
        return static_cast<void*>(this);
    return QDBusAbstractAdaptor::qt_metacast(_clname);
}

int KorganizerAdaptor::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QDBusAbstractAdaptor::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 12)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 12;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 12)
            *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType();
        _id -= 12;
    }
    return _id;
}
QT_WARNING_POP
