/*
 * This file was generated by qdbusxml2cpp version 0.8
 * Source file was org.kde.Korganizer.Calendar.xml
 *
 * qdbusxml2cpp is Copyright (C) The Qt Company Ltd. and other contributors.
 *
 * This is an auto-generated file.
 * This file may have been hand-edited. Look for HAND-EDIT comments
 * before re-generating it.
 */

#ifndef CALENDARADAPTOR_H
#define CALENDARADAPTOR_H

#include <QtCore/QObject>
#include <QtDBus/QtDBus>
#include "actionmanager.h"
#include <QtCore/qcontainerfwd.h>

/*
 * Adaptor class for interface org.kde.Korganizer.Calendar
 */
class KOrgCalendarAdaptor: public QDBusAbstractAdaptor
{
    Q_OBJECT
    Q_CLASSINFO("D-Bus Interface", "org.kde.Korganizer.Calendar")
    Q_CLASSINFO("D-Bus Introspection", ""
"  <interface name=\"org.kde.Korganizer.Calendar\">\n"
"    <method name=\"showJournalView\"/>\n"
"    <method name=\"showTodoView\"/>\n"
"    <method name=\"showEventView\"/>\n"
"    <method name=\"goDate\">\n"
"      <arg direction=\"in\" type=\"(iii)\" name=\"date\"/>\n"
"      <annotation value=\"QDate\" name=\"org.qtproject.QtDBus.QtTypeName.In0\"/>\n"
"    </method>\n"
"    <method name=\"goDate\">\n"
"      <arg direction=\"in\" type=\"s\" name=\"date\"/>\n"
"    </method>\n"
"    <method name=\"showDate\">\n"
"      <arg direction=\"in\" type=\"(iii)\" name=\"date\"/>\n"
"      <annotation value=\"QDate\" name=\"org.qtproject.QtDBus.QtTypeName.In0\"/>\n"
"    </method>\n"
"    <method name=\"openEventEditor\"/>\n"
"    <method name=\"openEventEditor\">\n"
"      <arg direction=\"in\" type=\"s\" name=\"text\"/>\n"
"    </method>\n"
"    <method name=\"openEventEditor\">\n"
"      <arg direction=\"in\" type=\"s\" name=\"summary\"/>\n"
"      <arg direction=\"in\" type=\"s\" name=\"description\"/>\n"
"      <arg direction=\"in\" type=\"as\" name=\"attachments\"/>\n"
"    </method>\n"
"    <method name=\"openEventEditor\">\n"
"      <arg direction=\"in\" type=\"s\" name=\"summary\"/>\n"
"      <arg direction=\"in\" type=\"s\" name=\"description\"/>\n"
"      <arg direction=\"in\" type=\"s\" name=\"uri\"/>\n"
"      <arg direction=\"in\" type=\"s\" name=\"file\"/>\n"
"      <arg direction=\"in\" type=\"as\" name=\"attendees\"/>\n"
"      <arg direction=\"in\" type=\"s\" name=\"attachmentMimetype\"/>\n"
"    </method>\n"
"    <method name=\"openEventEditor\">\n"
"      <arg direction=\"in\" type=\"s\" name=\"summary\"/>\n"
"      <arg direction=\"in\" type=\"s\" name=\"description\"/>\n"
"      <arg direction=\"in\" type=\"as\" name=\"attachments\"/>\n"
"      <arg direction=\"in\" type=\"as\" name=\"attendees\"/>\n"
"    </method>\n"
"    <method name=\"openEventEditor\">\n"
"      <arg direction=\"in\" type=\"s\" name=\"summary\"/>\n"
"      <arg direction=\"in\" type=\"s\" name=\"description\"/>\n"
"      <arg direction=\"in\" type=\"as\" name=\"attachmentUris\"/>\n"
"      <arg direction=\"in\" type=\"as\" name=\"attendees\"/>\n"
"      <arg direction=\"in\" type=\"as\" name=\"attachmentMimetypes\"/>\n"
"      <arg direction=\"in\" type=\"b\" name=\"attachmentIsInline\"/>\n"
"    </method>\n"
"    <method name=\"openTodoEditor\">\n"
"      <arg direction=\"in\" type=\"s\" name=\"text\"/>\n"
"    </method>\n"
"    <method name=\"openTodoEditor\">\n"
"      <arg direction=\"in\" type=\"s\" name=\"summary\"/>\n"
"      <arg direction=\"in\" type=\"s\" name=\"description\"/>\n"
"      <arg direction=\"in\" type=\"as\" name=\"attachments\"/>\n"
"    </method>\n"
"    <method name=\"openTodoEditor\">\n"
"      <arg direction=\"in\" type=\"s\" name=\"summary\"/>\n"
"      <arg direction=\"in\" type=\"s\" name=\"description\"/>\n"
"      <arg direction=\"in\" type=\"as\" name=\"attachments\"/>\n"
"      <arg direction=\"in\" type=\"as\" name=\"attendees\"/>\n"
"    </method>\n"
"    <method name=\"openTodoEditor\">\n"
"      <arg direction=\"in\" type=\"s\" name=\"summary\"/>\n"
"      <arg direction=\"in\" type=\"s\" name=\"description\"/>\n"
"      <arg direction=\"in\" type=\"s\" name=\"uri\"/>\n"
"      <arg direction=\"in\" type=\"s\" name=\"file\"/>\n"
"      <arg direction=\"in\" type=\"as\" name=\"attendees\"/>\n"
"      <arg direction=\"in\" type=\"s\" name=\"attachmentMimetype\"/>\n"
"    </method>\n"
"    <method name=\"openTodoEditor\">\n"
"      <arg direction=\"in\" type=\"s\" name=\"summary\"/>\n"
"      <arg direction=\"in\" type=\"s\" name=\"description\"/>\n"
"      <arg direction=\"in\" type=\"as\" name=\"attachmentUris\"/>\n"
"      <arg direction=\"in\" type=\"as\" name=\"attendees\"/>\n"
"      <arg direction=\"in\" type=\"as\" name=\"attachmentMimetypes\"/>\n"
"      <arg direction=\"in\" type=\"b\" name=\"attachmentIsInline\"/>\n"
"    </method>\n"
"    <method name=\"openJournalEditor\">\n"
"      <arg direction=\"in\" type=\"(iii)\" name=\"date\"/>\n"
"      <annotation value=\"QDate\" name=\"org.qtproject.QtDBus.QtTypeName.In0\"/>\n"
"    </method>\n"
"    <method name=\"openJournalEditor\">\n"
"      <arg direction=\"in\" type=\"s\" name=\"text\"/>\n"
"      <arg direction=\"in\" type=\"(iii)\" name=\"date\"/>\n"
"      <annotation value=\"QDate\" name=\"org.qtproject.QtDBus.QtTypeName.In1\"/>\n"
"    </method>\n"
"    <method name=\"openJournalEditor\">\n"
"      <arg direction=\"in\" type=\"s\" name=\"text\"/>\n"
"    </method>\n"
"  </interface>\n"
        "")
public:
    KOrgCalendarAdaptor(ActionManager *parent);
    ~KOrgCalendarAdaptor() override;

    inline ActionManager *parent() const
    { return static_cast<ActionManager *>(QObject::parent()); }

public: // PROPERTIES
public Q_SLOTS: // METHODS
    void goDate(const QString &date);
    void goDate(const QDate &date);
    void openEventEditor(const QString &summary, const QString &description, const QStringList &attachmentUris, const QStringList &attendees, const QStringList &attachmentMimetypes, bool attachmentIsInline);
    void openEventEditor(const QString &summary, const QString &description, const QStringList &attachments, const QStringList &attendees);
    void openEventEditor(const QString &summary, const QString &description, const QString &uri, const QString &file, const QStringList &attendees, const QString &attachmentMimetype);
    void openEventEditor(const QString &summary, const QString &description, const QStringList &attachments);
    void openEventEditor(const QString &text);
    void openEventEditor();
    void openJournalEditor(const QString &text);
    void openJournalEditor(const QString &text, const QDate &date);
    void openJournalEditor(const QDate &date);
    void openTodoEditor(const QString &summary, const QString &description, const QStringList &attachmentUris, const QStringList &attendees, const QStringList &attachmentMimetypes, bool attachmentIsInline);
    void openTodoEditor(const QString &summary, const QString &description, const QString &uri, const QString &file, const QStringList &attendees, const QString &attachmentMimetype);
    void openTodoEditor(const QString &summary, const QString &description, const QStringList &attachments, const QStringList &attendees);
    void openTodoEditor(const QString &summary, const QString &description, const QStringList &attachments);
    void openTodoEditor(const QString &text);
    void showDate(const QDate &date);
    void showEventView();
    void showJournalView();
    void showTodoView();
Q_SIGNALS: // SIGNALS
};

#endif
