// This file is generated by kconfig_compiler_kf6 from korganizer.kcfg.
// All changes you do to this file will be lost.

#include "koprefs_base.h"

#include <klocalizedstring.h>

KOPrefsBase::KOPrefsBase( )
  : KConfigSkeleton( QStringLiteral( "korganizerrc" ) )
{
  setCurrentGroup( QStringLiteral( "Save Settings" ) );

  mConfirmItem = new KConfigSkeleton::ItemBool( currentGroup(), QStringLiteral( "Confirm Deletes" ), mConfirm, true );
  mConfirmItem->setLabel( i18nd("korganizer", "Confirm deletes") );
  mConfirmItem->setToolTip( i18nd("korganizer", "Always confirm when deleting items") );
  mConfirmItem->setWhatsThis( i18nd("korganizer", "Check this box to display a confirmation dialog when deleting items.") );
  addItem( mConfirmItem, QStringLiteral( "Confirm" ) );
  QList<KConfigSkeleton::ItemEnum::Choice> valuesDestination;
  {
    KConfigSkeleton::ItemEnum::Choice choice;
    choice.name = QStringLiteral("standardDestination");
    choice.label = i18nd("korganizer", "Be added to the default calendar");
    choice.whatsThis = i18nd("korganizer", "Select this option to always record new events, to-dos and journal entries using the current default calendar.");
    valuesDestination.append( choice );
  }
  {
    KConfigSkeleton::ItemEnum::Choice choice;
    choice.name = QStringLiteral("askDestination");
    choice.label = i18nd("korganizer", "Be asked which calendar to use");
    choice.whatsThis = i18nd("korganizer", "Select this option to choose the calendar to be used to record the item each time you create a new event, to-do or journal entry. This choice is recommended if you intend to use the shared folders functionality of the Kolab server or have to manage multiple accounts using Kontact as a KDE Kolab client. ");
    valuesDestination.append( choice );
  }
  mDestinationItem = new KConfigSkeleton::ItemEnum( currentGroup(), QStringLiteral( "Destination" ), mDestination, valuesDestination, askDestination );
  mDestinationItem->setLabel( i18nd("korganizer", "New Events, To-dos and Journal Entries Should") );
  addItem( mDestinationItem, QStringLiteral( "Destination" ) );

  setCurrentGroup( QStringLiteral( "Time & Date" ) );

  mTimeZoneIdItem = new KConfigSkeleton::ItemString( currentGroup(), QStringLiteral( "TimeZoneId" ), mTimeZoneId );
  mTimeZoneIdItem->setLabel( i18nd("korganizer", "TimeZoneId") );
  mTimeZoneIdItem->setWhatsThis( i18nd("korganizer", "Select your timezone from the list of locations on this drop down box. If your city is not listed, select one which shares the same timezone. KOrganizer will automatically adjust for daylight savings.") );
  addItem( mTimeZoneIdItem, QStringLiteral( "TimeZoneId" ) );
  QList<KConfigSkeleton::ItemEnum::Choice> valuesWeekStartDay;
  mWeekStartDayItem = new KConfigSkeleton::ItemEnum( currentGroup(), QStringLiteral( "WeekStartDay" ), mWeekStartDay, valuesWeekStartDay, QLocale().firstDayOfWeek()-1 );
  mWeekStartDayItem->setLabel( i18nd("korganizer", "Weekly start day:") );
  mWeekStartDayItem->setToolTip( i18nd("korganizer", "Select the first day of each week") );
  mWeekStartDayItem->setWhatsThis( i18nd("korganizer", "Select the first day of each week. Normally, you can ignore this since it is set in your locale.") );
  addItem( mWeekStartDayItem, QStringLiteral( "WeekStartDay" ) );
  mWorkingHoursStartItem = new KConfigSkeleton::ItemDateTime( currentGroup(), QStringLiteral( "WorkingHoursStart" ), mWorkingHoursStart, QDateTime(QDate(1752,1,1), QTime(8,0)) );
  mWorkingHoursStartItem->setLabel( i18nd("korganizer", "Daily starting hour") );
  mWorkingHoursStartItem->setToolTip( i18nd("korganizer", "Set the time you typically start your day") );
  mWorkingHoursStartItem->setWhatsThis( i18nd("korganizer", "Enter the start time for your daily schedule here. Your daily schedule hours will be marked with a separate color.") );
  addItem( mWorkingHoursStartItem, QStringLiteral( "WorkingHoursStart" ) );
  mWorkingHoursEndItem = new KConfigSkeleton::ItemDateTime( currentGroup(), QStringLiteral( "WorkingHoursEnd" ), mWorkingHoursEnd, QDateTime(QDate(1752,1,1), QTime(17,0)) );
  mWorkingHoursEndItem->setLabel( i18nd("korganizer", "Daily ending hour") );
  mWorkingHoursEndItem->setToolTip( i18nd("korganizer", "Set the time you typically end your day") );
  mWorkingHoursEndItem->setWhatsThis( i18nd("korganizer", "Enter the ending time for your daily schedule here. Your daily schedule hours will be marked with a separate color.") );
  addItem( mWorkingHoursEndItem, QStringLiteral( "WorkingHoursEnd" ) );
  mColorMonthBusyDaysEnabledItem = new KConfigSkeleton::ItemBool( currentGroup(), QStringLiteral( "ColorMonthBusyDaysEnabled" ), mColorMonthBusyDaysEnabled, false );
  mColorMonthBusyDaysEnabledItem->setLabel( i18nd("korganizer", "Color busy days with a different background color") );
  mColorMonthBusyDaysEnabledItem->setWhatsThis( i18nd("korganizer", "Check this box if you want month view's background to be filled with a different color on days which have at least one all day event marked as busy. Also, you can change the background color used for this option on the Colors configuration page. Look for the \"Busy days background color\" setting.") );
  addItem( mColorMonthBusyDaysEnabledItem, QStringLiteral( "ColorMonthBusyDaysEnabled" ) );

  setCurrentGroup( QStringLiteral( "General View" ) );

  mEnableToolTipsItem = new KConfigSkeleton::ItemBool( currentGroup(), QStringLiteral( "Enable ToolTips" ), mEnableToolTips, true );
  mEnableToolTipsItem->setLabel( i18nd("korganizer", "Enable tooltips for displaying summaries") );
  mEnableToolTipsItem->setWhatsThis( i18nd("korganizer", "Check this box to display summary tooltips when hovering the mouse over an event or a to-do.") );
  addItem( mEnableToolTipsItem, QStringLiteral( "EnableToolTips" ) );
  mTodosUseCategoryColorsItem = new KConfigSkeleton::ItemBool( currentGroup(), QStringLiteral( "TodosUseCategoryColors" ), mTodosUseCategoryColors, false );
  mTodosUseCategoryColorsItem->setLabel( i18nd("korganizer", "To-dos use tag colors") );
  mTodosUseCategoryColorsItem->setWhatsThis( i18nd("korganizer", "Check this box so that to-dos will use tag colors and not colors specific to their due, due today or overdue state") );
  addItem( mTodosUseCategoryColorsItem, QStringLiteral( "TodosUseCategoryColors" ) );
  mNextXDaysItem = new KConfigSkeleton::ItemInt( currentGroup(), QStringLiteral( "Next X Days" ), mNextXDays, 3 );
  mNextXDaysItem->setLabel( i18nd("korganizer", "Next x days") );
  mNextXDaysItem->setToolTip( i18nd("korganizer", "Show this many days at a time in the Next \"x\" days view") );
  mNextXDaysItem->setWhatsThis( i18nd("korganizer", "Select the number of \"x\" days to be displayed in the next days view. To access the next \"x\" days view, choose the \"Next X Days\" menu item from the \"View\" menu.") );
  addItem( mNextXDaysItem, QStringLiteral( "NextXDays" ) );
  mDailyRecurItem = new KConfigSkeleton::ItemBool( currentGroup(), QStringLiteral( "Show Daily Recurrences" ), mDailyRecur, true );
  mDailyRecurItem->setLabel( i18nd("korganizer", "Show items that recur daily") );
  mDailyRecurItem->setWhatsThis( i18nd("korganizer", "Check this box to show the days containing daily recurring events in bold typeface in the Date Navigator, or uncheck it to give more prominence to other (non daily recurring) events.") );
  addItem( mDailyRecurItem, QStringLiteral( "DailyRecur" ) );
  mWeeklyRecurItem = new KConfigSkeleton::ItemBool( currentGroup(), QStringLiteral( "Show Weekly Recurrences" ), mWeeklyRecur, true );
  mWeeklyRecurItem->setLabel( i18nd("korganizer", "Show items that recur weekly") );
  mWeeklyRecurItem->setWhatsThis( i18nd("korganizer", "Check this box to show the days containing weekly recurring events in bold typeface in the Date Navigator, or uncheck it to give more prominence to other (non weekly recurring) events.") );
  addItem( mWeeklyRecurItem, QStringLiteral( "WeeklyRecur" ) );
  mHighlightTodosItem = new KConfigSkeleton::ItemBool( currentGroup(), QStringLiteral( "Highlight To-dos" ), mHighlightTodos, true );
  mHighlightTodosItem->setLabel( i18nd("korganizer", "Show to-dos instead of events when in Todo View") );
  mHighlightTodosItem->setWhatsThis( i18nd("korganizer", "Check this box to show the days containing to-dos in bold typeface in the Date Navigator when in to-do view.") );
  addItem( mHighlightTodosItem, QStringLiteral( "HighlightTodos" ) );
  mHighlightJournalsItem = new KConfigSkeleton::ItemBool( currentGroup(), QStringLiteral( "Highlight Journals" ), mHighlightJournals, true );
  mHighlightJournalsItem->setLabel( i18nd("korganizer", "Show journals instead of events when in Journal View") );
  mHighlightJournalsItem->setWhatsThis( i18nd("korganizer", "Check this box to show the days containing journals in bold typeface in the Date Navigator when in journal view.") );
  addItem( mHighlightJournalsItem, QStringLiteral( "HighlightJournals" ) );
  mWeekNumbersShowItem = new KConfigSkeleton::ItemBool( currentGroup(), QStringLiteral( "Show Week Numbers" ), mWeekNumbersShow, true );
  mWeekNumbersShowItem->setLabel( i18nd("korganizer", "Show week numbers") );
  mWeekNumbersShowItem->setWhatsThis( i18nd("korganizer", "Check this box to show the Date Navigator's week numbers.") );
  addItem( mWeekNumbersShowItem, QStringLiteral( "WeekNumbersShow" ) );
  mWeekNumbersShowWorkItem = new KConfigSkeleton::ItemBool( currentGroup(), QStringLiteral( "Week Numbers Show Work Week" ), mWeekNumbersShowWork, true );
  mWeekNumbersShowWorkItem->setLabel( i18nd("korganizer", "Week numbers select a work week when in work week mode") );
  mWeekNumbersShowWorkItem->setWhatsThis( i18nd("korganizer", "Check this box to select a working week when clicking on the Date Navigator's week numbers, or uncheck it to choose the whole week.  Ignored if week numbers are not shown.") );
  addItem( mWeekNumbersShowWorkItem, QStringLiteral( "WeekNumbersShowWork" ) );

  setCurrentGroup( QStringLiteral( "Agenda View" ) );

  mHourSizeItem = new KConfigSkeleton::ItemInt( currentGroup(), QStringLiteral( "Hour Size" ), mHourSize, 10 );
  mHourSizeItem->setMinValue(4);
  mHourSizeItem->setMaxValue(30);
  mHourSizeItem->setLabel( i18nd("korganizer", "Hour size") );
  mHourSizeItem->setToolTip( i18nd("korganizer", "Set the height (in pixels) for an hour in the agenda grid") );
  mHourSizeItem->setWhatsThis( i18nd("korganizer", "Select the height of the hour rows in the agenda grid, in pixels. Increasing this value will make each row in the agenda grid taller.") );
  addItem( mHourSizeItem, QStringLiteral( "HourSize" ) );
  mEnableAgendaItemIconsItem = new KConfigSkeleton::ItemBool( currentGroup(), QStringLiteral( "Show Icons in Agenda View" ), mEnableAgendaItemIcons, true );
  mEnableAgendaItemIconsItem->setLabel( i18nd("korganizer", "Show icons in agenda view items") );
  mEnableAgendaItemIconsItem->setToolTip( i18nd("korganizer", "Display icons in agenda view items") );
  mEnableAgendaItemIconsItem->setWhatsThis( i18nd("korganizer", "Check this box to display icons (alarm, recursion, etc.) in agenda view items.") );
  addItem( mEnableAgendaItemIconsItem, QStringLiteral( "EnableAgendaItemIcons" ) );
  mEnableAgendaBoldEvenHoursItem = new KConfigSkeleton::ItemBool( currentGroup(), QStringLiteral( "Draw Bold Even Hour Grid Lines" ), mEnableAgendaBoldEvenHours, false );
  mEnableAgendaBoldEvenHoursItem->setLabel( i18nd("korganizer", "Draw bold horizontal grid lines for the even hours") );
  mEnableAgendaBoldEvenHoursItem->setToolTip( i18nd("korganizer", "Draw bolder even hour grid lines") );
  mEnableAgendaBoldEvenHoursItem->setWhatsThis( i18nd("korganizer", "Draw a bolder horizontal grid line for the even hours (12am, 2am, 4am, etc).") );
  addItem( mEnableAgendaBoldEvenHoursItem, QStringLiteral( "EnableAgendaBoldEvenHours" ) );
  mEnableAgendaItemDescItem = new KConfigSkeleton::ItemBool( currentGroup(), QStringLiteral( "Show Incidence Descriptions in Agenda View" ), mEnableAgendaItemDesc, false );
  mEnableAgendaItemDescItem->setLabel( i18nd("korganizer", "Show incidence descriptions in agenda view items") );
  mEnableAgendaItemDescItem->setToolTip( i18nd("korganizer", "Display incidence descriptions agenda view items") );
  mEnableAgendaItemDescItem->setWhatsThis( i18nd("korganizer", "Check this box to display the incidence descriptions in agenda view items.") );
  addItem( mEnableAgendaItemDescItem, QStringLiteral( "EnableAgendaItemDesc" ) );
  mEnableAgendaItemLocationItem = new KConfigSkeleton::ItemBool( currentGroup(), QStringLiteral( "Show Incidence Locationss in Agenda View" ), mEnableAgendaItemLocation, false );
  mEnableAgendaItemLocationItem->setLabel( i18nd("korganizer", "Show incidence locations in agenda view items") );
  mEnableAgendaItemLocationItem->setToolTip( i18nd("korganizer", "Display incidence locations agenda view items") );
  mEnableAgendaItemLocationItem->setWhatsThis( i18nd("korganizer", "Check this box to display the incidence locations in agenda view items.") );
  addItem( mEnableAgendaItemLocationItem, QStringLiteral( "EnableAgendaItemLocation" ) );
  mShowTodosAgendaViewItem = new KConfigSkeleton::ItemBool( currentGroup(), QStringLiteral( "ShowTodosAgendaView" ), mShowTodosAgendaView, true );
  mShowTodosAgendaViewItem->setLabel( i18nd("korganizer", "Show to-dos") );
  mShowTodosAgendaViewItem->setToolTip( i18nd("korganizer", "Display to-dos in the agenda view") );
  mShowTodosAgendaViewItem->setWhatsThis( i18nd("korganizer", "Check this box to display to-dos in the agenda view.") );
  addItem( mShowTodosAgendaViewItem, QStringLiteral( "ShowTodosAgendaView" ) );
  mMarcusBainsEnabledItem = new KConfigSkeleton::ItemBool( currentGroup(), QStringLiteral( "Show current-time line" ), mMarcusBainsEnabled, true );
  mMarcusBainsEnabledItem->setLabel( i18nd("korganizer", "Show current-time (Marcus Bains) line") );
  mMarcusBainsEnabledItem->setToolTip( i18nd("korganizer", "Display the current-time indicator") );
  mMarcusBainsEnabledItem->setWhatsThis( i18nd("korganizer", "Check this box to display a line in the day or week view indicating the current-time line (Marcus Bains line).") );
  addItem( mMarcusBainsEnabledItem, QStringLiteral( "MarcusBainsEnabled" ) );
  mMarcusBainsShowSecondsItem = new KConfigSkeleton::ItemBool( currentGroup(), QStringLiteral( "Current-time line shows seconds" ), mMarcusBainsShowSeconds, false );
  mMarcusBainsShowSecondsItem->setLabel( i18nd("korganizer", "Show seconds and timezone on the current-time (Marcus Bains) line") );
  mMarcusBainsShowSecondsItem->setToolTip( i18nd("korganizer", "Display seconds (possibly with timezone) with the current-time indicator") );
  mMarcusBainsShowSecondsItem->setWhatsThis( i18nd("korganizer", "Check this box if you want to show seconds on the current-time (Marcus Bains) line. Depending on your locale, the timezone will also be displayed.") );
  addItem( mMarcusBainsShowSecondsItem, QStringLiteral( "MarcusBainsShowSeconds" ) );
  mSelectionStartsEditorItem = new KConfigSkeleton::ItemBool( currentGroup(), QStringLiteral( "SelectionStartsEditor" ), mSelectionStartsEditor, false );
  mSelectionStartsEditorItem->setLabel( i18nd("korganizer", "Time range selection in agenda view starts event editor") );
  mSelectionStartsEditorItem->setToolTip( i18nd("korganizer", "Enable automatic event editor with time range selection") );
  mSelectionStartsEditorItem->setWhatsThis( i18nd("korganizer", "Check this box to start the event editor automatically when you select a time range in the daily and weekly view. To select a time range, drag the mouse from the start time to the end time of the event you are about to plan.") );
  addItem( mSelectionStartsEditorItem, QStringLiteral( "SelectionStartsEditor" ) );
  QList<KConfigSkeleton::ItemEnum::Choice> valuesAgendaViewColors;
  {
    KConfigSkeleton::ItemEnum::Choice choice;
    choice.name = QStringLiteral("CategoryInsideResourceOutside");
    choice.label = i18nd("korganizer", "Tag inside, calendar outside");
    choice.toolTip = i18nd("korganizer", "Draw agenda items with their tag color inside and calendar color for their border");
    choice.whatsThis = i18nd("korganizer", "Select the \"Tag inside, calendar outside\" option if you would like to draw calendar items using their associated tag color, with the item's border drawn in the color of its calendar.  Please use the Colors and Fonts configuration page for setting these colors.");
    valuesAgendaViewColors.append( choice );
  }
  {
    KConfigSkeleton::ItemEnum::Choice choice;
    choice.name = QStringLiteral("ResourceInsideCategoryOutside");
    choice.label = i18nd("korganizer", "Calendar inside, tag outside");
    choice.toolTip = i18nd("korganizer", "Draw agenda items with their calendar color inside and tag color for their border");
    choice.whatsThis = i18nd("korganizer", "Select the \"Calendar inside, tag outside\" option if you would like to draw calendar items using their associated calendar color, with the item's border drawn in the color of its tag.  Please use the Colors and Fonts configuration page for setting these colors.");
    valuesAgendaViewColors.append( choice );
  }
  {
    KConfigSkeleton::ItemEnum::Choice choice;
    choice.name = QStringLiteral("CategoryOnly");
    choice.label = i18nd("korganizer", "Only tag");
    choice.toolTip = i18nd("korganizer", "Draw agenda items using their tag color for the inside and border");
    choice.whatsThis = i18nd("korganizer", "Select the \"Only tag\" option if you would like to draw calendar items (both inside and border) using the color of their associated tag.  Please use the Colors and Fonts configuration page for setting these colors.");
    valuesAgendaViewColors.append( choice );
  }
  {
    KConfigSkeleton::ItemEnum::Choice choice;
    choice.name = QStringLiteral("ResourceOnly");
    choice.label = i18nd("korganizer", "Only calendar");
    choice.toolTip = i18nd("korganizer", "Draw agenda items using their calendar color for the inside and border");
    choice.whatsThis = i18nd("korganizer", "Select the \"Only calendar\" option if you would like to draw calendar items (both inside and border) using the color of their calendar. Please use the Colors and Fonts configuration page for setting these colors.");
    valuesAgendaViewColors.append( choice );
  }
  mAgendaViewColorsItem = new KConfigSkeleton::ItemEnum( currentGroup(), QStringLiteral( "AgendaViewColors" ), mAgendaViewColors, valuesAgendaViewColors, CategoryInsideResourceOutside );
  mAgendaViewColorsItem->setLabel( i18nd("korganizer", "Color Usage") );
  addItem( mAgendaViewColorsItem, QStringLiteral( "AgendaViewColors" ) );
  mColorBusyDaysEnabledItem = new KConfigSkeleton::ItemBool( currentGroup(), QStringLiteral( "ColorBusyDaysEnabled" ), mColorBusyDaysEnabled, false );
  mColorBusyDaysEnabledItem->setLabel( i18nd("korganizer", "Color busy days with a different background color") );
  mColorBusyDaysEnabledItem->setWhatsThis( i18nd("korganizer", "Check this box if you want agenda's background to be filled with a different color on days which have at least one all day event marked as busy. Also, you can change the background color used for this option on the Colors configuration page. Look for the \"Busy days background color\" setting.") );
  addItem( mColorBusyDaysEnabledItem, QStringLiteral( "ColorBusyDaysEnabled" ) );
  QList<KConfigSkeleton::ItemEnum::Choice> valuesAgendaViewCalendarDisplay;
  {
    KConfigSkeleton::ItemEnum::Choice choice;
    choice.name = QStringLiteral("CalendarsMerged");
    choice.label = i18nd("korganizer", "Merge all calendars into one view");
    choice.toolTip = i18nd("korganizer", "Show all calendars merged together");
    choice.whatsThis = i18nd("korganizer", "Select the \"Merge all calendars into one view\" option if you would like all your calendars to be shown together in one agenda view.");
    valuesAgendaViewCalendarDisplay.append( choice );
  }
  {
    KConfigSkeleton::ItemEnum::Choice choice;
    choice.name = QStringLiteral("CalendarsSideBySide");
    choice.label = i18nd("korganizer", "Show calendars side by side");
    choice.toolTip = i18nd("korganizer", "Show two calendars side-by-side");
    choice.whatsThis = i18nd("korganizer", "Select the \"Show calendars side by side\" option if you would like to see two calendars at once, in a side-by-side view.");
    valuesAgendaViewCalendarDisplay.append( choice );
  }
  {
    KConfigSkeleton::ItemEnum::Choice choice;
    choice.name = QStringLiteral("AllCalendarViews");
    choice.label = i18nd("korganizer", "Switch between views with tabs");
    choice.toolTip = i18nd("korganizer", "Tab through calendars");
    choice.whatsThis = i18nd("korganizer", "Select \"Switch between views with tabs\" if you would like to alternate between calendars using the tab key.");
    valuesAgendaViewCalendarDisplay.append( choice );
  }
  mAgendaViewCalendarDisplayItem = new KConfigSkeleton::ItemEnum( currentGroup(), QStringLiteral( "AgendaViewCalendarDisplay" ), mAgendaViewCalendarDisplay, valuesAgendaViewCalendarDisplay, CalendarsMerged );
  mAgendaViewCalendarDisplayItem->setLabel( i18nd("korganizer", "Multiple Calendar Display") );
  addItem( mAgendaViewCalendarDisplayItem, QStringLiteral( "AgendaViewCalendarDisplay" ) );

  setCurrentGroup( QStringLiteral( "Month View" ) );

  mEnableMonthItemIconsItem = new KConfigSkeleton::ItemBool( currentGroup(), QStringLiteral( "Show Icons in Month View" ), mEnableMonthItemIcons, true );
  mEnableMonthItemIconsItem->setLabel( i18nd("korganizer", "Show icons in month view items") );
  mEnableMonthItemIconsItem->setToolTip( i18nd("korganizer", "Display icons in month view items") );
  mEnableMonthItemIconsItem->setWhatsThis( i18nd("korganizer", "Check this box to display icons (alarm, recursion, etc.) in month view items.") );
  addItem( mEnableMonthItemIconsItem, QStringLiteral( "EnableMonthItemIcons" ) );
  mShowTimeInMonthViewItem = new KConfigSkeleton::ItemBool( currentGroup(), QStringLiteral( "Show time in Month View" ), mShowTimeInMonthView, false );
  mShowTimeInMonthViewItem->setLabel( i18nd("korganizer", "Show start-times without end-times in month view items") );
  mShowTimeInMonthViewItem->setToolTip( i18nd("korganizer", "Display start-time without the end-time in month view items") );
  mShowTimeInMonthViewItem->setWhatsThis( i18nd("korganizer", "Check this box to display the start-time without the end-time in month view items.") );
  addItem( mShowTimeInMonthViewItem, QStringLiteral( "ShowTimeInMonthView" ) );
  mShowEndTimeInMonthViewItem = new KConfigSkeleton::ItemBool( currentGroup(), QStringLiteral( "Show end-time in Month View" ), mShowEndTimeInMonthView, false );
  mShowEndTimeInMonthViewItem->setLabel( i18nd("korganizer", "Show the start-time and the end-time in month view items") );
  mShowEndTimeInMonthViewItem->setToolTip( i18nd("korganizer", "Display the start and end times in month view items") );
  mShowEndTimeInMonthViewItem->setWhatsThis( i18nd("korganizer", "Check this box to display the start and end times in month view items.") );
  addItem( mShowEndTimeInMonthViewItem, QStringLiteral( "ShowEndTimeInMonthView" ) );
  mShowTodosMonthViewItem = new KConfigSkeleton::ItemBool( currentGroup(), QStringLiteral( "ShowTodosMonthView" ), mShowTodosMonthView, true );
  mShowTodosMonthViewItem->setLabel( i18nd("korganizer", "Show to-dos") );
  mShowTodosMonthViewItem->setToolTip( i18nd("korganizer", "Display to-dos in the month view") );
  mShowTodosMonthViewItem->setWhatsThis( i18nd("korganizer", "Check this box to display to-dos in the month view.") );
  addItem( mShowTodosMonthViewItem, QStringLiteral( "ShowTodosMonthView" ) );
  mShowJournalsMonthViewItem = new KConfigSkeleton::ItemBool( currentGroup(), QStringLiteral( "ShowJournalsMonthView" ), mShowJournalsMonthView, true );
  mShowJournalsMonthViewItem->setLabel( i18nd("korganizer", "Show journals") );
  mShowJournalsMonthViewItem->setToolTip( i18nd("korganizer", "Display journals in the month view") );
  mShowJournalsMonthViewItem->setWhatsThis( i18nd("korganizer", "Check this box to display journals in the month view.") );
  addItem( mShowJournalsMonthViewItem, QStringLiteral( "ShowJournalsMonthView" ) );
  mShowHolidaysMonthViewItem = new KConfigSkeleton::ItemBool( currentGroup(), QStringLiteral( "ShowHolidaysMonthView" ), mShowHolidaysMonthView, true );
  mShowHolidaysMonthViewItem->setLabel( i18nd("korganizer", "Show holidays") );
  mShowHolidaysMonthViewItem->setToolTip( i18nd("korganizer", "Display holidays in the month view") );
  mShowHolidaysMonthViewItem->setWhatsThis( i18nd("korganizer", "Check this box to display holidays in the month view.") );
  addItem( mShowHolidaysMonthViewItem, QStringLiteral( "ShowHolidaysMonthView" ) );
  mShowHolidaysBackgroundMonthViewItem = new KConfigSkeleton::ItemBool( currentGroup(), QStringLiteral( "ShowHolidaysBackgroundMonthView" ), mShowHolidaysBackgroundMonthView, false );
  mShowHolidaysBackgroundMonthViewItem->setLabel( i18nd("korganizer", "Use the Holiday background color when a holiday lands on the date") );
  mShowHolidaysBackgroundMonthViewItem->setToolTip( i18nd("korganizer", "Display holidays in the month view") );
  mShowHolidaysBackgroundMonthViewItem->setWhatsThis( i18nd("korganizer", "Check this box to use the custom holiday as the date's background color when at least one holiday lands on a date. Configure the holiday color in the Settings->Colors and Fonts.") );
  addItem( mShowHolidaysBackgroundMonthViewItem, QStringLiteral( "ShowHolidaysBackgroundMonthView" ) );
  mFullViewMonthItem = new KConfigSkeleton::ItemBool( currentGroup(), QStringLiteral( "Full View Month" ), mFullViewMonth, false );
  mFullViewMonthItem->setLabel( i18nd("korganizer", "Month view uses full window") );
  mFullViewMonthItem->setWhatsThis( i18nd("korganizer", "Check this box to use the full KOrganizer window when displaying the month view. If this box is checked, you will gain some space for the monthly view, but other widgets, such as the date navigator, the item details and the calendars list, will not be displayed.") );
  addItem( mFullViewMonthItem, QStringLiteral( "FullViewMonth" ) );
  QList<KConfigSkeleton::ItemEnum::Choice> valuesMonthViewColors;
  {
    KConfigSkeleton::ItemEnum::Choice choice;
    choice.name = QStringLiteral("MonthItemCategoryInsideResourceOutside");
    choice.label = i18nd("korganizer", "Tag inside, calendar outside");
    choice.toolTip = i18nd("korganizer", "Draw month items with their tag color inside and calendar color for their border");
    choice.whatsThis = i18nd("korganizer", "Select the \"Tag inside, calendar outside\" option if you would like to draw calendar items using their associated tag color, with the item's border drawn in the color of its calendar.  Please use the Colors and Fonts configuration page for setting these colors.");
    valuesMonthViewColors.append( choice );
  }
  {
    KConfigSkeleton::ItemEnum::Choice choice;
    choice.name = QStringLiteral("MonthItemResourceInsideCategoryOutside");
    choice.label = i18nd("korganizer", "Calendar inside, tag outside");
    choice.toolTip = i18nd("korganizer", "Draw month items with their calendar color inside and tag color for their border");
    choice.whatsThis = i18nd("korganizer", "Select the \"Calendar inside, tag outside\" option if you would like to draw calendar items using their associated calendar color, with the item's border drawn in the color of its tag.  Please use the Colors and Fonts configuration page for setting these colors.");
    valuesMonthViewColors.append( choice );
  }
  {
    KConfigSkeleton::ItemEnum::Choice choice;
    choice.name = QStringLiteral("MonthItemCategoryOnly");
    choice.label = i18nd("korganizer", "Only tag");
    choice.toolTip = i18nd("korganizer", "Draw month items using their tag color for the inside and border");
    choice.whatsThis = i18nd("korganizer", "Select the \"Only tag\" option if you would like to draw calendar items (both inside and border) in the color of their associated tag.  Please use the Colors and Fonts configuration page for setting these colors.");
    valuesMonthViewColors.append( choice );
  }
  {
    KConfigSkeleton::ItemEnum::Choice choice;
    choice.name = QStringLiteral("MonthItemResourceOnly");
    choice.label = i18nd("korganizer", "Only calendar");
    choice.toolTip = i18nd("korganizer", "Draw month items using their calendar color for the inside and border");
    choice.whatsThis = i18nd("korganizer", "Select the \"Only calendar\" option if you would like to draw calendar items (both inside and border) in the color of their calendar.  Please use the Colors and Fonts configuration page for setting these colors.");
    valuesMonthViewColors.append( choice );
  }
  mMonthViewColorsItem = new KConfigSkeleton::ItemEnum( currentGroup(), QStringLiteral( "MonthViewColors" ), mMonthViewColors, valuesMonthViewColors, MonthItemCategoryInsideResourceOutside );
  mMonthViewColorsItem->setLabel( i18nd("korganizer", "Color Usage") );
  addItem( mMonthViewColorsItem, QStringLiteral( "MonthViewColors" ) );

  setCurrentGroup( QStringLiteral( "Todo View" ) );

  mSortCompletedTodosSeparatelyItem = new KConfigSkeleton::ItemBool( currentGroup(), QStringLiteral( "Sort Completed Todos Separately" ), mSortCompletedTodosSeparately, true );
  mSortCompletedTodosSeparatelyItem->setLabel( i18nd("korganizer", "Always display completed to-dos at the bottom of the list") );
  mSortCompletedTodosSeparatelyItem->setToolTip( i18nd("korganizer", "Completed to-dos are displayed at the bottom of the list, regardless of priority") );
  mSortCompletedTodosSeparatelyItem->setWhatsThis( i18nd("korganizer", "Check this box if you want all completed to-dos to be always grouped at the bottom of the to-do list.") );
  addItem( mSortCompletedTodosSeparatelyItem, QStringLiteral( "SortCompletedTodosSeparately" ) );
  mFullViewTodoItem = new KConfigSkeleton::ItemBool( currentGroup(), QStringLiteral( "Full View Todo" ), mFullViewTodo, false );
  mFullViewTodoItem->setLabel( i18nd("korganizer", "To-do list view uses full window") );
  mFullViewTodoItem->setToolTip( i18nd("korganizer", "Display to-do list in a full KOrganizer window") );
  mFullViewTodoItem->setWhatsThis( i18nd("korganizer", "Check this box to use the full KOrganizer window when displaying the to-do list view. If this box is checked, you will gain some space for the to-do list view, but other widgets, such as the date navigator, the to-do details and the calendars list, will not be displayed.") );
  addItem( mFullViewTodoItem, QStringLiteral( "FullViewTodo" ) );
  mFlatListTodoItem = new KConfigSkeleton::ItemBool( currentGroup(), QStringLiteral( "Flat List Todo" ), mFlatListTodo, false );
  mFlatListTodoItem->setLabel( i18nd("korganizer", "Display to-dos in a flat list") );
  mFlatListTodoItem->setToolTip( i18nd("korganizer", "Display to-dos as a flat list instead of a hierarchical tree") );
  mFlatListTodoItem->setWhatsThis( i18nd("korganizer", "Check this box if you want to see all your to-dos in a flat list instead of being arranged in a hierarchical tree.") );
  addItem( mFlatListTodoItem, QStringLiteral( "FlatListTodo" ) );
  mRecordTodosInJournalsItem = new KConfigSkeleton::ItemBool( currentGroup(), QStringLiteral( "Record Todos In Journals" ), mRecordTodosInJournals, false );
  mRecordTodosInJournalsItem->setLabel( i18nd("korganizer", "Record completed to-dos in journal entries") );
  mRecordTodosInJournalsItem->setWhatsThis( i18nd("korganizer", "Check this box to record the completion of a to-do in a new entry of your journal automatically.") );
  addItem( mRecordTodosInJournalsItem, QStringLiteral( "RecordTodosInJournals" ) );

  setCurrentGroup( QStringLiteral( "Colors" ) );

  mHolidayColorItem = new KConfigSkeleton::ItemColor( currentGroup(), QStringLiteral( "Holiday Color" ), mHolidayColor, QColor( 255, 100, 100 ) );
  mHolidayColorItem->setLabel( i18nd("korganizer", "Holiday color") );
  mHolidayColorItem->setWhatsThis( i18nd("korganizer", "Select the holiday color here. The holiday color will be used for the holiday name in the month view and the holiday number in the date navigator.") );
  addItem( mHolidayColorItem, QStringLiteral( "HolidayColor" ) );
  mAgendaBgColorItem = new KConfigSkeleton::ItemColor( currentGroup(), QStringLiteral( "AgendaBackgroundColor" ), mAgendaBgColor, QColor( 255, 255, 255 ) );
  mAgendaBgColorItem->setLabel( i18nd("korganizer", "Agenda view background color") );
  mAgendaBgColorItem->setWhatsThis( i18nd("korganizer", "Select the agenda view background color here.") );
  addItem( mAgendaBgColorItem, QStringLiteral( "AgendaBgColor" ) );
  mAgendaMarcusBainsLineLineColorItem = new KConfigSkeleton::ItemColor( currentGroup(), QStringLiteral( "Agenda MarcusBainsLine Line Color" ), mAgendaMarcusBainsLineLineColor, QColor( 255,0,0 ) );
  mAgendaMarcusBainsLineLineColorItem->setLabel( i18nd("korganizer", "Agenda view current-time (Marcus Bains) line color") );
  mAgendaMarcusBainsLineLineColorItem->setToolTip( i18nd("korganizer", "Use this color for the Agenda View current-time (Marcus Bains) line") );
  mAgendaMarcusBainsLineLineColorItem->setWhatsThis( i18nd("korganizer", "Select a color to use for the current-time (Marcus Bains) line.") );
  addItem( mAgendaMarcusBainsLineLineColorItem, QStringLiteral( "AgendaMarcusBainsLineLineColor" ) );
  mViewBgBusyColorItem = new KConfigSkeleton::ItemColor( currentGroup(), QStringLiteral( "ViewBackgroundBusyColor" ), mViewBgBusyColor, QColor( 136, 255, 219 ) );
  mViewBgBusyColorItem->setLabel( i18nd("korganizer", "Busy days background color") );
  mViewBgBusyColorItem->setWhatsThis( i18nd("korganizer", "When you have an all day event marked as busy, you can have a different agenda or month view background color for that day. Select the color here.") );
  addItem( mViewBgBusyColorItem, QStringLiteral( "ViewBgBusyColor" ) );
  mWorkingHoursColorItem = new KConfigSkeleton::ItemColor( currentGroup(), QStringLiteral( "WorkingHoursColor" ), mWorkingHoursColor, QColor( 255, 235, 154 ) );
  mWorkingHoursColorItem->setLabel( i18nd("korganizer", "Working hours color") );
  mWorkingHoursColorItem->setWhatsThis( i18nd("korganizer", "Select the working hours color for the agenda view here.") );
  addItem( mWorkingHoursColorItem, QStringLiteral( "WorkingHoursColor" ) );
  mTodoDueTodayColorItem = new KConfigSkeleton::ItemColor( currentGroup(), QStringLiteral( "Todo due today Color" ), mTodoDueTodayColor, QColor( 255, 200, 50 ) );
  mTodoDueTodayColorItem->setLabel( i18nd("korganizer", "To-do due today color") );
  mTodoDueTodayColorItem->setWhatsThis( i18nd("korganizer", "Select the to-do due today color here.") );
  addItem( mTodoDueTodayColorItem, QStringLiteral( "TodoDueTodayColor" ) );
  mTodoOverdueColorItem = new KConfigSkeleton::ItemColor( currentGroup(), QStringLiteral( "Todo overdue Color" ), mTodoOverdueColor, QColor( 255, 100, 100 ) );
  mTodoOverdueColorItem->setLabel( i18nd("korganizer", "To-do overdue color") );
  mTodoOverdueColorItem->setWhatsThis( i18nd("korganizer", "Select the to-do overdue color here.") );
  addItem( mTodoOverdueColorItem, QStringLiteral( "TodoOverdueColor" ) );
  mMonthTodayColorItem = new KConfigSkeleton::ItemColor( currentGroup(), QStringLiteral( "Month Today Color" ), mMonthTodayColor, QColor( 221, 251, 232 ) );
  mMonthTodayColorItem->setLabel( i18nd("korganizer", "Month view today background color") );
  mMonthTodayColorItem->setToolTip( i18nd("korganizer", "Set the background color for today's date in month view") );
  mMonthTodayColorItem->setWhatsThis( i18nd("korganizer", "In Month View, select the background color for today's date.") );
  addItem( mMonthTodayColorItem, QStringLiteral( "MonthTodayColor" ) );

  setCurrentGroup( QStringLiteral( "Fonts" ) );

  mAgendaTimeLabelsFontItem = new KConfigSkeleton::ItemFont( currentGroup(), QStringLiteral( "Agenda TimeLabels Font" ), mAgendaTimeLabelsFont );
  mAgendaTimeLabelsFontItem->setLabel( i18nd("korganizer", "Time bar") );
  mAgendaTimeLabelsFontItem->setWhatsThis( i18nd("korganizer", "Press this button to configure the time bar font. The time bar is the widget that shows the hours in the agenda view. This button will open the \"Select Font\" dialog, allowing you to choose the hour font for the time bar.") );
  addItem( mAgendaTimeLabelsFontItem, QStringLiteral( "AgendaTimeLabelsFont" ) );
  mMonthViewFontItem = new KConfigSkeleton::ItemFont( currentGroup(), QStringLiteral( "MonthView Font" ), mMonthViewFont );
  mMonthViewFontItem->setLabel( i18nd("korganizer", "Month view") );
  mMonthViewFontItem->setWhatsThis( i18nd("korganizer", "Press this button to configure the month view font. This button will open the \"Select Font\" dialog, allowing you to choose the font for the items in the month view.") );
  addItem( mMonthViewFontItem, QStringLiteral( "MonthViewFont" ) );
  mAgendaViewFontItem = new KConfigSkeleton::ItemFont( currentGroup(), QStringLiteral( "AgendaView Font" ), mAgendaViewFont );
  mAgendaViewFontItem->setLabel( i18nd("korganizer", "Agenda view") );
  mAgendaViewFontItem->setWhatsThis( i18nd("korganizer", "Press this button to configure the agenda view font. This button will open the \"Select Font\" dialog, allowing you to choose the font for the events in the agenda view.") );
  addItem( mAgendaViewFontItem, QStringLiteral( "AgendaViewFont" ) );
  mAgendaMarcusBainsLineFontItem = new KConfigSkeleton::ItemFont( currentGroup(), QStringLiteral( "Agenda MarcusBainsLine Font" ), mAgendaMarcusBainsLineFont );
  mAgendaMarcusBainsLineFontItem->setLabel( i18nd("korganizer", "Current-time (Marcus Bains) line") );
  mAgendaMarcusBainsLineFontItem->setWhatsThis( i18nd("korganizer", "Press this button to configure the current-time (Marcus Bains) line font. This button will open the \"Select Font\" dialog, allowing you to choose the font for the current-time line in the agenda view.") );
  addItem( mAgendaMarcusBainsLineFontItem, QStringLiteral( "AgendaMarcusBainsLineFont" ) );

  setCurrentGroup( QStringLiteral( "KOrganizer Plugins" ) );

  mSelectedPluginsItem = new KConfigSkeleton::ItemStringList( currentGroup(), QStringLiteral( "SelectedPlugins" ), mSelectedPlugins );
  mSelectedPluginsItem->setLabel( i18nd("korganizer", "SelectedPlugins") );
  addItem( mSelectedPluginsItem, QStringLiteral( "SelectedPlugins" ) );

  setCurrentGroup( QStringLiteral( "Hidden Options" ) );

  mEnableQuickTodoItem = new KConfigSkeleton::ItemBool( currentGroup(), QStringLiteral( "Quick Todo" ), mEnableQuickTodo, true );
  mEnableQuickTodoItem->setLabel( i18nd("korganizer", "Quick Todo") );
  addItem( mEnableQuickTodoItem, QStringLiteral( "EnableQuickTodo" ) );
  mEnableTodoQuickSearchItem = new KConfigSkeleton::ItemBool( currentGroup(), QStringLiteral( "Todo Quick Search" ), mEnableTodoQuickSearch, true );
  mEnableTodoQuickSearchItem->setLabel( i18nd("korganizer", "Todo Quick Search") );
  addItem( mEnableTodoQuickSearchItem, QStringLiteral( "EnableTodoQuickSearch" ) );
  QList<KConfigSkeleton::ItemEnum::Choice> valuesDefaultTodoAttachMethod;
  {
    KConfigSkeleton::ItemEnum::Choice choice;
    choice.name = QStringLiteral("TodoAttachAsk");
    choice.label = i18nd("korganizer", "Always ask");
    valuesDefaultTodoAttachMethod.append( choice );
  }
  {
    KConfigSkeleton::ItemEnum::Choice choice;
    choice.name = QStringLiteral("TodoAttachLink");
    choice.label = i18nd("korganizer", "Only attach link to message");
    valuesDefaultTodoAttachMethod.append( choice );
  }
  {
    KConfigSkeleton::ItemEnum::Choice choice;
    choice.name = QStringLiteral("TodoAttachInlineFull");
    choice.label = i18nd("korganizer", "Attach complete message");
    valuesDefaultTodoAttachMethod.append( choice );
  }
  mDefaultTodoAttachMethodItem = new KConfigSkeleton::ItemEnum( currentGroup(), QStringLiteral( "DefaultTodoAttachMethod" ), mDefaultTodoAttachMethod, valuesDefaultTodoAttachMethod, TodoAttachInlineFull );
  mDefaultTodoAttachMethodItem->setLabel( i18nd("korganizer", "Default todo attachment method") );
  mDefaultTodoAttachMethodItem->setWhatsThis( i18nd("korganizer", "The default way of attaching dropped emails to a task") );
  addItem( mDefaultTodoAttachMethodItem, QStringLiteral( "DefaultTodoAttachMethod" ) );
  mCompactDialogsItem = new KConfigSkeleton::ItemBool( currentGroup(), QStringLiteral( "CompactDialogs" ), mCompactDialogs, false );
  mCompactDialogsItem->setLabel( i18nd("korganizer", "CompactDialogs") );
  addItem( mCompactDialogsItem, QStringLiteral( "CompactDialogs" ) );
  mShowMenuBarItem = new KConfigSkeleton::ItemBool( currentGroup(), QStringLiteral( "ShowMenuBar" ), mShowMenuBar, true );
  mShowMenuBarItem->setLabel( i18nd("korganizer", "ShowMenuBar") );
  addItem( mShowMenuBarItem, QStringLiteral( "ShowMenuBar" ) );

  setCurrentGroup( QStringLiteral( "Internal Settings" ) );

  mWorkWeekMaskItem = new KConfigSkeleton::ItemInt( currentGroup(), QStringLiteral( "Work Week Mask" ), mWorkWeekMask, 31 );
  mWorkWeekMaskItem->setLabel( i18nd("korganizer", "Work Week Mask") );
  addItem( mWorkWeekMaskItem, QStringLiteral( "WorkWeekMask" ) );
  mDefaultResourceColorSeedItem = new KConfigSkeleton::ItemInt( currentGroup(), QStringLiteral( "DefaultResourceColorSeed" ), mDefaultResourceColorSeed, 0 );
  mDefaultResourceColorSeedItem->setLabel( i18nd("korganizer", "DefaultResourceColorSeed") );
  addItem( mDefaultResourceColorSeedItem, QStringLiteral( "DefaultResourceColorSeed" ) );
  QStringList defaultDefaultResourceColors;
  defaultDefaultResourceColors.append( QString::fromUtf8( "#c1d4e7" ) );
  defaultDefaultResourceColors.append( QString::fromUtf8( "#d0e7c1" ) );
  defaultDefaultResourceColors.append( QString::fromUtf8( "#e3e7c1" ) );
  defaultDefaultResourceColors.append( QString::fromUtf8( "#e7c1e6" ) );
  defaultDefaultResourceColors.append( QString::fromUtf8( "#a1b1c1" ) );

  mDefaultResourceColorsItem = new KConfigSkeleton::ItemStringList( currentGroup(), QStringLiteral( "DefaultResourceColors" ), mDefaultResourceColors, defaultDefaultResourceColors );
  mDefaultResourceColorsItem->setLabel( i18nd("korganizer", "DefaultResourceColors") );
  addItem( mDefaultResourceColorsItem, QStringLiteral( "DefaultResourceColors" ) );
  mAssignDefaultResourceColorsItem = new KConfigSkeleton::ItemBool( currentGroup(), QStringLiteral( "AssignDefaultResourceColors" ), mAssignDefaultResourceColors, true );
  mAssignDefaultResourceColorsItem->setLabel( i18nd("korganizer", "AssignDefaultResourceColors") );
  addItem( mAssignDefaultResourceColorsItem, QStringLiteral( "AssignDefaultResourceColors" ) );
  mDecorationsAtMonthViewTopItem = new KConfigSkeleton::ItemStringList( currentGroup(), QStringLiteral( "Decorations At Month View Top" ), mDecorationsAtMonthViewTop );
  mDecorationsAtMonthViewTopItem->setLabel( i18nd("korganizer", "Decorations At Month View Top") );
  addItem( mDecorationsAtMonthViewTopItem, QStringLiteral( "DecorationsAtMonthViewTop" ) );
  mDecorationsAtAgendaViewTopItem = new KConfigSkeleton::ItemStringList( currentGroup(), QStringLiteral( "Decorations At Agenda View Top" ), mDecorationsAtAgendaViewTop );
  mDecorationsAtAgendaViewTopItem->setLabel( i18nd("korganizer", "Decorations At Agenda View Top") );
  addItem( mDecorationsAtAgendaViewTopItem, QStringLiteral( "DecorationsAtAgendaViewTop" ) );
  mDecorationsAtAgendaViewBottomItem = new KConfigSkeleton::ItemStringList( currentGroup(), QStringLiteral( "Decorations At Agenda View Bottom" ), mDecorationsAtAgendaViewBottom );
  mDecorationsAtAgendaViewBottomItem->setLabel( i18nd("korganizer", "Decorations At Agenda View Bottom") );
  addItem( mDecorationsAtAgendaViewBottomItem, QStringLiteral( "DecorationsAtAgendaViewBottom" ) );
  mAgendaViewShowSidebarItem = new KConfigSkeleton::ItemBool( currentGroup(), QStringLiteral( "AgendaView Show Sidebar" ), mAgendaViewShowSidebar );
  mAgendaViewShowSidebarItem->setLabel( i18nd("korganizer", "AgendaView Show Sidebar") );
  addItem( mAgendaViewShowSidebarItem, QStringLiteral( "AgendaViewShowSidebar" ) );
  mJournalViewShowSidebarItem = new KConfigSkeleton::ItemBool( currentGroup(), QStringLiteral( "JournalView Show Sidebar" ), mJournalViewShowSidebar );
  mJournalViewShowSidebarItem->setLabel( i18nd("korganizer", "JournalView Show Sidebar") );
  addItem( mJournalViewShowSidebarItem, QStringLiteral( "JournalViewShowSidebar" ) );
  mListViewShowSidebarItem = new KConfigSkeleton::ItemBool( currentGroup(), QStringLiteral( "ListView Show Sidebar" ), mListViewShowSidebar );
  mListViewShowSidebarItem->setLabel( i18nd("korganizer", "ListView Show Sidebar") );
  addItem( mListViewShowSidebarItem, QStringLiteral( "ListViewShowSidebar" ) );
  mMonthViewShowSidebarItem = new KConfigSkeleton::ItemBool( currentGroup(), QStringLiteral( "MonthView Show Sidebar" ), mMonthViewShowSidebar );
  mMonthViewShowSidebarItem->setLabel( i18nd("korganizer", "MonthView Show Sidebar") );
  addItem( mMonthViewShowSidebarItem, QStringLiteral( "MonthViewShowSidebar" ) );
  mTimelineViewShowSidebarItem = new KConfigSkeleton::ItemBool( currentGroup(), QStringLiteral( "TimelineView Show Sidebar" ), mTimelineViewShowSidebar );
  mTimelineViewShowSidebarItem->setLabel( i18nd("korganizer", "TimelineView Show Sidebar") );
  addItem( mTimelineViewShowSidebarItem, QStringLiteral( "TimelineViewShowSidebar" ) );
  mTodoViewShowSidebarItem = new KConfigSkeleton::ItemBool( currentGroup(), QStringLiteral( "TodoView Show Sidebar" ), mTodoViewShowSidebar );
  mTodoViewShowSidebarItem->setLabel( i18nd("korganizer", "TodoView Show Sidebar") );
  addItem( mTodoViewShowSidebarItem, QStringLiteral( "TodoViewShowSidebar" ) );
  mWhatsNextViewShowSidebarItem = new KConfigSkeleton::ItemBool( currentGroup(), QStringLiteral( "WhatsNextView Show Sidebar" ), mWhatsNextViewShowSidebar );
  mWhatsNextViewShowSidebarItem->setLabel( i18nd("korganizer", "WhatsNextView Show Sidebar") );
  addItem( mWhatsNextViewShowSidebarItem, QStringLiteral( "WhatsNextViewShowSidebar" ) );

  setCurrentGroup( QStringLiteral( "Theming" ) );

  mAgendaGridBackgroundColorItem = new KConfigSkeleton::ItemColor( currentGroup(), QStringLiteral( "Agenda Grid Background Color" ), mAgendaGridBackgroundColor, QColor( 255, 255, 255 ) );
  mAgendaGridBackgroundColorItem->setLabel( i18nd("korganizer", "Agenda view background color") );
  mAgendaGridBackgroundColorItem->setWhatsThis( i18nd("korganizer", "Select the agenda view background color here.") );
  addItem( mAgendaGridBackgroundColorItem, QStringLiteral( "AgendaGridBackgroundColor" ) );
  mAgendaGridBackgroundImageItem = new KConfigSkeleton::ItemString( currentGroup(), QStringLiteral( "Agenda Grid Background Image" ), mAgendaGridBackgroundImage );
  mAgendaGridBackgroundImageItem->setLabel( i18nd("korganizer", "Agenda Grid Background Image") );
  addItem( mAgendaGridBackgroundImageItem, QStringLiteral( "AgendaGridBackgroundImage" ) );
  mAgendaGridHighlightColorItem = new KConfigSkeleton::ItemColor( currentGroup(), QStringLiteral( "Agenda Grid Highlight Color" ), mAgendaGridHighlightColor, QColor( 100, 100, 255 ) );
  mAgendaGridHighlightColorItem->setLabel( i18nd("korganizer", "Highlight color") );
  mAgendaGridHighlightColorItem->setWhatsThis( i18nd("korganizer", "Select the highlight color here. The highlight color will be used for marking the currently selected area in your agenda and in the date navigator.") );
  addItem( mAgendaGridHighlightColorItem, QStringLiteral( "AgendaGridHighlightColor" ) );
  mAgendaGridWorkHoursBackgroundImageItem = new KConfigSkeleton::ItemString( currentGroup(), QStringLiteral( "Agenda Grid WorkHours Background Image" ), mAgendaGridWorkHoursBackgroundImage );
  mAgendaGridWorkHoursBackgroundImageItem->setLabel( i18nd("korganizer", "Agenda Grid WorkHours Background Image") );
  addItem( mAgendaGridWorkHoursBackgroundImageItem, QStringLiteral( "AgendaGridWorkHoursBackgroundImage" ) );
  mAgendaCalendarItemsBackgroundColorItem = new KConfigSkeleton::ItemColor( currentGroup(), QStringLiteral( "Agenda CalendarItems Background Color" ), mAgendaCalendarItemsBackgroundColor, QColor( 255, 100, 100 ) );
  mAgendaCalendarItemsBackgroundColorItem->setLabel( i18nd("korganizer", "Agenda CalendarItems Background Color") );
  addItem( mAgendaCalendarItemsBackgroundColorItem, QStringLiteral( "AgendaCalendarItemsBackgroundColor" ) );
  mAgendaCalendarItemsBackgroundImageItem = new KConfigSkeleton::ItemString( currentGroup(), QStringLiteral( "Agenda CalendarItems Background Image" ), mAgendaCalendarItemsBackgroundImage );
  mAgendaCalendarItemsBackgroundImageItem->setLabel( i18nd("korganizer", "Agenda CalendarItems Background Image") );
  addItem( mAgendaCalendarItemsBackgroundImageItem, QStringLiteral( "AgendaCalendarItemsBackgroundImage" ) );
  mAgendaCalendarItemsFontItem = new KConfigSkeleton::ItemFont( currentGroup(), QStringLiteral( "Agenda CalendarItems Font" ), mAgendaCalendarItemsFont );
  mAgendaCalendarItemsFontItem->setLabel( i18nd("korganizer", "Agenda CalendarItems Font") );
  addItem( mAgendaCalendarItemsFontItem, QStringLiteral( "AgendaCalendarItemsFont" ) );
  mAgendaCalendarItemsFrameColorItem = new KConfigSkeleton::ItemColor( currentGroup(), QStringLiteral( "Agenda CalendarItems Frame Color" ), mAgendaCalendarItemsFrameColor, QColor( 255, 100, 100 ) );
  mAgendaCalendarItemsFrameColorItem->setLabel( i18nd("korganizer", "Agenda CalendarItems Frame Color") );
  addItem( mAgendaCalendarItemsFrameColorItem, QStringLiteral( "AgendaCalendarItemsFrameColor" ) );
  mAgendaCalendarItemsIconItem = new KConfigSkeleton::ItemString( currentGroup(), QStringLiteral( "Agenda CalendarItems Icon" ), mAgendaCalendarItemsIcon );
  mAgendaCalendarItemsIconItem->setLabel( i18nd("korganizer", "Agenda CalendarItems Icon") );
  addItem( mAgendaCalendarItemsIconItem, QStringLiteral( "AgendaCalendarItemsIcon" ) );
  mAgendaCalendarItemsEventsBackgroundImageItem = new KConfigSkeleton::ItemString( currentGroup(), QStringLiteral( "Agenda CalendarItems Events Background Image" ), mAgendaCalendarItemsEventsBackgroundImage );
  mAgendaCalendarItemsEventsBackgroundImageItem->setLabel( i18nd("korganizer", "Agenda CalendarItems Events Background Image") );
  addItem( mAgendaCalendarItemsEventsBackgroundImageItem, QStringLiteral( "AgendaCalendarItemsEventsBackgroundImage" ) );
  mAgendaCalendarItemsEventsFontItem = new KConfigSkeleton::ItemFont( currentGroup(), QStringLiteral( "Agenda CalendarItems Events Font" ), mAgendaCalendarItemsEventsFont );
  mAgendaCalendarItemsEventsFontItem->setLabel( i18nd("korganizer", "Agenda CalendarItems Events Font") );
  addItem( mAgendaCalendarItemsEventsFontItem, QStringLiteral( "AgendaCalendarItemsEventsFont" ) );
  mAgendaCalendarItemsEventsFrameColorItem = new KConfigSkeleton::ItemColor( currentGroup(), QStringLiteral( "Agenda CalendarItems Events Frame Color" ), mAgendaCalendarItemsEventsFrameColor, QColor( 255, 100, 100 ) );
  mAgendaCalendarItemsEventsFrameColorItem->setLabel( i18nd("korganizer", "Agenda CalendarItems Events Frame Color") );
  addItem( mAgendaCalendarItemsEventsFrameColorItem, QStringLiteral( "AgendaCalendarItemsEventsFrameColor" ) );
  mAgendaCalendarItemsEventsIconItem = new KConfigSkeleton::ItemString( currentGroup(), QStringLiteral( "Agenda CalendarItems Events Icon" ), mAgendaCalendarItemsEventsIcon );
  mAgendaCalendarItemsEventsIconItem->setLabel( i18nd("korganizer", "Agenda CalendarItems Events Icon") );
  addItem( mAgendaCalendarItemsEventsIconItem, QStringLiteral( "AgendaCalendarItemsEventsIcon" ) );
  mAgendaCalendarItemsToDosBackgroundColorItem = new KConfigSkeleton::ItemColor( currentGroup(), QStringLiteral( "Agenda CalendarItems ToDos Background Color" ), mAgendaCalendarItemsToDosBackgroundColor, QColor( 255, 100, 100 ) );
  mAgendaCalendarItemsToDosBackgroundColorItem->setLabel( i18nd("korganizer", "Agenda CalendarItems ToDos Background Color") );
  addItem( mAgendaCalendarItemsToDosBackgroundColorItem, QStringLiteral( "AgendaCalendarItemsToDosBackgroundColor" ) );
  mAgendaCalendarItemsToDosBackgroundImageItem = new KConfigSkeleton::ItemString( currentGroup(), QStringLiteral( "Agenda CalendarItems ToDos Background Image" ), mAgendaCalendarItemsToDosBackgroundImage );
  mAgendaCalendarItemsToDosBackgroundImageItem->setLabel( i18nd("korganizer", "Agenda CalendarItems ToDos Background Image") );
  addItem( mAgendaCalendarItemsToDosBackgroundImageItem, QStringLiteral( "AgendaCalendarItemsToDosBackgroundImage" ) );
  mAgendaCalendarItemsToDosFontItem = new KConfigSkeleton::ItemFont( currentGroup(), QStringLiteral( "Agenda CalendarItems ToDos Font" ), mAgendaCalendarItemsToDosFont );
  mAgendaCalendarItemsToDosFontItem->setLabel( i18nd("korganizer", "Agenda CalendarItems ToDos Font") );
  addItem( mAgendaCalendarItemsToDosFontItem, QStringLiteral( "AgendaCalendarItemsToDosFont" ) );
  mAgendaCalendarItemsToDosFrameColorItem = new KConfigSkeleton::ItemColor( currentGroup(), QStringLiteral( "Agenda CalendarItems ToDos Frame Color" ), mAgendaCalendarItemsToDosFrameColor, QColor( 255, 100, 100 ) );
  mAgendaCalendarItemsToDosFrameColorItem->setLabel( i18nd("korganizer", "Agenda CalendarItems ToDos Frame Color") );
  addItem( mAgendaCalendarItemsToDosFrameColorItem, QStringLiteral( "AgendaCalendarItemsToDosFrameColor" ) );
  mAgendaCalendarItemsToDosIconItem = new KConfigSkeleton::ItemString( currentGroup(), QStringLiteral( "Agenda CalendarItems ToDos Icon" ), mAgendaCalendarItemsToDosIcon );
  mAgendaCalendarItemsToDosIconItem->setLabel( i18nd("korganizer", "Agenda CalendarItems ToDos Icon") );
  addItem( mAgendaCalendarItemsToDosIconItem, QStringLiteral( "AgendaCalendarItemsToDosIcon" ) );
  mAgendaCalendarItemsToDosDueTodayBackgroundImageItem = new KConfigSkeleton::ItemString( currentGroup(), QStringLiteral( "Agenda CalendarItems ToDos DueToday Background Image" ), mAgendaCalendarItemsToDosDueTodayBackgroundImage );
  mAgendaCalendarItemsToDosDueTodayBackgroundImageItem->setLabel( i18nd("korganizer", "Agenda CalendarItems ToDos DueToday Background Image") );
  addItem( mAgendaCalendarItemsToDosDueTodayBackgroundImageItem, QStringLiteral( "AgendaCalendarItemsToDosDueTodayBackgroundImage" ) );
  mAgendaCalendarItemsToDosDueTodayFontItem = new KConfigSkeleton::ItemFont( currentGroup(), QStringLiteral( "Agenda CalendarItems ToDos DueToday Font" ), mAgendaCalendarItemsToDosDueTodayFont );
  mAgendaCalendarItemsToDosDueTodayFontItem->setLabel( i18nd("korganizer", "Agenda CalendarItems ToDos DueToday Font") );
  addItem( mAgendaCalendarItemsToDosDueTodayFontItem, QStringLiteral( "AgendaCalendarItemsToDosDueTodayFont" ) );
  mAgendaCalendarItemsToDosDueTodayFrameColorItem = new KConfigSkeleton::ItemColor( currentGroup(), QStringLiteral( "Agenda CalendarItems ToDos DueToday Frame Color" ), mAgendaCalendarItemsToDosDueTodayFrameColor );
  mAgendaCalendarItemsToDosDueTodayFrameColorItem->setLabel( i18nd("korganizer", "Agenda CalendarItems ToDos DueToday Frame Color") );
  addItem( mAgendaCalendarItemsToDosDueTodayFrameColorItem, QStringLiteral( "AgendaCalendarItemsToDosDueTodayFrameColor" ) );
  mAgendaCalendarItemsToDosDueTodayIconItem = new KConfigSkeleton::ItemString( currentGroup(), QStringLiteral( "Agenda CalendarItems ToDos DueToday Icon" ), mAgendaCalendarItemsToDosDueTodayIcon );
  mAgendaCalendarItemsToDosDueTodayIconItem->setLabel( i18nd("korganizer", "Agenda CalendarItems ToDos DueToday Icon") );
  addItem( mAgendaCalendarItemsToDosDueTodayIconItem, QStringLiteral( "AgendaCalendarItemsToDosDueTodayIcon" ) );
  mAgendaCalendarItemsToDosOverdueBackgroundImageItem = new KConfigSkeleton::ItemString( currentGroup(), QStringLiteral( "Agenda CalendarItems ToDos Overdue Background Image" ), mAgendaCalendarItemsToDosOverdueBackgroundImage );
  mAgendaCalendarItemsToDosOverdueBackgroundImageItem->setLabel( i18nd("korganizer", "Agenda CalendarItems ToDos Overdue Background Image") );
  addItem( mAgendaCalendarItemsToDosOverdueBackgroundImageItem, QStringLiteral( "AgendaCalendarItemsToDosOverdueBackgroundImage" ) );
  mAgendaCalendarItemsToDosOverdueFontItem = new KConfigSkeleton::ItemFont( currentGroup(), QStringLiteral( "Agenda CalendarItems ToDos Overdue Font" ), mAgendaCalendarItemsToDosOverdueFont );
  mAgendaCalendarItemsToDosOverdueFontItem->setLabel( i18nd("korganizer", "Agenda CalendarItems ToDos Overdue Font") );
  addItem( mAgendaCalendarItemsToDosOverdueFontItem, QStringLiteral( "AgendaCalendarItemsToDosOverdueFont" ) );
  mAgendaCalendarItemsToDosOverdueFrameColorItem = new KConfigSkeleton::ItemColor( currentGroup(), QStringLiteral( "Agenda CalendarItems ToDos Overdue Frame Color" ), mAgendaCalendarItemsToDosOverdueFrameColor );
  mAgendaCalendarItemsToDosOverdueFrameColorItem->setLabel( i18nd("korganizer", "Agenda CalendarItems ToDos Overdue Frame Color") );
  addItem( mAgendaCalendarItemsToDosOverdueFrameColorItem, QStringLiteral( "AgendaCalendarItemsToDosOverdueFrameColor" ) );
  mAgendaCalendarItemsToDosOverdueIconItem = new KConfigSkeleton::ItemString( currentGroup(), QStringLiteral( "Agenda CalendarItems ToDos Overdue Icon" ), mAgendaCalendarItemsToDosOverdueIcon );
  mAgendaCalendarItemsToDosOverdueIconItem->setLabel( i18nd("korganizer", "Agenda CalendarItems ToDos Overdue Icon") );
  addItem( mAgendaCalendarItemsToDosOverdueIconItem, QStringLiteral( "AgendaCalendarItemsToDosOverdueIcon" ) );
  mAgendaHolidaysBackgroundColorItem = new KConfigSkeleton::ItemColor( currentGroup(), QStringLiteral( "Agenda Holidays Background Color" ), mAgendaHolidaysBackgroundColor, QColor( 255, 100, 100 ) );
  mAgendaHolidaysBackgroundColorItem->setLabel( i18nd("korganizer", "Holiday color") );
  mAgendaHolidaysBackgroundColorItem->setWhatsThis( i18nd("korganizer", "Select the holiday color here. The holiday color will be used for the holiday name in the month view and the holiday number in the date navigator.") );
  addItem( mAgendaHolidaysBackgroundColorItem, QStringLiteral( "AgendaHolidaysBackgroundColor" ) );
  mUseSystemColorItem = new KConfigSkeleton::ItemBool( currentGroup(), QStringLiteral( "Use System Color" ), mUseSystemColor, true );
  mUseSystemColorItem->setLabel( i18nd("korganizer", "Use system colors for some background colors") );
  mUseSystemColorItem->setToolTip( i18nd("korganizer", "Use system colors instead of custom colors for some background colors") );
  mUseSystemColorItem->setWhatsThis( i18nd("korganizer", "Use system colors instead of user defined colors for the \"Agenda view background color\", \"Busy days background color\" and the \"Working hours color\" (and possibly others).") );
  addItem( mUseSystemColorItem, QStringLiteral( "UseSystemColor" ) );
  mAgendaHolidaysBackgroundImageItem = new KConfigSkeleton::ItemString( currentGroup(), QStringLiteral( "Agenda Holidays Background Image" ), mAgendaHolidaysBackgroundImage );
  mAgendaHolidaysBackgroundImageItem->setLabel( i18nd("korganizer", "Agenda Holidays Background Image") );
  addItem( mAgendaHolidaysBackgroundImageItem, QStringLiteral( "AgendaHolidaysBackgroundImage" ) );

  setCurrentGroup( QStringLiteral( "Theme/Month view" ) );

  mMonthGridBackgroundColorItem = new KConfigSkeleton::ItemColor( currentGroup(), QStringLiteral( "Month Grid Background Color" ), mMonthGridBackgroundColor, QColor( 255, 255, 255 ) );
  mMonthGridBackgroundColorItem->setLabel( i18nd("korganizer", "Month view background color") );
  mMonthGridBackgroundColorItem->setWhatsThis( i18nd("korganizer", "Select the Month view background color here.") );
  addItem( mMonthGridBackgroundColorItem, QStringLiteral( "MonthGridBackgroundColor" ) );
  mMonthGridBackgroundImageItem = new KConfigSkeleton::ItemString( currentGroup(), QStringLiteral( "Month Grid Background Image" ), mMonthGridBackgroundImage );
  mMonthGridBackgroundImageItem->setLabel( i18nd("korganizer", "Month Grid Background Image") );
  addItem( mMonthGridBackgroundImageItem, QStringLiteral( "MonthGridBackgroundImage" ) );
  mMonthGridHighlightColorItem = new KConfigSkeleton::ItemColor( currentGroup(), QStringLiteral( "Month Grid Highlight Color" ), mMonthGridHighlightColor, QColor( 100, 100, 255 ) );
  mMonthGridHighlightColorItem->setLabel( i18nd("korganizer", "Highlight color") );
  mMonthGridHighlightColorItem->setWhatsThis( i18nd("korganizer", "Select the highlight color here. The highlight color will be used for marking the currently selected area in your Month and in the date navigator.") );
  addItem( mMonthGridHighlightColorItem, QStringLiteral( "MonthGridHighlightColor" ) );
  mMonthGridWorkHoursBackgroundColorItem = new KConfigSkeleton::ItemColor( currentGroup(), QStringLiteral( "Month Grid WorkHours Background Color" ), mMonthGridWorkHoursBackgroundColor, QColor( 225, 225, 255 ) );
  mMonthGridWorkHoursBackgroundColorItem->setLabel( i18nd("korganizer", "Working hours color") );
  mMonthGridWorkHoursBackgroundColorItem->setWhatsThis( i18nd("korganizer", "Select the working hours background color for the Month view here.") );
  addItem( mMonthGridWorkHoursBackgroundColorItem, QStringLiteral( "MonthGridWorkHoursBackgroundColor" ) );
  mMonthGridWorkHoursBackgroundImageItem = new KConfigSkeleton::ItemString( currentGroup(), QStringLiteral( "Month Grid WorkHours Background Image" ), mMonthGridWorkHoursBackgroundImage );
  mMonthGridWorkHoursBackgroundImageItem->setLabel( i18nd("korganizer", "Month Grid WorkHours Background Image") );
  addItem( mMonthGridWorkHoursBackgroundImageItem, QStringLiteral( "MonthGridWorkHoursBackgroundImage" ) );
  mMonthCalendarItemsBackgroundColorItem = new KConfigSkeleton::ItemColor( currentGroup(), QStringLiteral( "Month CalendarItems Background Color" ), mMonthCalendarItemsBackgroundColor, QColor( 255, 100, 100 ) );
  mMonthCalendarItemsBackgroundColorItem->setLabel( i18nd("korganizer", "Month CalendarItems Background Color") );
  addItem( mMonthCalendarItemsBackgroundColorItem, QStringLiteral( "MonthCalendarItemsBackgroundColor" ) );
  mMonthCalendarItemsBackgroundImageItem = new KConfigSkeleton::ItemString( currentGroup(), QStringLiteral( "Month CalendarItems Background Image" ), mMonthCalendarItemsBackgroundImage );
  mMonthCalendarItemsBackgroundImageItem->setLabel( i18nd("korganizer", "Month CalendarItems Background Image") );
  addItem( mMonthCalendarItemsBackgroundImageItem, QStringLiteral( "MonthCalendarItemsBackgroundImage" ) );
  mMonthCalendarItemsFontItem = new KConfigSkeleton::ItemFont( currentGroup(), QStringLiteral( "Month CalendarItems Font" ), mMonthCalendarItemsFont );
  mMonthCalendarItemsFontItem->setLabel( i18nd("korganizer", "Month CalendarItems Font") );
  addItem( mMonthCalendarItemsFontItem, QStringLiteral( "MonthCalendarItemsFont" ) );
  mMonthCalendarItemsFrameColorItem = new KConfigSkeleton::ItemColor( currentGroup(), QStringLiteral( "Month CalendarItems Frame Color" ), mMonthCalendarItemsFrameColor, QColor( 255, 100, 100 ) );
  mMonthCalendarItemsFrameColorItem->setLabel( i18nd("korganizer", "Month CalendarItems Frame Color") );
  addItem( mMonthCalendarItemsFrameColorItem, QStringLiteral( "MonthCalendarItemsFrameColor" ) );
  mMonthCalendarItemsIconItem = new KConfigSkeleton::ItemString( currentGroup(), QStringLiteral( "Month CalendarItems Icon" ), mMonthCalendarItemsIcon );
  mMonthCalendarItemsIconItem->setLabel( i18nd("korganizer", "Month CalendarItems Icon") );
  addItem( mMonthCalendarItemsIconItem, QStringLiteral( "MonthCalendarItemsIcon" ) );
  mMonthCalendarItemsEventsBackgroundColorItem = new KConfigSkeleton::ItemColor( currentGroup(), QStringLiteral( "Month CalendarItems Events Background Color" ), mMonthCalendarItemsEventsBackgroundColor, QColor( 151, 235, 121 ) );
  mMonthCalendarItemsEventsBackgroundColorItem->setLabel( i18nd("korganizer", "Default event color") );
  mMonthCalendarItemsEventsBackgroundColorItem->setWhatsThis( i18nd("korganizer", "Select the default event color here. The default event color will be used for events in your Month. Note that you can specify a separate color for each event tag below.") );
  addItem( mMonthCalendarItemsEventsBackgroundColorItem, QStringLiteral( "MonthCalendarItemsEventsBackgroundColor" ) );
  mMonthCalendarItemsEventsBackgroundImageItem = new KConfigSkeleton::ItemString( currentGroup(), QStringLiteral( "Month CalendarItems Events Background Image" ), mMonthCalendarItemsEventsBackgroundImage );
  mMonthCalendarItemsEventsBackgroundImageItem->setLabel( i18nd("korganizer", "Month CalendarItems Events Background Image") );
  addItem( mMonthCalendarItemsEventsBackgroundImageItem, QStringLiteral( "MonthCalendarItemsEventsBackgroundImage" ) );
  mMonthCalendarItemsEventsFontItem = new KConfigSkeleton::ItemFont( currentGroup(), QStringLiteral( "Month CalendarItems Events Font" ), mMonthCalendarItemsEventsFont );
  mMonthCalendarItemsEventsFontItem->setLabel( i18nd("korganizer", "Month CalendarItems Events Font") );
  addItem( mMonthCalendarItemsEventsFontItem, QStringLiteral( "MonthCalendarItemsEventsFont" ) );
  mMonthCalendarItemsEventsFrameColorItem = new KConfigSkeleton::ItemColor( currentGroup(), QStringLiteral( "Month CalendarItems Events Frame Color" ), mMonthCalendarItemsEventsFrameColor, QColor( 255, 100, 100 ) );
  mMonthCalendarItemsEventsFrameColorItem->setLabel( i18nd("korganizer", "Month CalendarItems Events Frame Color") );
  addItem( mMonthCalendarItemsEventsFrameColorItem, QStringLiteral( "MonthCalendarItemsEventsFrameColor" ) );
  mMonthCalendarItemsEventsIconItem = new KConfigSkeleton::ItemString( currentGroup(), QStringLiteral( "Month CalendarItems Events Icon" ), mMonthCalendarItemsEventsIcon );
  mMonthCalendarItemsEventsIconItem->setLabel( i18nd("korganizer", "Month CalendarItems Events Icon") );
  addItem( mMonthCalendarItemsEventsIconItem, QStringLiteral( "MonthCalendarItemsEventsIcon" ) );
  mMonthCalendarItemsToDosBackgroundColorItem = new KConfigSkeleton::ItemColor( currentGroup(), QStringLiteral( "Month CalendarItems ToDos Background Color" ), mMonthCalendarItemsToDosBackgroundColor, QColor( 255, 100, 100 ) );
  mMonthCalendarItemsToDosBackgroundColorItem->setLabel( i18nd("korganizer", "Month CalendarItems ToDos Background Color") );
  addItem( mMonthCalendarItemsToDosBackgroundColorItem, QStringLiteral( "MonthCalendarItemsToDosBackgroundColor" ) );
  mMonthCalendarItemsToDosBackgroundImageItem = new KConfigSkeleton::ItemString( currentGroup(), QStringLiteral( "Month CalendarItems ToDos Background Image" ), mMonthCalendarItemsToDosBackgroundImage );
  mMonthCalendarItemsToDosBackgroundImageItem->setLabel( i18nd("korganizer", "Month CalendarItems ToDos Background Image") );
  addItem( mMonthCalendarItemsToDosBackgroundImageItem, QStringLiteral( "MonthCalendarItemsToDosBackgroundImage" ) );
  mMonthCalendarItemsToDosFontItem = new KConfigSkeleton::ItemFont( currentGroup(), QStringLiteral( "Month CalendarItems ToDos Font" ), mMonthCalendarItemsToDosFont );
  mMonthCalendarItemsToDosFontItem->setLabel( i18nd("korganizer", "Month CalendarItems ToDos Font") );
  addItem( mMonthCalendarItemsToDosFontItem, QStringLiteral( "MonthCalendarItemsToDosFont" ) );
  mMonthCalendarItemsToDosFrameColorItem = new KConfigSkeleton::ItemColor( currentGroup(), QStringLiteral( "Month CalendarItems ToDos Frame Color" ), mMonthCalendarItemsToDosFrameColor, QColor( 255, 100, 100 ) );
  mMonthCalendarItemsToDosFrameColorItem->setLabel( i18nd("korganizer", "Month CalendarItems ToDos Frame Color") );
  addItem( mMonthCalendarItemsToDosFrameColorItem, QStringLiteral( "MonthCalendarItemsToDosFrameColor" ) );
  mMonthCalendarItemsToDosIconItem = new KConfigSkeleton::ItemString( currentGroup(), QStringLiteral( "Month CalendarItems ToDos Icon" ), mMonthCalendarItemsToDosIcon );
  mMonthCalendarItemsToDosIconItem->setLabel( i18nd("korganizer", "Month CalendarItems ToDos Icon") );
  addItem( mMonthCalendarItemsToDosIconItem, QStringLiteral( "MonthCalendarItemsToDosIcon" ) );
  mMonthCalendarItemsToDosDueTodayBackgroundColorItem = new KConfigSkeleton::ItemColor( currentGroup(), QStringLiteral( "Month CalendarItems ToDos DueTodayBackground Color" ), mMonthCalendarItemsToDosDueTodayBackgroundColor, QColor( 255, 200, 50 ) );
  mMonthCalendarItemsToDosDueTodayBackgroundColorItem->setLabel( i18nd("korganizer", "To-do due today color") );
  mMonthCalendarItemsToDosDueTodayBackgroundColorItem->setWhatsThis( i18nd("korganizer", "Select the to-do due today color here.") );
  addItem( mMonthCalendarItemsToDosDueTodayBackgroundColorItem, QStringLiteral( "MonthCalendarItemsToDosDueTodayBackgroundColor" ) );
  mMonthCalendarItemsToDosDueTodayBackgroundImageItem = new KConfigSkeleton::ItemString( currentGroup(), QStringLiteral( "Month CalendarItems ToDos DueToday Background Image" ), mMonthCalendarItemsToDosDueTodayBackgroundImage );
  mMonthCalendarItemsToDosDueTodayBackgroundImageItem->setLabel( i18nd("korganizer", "Month CalendarItems ToDos DueToday Background Image") );
  addItem( mMonthCalendarItemsToDosDueTodayBackgroundImageItem, QStringLiteral( "MonthCalendarItemsToDosDueTodayBackgroundImage" ) );
  mMonthCalendarItemsToDosDueTodayFontItem = new KConfigSkeleton::ItemFont( currentGroup(), QStringLiteral( "Month CalendarItems ToDos DueToday Font" ), mMonthCalendarItemsToDosDueTodayFont );
  mMonthCalendarItemsToDosDueTodayFontItem->setLabel( i18nd("korganizer", "Month CalendarItems ToDos DueToday Font") );
  addItem( mMonthCalendarItemsToDosDueTodayFontItem, QStringLiteral( "MonthCalendarItemsToDosDueTodayFont" ) );
  mMonthCalendarItemsToDosDueTodayFrameColorItem = new KConfigSkeleton::ItemColor( currentGroup(), QStringLiteral( "Month CalendarItems ToDos DueToday Frame Color" ), mMonthCalendarItemsToDosDueTodayFrameColor );
  mMonthCalendarItemsToDosDueTodayFrameColorItem->setLabel( i18nd("korganizer", "Month CalendarItems ToDos DueToday Frame Color") );
  addItem( mMonthCalendarItemsToDosDueTodayFrameColorItem, QStringLiteral( "MonthCalendarItemsToDosDueTodayFrameColor" ) );
  mMonthCalendarItemsToDosDueTodayIconItem = new KConfigSkeleton::ItemString( currentGroup(), QStringLiteral( "Month CalendarItems ToDos DueToday Icon" ), mMonthCalendarItemsToDosDueTodayIcon );
  mMonthCalendarItemsToDosDueTodayIconItem->setLabel( i18nd("korganizer", "Month CalendarItems ToDos DueToday Icon") );
  addItem( mMonthCalendarItemsToDosDueTodayIconItem, QStringLiteral( "MonthCalendarItemsToDosDueTodayIcon" ) );
  mMonthCalendarItemsToDosOverdueBackgroundColorItem = new KConfigSkeleton::ItemColor( currentGroup(), QStringLiteral( "Month CalendarItems ToDos Overdue Background Color" ), mMonthCalendarItemsToDosOverdueBackgroundColor, QColor( 255, 100, 100 ) );
  mMonthCalendarItemsToDosOverdueBackgroundColorItem->setLabel( i18nd("korganizer", "To-do overdue color") );
  mMonthCalendarItemsToDosOverdueBackgroundColorItem->setWhatsThis( i18nd("korganizer", "Select the to-do overdue color here.") );
  addItem( mMonthCalendarItemsToDosOverdueBackgroundColorItem, QStringLiteral( "MonthCalendarItemsToDosOverdueBackgroundColor" ) );
  mMonthCalendarItemsToDosOverdueBackgroundImageItem = new KConfigSkeleton::ItemString( currentGroup(), QStringLiteral( "Month CalendarItems ToDos Overdue Background Image" ), mMonthCalendarItemsToDosOverdueBackgroundImage );
  mMonthCalendarItemsToDosOverdueBackgroundImageItem->setLabel( i18nd("korganizer", "Month CalendarItems ToDos Overdue Background Image") );
  addItem( mMonthCalendarItemsToDosOverdueBackgroundImageItem, QStringLiteral( "MonthCalendarItemsToDosOverdueBackgroundImage" ) );
  mMonthCalendarItemsToDosOverdueFontItem = new KConfigSkeleton::ItemFont( currentGroup(), QStringLiteral( "Month CalendarItems ToDos Overdue Font" ), mMonthCalendarItemsToDosOverdueFont );
  mMonthCalendarItemsToDosOverdueFontItem->setLabel( i18nd("korganizer", "Month CalendarItems ToDos Overdue Font") );
  addItem( mMonthCalendarItemsToDosOverdueFontItem, QStringLiteral( "MonthCalendarItemsToDosOverdueFont" ) );
  mMonthCalendarItemsToDosOverdueFrameColorItem = new KConfigSkeleton::ItemColor( currentGroup(), QStringLiteral( "Month CalendarItems ToDos Overdue Frame Color" ), mMonthCalendarItemsToDosOverdueFrameColor );
  mMonthCalendarItemsToDosOverdueFrameColorItem->setLabel( i18nd("korganizer", "Month CalendarItems ToDos Overdue Frame Color") );
  addItem( mMonthCalendarItemsToDosOverdueFrameColorItem, QStringLiteral( "MonthCalendarItemsToDosOverdueFrameColor" ) );
  mMonthCalendarItemsToDosOverdueIconItem = new KConfigSkeleton::ItemString( currentGroup(), QStringLiteral( "Month CalendarItems ToDos Overdue Icon" ), mMonthCalendarItemsToDosOverdueIcon );
  mMonthCalendarItemsToDosOverdueIconItem->setLabel( i18nd("korganizer", "Month CalendarItems ToDos Overdue Icon") );
  addItem( mMonthCalendarItemsToDosOverdueIconItem, QStringLiteral( "MonthCalendarItemsToDosOverdueIcon" ) );
  mMonthHolidaysBackgroundColorItem = new KConfigSkeleton::ItemColor( currentGroup(), QStringLiteral( "Month Holidays Background Color" ), mMonthHolidaysBackgroundColor, QColor( 255, 100, 100 ) );
  mMonthHolidaysBackgroundColorItem->setLabel( i18nd("korganizer", "Holiday color") );
  mMonthHolidaysBackgroundColorItem->setWhatsThis( i18nd("korganizer", "Select the holiday color here. The holiday color will be used for the holiday name in the month view and the holiday number in the date navigator.") );
  addItem( mMonthHolidaysBackgroundColorItem, QStringLiteral( "MonthHolidaysBackgroundColor" ) );
  mMonthHolidaysBackgroundImageItem = new KConfigSkeleton::ItemString( currentGroup(), QStringLiteral( "Month Holidays Background Image" ), mMonthHolidaysBackgroundImage );
  mMonthHolidaysBackgroundImageItem->setLabel( i18nd("korganizer", "Month Holidays Background Image") );
  addItem( mMonthHolidaysBackgroundImageItem, QStringLiteral( "MonthHolidaysBackgroundImage" ) );

  setCurrentGroup( QStringLiteral( "Activities" ) );

  mEnabledActivitiesItem = new KConfigSkeleton::ItemBool( currentGroup(), QStringLiteral( "EnabledActivities" ), mEnabledActivities, false );
  mEnabledActivitiesItem->setLabel( i18nd("korganizer", "EnabledActivities") );
  addItem( mEnabledActivitiesItem, QStringLiteral( "EnabledActivities" ) );

  setCurrentGroup( QStringLiteral( "General" ) );

  mPreviousNewFeaturesMD5Item = new KConfigSkeleton::ItemString( currentGroup(), QStringLiteral( "PreviousNewFeaturesMD5" ), mPreviousNewFeaturesMD5 );
  mPreviousNewFeaturesMD5Item->setLabel( i18nd("korganizer", "PreviousNewFeaturesMD5") );
  addItem( mPreviousNewFeaturesMD5Item, QStringLiteral( "PreviousNewFeaturesMD5" ) );
}

KOPrefsBase::~KOPrefsBase()
{
}

