/*
 * This file was generated by qdbusxml2cpp version 0.8
 * Source file was org.kde.korganizer.Korganizer.xml
 *
 * qdbusxml2cpp is Copyright (C) The Qt Company Ltd. and other contributors.
 *
 * This is an auto-generated file.
 * Do not edit! All changes made to it will be lost.
 */

#ifndef KORGANIZERINTERFACE_H
#define KORGANIZERINTERFACE_H

#include <QtCore/QObject>
#include <QtCore/QByteArray>
#include <QtCore/QList>
#include <QtCore/QMap>
#include <QtCore/QString>
#include <QtCore/QStringList>
#include <QtCore/QVariant>
#include <QtDBus/QtDBus>

/*
 * Proxy class for interface org.kde.korganizer.Korganizer
 */
class OrgKdeKorganizerKorganizerInterface: public QDBusAbstractInterface
{
    Q_OBJECT
public:
    static inline const char *staticInterfaceName()
    { return "org.kde.korganizer.Korganizer"; }

public:
    OrgKdeKorganizerKorganizerInterface(const QString &service, const QString &path, const QDBusConnection &connection, QObject *parent = nullptr);

    ~OrgKdeKorganizerKorganizerInterface();

public Q_SLOTS: // METHODS
    inline QDBusPendingReply<bool> addIncidence(const QString &ical)
    {
        QList<QVariant> argumentList;
        argumentList << QVariant::fromValue(ical);
        return asyncCallWithArgumentList(QStringLiteral("addIncidence"), argumentList);
    }

    inline QDBusPendingReply<bool> deleteIncidence(const QString &url, bool force)
    {
        QList<QVariant> argumentList;
        argumentList << QVariant::fromValue(url) << QVariant::fromValue(force);
        return asyncCallWithArgumentList(QStringLiteral("deleteIncidence"), argumentList);
    }

    inline QDBusPendingReply<bool> deleteIncidence(const QString &url)
    {
        QList<QVariant> argumentList;
        argumentList << QVariant::fromValue(url);
        return asyncCallWithArgumentList(QStringLiteral("deleteIncidence"), argumentList);
    }

    inline QDBusPendingReply<bool> editIncidence(const QString &url)
    {
        QList<QVariant> argumentList;
        argumentList << QVariant::fromValue(url);
        return asyncCallWithArgumentList(QStringLiteral("editIncidence"), argumentList);
    }

    inline QDBusPendingReply<QString> getCurrentURLasString()
    {
        QList<QVariant> argumentList;
        return asyncCallWithArgumentList(QStringLiteral("getCurrentURLasString"), argumentList);
    }

    inline QDBusPendingReply<bool> handleCommandLine(const QStringList &args)
    {
        QList<QVariant> argumentList;
        argumentList << QVariant::fromValue(args);
        return asyncCallWithArgumentList(QStringLiteral("handleCommandLine"), argumentList);
    }

    inline QDBusPendingReply<bool> mergeURL(const QString &url)
    {
        QList<QVariant> argumentList;
        argumentList << QVariant::fromValue(url);
        return asyncCallWithArgumentList(QStringLiteral("mergeURL"), argumentList);
    }

    inline QDBusPendingReply<bool> openURL(const QString &url)
    {
        QList<QVariant> argumentList;
        argumentList << QVariant::fromValue(url);
        return asyncCallWithArgumentList(QStringLiteral("openURL"), argumentList);
    }

    inline QDBusPendingReply<bool> saveAsURL(const QString &url)
    {
        QList<QVariant> argumentList;
        argumentList << QVariant::fromValue(url);
        return asyncCallWithArgumentList(QStringLiteral("saveAsURL"), argumentList);
    }

    inline QDBusPendingReply<bool> saveURL()
    {
        QList<QVariant> argumentList;
        return asyncCallWithArgumentList(QStringLiteral("saveURL"), argumentList);
    }

    inline QDBusPendingReply<bool> showIncidence(const QString &url)
    {
        QList<QVariant> argumentList;
        argumentList << QVariant::fromValue(url);
        return asyncCallWithArgumentList(QStringLiteral("showIncidence"), argumentList);
    }

    inline QDBusPendingReply<bool> showIncidenceContext(const QString &url)
    {
        QList<QVariant> argumentList;
        argumentList << QVariant::fromValue(url);
        return asyncCallWithArgumentList(QStringLiteral("showIncidenceContext"), argumentList);
    }

Q_SIGNALS: // SIGNALS
};

namespace org {
  namespace kde {
    namespace korganizer {
      using Korganizer = ::OrgKdeKorganizerKorganizerInterface;
    }
  }
}

#endif
