/*
Configuration page for the Korganizer Event Summary
*/

/********************************************************************************
** Form generated from reading UI file 'apptsummaryconfig_base.ui'
**
** Created by: Qt User Interface Compiler version 6.11.2
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef UI_APPTSUMMARYCONFIG_BASE_H
#define UI_APPTSUMMARYCONFIG_BASE_H

#include <QtCore/QVariant>
#include <QtWidgets/QApplication>
#include <QtWidgets/QCheckBox>
#include <QtWidgets/QGroupBox>
#include <QtWidgets/QHBoxLayout>
#include <QtWidgets/QRadioButton>
#include <QtWidgets/QSpacerItem>
#include <QtWidgets/QSpinBox>
#include <QtWidgets/QVBoxLayout>
#include <QtWidgets/QWidget>
#include <klocalizedstring.h>

QT_BEGIN_NAMESPACE

class Ui_ApptSummaryConfig_Base
{
public:
    QVBoxLayout *verticalLayout_4;
    QGroupBox *mDaysButtonGroup;
    QVBoxLayout *verticalLayout_2;
    QRadioButton *mDateTodayButton;
    QRadioButton *mDateMonthButton;
    QHBoxLayout *horizontalLayout;
    QRadioButton *mDateRangeButton;
    QSpinBox *mCustomDays;
    QSpacerItem *horizontalSpacer;
    QGroupBox *mShowButtonGroup;
    QVBoxLayout *verticalLayout;
    QCheckBox *mShowBirthdaysFromCal;
    QCheckBox *mShowAnniversariesFromCal;
    QSpacerItem *verticalSpacer;

    void setupUi(QWidget *ApptSummaryConfig_Base)
    {
        if (ApptSummaryConfig_Base->objectName().isEmpty())
            ApptSummaryConfig_Base->setObjectName("ApptSummaryConfig_Base");
        ApptSummaryConfig_Base->resize(291, 301);
        verticalLayout_4 = new QVBoxLayout(ApptSummaryConfig_Base);
        verticalLayout_4->setObjectName("verticalLayout_4");
        mDaysButtonGroup = new QGroupBox(ApptSummaryConfig_Base);
        mDaysButtonGroup->setObjectName("mDaysButtonGroup");
        verticalLayout_2 = new QVBoxLayout(mDaysButtonGroup);
        verticalLayout_2->setObjectName("verticalLayout_2");
        mDateTodayButton = new QRadioButton(mDaysButtonGroup);
        mDateTodayButton->setObjectName("mDateTodayButton");
        mDateTodayButton->setChecked(true);

        verticalLayout_2->addWidget(mDateTodayButton);

        mDateMonthButton = new QRadioButton(mDaysButtonGroup);
        mDateMonthButton->setObjectName("mDateMonthButton");
        mDateMonthButton->setChecked(false);

        verticalLayout_2->addWidget(mDateMonthButton);

        horizontalLayout = new QHBoxLayout();
        horizontalLayout->setObjectName("horizontalLayout");
        mDateRangeButton = new QRadioButton(mDaysButtonGroup);
        mDateRangeButton->setObjectName("mDateRangeButton");
        mDateRangeButton->setEnabled(true);
        mDateRangeButton->setChecked(false);

        horizontalLayout->addWidget(mDateRangeButton);

        mCustomDays = new QSpinBox(mDaysButtonGroup);
        mCustomDays->setObjectName("mCustomDays");
        mCustomDays->setEnabled(false);
        mCustomDays->setMinimum(1);
        mCustomDays->setMaximum(365);
        mCustomDays->setSingleStep(1);
        mCustomDays->setValue(7);

        horizontalLayout->addWidget(mCustomDays);

        horizontalSpacer = new QSpacerItem(1, 0, QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Minimum);

        horizontalLayout->addItem(horizontalSpacer);


        verticalLayout_2->addLayout(horizontalLayout);


        verticalLayout_4->addWidget(mDaysButtonGroup);

        mShowButtonGroup = new QGroupBox(ApptSummaryConfig_Base);
        mShowButtonGroup->setObjectName("mShowButtonGroup");
        verticalLayout = new QVBoxLayout(mShowButtonGroup);
        verticalLayout->setObjectName("verticalLayout");
        mShowBirthdaysFromCal = new QCheckBox(mShowButtonGroup);
        mShowBirthdaysFromCal->setObjectName("mShowBirthdaysFromCal");

        verticalLayout->addWidget(mShowBirthdaysFromCal);

        mShowAnniversariesFromCal = new QCheckBox(mShowButtonGroup);
        mShowAnniversariesFromCal->setObjectName("mShowAnniversariesFromCal");

        verticalLayout->addWidget(mShowAnniversariesFromCal);


        verticalLayout_4->addWidget(mShowButtonGroup);

        verticalSpacer = new QSpacerItem(0, 1, QSizePolicy::Policy::Minimum, QSizePolicy::Policy::Expanding);

        verticalLayout_4->addItem(verticalSpacer);


        retranslateUi(ApptSummaryConfig_Base);

        QMetaObject::connectSlotsByName(ApptSummaryConfig_Base);
    } // setupUi

    void retranslateUi(QWidget *ApptSummaryConfig_Base)
    {
        ApptSummaryConfig_Base->setWindowTitle(tr2i18n("Event Summary Configuration", nullptr));
        mDaysButtonGroup->setTitle(tr2i18n("Show Upcoming Events Starting", nullptr));
#if QT_CONFIG(tooltip)
        mDateTodayButton->setToolTip(tr2i18n("Show events for today only", nullptr));
#endif // QT_CONFIG(tooltip)
#if QT_CONFIG(whatsthis)
        mDateTodayButton->setWhatsThis(tr2i18n("Check this box if you want to see events occurring on this date only.", nullptr));
#endif // QT_CONFIG(whatsthis)
        mDateTodayButton->setText(tr2i18n("&Today only", nullptr));
#if QT_CONFIG(tooltip)
        mDateMonthButton->setToolTip(tr2i18n("Show events starting within the next month", nullptr));
#endif // QT_CONFIG(tooltip)
#if QT_CONFIG(whatsthis)
        mDateMonthButton->setWhatsThis(tr2i18n("Check this box if you want to see events that start sometime during the next 31 days.", nullptr));
#endif // QT_CONFIG(whatsthis)
        mDateMonthButton->setText(tr2i18n("Within the next &month (31 days)", nullptr));
#if QT_CONFIG(tooltip)
        mDateRangeButton->setToolTip(tr2i18n("Select the days for showing upcoming events", nullptr));
#endif // QT_CONFIG(tooltip)
#if QT_CONFIG(whatsthis)
        mDateRangeButton->setWhatsThis(tr2i18n("Check this box if you want to specify the number of days in the future for upcoming events.", nullptr));
#endif // QT_CONFIG(whatsthis)
        mDateRangeButton->setText(tr2i18n("Within the &next:", nullptr));
#if QT_CONFIG(tooltip)
        mCustomDays->setToolTip(tr2i18n("Set the number of days to show upcoming events", nullptr));
#endif // QT_CONFIG(tooltip)
#if QT_CONFIG(whatsthis)
        mCustomDays->setWhatsThis(tr2i18n("Use this spinbox to set the number of days to show upcoming events up to 1 year in the future.", nullptr));
#endif // QT_CONFIG(whatsthis)
        mCustomDays->setSpecialValueText(tr2i18n("1 day", nullptr));
        mCustomDays->setSuffix(tr2i18n(" days", "days to show in summary"));
        mShowButtonGroup->setTitle(tr2i18n("Show These Upcoming Events From Your Calendar", nullptr));
#if QT_CONFIG(tooltip)
        mShowBirthdaysFromCal->setToolTip(tr2i18n("Show birthdays from your calendar when also using the Birthday resource", nullptr));
#endif // QT_CONFIG(tooltip)
#if QT_CONFIG(whatsthis)
        mShowBirthdaysFromCal->setWhatsThis(tr2i18n("Enable this option to include birthdays from your calendar in the upcoming events summary. This option is only available if you are using the Birthdays resource in your calendar.", nullptr));
#endif // QT_CONFIG(whatsthis)
        mShowBirthdaysFromCal->setText(tr2i18n("Show &birthdays", nullptr));
#if QT_CONFIG(tooltip)
        mShowAnniversariesFromCal->setToolTip(tr2i18n("Shows anniversaries from your calendar when using the Birthdays resource", nullptr));
#endif // QT_CONFIG(tooltip)
#if QT_CONFIG(whatsthis)
        mShowAnniversariesFromCal->setWhatsThis(tr2i18n("Enable this option to include anniversaries from your calendar in the upcoming events summary. This option is only available if you are using the Birthdays resource in your calendar.", nullptr));
#endif // QT_CONFIG(whatsthis)
        mShowAnniversariesFromCal->setText(tr2i18n("Show &anniversaries", nullptr));
    } // retranslateUi

};

namespace Ui {
    class ApptSummaryConfig_Base: public Ui_ApptSummaryConfig_Base {};
} // namespace Ui

QT_END_NAMESPACE

#endif // APPTSUMMARYCONFIG_BASE_H

