// This file was generated by ecm_qt_declare_logging_category(): DO NOT EDIT!

#include "korganizer_kontactplugins_specialdates_debug.h"


Q_LOGGING_CATEGORY(KORGANIZER_KONTACTPLUGINS_SPECIALDATES_LOG, "org.kde.pim.korganizer_kontactplugins_specialdates", QtInfoMsg)

