/****************************************************************************
** Meta object code from reading C++ file 'calendaradaptor.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.11.2)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "calendaradaptor.h"
#include <QtCore/qmetatype.h>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'calendaradaptor.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.11.2. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN19KOrgCalendarAdaptorE_t {};
} // unnamed namespace

template <> constexpr inline auto KOrgCalendarAdaptor::qt_create_metaobjectdata<qt_meta_tag_ZN19KOrgCalendarAdaptorE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "KOrgCalendarAdaptor",
        "D-Bus Interface",
        "org.kde.Korganizer.Calendar",
        "D-Bus Introspection",
        "  <interface name=\"org.kde.Korganizer.Calendar\">\n    <method na"
        "me=\"showJournalView\"/>\n    <method name=\"showTodoView\"/>\n   "
        " <method name=\"showEventView\"/>\n    <method name=\"goDate\">\n "
        "     <arg direction=\"in\" type=\"(iii)\" name=\"date\"/>\n      <"
        "annotation value=\"QDate\" name=\"org.qtproject.QtDBus.QtTypeName."
        "In0\"/>\n    </method>\n    <method name=\"goDate\">\n      <arg d"
        "irection=\"in\" type=\"s\" name=\"date\"/>\n    </method>\n    <me"
        "thod name=\"showDate\">\n      <arg direction=\"in\" type=\"(iii)\""
        " name=\"date\"/>\n      <annotation value=\"QDate\" name=\"org.qtp"
        "roject.QtDBus.QtTypeName.In0\"/>\n    </method>\n    <method name="
        "\"openEventEditor\"/>\n    <method name=\"openEventEditor\">\n    "
        "  <arg direction=\"in\" type=\"s\" name=\"text\"/>\n    </method>\n"
        "    <method name=\"openEventEditor\">\n      <arg direction=\"in\""
        " type=\"s\" name=\"summary\"/>\n      <arg direction=\"in\" type=\""
        "s\" name=\"description\"/>\n      <arg direction=\"in\" type=\"as\""
        " name=\"attachments\"/>\n    </method>\n    <method name=\"openEve"
        "ntEditor\">\n      <arg direction=\"in\" type=\"s\" name=\"summary"
        "\"/>\n      <arg direction=\"in\" type=\"s\" name=\"description\"/"
        ">\n      <arg direction=\"in\" type=\"s\" name=\"uri\"/>\n      <a"
        "rg direction=\"in\" type=\"s\" name=\"file\"/>\n      <arg directi"
        "on=\"in\" type=\"as\" name=\"attendees\"/>\n      <arg direction=\""
        "in\" type=\"s\" name=\"attachmentMimetype\"/>\n    </method>\n    "
        "<method name=\"openEventEditor\">\n      <arg direction=\"in\" typ"
        "e=\"s\" name=\"summary\"/>\n      <arg direction=\"in\" type=\"s\""
        " name=\"description\"/>\n      <arg direction=\"in\" type=\"as\" n"
        "ame=\"attachments\"/>\n      <arg direction=\"in\" type=\"as\" nam"
        "e=\"attendees\"/>\n    </method>\n    <method name=\"openEventEdit"
        "or\">\n      <arg direction=\"in\" type=\"s\" name=\"summary\"/>\n"
        "      <arg direction=\"in\" type=\"s\" name=\"description\"/>\n   "
        "   <arg direction=\"in\" type=\"as\" name=\"attachmentUris\"/>\n  "
        "    <arg direction=\"in\" type=\"as\" name=\"attendees\"/>\n      "
        "<arg direction=\"in\" type=\"as\" name=\"attachmentMimetypes\"/>\n"
        "      <arg direction=\"in\" type=\"b\" name=\"attachmentIsInline\""
        "/>\n    </method>\n    <method name=\"openTodoEditor\">\n      <ar"
        "g direction=\"in\" type=\"s\" name=\"text\"/>\n    </method>\n    "
        "<method name=\"openTodoEditor\">\n      <arg direction=\"in\" type"
        "=\"s\" name=\"summary\"/>\n      <arg direction=\"in\" type=\"s\" "
        "name=\"description\"/>\n      <arg direction=\"in\" type=\"as\" na"
        "me=\"attachments\"/>\n    </method>\n    <method name=\"openTodoEd"
        "itor\">\n      <arg direction=\"in\" type=\"s\" name=\"summary\"/>"
        "\n      <arg direction=\"in\" type=\"s\" name=\"description\"/>\n "
        "     <arg direction=\"in\" type=\"as\" name=\"attachments\"/>\n   "
        "   <arg direction=\"in\" type=\"as\" name=\"attendees\"/>\n    </m"
        "ethod>\n    <method name=\"openTodoEditor\">\n      <arg direction"
        "=\"in\" type=\"s\" name=\"summary\"/>\n      <arg direction=\"in\""
        " type=\"s\" name=\"description\"/>\n      <arg direction=\"in\" ty"
        "pe=\"s\" name=\"uri\"/>\n      <arg direction=\"in\" type=\"s\" na"
        "me=\"file\"/>\n      <arg direction=\"in\" type=\"as\" name=\"atte"
        "ndees\"/>\n      <arg direction=\"in\" type=\"s\" name=\"attachmen"
        "tMimetype\"/>\n    </method>\n    <method name=\"openTodoEditor\">"
        "\n      <arg direction=\"in\" type=\"s\" name=\"summary\"/>\n     "
        " <arg direction=\"in\" type=\"s\" name=\"description\"/>\n      <a"
        "rg direction=\"in\" type=\"as\" name=\"attachmentUris\"/>\n      <"
        "arg direction=\"in\" type=\"as\" name=\"attendees\"/>\n      <arg "
        "direction=\"in\" type=\"as\" name=\"attachmentMimetypes\"/>\n     "
        " <arg direction=\"in\" type=\"b\" name=\"attachmentIsInline\"/>\n "
        "   </method>\n    <method name=\"openJournalEditor\">\n      <arg "
        "direction=\"in\" type=\"(iii)\" name=\"date\"/>\n      <annotation"
        " value=\"QDate\" name=\"org.qtproject.QtDBus.QtTypeName.In0\"/>\n "
        "   </method>\n    <method name=\"openJournalEditor\">\n      <arg "
        "direction=\"in\" type=\"s\" name=\"text\"/>\n      <arg direction="
        "\"in\" type=\"(iii)\" name=\"date\"/>\n      <annotation value=\"Q"
        "Date\" name=\"org.qtproject.QtDBus.QtTypeName.In1\"/>\n    </metho"
        "d>\n    <method name=\"openJournalEditor\">\n      <arg direction="
        "\"in\" type=\"s\" name=\"text\"/>\n    </method>\n  </interface>\n",
        "goDate",
        "",
        "date",
        "openEventEditor",
        "summary",
        "description",
        "attachmentUris",
        "attendees",
        "attachmentMimetypes",
        "attachmentIsInline",
        "attachments",
        "uri",
        "file",
        "attachmentMimetype",
        "text",
        "openJournalEditor",
        "openTodoEditor",
        "showDate",
        "showEventView",
        "showJournalView",
        "showTodoView"
    };

    QtMocHelpers::UintData qt_methods {
        // Slot 'goDate'
        QtMocHelpers::SlotData<void(const QString &)>(5, 6, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 7 },
        }}),
        // Slot 'goDate'
        QtMocHelpers::SlotData<void(const QDate &)>(5, 6, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QDate, 7 },
        }}),
        // Slot 'openEventEditor'
        QtMocHelpers::SlotData<void(const QString &, const QString &, const QStringList &, const QStringList &, const QStringList &, bool)>(8, 6, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 9 }, { QMetaType::QString, 10 }, { QMetaType::QStringList, 11 }, { QMetaType::QStringList, 12 },
            { QMetaType::QStringList, 13 }, { QMetaType::Bool, 14 },
        }}),
        // Slot 'openEventEditor'
        QtMocHelpers::SlotData<void(const QString &, const QString &, const QStringList &, const QStringList &)>(8, 6, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 9 }, { QMetaType::QString, 10 }, { QMetaType::QStringList, 15 }, { QMetaType::QStringList, 12 },
        }}),
        // Slot 'openEventEditor'
        QtMocHelpers::SlotData<void(const QString &, const QString &, const QString &, const QString &, const QStringList &, const QString &)>(8, 6, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 9 }, { QMetaType::QString, 10 }, { QMetaType::QString, 16 }, { QMetaType::QString, 17 },
            { QMetaType::QStringList, 12 }, { QMetaType::QString, 18 },
        }}),
        // Slot 'openEventEditor'
        QtMocHelpers::SlotData<void(const QString &, const QString &, const QStringList &)>(8, 6, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 9 }, { QMetaType::QString, 10 }, { QMetaType::QStringList, 15 },
        }}),
        // Slot 'openEventEditor'
        QtMocHelpers::SlotData<void(const QString &)>(8, 6, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 19 },
        }}),
        // Slot 'openEventEditor'
        QtMocHelpers::SlotData<void()>(8, 6, QMC::AccessPublic, QMetaType::Void),
        // Slot 'openJournalEditor'
        QtMocHelpers::SlotData<void(const QString &)>(20, 6, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 19 },
        }}),
        // Slot 'openJournalEditor'
        QtMocHelpers::SlotData<void(const QString &, const QDate &)>(20, 6, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 19 }, { QMetaType::QDate, 7 },
        }}),
        // Slot 'openJournalEditor'
        QtMocHelpers::SlotData<void(const QDate &)>(20, 6, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QDate, 7 },
        }}),
        // Slot 'openTodoEditor'
        QtMocHelpers::SlotData<void(const QString &, const QString &, const QStringList &, const QStringList &, const QStringList &, bool)>(21, 6, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 9 }, { QMetaType::QString, 10 }, { QMetaType::QStringList, 11 }, { QMetaType::QStringList, 12 },
            { QMetaType::QStringList, 13 }, { QMetaType::Bool, 14 },
        }}),
        // Slot 'openTodoEditor'
        QtMocHelpers::SlotData<void(const QString &, const QString &, const QString &, const QString &, const QStringList &, const QString &)>(21, 6, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 9 }, { QMetaType::QString, 10 }, { QMetaType::QString, 16 }, { QMetaType::QString, 17 },
            { QMetaType::QStringList, 12 }, { QMetaType::QString, 18 },
        }}),
        // Slot 'openTodoEditor'
        QtMocHelpers::SlotData<void(const QString &, const QString &, const QStringList &, const QStringList &)>(21, 6, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 9 }, { QMetaType::QString, 10 }, { QMetaType::QStringList, 15 }, { QMetaType::QStringList, 12 },
        }}),
        // Slot 'openTodoEditor'
        QtMocHelpers::SlotData<void(const QString &, const QString &, const QStringList &)>(21, 6, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 9 }, { QMetaType::QString, 10 }, { QMetaType::QStringList, 15 },
        }}),
        // Slot 'openTodoEditor'
        QtMocHelpers::SlotData<void(const QString &)>(21, 6, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 19 },
        }}),
        // Slot 'showDate'
        QtMocHelpers::SlotData<void(const QDate &)>(22, 6, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QDate, 7 },
        }}),
        // Slot 'showEventView'
        QtMocHelpers::SlotData<void()>(23, 6, QMC::AccessPublic, QMetaType::Void),
        // Slot 'showJournalView'
        QtMocHelpers::SlotData<void()>(24, 6, QMC::AccessPublic, QMetaType::Void),
        // Slot 'showTodoView'
        QtMocHelpers::SlotData<void()>(25, 6, QMC::AccessPublic, QMetaType::Void),
    };
    QtMocHelpers::UintData qt_properties {
    };
    QtMocHelpers::UintData qt_enums {
    };
    QtMocHelpers::UintData qt_constructors {};
    QtMocHelpers::ClassInfos qt_classinfo({
            {    1,    2 },
            {    3,    4 },
    });
    return QtMocHelpers::metaObjectData<KOrgCalendarAdaptor, qt_meta_tag_ZN19KOrgCalendarAdaptorE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums, qt_constructors, qt_classinfo);
}
Q_CONSTINIT const QMetaObject KOrgCalendarAdaptor::staticMetaObject = { {
    QMetaObject::SuperData::link<QDBusAbstractAdaptor::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN19KOrgCalendarAdaptorE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN19KOrgCalendarAdaptorE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN19KOrgCalendarAdaptorE_t>.metaTypes,
    nullptr
} };

void KOrgCalendarAdaptor::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<KOrgCalendarAdaptor *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->goDate((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 1: _t->goDate((*reinterpret_cast<std::add_pointer_t<QDate>>(_a[1]))); break;
        case 2: _t->openEventEditor((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<QStringList>>(_a[3])),(*reinterpret_cast<std::add_pointer_t<QStringList>>(_a[4])),(*reinterpret_cast<std::add_pointer_t<QStringList>>(_a[5])),(*reinterpret_cast<std::add_pointer_t<bool>>(_a[6]))); break;
        case 3: _t->openEventEditor((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<QStringList>>(_a[3])),(*reinterpret_cast<std::add_pointer_t<QStringList>>(_a[4]))); break;
        case 4: _t->openEventEditor((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[3])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[4])),(*reinterpret_cast<std::add_pointer_t<QStringList>>(_a[5])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[6]))); break;
        case 5: _t->openEventEditor((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<QStringList>>(_a[3]))); break;
        case 6: _t->openEventEditor((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 7: _t->openEventEditor(); break;
        case 8: _t->openJournalEditor((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 9: _t->openJournalEditor((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QDate>>(_a[2]))); break;
        case 10: _t->openJournalEditor((*reinterpret_cast<std::add_pointer_t<QDate>>(_a[1]))); break;
        case 11: _t->openTodoEditor((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<QStringList>>(_a[3])),(*reinterpret_cast<std::add_pointer_t<QStringList>>(_a[4])),(*reinterpret_cast<std::add_pointer_t<QStringList>>(_a[5])),(*reinterpret_cast<std::add_pointer_t<bool>>(_a[6]))); break;
        case 12: _t->openTodoEditor((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[3])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[4])),(*reinterpret_cast<std::add_pointer_t<QStringList>>(_a[5])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[6]))); break;
        case 13: _t->openTodoEditor((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<QStringList>>(_a[3])),(*reinterpret_cast<std::add_pointer_t<QStringList>>(_a[4]))); break;
        case 14: _t->openTodoEditor((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<QStringList>>(_a[3]))); break;
        case 15: _t->openTodoEditor((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 16: _t->showDate((*reinterpret_cast<std::add_pointer_t<QDate>>(_a[1]))); break;
        case 17: _t->showEventView(); break;
        case 18: _t->showJournalView(); break;
        case 19: _t->showTodoView(); break;
        default: ;
        }
    }
}

const QMetaObject *KOrgCalendarAdaptor::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *KOrgCalendarAdaptor::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN19KOrgCalendarAdaptorE_t>.strings))
        return static_cast<void*>(this);
    return QDBusAbstractAdaptor::qt_metacast(_clname);
}

int KOrgCalendarAdaptor::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QDBusAbstractAdaptor::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 20)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 20;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 20)
            *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType();
        _id -= 20;
    }
    return _id;
}
QT_WARNING_POP
