/****************************************************************************
** Meta object code from reading C++ file 'koagendaview.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.11.2)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../../korganizer-26.08.0/src/views/agendaview/koagendaview.h"
#include <QtCore/qmetatype.h>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'koagendaview.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.11.2. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN12KOAgendaViewE_t {};
} // unnamed namespace

template <> constexpr inline auto KOAgendaView::qt_create_metaobjectdata<qt_meta_tag_ZN12KOAgendaViewE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "KOAgendaView",
        "zoomViewHorizontally",
        "",
        "timeSpanSelectionChanged",
        "updateView",
        "updateConfig",
        "showIncidences",
        "Akonadi::Item::List",
        "incidences",
        "date",
        "changeIncidenceDisplay",
        "Akonadi::Item",
        "incidence",
        "Akonadi::IncidenceChanger::ChangeType",
        "clearSelection",
        "readSettings",
        "KConfig*",
        "writeSettings",
        "enableAgendaUpdate",
        "enable",
        "setIncidenceChanger",
        "Akonadi::IncidenceChanger*",
        "changer",
        "zoomInHorizontally",
        "zoomOutHorizontally",
        "zoomInVertically",
        "zoomOutVertically",
        "zoomView",
        "delta",
        "QPoint",
        "pos",
        "Qt::Orientation",
        "orient",
        "calendarAdded",
        "Akonadi::CollectionCalendar::Ptr",
        "calendar",
        "calendarRemoved"
    };

    QtMocHelpers::UintData qt_methods {
        // Signal 'zoomViewHorizontally'
        QtMocHelpers::SignalData<void(const QDate &, int)>(1, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QDate, 2 }, { QMetaType::Int, 2 },
        }}),
        // Signal 'timeSpanSelectionChanged'
        QtMocHelpers::SignalData<void()>(3, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'updateView'
        QtMocHelpers::SlotData<void()>(4, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'updateConfig'
        QtMocHelpers::SlotData<void()>(5, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'showIncidences'
        QtMocHelpers::SlotData<void(const Akonadi::Item::List &, const QDate &)>(6, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 7, 8 }, { QMetaType::QDate, 9 },
        }}),
        // Slot 'changeIncidenceDisplay'
        QtMocHelpers::SlotData<void(const Akonadi::Item &, Akonadi::IncidenceChanger::ChangeType)>(10, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 11, 12 }, { 0x80000000 | 13, 2 },
        }}),
        // Slot 'clearSelection'
        QtMocHelpers::SlotData<void()>(14, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'readSettings'
        QtMocHelpers::SlotData<void()>(15, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'readSettings'
        QtMocHelpers::SlotData<void(KConfig *)>(15, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 16, 2 },
        }}),
        // Slot 'writeSettings'
        QtMocHelpers::SlotData<void(KConfig *)>(17, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 16, 2 },
        }}),
        // Slot 'enableAgendaUpdate'
        QtMocHelpers::SlotData<void(bool)>(18, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Bool, 19 },
        }}),
        // Slot 'setIncidenceChanger'
        QtMocHelpers::SlotData<void(Akonadi::IncidenceChanger *)>(20, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 21, 22 },
        }}),
        // Slot 'zoomInHorizontally'
        QtMocHelpers::SlotData<void(QDate)>(23, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QDate, 9 },
        }}),
        // Slot 'zoomInHorizontally'
        QtMocHelpers::SlotData<void()>(23, 2, QMC::AccessPublic | QMC::MethodCloned, QMetaType::Void),
        // Slot 'zoomOutHorizontally'
        QtMocHelpers::SlotData<void(QDate)>(24, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QDate, 9 },
        }}),
        // Slot 'zoomOutHorizontally'
        QtMocHelpers::SlotData<void()>(24, 2, QMC::AccessPublic | QMC::MethodCloned, QMetaType::Void),
        // Slot 'zoomInVertically'
        QtMocHelpers::SlotData<void()>(25, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'zoomOutVertically'
        QtMocHelpers::SlotData<void()>(26, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'zoomView'
        QtMocHelpers::SlotData<void(const int, const QPoint &, const Qt::Orientation)>(27, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Int, 28 }, { 0x80000000 | 29, 30 }, { 0x80000000 | 31, 32 },
        }}),
        // Slot 'zoomView'
        QtMocHelpers::SlotData<void(const int, const QPoint &)>(27, 2, QMC::AccessPublic | QMC::MethodCloned, QMetaType::Void, {{
            { QMetaType::Int, 28 }, { 0x80000000 | 29, 30 },
        }}),
        // Slot 'calendarAdded'
        QtMocHelpers::SlotData<void(const Akonadi::CollectionCalendar::Ptr &)>(33, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 34, 35 },
        }}),
        // Slot 'calendarRemoved'
        QtMocHelpers::SlotData<void(const Akonadi::CollectionCalendar::Ptr &)>(36, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 34, 35 },
        }}),
    };
    QtMocHelpers::UintData qt_properties {
    };
    QtMocHelpers::UintData qt_enums {
    };
    return QtMocHelpers::metaObjectData<KOAgendaView, qt_meta_tag_ZN12KOAgendaViewE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject KOAgendaView::staticMetaObject = { {
    QMetaObject::SuperData::link<KOEventView::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN12KOAgendaViewE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN12KOAgendaViewE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN12KOAgendaViewE_t>.metaTypes,
    nullptr
} };

void KOAgendaView::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<KOAgendaView *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->zoomViewHorizontally((*reinterpret_cast<std::add_pointer_t<QDate>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[2]))); break;
        case 1: _t->timeSpanSelectionChanged(); break;
        case 2: _t->updateView(); break;
        case 3: _t->updateConfig(); break;
        case 4: _t->showIncidences((*reinterpret_cast<std::add_pointer_t<Akonadi::Item::List>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QDate>>(_a[2]))); break;
        case 5: _t->changeIncidenceDisplay((*reinterpret_cast<std::add_pointer_t<Akonadi::Item>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<Akonadi::IncidenceChanger::ChangeType>>(_a[2]))); break;
        case 6: _t->clearSelection(); break;
        case 7: _t->readSettings(); break;
        case 8: _t->readSettings((*reinterpret_cast<std::add_pointer_t<KConfig*>>(_a[1]))); break;
        case 9: _t->writeSettings((*reinterpret_cast<std::add_pointer_t<KConfig*>>(_a[1]))); break;
        case 10: _t->enableAgendaUpdate((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 11: _t->setIncidenceChanger((*reinterpret_cast<std::add_pointer_t<Akonadi::IncidenceChanger*>>(_a[1]))); break;
        case 12: _t->zoomInHorizontally((*reinterpret_cast<std::add_pointer_t<QDate>>(_a[1]))); break;
        case 13: _t->zoomInHorizontally(); break;
        case 14: _t->zoomOutHorizontally((*reinterpret_cast<std::add_pointer_t<QDate>>(_a[1]))); break;
        case 15: _t->zoomOutHorizontally(); break;
        case 16: _t->zoomInVertically(); break;
        case 17: _t->zoomOutVertically(); break;
        case 18: _t->zoomView((*reinterpret_cast<std::add_pointer_t<int>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QPoint>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<Qt::Orientation>>(_a[3]))); break;
        case 19: _t->zoomView((*reinterpret_cast<std::add_pointer_t<int>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QPoint>>(_a[2]))); break;
        case 20: _t->calendarAdded((*reinterpret_cast<std::add_pointer_t<Akonadi::CollectionCalendar::Ptr>>(_a[1]))); break;
        case 21: _t->calendarRemoved((*reinterpret_cast<std::add_pointer_t<Akonadi::CollectionCalendar::Ptr>>(_a[1]))); break;
        default: ;
        }
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        switch (_id) {
        default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
        case 4:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< Akonadi::Item::List >(); break;
            }
            break;
        case 5:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 1:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< Akonadi::IncidenceChanger::ChangeType >(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< Akonadi::Item >(); break;
            }
            break;
        case 11:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< Akonadi::IncidenceChanger* >(); break;
            }
            break;
        }
    }
    if (_c == QMetaObject::IndexOfMethod) {
        if (QtMocHelpers::indexOfMethod<void (KOAgendaView::*)(const QDate & , int )>(_a, &KOAgendaView::zoomViewHorizontally, 0))
            return;
        if (QtMocHelpers::indexOfMethod<void (KOAgendaView::*)()>(_a, &KOAgendaView::timeSpanSelectionChanged, 1))
            return;
    }
}

const QMetaObject *KOAgendaView::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *KOAgendaView::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN12KOAgendaViewE_t>.strings))
        return static_cast<void*>(this);
    return KOEventView::qt_metacast(_clname);
}

int KOAgendaView::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = KOEventView::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 22)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 22;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 22)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 22;
    }
    return _id;
}

// SIGNAL 0
void KOAgendaView::zoomViewHorizontally(const QDate & _t1, int _t2)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 0, nullptr, _t1, _t2);
}

// SIGNAL 1
void KOAgendaView::timeSpanSelectionChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 1, nullptr);
}
QT_WARNING_POP
