/********************************************************************************
** Form generated from reading UI file 'kogroupwareprefspage.ui'
**
** Created by: Qt User Interface Compiler version 6.11.2
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef UI_KOGROUPWAREPREFSPAGE_H
#define UI_KOGROUPWAREPREFSPAGE_H

#include <QtCore/QVariant>
#include <QtWidgets/QApplication>
#include <QtWidgets/QCheckBox>
#include <QtWidgets/QFrame>
#include <QtWidgets/QGridLayout>
#include <QtWidgets/QGroupBox>
#include <QtWidgets/QHBoxLayout>
#include <QtWidgets/QLabel>
#include <QtWidgets/QLineEdit>
#include <QtWidgets/QSpacerItem>
#include <QtWidgets/QSpinBox>
#include <QtWidgets/QTabWidget>
#include <QtWidgets/QVBoxLayout>
#include <QtWidgets/QWidget>
#include <klocalizedstring.h>

QT_BEGIN_NAMESPACE

class Ui_KOGroupwarePrefsPage
{
public:
    QVBoxLayout *vboxLayout;
    QTabWidget *groupwareTab;
    QWidget *tabPublish;
    QVBoxLayout *vboxLayout1;
    QLabel *TextLabel1;
    QCheckBox *publishEnable;
    QHBoxLayout *hboxLayout;
    QLabel *publishDelayLabel;
    QSpinBox *publishDelay;
    QHBoxLayout *hboxLayout1;
    QLabel *TextLabel3;
    QSpinBox *publishDays;
    QLabel *TextLabel4;
    QSpacerItem *spacerItem;
    QGroupBox *ButtonGroup2;
    QGridLayout *gridLayout;
    QFrame *frame5;
    QLineEdit *publishUrl;
    QLineEdit *publishPassword;
    QLabel *textLabel2;
    QLabel *TextLabel6;
    QLineEdit *publishUser;
    QCheckBox *publishSavePassword;
    QLabel *TextLabel7;
    QLabel *label;
    QSpacerItem *spacerItem1;
    QWidget *tabRetrieve;
    QVBoxLayout *vboxLayout2;
    QLabel *TextLabel2;
    QCheckBox *retrieveEnable;
    QCheckBox *fullDomainRetrieval;
    QGroupBox *ButtonGroup2_2;
    QGridLayout *gridLayout1;
    QLineEdit *retrievePassword;
    QLineEdit *retrieveUser;
    QLineEdit *retrieveUrl;
    QLabel *TextLabel7_2;
    QLabel *textLabel3;
    QLabel *textLabel4;
    QFrame *frame7;
    QCheckBox *retrieveSavePassword;
    QSpacerItem *spacerItem2;

    void setupUi(QWidget *KOGroupwarePrefsPage)
    {
        if (KOGroupwarePrefsPage->objectName().isEmpty())
            KOGroupwarePrefsPage->setObjectName("KOGroupwarePrefsPage");
        KOGroupwarePrefsPage->resize(511, 524);
        vboxLayout = new QVBoxLayout(KOGroupwarePrefsPage);
        vboxLayout->setObjectName("vboxLayout");
        vboxLayout->setContentsMargins(0, 0, 0, 0);
        groupwareTab = new QTabWidget(KOGroupwarePrefsPage);
        groupwareTab->setObjectName("groupwareTab");
        groupwareTab->setEnabled(true);
        groupwareTab->setDocumentMode(true);
        tabPublish = new QWidget();
        tabPublish->setObjectName("tabPublish");
        vboxLayout1 = new QVBoxLayout(tabPublish);
        vboxLayout1->setSpacing(6);
        vboxLayout1->setObjectName("vboxLayout1");
        vboxLayout1->setContentsMargins(9, 9, 9, 9);
        TextLabel1 = new QLabel(tabPublish);
        TextLabel1->setObjectName("TextLabel1");
        TextLabel1->setWordWrap(true);

        vboxLayout1->addWidget(TextLabel1);

        publishEnable = new QCheckBox(tabPublish);
        publishEnable->setObjectName("publishEnable");

        vboxLayout1->addWidget(publishEnable);

        hboxLayout = new QHBoxLayout();
        hboxLayout->setSpacing(6);
        hboxLayout->setObjectName("hboxLayout");
        hboxLayout->setContentsMargins(0, 0, 0, 0);
        publishDelayLabel = new QLabel(tabPublish);
        publishDelayLabel->setObjectName("publishDelayLabel");

        hboxLayout->addWidget(publishDelayLabel);

        publishDelay = new QSpinBox(tabPublish);
        publishDelay->setObjectName("publishDelay");
        publishDelay->setMinimum(1);

        hboxLayout->addWidget(publishDelay);


        vboxLayout1->addLayout(hboxLayout);

        hboxLayout1 = new QHBoxLayout();
        hboxLayout1->setSpacing(6);
        hboxLayout1->setObjectName("hboxLayout1");
        hboxLayout1->setContentsMargins(0, 0, 0, 0);
        TextLabel3 = new QLabel(tabPublish);
        TextLabel3->setObjectName("TextLabel3");

        hboxLayout1->addWidget(TextLabel3);

        publishDays = new QSpinBox(tabPublish);
        publishDays->setObjectName("publishDays");
        publishDays->setMinimum(1);
        publishDays->setMaximum(366);
        publishDays->setValue(60);

        hboxLayout1->addWidget(publishDays);

        TextLabel4 = new QLabel(tabPublish);
        TextLabel4->setObjectName("TextLabel4");

        hboxLayout1->addWidget(TextLabel4);

        spacerItem = new QSpacerItem(20, 20, QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Minimum);

        hboxLayout1->addItem(spacerItem);


        vboxLayout1->addLayout(hboxLayout1);

        ButtonGroup2 = new QGroupBox(tabPublish);
        ButtonGroup2->setObjectName("ButtonGroup2");
        gridLayout = new QGridLayout(ButtonGroup2);
        gridLayout->setSpacing(6);
        gridLayout->setObjectName("gridLayout");
        gridLayout->setContentsMargins(9, 9, 9, 9);
        frame5 = new QFrame(ButtonGroup2);
        frame5->setObjectName("frame5");

        gridLayout->addWidget(frame5, 2, 0, 1, 2);

        publishUrl = new QLineEdit(ButtonGroup2);
        publishUrl->setObjectName("publishUrl");
        publishUrl->setEnabled(true);

        gridLayout->addWidget(publishUrl, 1, 1, 1, 1);

        publishPassword = new QLineEdit(ButtonGroup2);
        publishPassword->setObjectName("publishPassword");
        publishPassword->setEchoMode(QLineEdit::Password);

        gridLayout->addWidget(publishPassword, 4, 1, 1, 1);

        textLabel2 = new QLabel(ButtonGroup2);
        textLabel2->setObjectName("textLabel2");

        gridLayout->addWidget(textLabel2, 4, 0, 1, 1);

        TextLabel6 = new QLabel(ButtonGroup2);
        TextLabel6->setObjectName("TextLabel6");

        gridLayout->addWidget(TextLabel6, 3, 0, 1, 1);

        publishUser = new QLineEdit(ButtonGroup2);
        publishUser->setObjectName("publishUser");
        publishUser->setMinimumSize(QSize(120, 0));

        gridLayout->addWidget(publishUser, 3, 1, 1, 1);

        publishSavePassword = new QCheckBox(ButtonGroup2);
        publishSavePassword->setObjectName("publishSavePassword");

        gridLayout->addWidget(publishSavePassword, 5, 0, 1, 2);

        TextLabel7 = new QLabel(ButtonGroup2);
        TextLabel7->setObjectName("TextLabel7");

        gridLayout->addWidget(TextLabel7, 1, 0, 1, 1);

        label = new QLabel(ButtonGroup2);
        label->setObjectName("label");

        gridLayout->addWidget(label, 0, 0, 1, 2);


        vboxLayout1->addWidget(ButtonGroup2);

        spacerItem1 = new QSpacerItem(21, 50, QSizePolicy::Policy::Minimum, QSizePolicy::Policy::Expanding);

        vboxLayout1->addItem(spacerItem1);

        groupwareTab->addTab(tabPublish, QString());
        tabRetrieve = new QWidget();
        tabRetrieve->setObjectName("tabRetrieve");
        vboxLayout2 = new QVBoxLayout(tabRetrieve);
        vboxLayout2->setSpacing(6);
        vboxLayout2->setObjectName("vboxLayout2");
        vboxLayout2->setContentsMargins(9, 9, 9, 9);
        TextLabel2 = new QLabel(tabRetrieve);
        TextLabel2->setObjectName("TextLabel2");
        TextLabel2->setWordWrap(true);

        vboxLayout2->addWidget(TextLabel2);

        retrieveEnable = new QCheckBox(tabRetrieve);
        retrieveEnable->setObjectName("retrieveEnable");

        vboxLayout2->addWidget(retrieveEnable);

        fullDomainRetrieval = new QCheckBox(tabRetrieve);
        fullDomainRetrieval->setObjectName("fullDomainRetrieval");
        fullDomainRetrieval->setEnabled(true);

        vboxLayout2->addWidget(fullDomainRetrieval);

        ButtonGroup2_2 = new QGroupBox(tabRetrieve);
        ButtonGroup2_2->setObjectName("ButtonGroup2_2");
        gridLayout1 = new QGridLayout(ButtonGroup2_2);
        gridLayout1->setSpacing(6);
        gridLayout1->setObjectName("gridLayout1");
        gridLayout1->setContentsMargins(9, 9, 9, 9);
        retrievePassword = new QLineEdit(ButtonGroup2_2);
        retrievePassword->setObjectName("retrievePassword");
        retrievePassword->setEchoMode(QLineEdit::Password);

        gridLayout1->addWidget(retrievePassword, 3, 1, 1, 1);

        retrieveUser = new QLineEdit(ButtonGroup2_2);
        retrieveUser->setObjectName("retrieveUser");

        gridLayout1->addWidget(retrieveUser, 2, 1, 1, 1);

        retrieveUrl = new QLineEdit(ButtonGroup2_2);
        retrieveUrl->setObjectName("retrieveUrl");
        retrieveUrl->setEnabled(true);

        gridLayout1->addWidget(retrieveUrl, 0, 1, 1, 1);

        TextLabel7_2 = new QLabel(ButtonGroup2_2);
        TextLabel7_2->setObjectName("TextLabel7_2");

        gridLayout1->addWidget(TextLabel7_2, 0, 0, 1, 1);

        textLabel3 = new QLabel(ButtonGroup2_2);
        textLabel3->setObjectName("textLabel3");

        gridLayout1->addWidget(textLabel3, 2, 0, 1, 1);

        textLabel4 = new QLabel(ButtonGroup2_2);
        textLabel4->setObjectName("textLabel4");

        gridLayout1->addWidget(textLabel4, 3, 0, 1, 1);

        frame7 = new QFrame(ButtonGroup2_2);
        frame7->setObjectName("frame7");

        gridLayout1->addWidget(frame7, 1, 0, 1, 2);

        retrieveSavePassword = new QCheckBox(ButtonGroup2_2);
        retrieveSavePassword->setObjectName("retrieveSavePassword");
        retrieveSavePassword->setEnabled(true);

        gridLayout1->addWidget(retrieveSavePassword, 4, 0, 1, 2);


        vboxLayout2->addWidget(ButtonGroup2_2);

        spacerItem2 = new QSpacerItem(20, 160, QSizePolicy::Policy::Minimum, QSizePolicy::Policy::Expanding);

        vboxLayout2->addItem(spacerItem2);

        groupwareTab->addTab(tabRetrieve, QString());

        vboxLayout->addWidget(groupwareTab);

#if QT_CONFIG(shortcut)
        publishDelayLabel->setBuddy(publishDelay);
        TextLabel3->setBuddy(publishDays);
        textLabel2->setBuddy(publishPassword);
        TextLabel6->setBuddy(publishUser);
        TextLabel7->setBuddy(publishUrl);
        TextLabel7_2->setBuddy(retrieveUrl);
        textLabel3->setBuddy(retrieveUser);
        textLabel4->setBuddy(retrievePassword);
#endif // QT_CONFIG(shortcut)
        QWidget::setTabOrder(groupwareTab, publishEnable);
        QWidget::setTabOrder(publishEnable, publishDelay);
        QWidget::setTabOrder(publishDelay, publishDays);
        QWidget::setTabOrder(publishDays, publishUrl);
        QWidget::setTabOrder(publishUrl, publishUser);
        QWidget::setTabOrder(publishUser, publishPassword);
        QWidget::setTabOrder(publishPassword, publishSavePassword);
        QWidget::setTabOrder(publishSavePassword, retrieveEnable);
        QWidget::setTabOrder(retrieveEnable, fullDomainRetrieval);
        QWidget::setTabOrder(fullDomainRetrieval, retrieveUrl);
        QWidget::setTabOrder(retrieveUrl, retrieveUser);
        QWidget::setTabOrder(retrieveUser, retrievePassword);
        QWidget::setTabOrder(retrievePassword, retrieveSavePassword);

        retranslateUi(KOGroupwarePrefsPage);

        groupwareTab->setCurrentIndex(0);


        QMetaObject::connectSlotsByName(KOGroupwarePrefsPage);
    } // setupUi

    void retranslateUi(QWidget *KOGroupwarePrefsPage)
    {
        TextLabel1->setText(tr2i18n("By publishing Free/Busy information, you allow others to take your calendar into account when inviting you for a meeting. Only the times you have already busy are published, not why they are busy.", nullptr));
#if QT_CONFIG(whatsthis)
        publishEnable->setWhatsThis(tr2i18n("Check this box to upload your Free/Busy information automatically.\n"
"It is possible to skip this option and mail or upload your Free/Busy information using the Schedule menu of KOrganizer.\n"
"Note: If KOrganizer is acting as a KDE Kolab client, this is not required, as the Kolab2 server taking care of publishing your Free/Busy information and manages the access to it from other users.", nullptr));
#endif // QT_CONFIG(whatsthis)
        publishEnable->setText(tr2i18n("Publish your free/&busy information automatically", nullptr));
#if QT_CONFIG(whatsthis)
        publishDelayLabel->setWhatsThis(tr2i18n("Configure minimum the interval of time in minutes between each upload here. This configuration is only effective in case you choose to publish your information automatically.", nullptr));
#endif // QT_CONFIG(whatsthis)
        publishDelayLabel->setText(tr2i18n("Minimum time between uploads (in minutes):", nullptr));
#if QT_CONFIG(whatsthis)
        publishDelay->setWhatsThis(tr2i18n("Configure minimum the interval of time in minutes between each upload here. This configuration is only effective in case you choose to publish your information automatically.", nullptr));
#endif // QT_CONFIG(whatsthis)
#if QT_CONFIG(whatsthis)
        TextLabel3->setWhatsThis(tr2i18n("Configure the number of calendar days you wish to be published and available to others here.", nullptr));
#endif // QT_CONFIG(whatsthis)
        TextLabel3->setText(tr2i18n("Publish", nullptr));
#if QT_CONFIG(whatsthis)
        publishDays->setWhatsThis(tr2i18n("Configure the number of calendar days you wish to be published and available to others here.", nullptr));
#endif // QT_CONFIG(whatsthis)
#if QT_CONFIG(whatsthis)
        TextLabel4->setWhatsThis(tr2i18n("Configure the number of calendar days you wish to be published and available to others here.", nullptr));
#endif // QT_CONFIG(whatsthis)
        TextLabel4->setText(tr2i18n("days of free/busy information", nullptr));
        ButtonGroup2->setTitle(tr2i18n("Server Information", nullptr));
#if QT_CONFIG(whatsthis)
        publishUrl->setWhatsThis(tr2i18n("Enter the URL for the server on which your Free/Busy information shall be published here.\n"
"Ask the server administrator for this information.", nullptr));
#endif // QT_CONFIG(whatsthis)
#if QT_CONFIG(whatsthis)
        publishPassword->setWhatsThis(tr2i18n("Enter your groupware server login password here.", nullptr));
#endif // QT_CONFIG(whatsthis)
#if QT_CONFIG(whatsthis)
        textLabel2->setWhatsThis(tr2i18n("Enter your groupware server login password here.", nullptr));
#endif // QT_CONFIG(whatsthis)
        textLabel2->setText(tr2i18n("Password:", nullptr));
#if QT_CONFIG(whatsthis)
        TextLabel6->setWhatsThis(tr2i18n("Enter the login information relative to your account on the server here.\n"
"\n"
"A Kolab2 server specificity: Registered your UID (Unique IDentifier). By default your UID would be your email address on the Kolab2 server but it may also be different. In the last case enter your UID.", nullptr));
#endif // QT_CONFIG(whatsthis)
        TextLabel6->setText(tr2i18n("Username:", "login name on the Kolab server"));
#if QT_CONFIG(whatsthis)
        publishUser->setWhatsThis(tr2i18n("Enter the login information relative to your account on the server here.\n"
"\n"
"A Kolab2 server specificity: Registered your UID (Unique IDentifier). By default your UID would be your email address on the Kolab2 server but it may also be different. In the last case enter your UID.", nullptr));
#endif // QT_CONFIG(whatsthis)
#if QT_CONFIG(whatsthis)
        publishSavePassword->setWhatsThis(tr2i18n("Check this box to make KOrganizer remember your password and skip asking you each time it uploads your Free/Busy information, by storing it in the configuration file.\n"
"For security reasons, it is not recommended to store your password in the configuration file.", nullptr));
#endif // QT_CONFIG(whatsthis)
        publishSavePassword->setText(tr2i18n("Remember p&assword", nullptr));
#if QT_CONFIG(whatsthis)
        TextLabel7->setWhatsThis(tr2i18n("Enter the URL for the server on which your Free/Busy information shall be published here.\n"
"Ask the server administrator for this information.", nullptr));
#endif // QT_CONFIG(whatsthis)
        TextLabel7->setText(tr2i18n("Server URL:", nullptr));
        label->setText(tr2i18n("(No need if using Kolab server version 2)", nullptr));
        groupwareTab->setTabText(groupwareTab->indexOf(tabPublish), tr2i18n("P&ublish", nullptr));
        TextLabel2->setText(tr2i18n("By retrieving Free/Busy information that others have published, you can take their calendar into account when inviting them to a meeting.", nullptr));
#if QT_CONFIG(whatsthis)
        retrieveEnable->setWhatsThis(tr2i18n("Check this box to retrieve other people's Free/Busy information automatically. Note that you have to fill the correct server information to make this possible.", nullptr));
#endif // QT_CONFIG(whatsthis)
        retrieveEnable->setText(tr2i18n("Retrieve other people's free/&busy information automatically", nullptr));
#if QT_CONFIG(tooltip)
        fullDomainRetrieval->setToolTip(tr2i18n("Set this to retrieve user@domain.ifb instead of user.ifb from the server", nullptr));
#endif // QT_CONFIG(tooltip)
#if QT_CONFIG(whatsthis)
        fullDomainRetrieval->setWhatsThis(tr2i18n("Check this box to download a free/busy file in the format \"user@domain.ifb\" (for example joe@company.com.ifb). Otherwise, it will download a free/busy file in the format user.ifb (for example joe.ifb). Ask the server Administrator if you are not sure about how to configure this option.", nullptr));
#endif // QT_CONFIG(whatsthis)
        fullDomainRetrieval->setText(tr2i18n("Use full email &address for retrieval", nullptr));
        ButtonGroup2_2->setTitle(tr2i18n("Server Information", nullptr));
#if QT_CONFIG(whatsthis)
        retrievePassword->setWhatsThis(tr2i18n("Enter your groupware server login password here.", nullptr));
#endif // QT_CONFIG(whatsthis)
#if QT_CONFIG(whatsthis)
        retrieveUser->setWhatsThis(tr2i18n("Enter the login information relative to your account on the server here.\n"
"\n"
"A Kolab2 server specificity: Registered your UID (Unique IDentifier). By default your UID would be your email address on the Kolab2 server but it may also be different. In the last case enter your UID.", nullptr));
#endif // QT_CONFIG(whatsthis)
#if QT_CONFIG(whatsthis)
        retrieveUrl->setWhatsThis(tr2i18n("Enter the URL for the server on which the Free/Busy information is published here.\n"
"Ask the server administrator for this information.\n"
"Here is a Kolab2 Server URL example:\n"
"\n"
"https://kolab2.example.com/freebusy/\n"
"\n"
"Alternatively, you can specify a full path to the Free/Busy. For example:\n"
"\n"
"https://kolab2.example.com/freebusy/user.xfb", "@info:whatsthis"));
#endif // QT_CONFIG(whatsthis)
#if QT_CONFIG(whatsthis)
        TextLabel7_2->setWhatsThis(tr2i18n("Enter the URL for the server on which the Free/Busy information is published here.\n"
"Ask the server administrator for this information.\n"
"Here is a Kolab2 Server URL example:\n"
"\n"
"https://kolab2.example.com/freebusy/\n"
"\n"
"Alternatively, you can specify a full path to the Free/Busy. For example:\n"
"\n"
"https://kolab2.example.com/freebusy/user.xfb", "@info:whatsthis"));
#endif // QT_CONFIG(whatsthis)
        TextLabel7_2->setText(tr2i18n("Server URL:", nullptr));
#if QT_CONFIG(whatsthis)
        textLabel3->setWhatsThis(tr2i18n("Enter the login information relative to your account on the server here.\n"
"\n"
"A Kolab2 server specificity: Registered your UID (Unique IDentifier). By default your UID would be your email address on the Kolab2 server but it may also be different. In the last case enter your UID.", nullptr));
#endif // QT_CONFIG(whatsthis)
        textLabel3->setText(tr2i18n("User&name:", nullptr));
#if QT_CONFIG(whatsthis)
        textLabel4->setWhatsThis(tr2i18n("Enter your groupware server login password here.", nullptr));
#endif // QT_CONFIG(whatsthis)
        textLabel4->setText(tr2i18n("Passwor&d:", nullptr));
#if QT_CONFIG(whatsthis)
        retrieveSavePassword->setWhatsThis(tr2i18n("Check this box to make KOrganizer remember your password and skip asking you each time it uploads your Free/Busy information, by storing it in the configuration file.\n"
"For security reasons, it is not recommended to store your password in the configuration file.", nullptr));
#endif // QT_CONFIG(whatsthis)
        retrieveSavePassword->setText(tr2i18n("Re&member password", nullptr));
        groupwareTab->setTabText(groupwareTab->indexOf(tabRetrieve), tr2i18n("&Retrieve", nullptr));
        (void)KOGroupwarePrefsPage;
    } // retranslateUi

};

namespace Ui {
    class KOGroupwarePrefsPage: public Ui_KOGroupwarePrefsPage {};
} // namespace Ui

QT_END_NAMESPACE

#endif // KOGROUPWAREPREFSPAGE_H

