/*
Configuration page for the Korganizer Special Dates Summary
*/

/********************************************************************************
** Form generated from reading UI file 'sdsummaryconfig_base.ui'
**
** Created by: Qt User Interface Compiler version 6.11.2
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef UI_SDSUMMARYCONFIG_BASE_H
#define UI_SDSUMMARYCONFIG_BASE_H

#include <QtCore/QVariant>
#include <QtWidgets/QApplication>
#include <QtWidgets/QCheckBox>
#include <QtWidgets/QGroupBox>
#include <QtWidgets/QHBoxLayout>
#include <QtWidgets/QRadioButton>
#include <QtWidgets/QSpacerItem>
#include <QtWidgets/QSpinBox>
#include <QtWidgets/QVBoxLayout>
#include <QtWidgets/QWidget>
#include <klocalizedstring.h>

QT_BEGIN_NAMESPACE

class Ui_SDSummaryConfig_Base
{
public:
    QVBoxLayout *verticalLayout_5;
    QGroupBox *mDaysGroup;
    QVBoxLayout *verticalLayout;
    QRadioButton *mDateTodayButton;
    QRadioButton *mDateMonthButton;
    QHBoxLayout *horizontalLayout;
    QRadioButton *mDateRangeButton;
    QSpinBox *mCustomDays;
    QSpacerItem *horizontalSpacer;
    QGroupBox *mShowFromCalGroup;
    QVBoxLayout *verticalLayout_2;
    QCheckBox *mShowBirthdaysFromCalBox;
    QCheckBox *mShowAnniversariesFromCalBox;
    QCheckBox *mShowHolidaysFromCalBox;
    QCheckBox *mShowSpecialsFromCalBox;
    QGroupBox *mShowFromKABButtonGroup;
    QVBoxLayout *verticalLayout_3;
    QCheckBox *mShowBirthdaysFromKABBox;
    QCheckBox *mShowAnniversariesFromKABBox;
    QSpacerItem *spacerItem;

    void setupUi(QWidget *SDSummaryConfig_Base)
    {
        if (SDSummaryConfig_Base->objectName().isEmpty())
            SDSummaryConfig_Base->setObjectName("SDSummaryConfig_Base");
        SDSummaryConfig_Base->resize(351, 458);
        verticalLayout_5 = new QVBoxLayout(SDSummaryConfig_Base);
        verticalLayout_5->setObjectName("verticalLayout_5");
        mDaysGroup = new QGroupBox(SDSummaryConfig_Base);
        mDaysGroup->setObjectName("mDaysGroup");
        verticalLayout = new QVBoxLayout(mDaysGroup);
        verticalLayout->setObjectName("verticalLayout");
        mDateTodayButton = new QRadioButton(mDaysGroup);
        mDateTodayButton->setObjectName("mDateTodayButton");
        mDateTodayButton->setChecked(true);

        verticalLayout->addWidget(mDateTodayButton);

        mDateMonthButton = new QRadioButton(mDaysGroup);
        mDateMonthButton->setObjectName("mDateMonthButton");
        mDateMonthButton->setChecked(false);

        verticalLayout->addWidget(mDateMonthButton);

        horizontalLayout = new QHBoxLayout();
        horizontalLayout->setObjectName("horizontalLayout");
        mDateRangeButton = new QRadioButton(mDaysGroup);
        mDateRangeButton->setObjectName("mDateRangeButton");
        mDateRangeButton->setEnabled(true);
        mDateRangeButton->setChecked(false);

        horizontalLayout->addWidget(mDateRangeButton);

        mCustomDays = new QSpinBox(mDaysGroup);
        mCustomDays->setObjectName("mCustomDays");
        mCustomDays->setEnabled(false);
        mCustomDays->setMinimum(1);
        mCustomDays->setMaximum(365);
        mCustomDays->setSingleStep(1);
        mCustomDays->setValue(7);

        horizontalLayout->addWidget(mCustomDays);

        horizontalSpacer = new QSpacerItem(1, 0, QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Minimum);

        horizontalLayout->addItem(horizontalSpacer);


        verticalLayout->addLayout(horizontalLayout);


        verticalLayout_5->addWidget(mDaysGroup);

        mShowFromCalGroup = new QGroupBox(SDSummaryConfig_Base);
        mShowFromCalGroup->setObjectName("mShowFromCalGroup");
        verticalLayout_2 = new QVBoxLayout(mShowFromCalGroup);
        verticalLayout_2->setObjectName("verticalLayout_2");
        mShowBirthdaysFromCalBox = new QCheckBox(mShowFromCalGroup);
        mShowBirthdaysFromCalBox->setObjectName("mShowBirthdaysFromCalBox");
        mShowBirthdaysFromCalBox->setChecked(true);

        verticalLayout_2->addWidget(mShowBirthdaysFromCalBox);

        mShowAnniversariesFromCalBox = new QCheckBox(mShowFromCalGroup);
        mShowAnniversariesFromCalBox->setObjectName("mShowAnniversariesFromCalBox");
        mShowAnniversariesFromCalBox->setChecked(true);

        verticalLayout_2->addWidget(mShowAnniversariesFromCalBox);

        mShowHolidaysFromCalBox = new QCheckBox(mShowFromCalGroup);
        mShowHolidaysFromCalBox->setObjectName("mShowHolidaysFromCalBox");
        mShowHolidaysFromCalBox->setChecked(true);

        verticalLayout_2->addWidget(mShowHolidaysFromCalBox);

        mShowSpecialsFromCalBox = new QCheckBox(mShowFromCalGroup);
        mShowSpecialsFromCalBox->setObjectName("mShowSpecialsFromCalBox");
        mShowSpecialsFromCalBox->setChecked(true);

        verticalLayout_2->addWidget(mShowSpecialsFromCalBox);


        verticalLayout_5->addWidget(mShowFromCalGroup);

        mShowFromKABButtonGroup = new QGroupBox(SDSummaryConfig_Base);
        mShowFromKABButtonGroup->setObjectName("mShowFromKABButtonGroup");
        verticalLayout_3 = new QVBoxLayout(mShowFromKABButtonGroup);
        verticalLayout_3->setObjectName("verticalLayout_3");
        mShowBirthdaysFromKABBox = new QCheckBox(mShowFromKABButtonGroup);
        mShowBirthdaysFromKABBox->setObjectName("mShowBirthdaysFromKABBox");
        mShowBirthdaysFromKABBox->setChecked(true);

        verticalLayout_3->addWidget(mShowBirthdaysFromKABBox);

        mShowAnniversariesFromKABBox = new QCheckBox(mShowFromKABButtonGroup);
        mShowAnniversariesFromKABBox->setObjectName("mShowAnniversariesFromKABBox");
        mShowAnniversariesFromKABBox->setChecked(true);

        verticalLayout_3->addWidget(mShowAnniversariesFromKABBox);


        verticalLayout_5->addWidget(mShowFromKABButtonGroup);

        spacerItem = new QSpacerItem(0, 1, QSizePolicy::Policy::Minimum, QSizePolicy::Policy::Expanding);

        verticalLayout_5->addItem(spacerItem);


        retranslateUi(SDSummaryConfig_Base);
        QObject::connect(mDateRangeButton, &QRadioButton::toggled, mCustomDays, &QSpinBox::setEnabled);

        QMetaObject::connectSlotsByName(SDSummaryConfig_Base);
    } // setupUi

    void retranslateUi(QWidget *SDSummaryConfig_Base)
    {
        SDSummaryConfig_Base->setWindowTitle(tr2i18n("Special Dates Summary Configuration", nullptr));
        mDaysGroup->setTitle(tr2i18n("Show Special Dates Starting", nullptr));
#if QT_CONFIG(tooltip)
        mDateTodayButton->setToolTip(tr2i18n("Show special occasions for today only", nullptr));
#endif // QT_CONFIG(tooltip)
#if QT_CONFIG(whatsthis)
        mDateTodayButton->setWhatsThis(tr2i18n("Check this box if you want to see special occasions occurring on this date only.", nullptr));
#endif // QT_CONFIG(whatsthis)
        mDateTodayButton->setText(tr2i18n("&Today only", nullptr));
#if QT_CONFIG(tooltip)
        mDateMonthButton->setToolTip(tr2i18n("Show special occasions starting within the next month", nullptr));
#endif // QT_CONFIG(tooltip)
#if QT_CONFIG(whatsthis)
        mDateMonthButton->setWhatsThis(tr2i18n("Check this box if you want to see special occasions that start sometime during the next 31 days.", nullptr));
#endif // QT_CONFIG(whatsthis)
        mDateMonthButton->setText(tr2i18n("Within the next &month (31 days)", nullptr));
#if QT_CONFIG(tooltip)
        mDateRangeButton->setToolTip(tr2i18n("Select the days for showing upcoming special occasions", nullptr));
#endif // QT_CONFIG(tooltip)
#if QT_CONFIG(whatsthis)
        mDateRangeButton->setWhatsThis(tr2i18n("Check this box if you want to specify the number of days in the future for upcoming special occasions.", nullptr));
#endif // QT_CONFIG(whatsthis)
        mDateRangeButton->setText(tr2i18n("Within the &next:", nullptr));
#if QT_CONFIG(tooltip)
        mCustomDays->setToolTip(tr2i18n("Set the number of days to show upcoming special occasions", nullptr));
#endif // QT_CONFIG(tooltip)
#if QT_CONFIG(whatsthis)
        mCustomDays->setWhatsThis(tr2i18n("Use this spinbox to set the number of days to show upcoming special occasions up to one year in the future.", nullptr));
#endif // QT_CONFIG(whatsthis)
        mCustomDays->setSpecialValueText(tr2i18n("1 day", nullptr));
        mCustomDays->setSuffix(tr2i18n(" days", "days to show in summary"));
        mShowFromCalGroup->setTitle(tr2i18n("Show These Special Dates From Your Calendar", nullptr));
#if QT_CONFIG(tooltip)
        mShowBirthdaysFromCalBox->setToolTip(tr2i18n("Show birthdays from your calendar", nullptr));
#endif // QT_CONFIG(tooltip)
#if QT_CONFIG(whatsthis)
        mShowBirthdaysFromCalBox->setWhatsThis(tr2i18n("Enable this option to include birthdays from your calendar in the upcoming special occasions summary. Typically, these are events with the \"Birthday\" tag.", nullptr));
#endif // QT_CONFIG(whatsthis)
        mShowBirthdaysFromCalBox->setText(tr2i18n("Show &birthdays", nullptr));
#if QT_CONFIG(tooltip)
        mShowAnniversariesFromCalBox->setToolTip(tr2i18n("Show anniversaries from your calendar", nullptr));
#endif // QT_CONFIG(tooltip)
#if QT_CONFIG(whatsthis)
        mShowAnniversariesFromCalBox->setWhatsThis(tr2i18n("Enable this option to include anniversaries from your calendar in the upcoming special occasions summary. Typically, these are events with the \"Anniversary\" tag.", nullptr));
#endif // QT_CONFIG(whatsthis)
        mShowAnniversariesFromCalBox->setText(tr2i18n("Show &anniversaries", nullptr));
#if QT_CONFIG(tooltip)
        mShowHolidaysFromCalBox->setToolTip(tr2i18n("Show holidays from your calendar", nullptr));
#endif // QT_CONFIG(tooltip)
#if QT_CONFIG(whatsthis)
        mShowHolidaysFromCalBox->setWhatsThis(tr2i18n("Enable this option to include holidays from your calendar in the upcoming special occasions summary. These are events from your configured holiday region, or events with the \"Holiday\" tag.", nullptr));
#endif // QT_CONFIG(whatsthis)
        mShowHolidaysFromCalBox->setText(tr2i18n("Show &holidays", nullptr));
#if QT_CONFIG(tooltip)
        mShowSpecialsFromCalBox->setToolTip(tr2i18n("Show special occasions from your calendar", nullptr));
#endif // QT_CONFIG(tooltip)
#if QT_CONFIG(whatsthis)
        mShowSpecialsFromCalBox->setWhatsThis(tr2i18n("Enable this option to include events from your calendar with the \"special occasion\" tag.", nullptr));
#endif // QT_CONFIG(whatsthis)
        mShowSpecialsFromCalBox->setText(tr2i18n("Show s&pecial occasions", nullptr));
        mShowFromKABButtonGroup->setTitle(tr2i18n("Show These Special Dates From Your Contact List", nullptr));
#if QT_CONFIG(tooltip)
        mShowBirthdaysFromKABBox->setToolTip(tr2i18n("Show birthdays from your address book", nullptr));
#endif // QT_CONFIG(tooltip)
#if QT_CONFIG(whatsthis)
        mShowBirthdaysFromKABBox->setWhatsThis(tr2i18n("Enable this option to include birthdays from your address book in the upcoming special occasions summary.", nullptr));
#endif // QT_CONFIG(whatsthis)
        mShowBirthdaysFromKABBox->setText(tr2i18n("Show birth&days", nullptr));
#if QT_CONFIG(tooltip)
        mShowAnniversariesFromKABBox->setToolTip(tr2i18n("Show anniversaries from your address book", nullptr));
#endif // QT_CONFIG(tooltip)
#if QT_CONFIG(whatsthis)
        mShowAnniversariesFromKABBox->setWhatsThis(tr2i18n("Enable this option to include anniversaries from your address book in the upcoming special occasions summary.", nullptr));
#endif // QT_CONFIG(whatsthis)
        mShowAnniversariesFromKABBox->setText(tr2i18n("Show anni&versaries", nullptr));
    } // retranslateUi

};

namespace Ui {
    class SDSummaryConfig_Base: public Ui_SDSummaryConfig_Base {};
} // namespace Ui

QT_END_NAMESPACE

#endif // SDSUMMARYCONFIG_BASE_H

