/****************************************************************************
** Meta object code from reading C++ file 'calendarview.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.11.2)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../../korganizer-26.08.0/src/calendarview.h"
#include <QtCore/qmetatype.h>
#include <QtCore/QList>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'calendarview.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.11.2. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN21CalendarViewExtensionE_t {};
} // unnamed namespace

template <> constexpr inline auto CalendarViewExtension::qt_create_metaobjectdata<qt_meta_tag_ZN21CalendarViewExtensionE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "CalendarViewExtension"
    };

    QtMocHelpers::UintData qt_methods {
    };
    QtMocHelpers::UintData qt_properties {
    };
    QtMocHelpers::UintData qt_enums {
    };
    return QtMocHelpers::metaObjectData<CalendarViewExtension, qt_meta_tag_ZN21CalendarViewExtensionE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject CalendarViewExtension::staticMetaObject = { {
    QMetaObject::SuperData::link<QWidget::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN21CalendarViewExtensionE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN21CalendarViewExtensionE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN21CalendarViewExtensionE_t>.metaTypes,
    nullptr
} };

void CalendarViewExtension::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<CalendarViewExtension *>(_o);
    (void)_t;
    (void)_c;
    (void)_id;
    (void)_a;
}

const QMetaObject *CalendarViewExtension::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *CalendarViewExtension::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN21CalendarViewExtensionE_t>.strings))
        return static_cast<void*>(this);
    return QWidget::qt_metacast(_clname);
}

int CalendarViewExtension::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QWidget::qt_metacall(_c, _id, _a);
    return _id;
}
namespace {
struct qt_meta_tag_ZN12CalendarViewE_t {};
} // unnamed namespace

template <> constexpr inline auto CalendarView::qt_create_metaobjectdata<qt_meta_tag_ZN12CalendarViewE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "CalendarView",
        "configChanged",
        "",
        "modifiedChanged",
        "organizerEventsSelected",
        "groupEventsSelected",
        "incidenceSelected",
        "Akonadi::Item",
        "todoSelected",
        "subtodoSelected",
        "dayPassed",
        "pasteEnabled",
        "statusMessage",
        "calendarViewExpanded",
        "autoArchivingSettingsModified",
        "filtersUpdated",
        "filterChanged",
        "calendarAdded",
        "Akonadi::CollectionCalendar::Ptr",
        "calendarRemoved",
        "updateConfig",
        "handleIncidenceCreated",
        "item",
        "saveCalendar",
        "filename",
        "archiveCalendar",
        "newEvent",
        "startDt",
        "EndDt",
        "allDay",
        "summary",
        "description",
        "attachment",
        "attendees",
        "attachmentMimetypes",
        "inlineAttachment",
        "showIncidence",
        "Akonadi::Item::Id",
        "id",
        "showOccurrence",
        "showIncidenceContext",
        "showIncidenceByUid",
        "uid",
        "activeDate",
        "editIncidence",
        "isCounter",
        "deleteIncidence",
        "force",
        "addIncidence",
        "ical",
        "KCalendarCore::Incidence::Ptr",
        "incidence",
        "cutIncidence",
        "copyIncidence",
        "pasteIncidence",
        "deleteIncidenceFamily",
        "newTodo",
        "date",
        "Akonadi::Collection",
        "collection",
        "newSubTodo",
        "todo",
        "attachments",
        "newJournal",
        "text",
        "configureCurrentView",
        "toggleAlarm",
        "toggleTodoCompleted",
        "toggleOccurrenceCompleted",
        "copyIncidenceToResource",
        "col",
        "moveIncidenceToResource",
        "dissociateOccurrences",
        "checkClipboard",
        "readSettings",
        "writeSettings",
        "readFilterSettings",
        "KConfig*",
        "config",
        "writeFilterSettings",
        "changeIncidenceDisplay",
        "Akonadi::IncidenceChanger::ChangeType",
        "slotCreateFinished",
        "changeId",
        "Akonadi::IncidenceChanger::ResultCode",
        "resultCode",
        "errorString",
        "slotModifyFinished",
        "slotDeleteFinished",
        "QList<Akonadi::Item::Id>",
        "itemIdList",
        "startMultiModify",
        "endMultiModify",
        "updateView",
        "start",
        "end",
        "preferredMonth",
        "updateTodos",
        "updateUnmanagedViews",
        "edit_cut",
        "edit_copy",
        "edit_paste",
        "onCutFinished",
        "edit_options",
        "print",
        "printPreview",
        "exportICalendar",
        "appointment_delete",
        "todo_unsub",
        "incidence_unsub",
        "makeSubTodosIndependent",
        "makeChildrenIndependent",
        "schedule_publish",
        "schedule_request",
        "schedule_refresh",
        "schedule_cancel",
        "schedule_reply",
        "schedule_counter",
        "schedule_forward",
        "mailFreeBusy",
        "daysToPublish",
        "uploadFreeBusy",
        "openAddressbook",
        "editFilters",
        "updateFilter",
        "showDateNavigator",
        "showTodoView",
        "showEventViewer",
        "goDate",
        "showDate",
        "goToday",
        "goSelectADate",
        "goNext",
        "goPrevious",
        "showLeftFrame",
        "show",
        "processMainViewSelection",
        "processTodoListSelection",
        "processIncidenceSelection",
        "purgeCompleted",
        "slotAutoArchivingSettingsModified",
        "schedule",
        "KCalendarCore::iTIPMethod",
        "addIncidenceOn",
        "itemadd",
        "moveIncidenceTo",
        "itemmove",
        "filterActivated",
        "filterNo",
        "resourcesChanged",
        "selectWeek",
        "changeFullView",
        "fullView",
        "selectShowSideBar",
        "showSideBar",
        "collectionSelected",
        "collectionDeselected",
        "leftSplitterMoved",
        "slotWhatsNew",
        "showDates",
        "KCalendarCore::DateList",
        "onTodosPurged",
        "success",
        "numDeleted",
        "numIgnored"
    };

    QtMocHelpers::UintData qt_methods {
        // Signal 'configChanged'
        QtMocHelpers::SignalData<void()>(1, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'modifiedChanged'
        QtMocHelpers::SignalData<void(bool)>(3, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Bool, 2 },
        }}),
        // Signal 'organizerEventsSelected'
        QtMocHelpers::SignalData<void(bool)>(4, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Bool, 2 },
        }}),
        // Signal 'groupEventsSelected'
        QtMocHelpers::SignalData<void(bool)>(5, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Bool, 2 },
        }}),
        // Signal 'incidenceSelected'
        QtMocHelpers::SignalData<void(const Akonadi::Item &, const QDate &)>(6, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 7, 2 }, { QMetaType::QDate, 2 },
        }}),
        // Signal 'todoSelected'
        QtMocHelpers::SignalData<void(bool)>(8, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Bool, 2 },
        }}),
        // Signal 'subtodoSelected'
        QtMocHelpers::SignalData<void(bool)>(9, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Bool, 2 },
        }}),
        // Signal 'dayPassed'
        QtMocHelpers::SignalData<void(const QDate &)>(10, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QDate, 2 },
        }}),
        // Signal 'pasteEnabled'
        QtMocHelpers::SignalData<void(bool)>(11, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Bool, 2 },
        }}),
        // Signal 'statusMessage'
        QtMocHelpers::SignalData<void(const QString &)>(12, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 2 },
        }}),
        // Signal 'calendarViewExpanded'
        QtMocHelpers::SignalData<void(bool)>(13, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Bool, 2 },
        }}),
        // Signal 'autoArchivingSettingsModified'
        QtMocHelpers::SignalData<void()>(14, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'filtersUpdated'
        QtMocHelpers::SignalData<void(const QStringList &, int)>(15, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QStringList, 2 }, { QMetaType::Int, 2 },
        }}),
        // Signal 'filterChanged'
        QtMocHelpers::SignalData<void()>(16, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'calendarAdded'
        QtMocHelpers::SignalData<void(const Akonadi::CollectionCalendar::Ptr &)>(17, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 18, 2 },
        }}),
        // Signal 'calendarRemoved'
        QtMocHelpers::SignalData<void(const Akonadi::CollectionCalendar::Ptr &)>(19, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 18, 2 },
        }}),
        // Slot 'updateConfig'
        QtMocHelpers::SlotData<void()>(20, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'handleIncidenceCreated'
        QtMocHelpers::SlotData<void(const Akonadi::Item &)>(21, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 7, 22 },
        }}),
        // Slot 'saveCalendar'
        QtMocHelpers::SlotData<bool(const QString &)>(23, 2, QMC::AccessPublic, QMetaType::Bool, {{
            { QMetaType::QString, 24 },
        }}),
        // Slot 'archiveCalendar'
        QtMocHelpers::SlotData<void()>(25, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'newEvent'
        QtMocHelpers::SlotData<void(const QDate &)>(26, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QDate, 2 },
        }}),
        // Slot 'newEvent'
        QtMocHelpers::SlotData<void()>(26, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'newEvent'
        QtMocHelpers::SlotData<void(const QDateTime &)>(26, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QDateTime, 27 },
        }}),
        // Slot 'newEvent'
        QtMocHelpers::SlotData<void(const QDateTime &, const QDateTime &, bool)>(26, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QDateTime, 27 }, { QMetaType::QDateTime, 28 }, { QMetaType::Bool, 29 },
        }}),
        // Slot 'newEvent'
        QtMocHelpers::SlotData<void(const QDateTime &, const QDateTime &)>(26, 2, QMC::AccessPublic | QMC::MethodCloned, QMetaType::Void, {{
            { QMetaType::QDateTime, 27 }, { QMetaType::QDateTime, 28 },
        }}),
        // Slot 'newEvent'
        QtMocHelpers::SlotData<void(const QString &, const QString &, const QStringList &, const QStringList &, const QStringList &, bool)>(26, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 30 }, { QMetaType::QString, 31 }, { QMetaType::QStringList, 32 }, { QMetaType::QStringList, 33 },
            { QMetaType::QStringList, 34 }, { QMetaType::Bool, 35 },
        }}),
        // Slot 'newEvent'
        QtMocHelpers::SlotData<void(const QString &, const QString &, const QStringList &, const QStringList &, const QStringList &)>(26, 2, QMC::AccessPublic | QMC::MethodCloned, QMetaType::Void, {{
            { QMetaType::QString, 30 }, { QMetaType::QString, 31 }, { QMetaType::QStringList, 32 }, { QMetaType::QStringList, 33 },
            { QMetaType::QStringList, 34 },
        }}),
        // Slot 'newEvent'
        QtMocHelpers::SlotData<void(const QString &, const QString &, const QStringList &, const QStringList &)>(26, 2, QMC::AccessPublic | QMC::MethodCloned, QMetaType::Void, {{
            { QMetaType::QString, 30 }, { QMetaType::QString, 31 }, { QMetaType::QStringList, 32 }, { QMetaType::QStringList, 33 },
        }}),
        // Slot 'newEvent'
        QtMocHelpers::SlotData<void(const QString &, const QString &, const QStringList &)>(26, 2, QMC::AccessPublic | QMC::MethodCloned, QMetaType::Void, {{
            { QMetaType::QString, 30 }, { QMetaType::QString, 31 }, { QMetaType::QStringList, 32 },
        }}),
        // Slot 'newEvent'
        QtMocHelpers::SlotData<void(const QString &, const QString &)>(26, 2, QMC::AccessPublic | QMC::MethodCloned, QMetaType::Void, {{
            { QMetaType::QString, 30 }, { QMetaType::QString, 31 },
        }}),
        // Slot 'newEvent'
        QtMocHelpers::SlotData<void(const QString &)>(26, 2, QMC::AccessPublic | QMC::MethodCloned, QMetaType::Void, {{
            { QMetaType::QString, 30 },
        }}),
        // Slot 'showIncidence'
        QtMocHelpers::SlotData<void(const Akonadi::Item &)>(36, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 7, 22 },
        }}),
        // Slot 'showIncidence'
        QtMocHelpers::SlotData<bool(Akonadi::Item::Id)>(36, 2, QMC::AccessPublic, QMetaType::Bool, {{
            { 0x80000000 | 37, 38 },
        }}),
        // Slot 'showIncidence'
        QtMocHelpers::SlotData<void()>(36, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'showOccurrence'
        QtMocHelpers::SlotData<void(const Akonadi::Item &, const QDate &)>(39, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 7, 2 }, { QMetaType::QDate, 2 },
        }}),
        // Slot 'showIncidenceContext'
        QtMocHelpers::SlotData<void(const Akonadi::Item &)>(40, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 7, 22 },
        }}),
        // Slot 'showIncidenceContext'
        QtMocHelpers::SlotData<bool(Akonadi::Item::Id)>(40, 2, QMC::AccessPublic, QMetaType::Bool, {{
            { 0x80000000 | 37, 38 },
        }}),
        // Slot 'showIncidenceByUid'
        QtMocHelpers::SlotData<void(const QString &, QDate)>(41, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 42 }, { QMetaType::QDate, 43 },
        }}),
        // Slot 'showIncidenceByUid'
        QtMocHelpers::SlotData<void(const QString &)>(41, 2, QMC::AccessPublic | QMC::MethodCloned, QMetaType::Void, {{
            { QMetaType::QString, 42 },
        }}),
        // Slot 'editIncidence'
        QtMocHelpers::SlotData<bool(const Akonadi::Item &, bool)>(44, 2, QMC::AccessPublic, QMetaType::Bool, {{
            { 0x80000000 | 7, 22 }, { QMetaType::Bool, 45 },
        }}),
        // Slot 'editIncidence'
        QtMocHelpers::SlotData<bool(const Akonadi::Item &)>(44, 2, QMC::AccessPublic | QMC::MethodCloned, QMetaType::Bool, {{
            { 0x80000000 | 7, 22 },
        }}),
        // Slot 'editIncidence'
        QtMocHelpers::SlotData<bool(Akonadi::Item::Id)>(44, 2, QMC::AccessPublic, QMetaType::Bool, {{
            { 0x80000000 | 37, 38 },
        }}),
        // Slot 'editIncidence'
        QtMocHelpers::SlotData<void()>(44, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'deleteIncidence'
        QtMocHelpers::SlotData<bool(const Akonadi::Item &, bool)>(46, 2, QMC::AccessPublic, QMetaType::Bool, {{
            { 0x80000000 | 7, 22 }, { QMetaType::Bool, 47 },
        }}),
        // Slot 'deleteIncidence'
        QtMocHelpers::SlotData<bool(const Akonadi::Item &)>(46, 2, QMC::AccessPublic | QMC::MethodCloned, QMetaType::Bool, {{
            { 0x80000000 | 7, 22 },
        }}),
        // Slot 'deleteIncidence'
        QtMocHelpers::SlotData<bool(Akonadi::Item::Id, bool)>(46, 2, QMC::AccessPublic, QMetaType::Bool, {{
            { 0x80000000 | 37, 38 }, { QMetaType::Bool, 47 },
        }}),
        // Slot 'deleteIncidence'
        QtMocHelpers::SlotData<bool(Akonadi::Item::Id)>(46, 2, QMC::AccessPublic | QMC::MethodCloned, QMetaType::Bool, {{
            { 0x80000000 | 37, 38 },
        }}),
        // Slot 'deleteIncidence'
        QtMocHelpers::SlotData<void()>(46, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'addIncidence'
        QtMocHelpers::SlotData<bool(const QString &)>(48, 2, QMC::AccessPublic, QMetaType::Bool, {{
            { QMetaType::QString, 49 },
        }}),
        // Slot 'addIncidence'
        QtMocHelpers::SlotData<bool(const KCalendarCore::Incidence::Ptr &)>(48, 2, QMC::AccessPublic, QMetaType::Bool, {{
            { 0x80000000 | 50, 51 },
        }}),
        // Slot 'cutIncidence'
        QtMocHelpers::SlotData<void(const Akonadi::Item &)>(52, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 7, 2 },
        }}),
        // Slot 'copyIncidence'
        QtMocHelpers::SlotData<void(const Akonadi::Item &)>(53, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 7, 2 },
        }}),
        // Slot 'pasteIncidence'
        QtMocHelpers::SlotData<void()>(54, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'deleteIncidenceFamily'
        QtMocHelpers::SlotData<void(const Akonadi::Item &)>(55, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 7, 22 },
        }}),
        // Slot 'newTodo'
        QtMocHelpers::SlotData<void()>(56, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'newTodo'
        QtMocHelpers::SlotData<void(const QDate &)>(56, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QDate, 57 },
        }}),
        // Slot 'newTodo'
        QtMocHelpers::SlotData<void(const Akonadi::Collection &)>(56, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 58, 59 },
        }}),
        // Slot 'newSubTodo'
        QtMocHelpers::SlotData<void()>(60, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'newSubTodo'
        QtMocHelpers::SlotData<void(const Akonadi::Item &)>(60, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 7, 61 },
        }}),
        // Slot 'newSubTodo'
        QtMocHelpers::SlotData<void(const Akonadi::Collection &)>(60, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 58, 59 },
        }}),
        // Slot 'newTodo'
        QtMocHelpers::SlotData<void(const QString &, const QString &, const QStringList &, const QStringList &, const QStringList &, bool)>(56, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 30 }, { QMetaType::QString, 31 }, { QMetaType::QStringList, 62 }, { QMetaType::QStringList, 33 },
            { QMetaType::QStringList, 34 }, { QMetaType::Bool, 35 },
        }}),
        // Slot 'newTodo'
        QtMocHelpers::SlotData<void(const QString &, const QString &, const QStringList &, const QStringList &, const QStringList &)>(56, 2, QMC::AccessPublic | QMC::MethodCloned, QMetaType::Void, {{
            { QMetaType::QString, 30 }, { QMetaType::QString, 31 }, { QMetaType::QStringList, 62 }, { QMetaType::QStringList, 33 },
            { QMetaType::QStringList, 34 },
        }}),
        // Slot 'newTodo'
        QtMocHelpers::SlotData<void(const QString &, const QString &, const QStringList &, const QStringList &)>(56, 2, QMC::AccessPublic | QMC::MethodCloned, QMetaType::Void, {{
            { QMetaType::QString, 30 }, { QMetaType::QString, 31 }, { QMetaType::QStringList, 62 }, { QMetaType::QStringList, 33 },
        }}),
        // Slot 'newTodo'
        QtMocHelpers::SlotData<void(const QString &, const QString &, const QStringList &)>(56, 2, QMC::AccessPublic | QMC::MethodCloned, QMetaType::Void, {{
            { QMetaType::QString, 30 }, { QMetaType::QString, 31 }, { QMetaType::QStringList, 62 },
        }}),
        // Slot 'newTodo'
        QtMocHelpers::SlotData<void(const QString &, const QString &)>(56, 2, QMC::AccessPublic | QMC::MethodCloned, QMetaType::Void, {{
            { QMetaType::QString, 30 }, { QMetaType::QString, 31 },
        }}),
        // Slot 'newTodo'
        QtMocHelpers::SlotData<void(const QString &)>(56, 2, QMC::AccessPublic | QMC::MethodCloned, QMetaType::Void, {{
            { QMetaType::QString, 30 },
        }}),
        // Slot 'newJournal'
        QtMocHelpers::SlotData<void()>(63, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'newJournal'
        QtMocHelpers::SlotData<void(const QDate &)>(63, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QDate, 57 },
        }}),
        // Slot 'newJournal'
        QtMocHelpers::SlotData<void(const QString &, QDate)>(63, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 64 }, { QMetaType::QDate, 57 },
        }}),
        // Slot 'newJournal'
        QtMocHelpers::SlotData<void(const QString &)>(63, 2, QMC::AccessPublic | QMC::MethodCloned, QMetaType::Void, {{
            { QMetaType::QString, 64 },
        }}),
        // Slot 'newJournal'
        QtMocHelpers::SlotData<void(const Akonadi::Collection &)>(63, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 58, 59 },
        }}),
        // Slot 'configureCurrentView'
        QtMocHelpers::SlotData<void()>(65, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'toggleAlarm'
        QtMocHelpers::SlotData<void(const Akonadi::Item &)>(66, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 7, 22 },
        }}),
        // Slot 'toggleTodoCompleted'
        QtMocHelpers::SlotData<void(const Akonadi::Item &)>(67, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 7, 22 },
        }}),
        // Slot 'toggleOccurrenceCompleted'
        QtMocHelpers::SlotData<void(const Akonadi::Item &, const QDate &)>(68, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 7, 2 }, { QMetaType::QDate, 2 },
        }}),
        // Slot 'copyIncidenceToResource'
        QtMocHelpers::SlotData<void(const Akonadi::Item &, const Akonadi::Collection &)>(69, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 7, 22 }, { 0x80000000 | 58, 70 },
        }}),
        // Slot 'moveIncidenceToResource'
        QtMocHelpers::SlotData<void(const Akonadi::Item &, const Akonadi::Collection &)>(71, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 7, 22 }, { 0x80000000 | 58, 70 },
        }}),
        // Slot 'dissociateOccurrences'
        QtMocHelpers::SlotData<void(const Akonadi::Item &, QDate)>(72, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 7, 22 }, { QMetaType::QDate, 57 },
        }}),
        // Slot 'checkClipboard'
        QtMocHelpers::SlotData<void()>(73, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'readSettings'
        QtMocHelpers::SlotData<void()>(74, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'writeSettings'
        QtMocHelpers::SlotData<void()>(75, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'readFilterSettings'
        QtMocHelpers::SlotData<void(KConfig *)>(76, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 77, 78 },
        }}),
        // Slot 'writeFilterSettings'
        QtMocHelpers::SlotData<void(KConfig *)>(79, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 77, 78 },
        }}),
        // Slot 'changeIncidenceDisplay'
        QtMocHelpers::SlotData<void(const Akonadi::Item &, Akonadi::IncidenceChanger::ChangeType)>(80, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 7, 22 }, { 0x80000000 | 81, 2 },
        }}),
        // Slot 'slotCreateFinished'
        QtMocHelpers::SlotData<void(int, const Akonadi::Item &, Akonadi::IncidenceChanger::ResultCode, const QString &)>(82, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Int, 83 }, { 0x80000000 | 7, 22 }, { 0x80000000 | 84, 85 }, { QMetaType::QString, 86 },
        }}),
        // Slot 'slotModifyFinished'
        QtMocHelpers::SlotData<void(int, const Akonadi::Item &, Akonadi::IncidenceChanger::ResultCode, const QString &)>(87, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Int, 83 }, { 0x80000000 | 7, 22 }, { 0x80000000 | 84, 85 }, { QMetaType::QString, 86 },
        }}),
        // Slot 'slotDeleteFinished'
        QtMocHelpers::SlotData<void(int, const QList<Akonadi::Item::Id> &, Akonadi::IncidenceChanger::ResultCode, const QString &)>(88, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Int, 83 }, { 0x80000000 | 89, 90 }, { 0x80000000 | 84, 85 }, { QMetaType::QString, 86 },
        }}),
        // Slot 'startMultiModify'
        QtMocHelpers::SlotData<void(const QString &)>(91, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 64 },
        }}),
        // Slot 'endMultiModify'
        QtMocHelpers::SlotData<void()>(92, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'updateView'
        QtMocHelpers::SlotData<void(const QDate &, const QDate &, const QDate &, const bool)>(93, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QDate, 94 }, { QMetaType::QDate, 95 }, { QMetaType::QDate, 96 }, { QMetaType::Bool, 97 },
        }}),
        // Slot 'updateView'
        QtMocHelpers::SlotData<void(const QDate &, const QDate &, const QDate &)>(93, 2, QMC::AccessPublic | QMC::MethodCloned, QMetaType::Void, {{
            { QMetaType::QDate, 94 }, { QMetaType::QDate, 95 }, { QMetaType::QDate, 96 },
        }}),
        // Slot 'updateView'
        QtMocHelpers::SlotData<void()>(93, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'updateUnmanagedViews'
        QtMocHelpers::SlotData<void()>(98, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'edit_cut'
        QtMocHelpers::SlotData<void()>(99, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'edit_copy'
        QtMocHelpers::SlotData<void()>(100, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'edit_paste'
        QtMocHelpers::SlotData<void()>(101, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'onCutFinished'
        QtMocHelpers::SlotData<void()>(102, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'edit_options'
        QtMocHelpers::SlotData<void()>(103, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'print'
        QtMocHelpers::SlotData<void()>(104, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'printPreview'
        QtMocHelpers::SlotData<void()>(105, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'exportICalendar'
        QtMocHelpers::SlotData<void()>(106, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'appointment_delete'
        QtMocHelpers::SlotData<void()>(107, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'todo_unsub'
        QtMocHelpers::SlotData<void()>(108, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'incidence_unsub'
        QtMocHelpers::SlotData<bool(const Akonadi::Item &)>(109, 2, QMC::AccessPublic, QMetaType::Bool, {{
            { 0x80000000 | 7, 22 },
        }}),
        // Slot 'makeSubTodosIndependent'
        QtMocHelpers::SlotData<bool()>(110, 2, QMC::AccessPublic, QMetaType::Bool),
        // Slot 'makeChildrenIndependent'
        QtMocHelpers::SlotData<bool(const Akonadi::Item &)>(111, 2, QMC::AccessPublic, QMetaType::Bool, {{
            { 0x80000000 | 7, 22 },
        }}),
        // Slot 'schedule_publish'
        QtMocHelpers::SlotData<void(const Akonadi::Item &)>(112, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 7, 22 },
        }}),
        // Slot 'schedule_publish'
        QtMocHelpers::SlotData<void()>(112, 2, QMC::AccessPublic | QMC::MethodCloned, QMetaType::Void),
        // Slot 'schedule_request'
        QtMocHelpers::SlotData<void(const Akonadi::Item &)>(113, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 7, 22 },
        }}),
        // Slot 'schedule_request'
        QtMocHelpers::SlotData<void()>(113, 2, QMC::AccessPublic | QMC::MethodCloned, QMetaType::Void),
        // Slot 'schedule_refresh'
        QtMocHelpers::SlotData<void(const Akonadi::Item &)>(114, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 7, 22 },
        }}),
        // Slot 'schedule_refresh'
        QtMocHelpers::SlotData<void()>(114, 2, QMC::AccessPublic | QMC::MethodCloned, QMetaType::Void),
        // Slot 'schedule_cancel'
        QtMocHelpers::SlotData<void(const Akonadi::Item &)>(115, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 7, 22 },
        }}),
        // Slot 'schedule_cancel'
        QtMocHelpers::SlotData<void()>(115, 2, QMC::AccessPublic | QMC::MethodCloned, QMetaType::Void),
        // Slot 'schedule_reply'
        QtMocHelpers::SlotData<void(const Akonadi::Item &)>(116, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 7, 22 },
        }}),
        // Slot 'schedule_reply'
        QtMocHelpers::SlotData<void()>(116, 2, QMC::AccessPublic | QMC::MethodCloned, QMetaType::Void),
        // Slot 'schedule_counter'
        QtMocHelpers::SlotData<void(const Akonadi::Item &)>(117, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 7, 22 },
        }}),
        // Slot 'schedule_counter'
        QtMocHelpers::SlotData<void()>(117, 2, QMC::AccessPublic | QMC::MethodCloned, QMetaType::Void),
        // Slot 'schedule_forward'
        QtMocHelpers::SlotData<void(const Akonadi::Item &)>(118, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 7, 22 },
        }}),
        // Slot 'schedule_forward'
        QtMocHelpers::SlotData<void()>(118, 2, QMC::AccessPublic | QMC::MethodCloned, QMetaType::Void),
        // Slot 'mailFreeBusy'
        QtMocHelpers::SlotData<void(int)>(119, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Int, 120 },
        }}),
        // Slot 'mailFreeBusy'
        QtMocHelpers::SlotData<void()>(119, 2, QMC::AccessPublic | QMC::MethodCloned, QMetaType::Void),
        // Slot 'uploadFreeBusy'
        QtMocHelpers::SlotData<void()>(121, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'openAddressbook'
        QtMocHelpers::SlotData<void()>(122, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'editFilters'
        QtMocHelpers::SlotData<void()>(123, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'updateFilter'
        QtMocHelpers::SlotData<void()>(124, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'showDateNavigator'
        QtMocHelpers::SlotData<void(bool)>(125, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Bool, 2 },
        }}),
        // Slot 'showTodoView'
        QtMocHelpers::SlotData<void(bool)>(126, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Bool, 2 },
        }}),
        // Slot 'showEventViewer'
        QtMocHelpers::SlotData<void(bool)>(127, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Bool, 2 },
        }}),
        // Slot 'goDate'
        QtMocHelpers::SlotData<void(QDate)>(128, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QDate, 57 },
        }}),
        // Slot 'showDate'
        QtMocHelpers::SlotData<void(QDate)>(129, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QDate, 57 },
        }}),
        // Slot 'goToday'
        QtMocHelpers::SlotData<void()>(130, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'goSelectADate'
        QtMocHelpers::SlotData<void()>(131, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'goNext'
        QtMocHelpers::SlotData<void()>(132, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'goPrevious'
        QtMocHelpers::SlotData<void()>(133, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'showLeftFrame'
        QtMocHelpers::SlotData<void(bool)>(134, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Bool, 135 },
        }}),
        // Slot 'showLeftFrame'
        QtMocHelpers::SlotData<void()>(134, 2, QMC::AccessPublic | QMC::MethodCloned, QMetaType::Void),
        // Slot 'processMainViewSelection'
        QtMocHelpers::SlotData<void(const Akonadi::Item &, const QDate &)>(136, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 7, 22 }, { QMetaType::QDate, 57 },
        }}),
        // Slot 'processTodoListSelection'
        QtMocHelpers::SlotData<void(const Akonadi::Item &, const QDate &)>(137, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 7, 22 }, { QMetaType::QDate, 57 },
        }}),
        // Slot 'processIncidenceSelection'
        QtMocHelpers::SlotData<void(const Akonadi::Item &, const QDate &)>(138, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 7, 22 }, { QMetaType::QDate, 57 },
        }}),
        // Slot 'purgeCompleted'
        QtMocHelpers::SlotData<void()>(139, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'slotAutoArchivingSettingsModified'
        QtMocHelpers::SlotData<void()>(140, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'schedule'
        QtMocHelpers::SlotData<void(KCalendarCore::iTIPMethod, const Akonadi::Item &)>(141, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 142, 2 }, { 0x80000000 | 7, 22 },
        }}),
        // Slot 'addIncidenceOn'
        QtMocHelpers::SlotData<void(const Akonadi::Item &, const QDate &)>(143, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 7, 144 }, { QMetaType::QDate, 2 },
        }}),
        // Slot 'moveIncidenceTo'
        QtMocHelpers::SlotData<void(const Akonadi::Item &, QDate)>(145, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 7, 146 }, { QMetaType::QDate, 2 },
        }}),
        // Slot 'filterActivated'
        QtMocHelpers::SlotData<void(int)>(147, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Int, 148 },
        }}),
        // Slot 'resourcesChanged'
        QtMocHelpers::SlotData<void()>(149, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'selectWeek'
        QtMocHelpers::SlotData<void(const QDate &, const QDate &)>(150, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QDate, 57 }, { QMetaType::QDate, 96 },
        }}),
        // Slot 'changeFullView'
        QtMocHelpers::SlotData<void(bool)>(151, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Bool, 152 },
        }}),
        // Slot 'selectShowSideBar'
        QtMocHelpers::SlotData<void()>(153, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'showSideBar'
        QtMocHelpers::SlotData<void(bool)>(154, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Bool, 135 },
        }}),
        // Slot 'collectionSelected'
        QtMocHelpers::SlotData<void(const Akonadi::Collection &)>(155, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 58, 59 },
        }}),
        // Slot 'collectionDeselected'
        QtMocHelpers::SlotData<void(const Akonadi::Collection &)>(156, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 58, 59 },
        }}),
        // Slot 'leftSplitterMoved'
        QtMocHelpers::SlotData<void(int, int)>(157, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Int, 2 }, { QMetaType::Int, 2 },
        }}),
        // Slot 'slotWhatsNew'
        QtMocHelpers::SlotData<void()>(158, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'showDates'
        QtMocHelpers::SlotData<void(const KCalendarCore::DateList &, const QDate &)>(159, 2, QMC::AccessProtected, QMetaType::Void, {{
            { 0x80000000 | 160, 2 }, { QMetaType::QDate, 96 },
        }}),
        // Slot 'showDates'
        QtMocHelpers::SlotData<void(const KCalendarCore::DateList &)>(159, 2, QMC::AccessProtected | QMC::MethodCloned, QMetaType::Void, {{
            { 0x80000000 | 160, 2 },
        }}),
        // Slot 'onTodosPurged'
        QtMocHelpers::SlotData<void(bool, int, int)>(161, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::Bool, 162 }, { QMetaType::Int, 163 }, { QMetaType::Int, 164 },
        }}),
    };
    QtMocHelpers::UintData qt_properties {
    };
    QtMocHelpers::UintData qt_enums {
    };
    return QtMocHelpers::metaObjectData<CalendarView, qt_meta_tag_ZN12CalendarViewE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject CalendarView::staticMetaObject = { {
    QMetaObject::SuperData::link<KOrg::CalendarViewBase::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN12CalendarViewE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN12CalendarViewE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN12CalendarViewE_t>.metaTypes,
    nullptr
} };

void CalendarView::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<CalendarView *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->configChanged(); break;
        case 1: _t->modifiedChanged((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 2: _t->organizerEventsSelected((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 3: _t->groupEventsSelected((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 4: _t->incidenceSelected((*reinterpret_cast<std::add_pointer_t<Akonadi::Item>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QDate>>(_a[2]))); break;
        case 5: _t->todoSelected((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 6: _t->subtodoSelected((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 7: _t->dayPassed((*reinterpret_cast<std::add_pointer_t<QDate>>(_a[1]))); break;
        case 8: _t->pasteEnabled((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 9: _t->statusMessage((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 10: _t->calendarViewExpanded((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 11: _t->autoArchivingSettingsModified(); break;
        case 12: _t->filtersUpdated((*reinterpret_cast<std::add_pointer_t<QStringList>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[2]))); break;
        case 13: _t->filterChanged(); break;
        case 14: _t->calendarAdded((*reinterpret_cast<std::add_pointer_t<Akonadi::CollectionCalendar::Ptr>>(_a[1]))); break;
        case 15: _t->calendarRemoved((*reinterpret_cast<std::add_pointer_t<Akonadi::CollectionCalendar::Ptr>>(_a[1]))); break;
        case 16: _t->updateConfig(); break;
        case 17: _t->handleIncidenceCreated((*reinterpret_cast<std::add_pointer_t<Akonadi::Item>>(_a[1]))); break;
        case 18: { bool _r = _t->saveCalendar((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])));
            if (_a[0]) *reinterpret_cast<bool*>(_a[0]) = std::move(_r); }  break;
        case 19: _t->archiveCalendar(); break;
        case 20: _t->newEvent((*reinterpret_cast<std::add_pointer_t<QDate>>(_a[1]))); break;
        case 21: _t->newEvent(); break;
        case 22: _t->newEvent((*reinterpret_cast<std::add_pointer_t<QDateTime>>(_a[1]))); break;
        case 23: _t->newEvent((*reinterpret_cast<std::add_pointer_t<QDateTime>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QDateTime>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<bool>>(_a[3]))); break;
        case 24: _t->newEvent((*reinterpret_cast<std::add_pointer_t<QDateTime>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QDateTime>>(_a[2]))); break;
        case 25: _t->newEvent((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<QStringList>>(_a[3])),(*reinterpret_cast<std::add_pointer_t<QStringList>>(_a[4])),(*reinterpret_cast<std::add_pointer_t<QStringList>>(_a[5])),(*reinterpret_cast<std::add_pointer_t<bool>>(_a[6]))); break;
        case 26: _t->newEvent((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<QStringList>>(_a[3])),(*reinterpret_cast<std::add_pointer_t<QStringList>>(_a[4])),(*reinterpret_cast<std::add_pointer_t<QStringList>>(_a[5]))); break;
        case 27: _t->newEvent((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<QStringList>>(_a[3])),(*reinterpret_cast<std::add_pointer_t<QStringList>>(_a[4]))); break;
        case 28: _t->newEvent((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<QStringList>>(_a[3]))); break;
        case 29: _t->newEvent((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[2]))); break;
        case 30: _t->newEvent((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 31: _t->showIncidence((*reinterpret_cast<std::add_pointer_t<Akonadi::Item>>(_a[1]))); break;
        case 32: { bool _r = _t->showIncidence((*reinterpret_cast<std::add_pointer_t<Akonadi::Item::Id>>(_a[1])));
            if (_a[0]) *reinterpret_cast<bool*>(_a[0]) = std::move(_r); }  break;
        case 33: _t->showIncidence(); break;
        case 34: _t->showOccurrence((*reinterpret_cast<std::add_pointer_t<Akonadi::Item>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QDate>>(_a[2]))); break;
        case 35: _t->showIncidenceContext((*reinterpret_cast<std::add_pointer_t<Akonadi::Item>>(_a[1]))); break;
        case 36: { bool _r = _t->showIncidenceContext((*reinterpret_cast<std::add_pointer_t<Akonadi::Item::Id>>(_a[1])));
            if (_a[0]) *reinterpret_cast<bool*>(_a[0]) = std::move(_r); }  break;
        case 37: _t->showIncidenceByUid((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QDate>>(_a[2]))); break;
        case 38: _t->showIncidenceByUid((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 39: { bool _r = _t->editIncidence((*reinterpret_cast<std::add_pointer_t<Akonadi::Item>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<bool>>(_a[2])));
            if (_a[0]) *reinterpret_cast<bool*>(_a[0]) = std::move(_r); }  break;
        case 40: { bool _r = _t->editIncidence((*reinterpret_cast<std::add_pointer_t<Akonadi::Item>>(_a[1])));
            if (_a[0]) *reinterpret_cast<bool*>(_a[0]) = std::move(_r); }  break;
        case 41: { bool _r = _t->editIncidence((*reinterpret_cast<std::add_pointer_t<Akonadi::Item::Id>>(_a[1])));
            if (_a[0]) *reinterpret_cast<bool*>(_a[0]) = std::move(_r); }  break;
        case 42: _t->editIncidence(); break;
        case 43: { bool _r = _t->deleteIncidence((*reinterpret_cast<std::add_pointer_t<Akonadi::Item>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<bool>>(_a[2])));
            if (_a[0]) *reinterpret_cast<bool*>(_a[0]) = std::move(_r); }  break;
        case 44: { bool _r = _t->deleteIncidence((*reinterpret_cast<std::add_pointer_t<Akonadi::Item>>(_a[1])));
            if (_a[0]) *reinterpret_cast<bool*>(_a[0]) = std::move(_r); }  break;
        case 45: { bool _r = _t->deleteIncidence((*reinterpret_cast<std::add_pointer_t<Akonadi::Item::Id>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<bool>>(_a[2])));
            if (_a[0]) *reinterpret_cast<bool*>(_a[0]) = std::move(_r); }  break;
        case 46: { bool _r = _t->deleteIncidence((*reinterpret_cast<std::add_pointer_t<Akonadi::Item::Id>>(_a[1])));
            if (_a[0]) *reinterpret_cast<bool*>(_a[0]) = std::move(_r); }  break;
        case 47: _t->deleteIncidence(); break;
        case 48: { bool _r = _t->addIncidence((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])));
            if (_a[0]) *reinterpret_cast<bool*>(_a[0]) = std::move(_r); }  break;
        case 49: { bool _r = _t->addIncidence((*reinterpret_cast<std::add_pointer_t<KCalendarCore::Incidence::Ptr>>(_a[1])));
            if (_a[0]) *reinterpret_cast<bool*>(_a[0]) = std::move(_r); }  break;
        case 50: _t->cutIncidence((*reinterpret_cast<std::add_pointer_t<Akonadi::Item>>(_a[1]))); break;
        case 51: _t->copyIncidence((*reinterpret_cast<std::add_pointer_t<Akonadi::Item>>(_a[1]))); break;
        case 52: _t->pasteIncidence(); break;
        case 53: _t->deleteIncidenceFamily((*reinterpret_cast<std::add_pointer_t<Akonadi::Item>>(_a[1]))); break;
        case 54: _t->newTodo(); break;
        case 55: _t->newTodo((*reinterpret_cast<std::add_pointer_t<QDate>>(_a[1]))); break;
        case 56: _t->newTodo((*reinterpret_cast<std::add_pointer_t<Akonadi::Collection>>(_a[1]))); break;
        case 57: _t->newSubTodo(); break;
        case 58: _t->newSubTodo((*reinterpret_cast<std::add_pointer_t<Akonadi::Item>>(_a[1]))); break;
        case 59: _t->newSubTodo((*reinterpret_cast<std::add_pointer_t<Akonadi::Collection>>(_a[1]))); break;
        case 60: _t->newTodo((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<QStringList>>(_a[3])),(*reinterpret_cast<std::add_pointer_t<QStringList>>(_a[4])),(*reinterpret_cast<std::add_pointer_t<QStringList>>(_a[5])),(*reinterpret_cast<std::add_pointer_t<bool>>(_a[6]))); break;
        case 61: _t->newTodo((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<QStringList>>(_a[3])),(*reinterpret_cast<std::add_pointer_t<QStringList>>(_a[4])),(*reinterpret_cast<std::add_pointer_t<QStringList>>(_a[5]))); break;
        case 62: _t->newTodo((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<QStringList>>(_a[3])),(*reinterpret_cast<std::add_pointer_t<QStringList>>(_a[4]))); break;
        case 63: _t->newTodo((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<QStringList>>(_a[3]))); break;
        case 64: _t->newTodo((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[2]))); break;
        case 65: _t->newTodo((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 66: _t->newJournal(); break;
        case 67: _t->newJournal((*reinterpret_cast<std::add_pointer_t<QDate>>(_a[1]))); break;
        case 68: _t->newJournal((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QDate>>(_a[2]))); break;
        case 69: _t->newJournal((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 70: _t->newJournal((*reinterpret_cast<std::add_pointer_t<Akonadi::Collection>>(_a[1]))); break;
        case 71: _t->configureCurrentView(); break;
        case 72: _t->toggleAlarm((*reinterpret_cast<std::add_pointer_t<Akonadi::Item>>(_a[1]))); break;
        case 73: _t->toggleTodoCompleted((*reinterpret_cast<std::add_pointer_t<Akonadi::Item>>(_a[1]))); break;
        case 74: _t->toggleOccurrenceCompleted((*reinterpret_cast<std::add_pointer_t<Akonadi::Item>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QDate>>(_a[2]))); break;
        case 75: _t->copyIncidenceToResource((*reinterpret_cast<std::add_pointer_t<Akonadi::Item>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<Akonadi::Collection>>(_a[2]))); break;
        case 76: _t->moveIncidenceToResource((*reinterpret_cast<std::add_pointer_t<Akonadi::Item>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<Akonadi::Collection>>(_a[2]))); break;
        case 77: _t->dissociateOccurrences((*reinterpret_cast<std::add_pointer_t<Akonadi::Item>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QDate>>(_a[2]))); break;
        case 78: _t->checkClipboard(); break;
        case 79: _t->readSettings(); break;
        case 80: _t->writeSettings(); break;
        case 81: _t->readFilterSettings((*reinterpret_cast<std::add_pointer_t<KConfig*>>(_a[1]))); break;
        case 82: _t->writeFilterSettings((*reinterpret_cast<std::add_pointer_t<KConfig*>>(_a[1]))); break;
        case 83: _t->changeIncidenceDisplay((*reinterpret_cast<std::add_pointer_t<Akonadi::Item>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<Akonadi::IncidenceChanger::ChangeType>>(_a[2]))); break;
        case 84: _t->slotCreateFinished((*reinterpret_cast<std::add_pointer_t<int>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<Akonadi::Item>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<Akonadi::IncidenceChanger::ResultCode>>(_a[3])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[4]))); break;
        case 85: _t->slotModifyFinished((*reinterpret_cast<std::add_pointer_t<int>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<Akonadi::Item>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<Akonadi::IncidenceChanger::ResultCode>>(_a[3])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[4]))); break;
        case 86: _t->slotDeleteFinished((*reinterpret_cast<std::add_pointer_t<int>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QList<Akonadi::Item::Id>>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<Akonadi::IncidenceChanger::ResultCode>>(_a[3])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[4]))); break;
        case 87: _t->startMultiModify((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 88: _t->endMultiModify(); break;
        case 89: _t->updateView((*reinterpret_cast<std::add_pointer_t<QDate>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QDate>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<QDate>>(_a[3])),(*reinterpret_cast<std::add_pointer_t<bool>>(_a[4]))); break;
        case 90: _t->updateView((*reinterpret_cast<std::add_pointer_t<QDate>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QDate>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<QDate>>(_a[3]))); break;
        case 91: _t->updateView(); break;
        case 92: _t->updateUnmanagedViews(); break;
        case 93: _t->edit_cut(); break;
        case 94: _t->edit_copy(); break;
        case 95: _t->edit_paste(); break;
        case 96: _t->onCutFinished(); break;
        case 97: _t->edit_options(); break;
        case 98: _t->print(); break;
        case 99: _t->printPreview(); break;
        case 100: _t->exportICalendar(); break;
        case 101: _t->appointment_delete(); break;
        case 102: _t->todo_unsub(); break;
        case 103: { bool _r = _t->incidence_unsub((*reinterpret_cast<std::add_pointer_t<Akonadi::Item>>(_a[1])));
            if (_a[0]) *reinterpret_cast<bool*>(_a[0]) = std::move(_r); }  break;
        case 104: { bool _r = _t->makeSubTodosIndependent();
            if (_a[0]) *reinterpret_cast<bool*>(_a[0]) = std::move(_r); }  break;
        case 105: { bool _r = _t->makeChildrenIndependent((*reinterpret_cast<std::add_pointer_t<Akonadi::Item>>(_a[1])));
            if (_a[0]) *reinterpret_cast<bool*>(_a[0]) = std::move(_r); }  break;
        case 106: _t->schedule_publish((*reinterpret_cast<std::add_pointer_t<Akonadi::Item>>(_a[1]))); break;
        case 107: _t->schedule_publish(); break;
        case 108: _t->schedule_request((*reinterpret_cast<std::add_pointer_t<Akonadi::Item>>(_a[1]))); break;
        case 109: _t->schedule_request(); break;
        case 110: _t->schedule_refresh((*reinterpret_cast<std::add_pointer_t<Akonadi::Item>>(_a[1]))); break;
        case 111: _t->schedule_refresh(); break;
        case 112: _t->schedule_cancel((*reinterpret_cast<std::add_pointer_t<Akonadi::Item>>(_a[1]))); break;
        case 113: _t->schedule_cancel(); break;
        case 114: _t->schedule_reply((*reinterpret_cast<std::add_pointer_t<Akonadi::Item>>(_a[1]))); break;
        case 115: _t->schedule_reply(); break;
        case 116: _t->schedule_counter((*reinterpret_cast<std::add_pointer_t<Akonadi::Item>>(_a[1]))); break;
        case 117: _t->schedule_counter(); break;
        case 118: _t->schedule_forward((*reinterpret_cast<std::add_pointer_t<Akonadi::Item>>(_a[1]))); break;
        case 119: _t->schedule_forward(); break;
        case 120: _t->mailFreeBusy((*reinterpret_cast<std::add_pointer_t<int>>(_a[1]))); break;
        case 121: _t->mailFreeBusy(); break;
        case 122: _t->uploadFreeBusy(); break;
        case 123: _t->openAddressbook(); break;
        case 124: _t->editFilters(); break;
        case 125: _t->updateFilter(); break;
        case 126: _t->showDateNavigator((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 127: _t->showTodoView((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 128: _t->showEventViewer((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 129: _t->goDate((*reinterpret_cast<std::add_pointer_t<QDate>>(_a[1]))); break;
        case 130: _t->showDate((*reinterpret_cast<std::add_pointer_t<QDate>>(_a[1]))); break;
        case 131: _t->goToday(); break;
        case 132: _t->goSelectADate(); break;
        case 133: _t->goNext(); break;
        case 134: _t->goPrevious(); break;
        case 135: _t->showLeftFrame((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 136: _t->showLeftFrame(); break;
        case 137: _t->processMainViewSelection((*reinterpret_cast<std::add_pointer_t<Akonadi::Item>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QDate>>(_a[2]))); break;
        case 138: _t->processTodoListSelection((*reinterpret_cast<std::add_pointer_t<Akonadi::Item>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QDate>>(_a[2]))); break;
        case 139: _t->processIncidenceSelection((*reinterpret_cast<std::add_pointer_t<Akonadi::Item>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QDate>>(_a[2]))); break;
        case 140: _t->purgeCompleted(); break;
        case 141: _t->slotAutoArchivingSettingsModified(); break;
        case 142: _t->schedule((*reinterpret_cast<std::add_pointer_t<KCalendarCore::iTIPMethod>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<Akonadi::Item>>(_a[2]))); break;
        case 143: _t->addIncidenceOn((*reinterpret_cast<std::add_pointer_t<Akonadi::Item>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QDate>>(_a[2]))); break;
        case 144: _t->moveIncidenceTo((*reinterpret_cast<std::add_pointer_t<Akonadi::Item>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QDate>>(_a[2]))); break;
        case 145: _t->filterActivated((*reinterpret_cast<std::add_pointer_t<int>>(_a[1]))); break;
        case 146: _t->resourcesChanged(); break;
        case 147: _t->selectWeek((*reinterpret_cast<std::add_pointer_t<QDate>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QDate>>(_a[2]))); break;
        case 148: _t->changeFullView((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 149: _t->selectShowSideBar(); break;
        case 150: _t->showSideBar((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 151: _t->collectionSelected((*reinterpret_cast<std::add_pointer_t<Akonadi::Collection>>(_a[1]))); break;
        case 152: _t->collectionDeselected((*reinterpret_cast<std::add_pointer_t<Akonadi::Collection>>(_a[1]))); break;
        case 153: _t->leftSplitterMoved((*reinterpret_cast<std::add_pointer_t<int>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[2]))); break;
        case 154: _t->slotWhatsNew(); break;
        case 155: _t->showDates((*reinterpret_cast<std::add_pointer_t<KCalendarCore::DateList>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QDate>>(_a[2]))); break;
        case 156: _t->showDates((*reinterpret_cast<std::add_pointer_t<KCalendarCore::DateList>>(_a[1]))); break;
        case 157: _t->onTodosPurged((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[3]))); break;
        default: ;
        }
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        switch (_id) {
        default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
        case 4:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< Akonadi::Item >(); break;
            }
            break;
        case 17:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< Akonadi::Item >(); break;
            }
            break;
        case 31:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< Akonadi::Item >(); break;
            }
            break;
        case 34:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< Akonadi::Item >(); break;
            }
            break;
        case 35:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< Akonadi::Item >(); break;
            }
            break;
        case 39:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< Akonadi::Item >(); break;
            }
            break;
        case 40:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< Akonadi::Item >(); break;
            }
            break;
        case 43:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< Akonadi::Item >(); break;
            }
            break;
        case 44:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< Akonadi::Item >(); break;
            }
            break;
        case 50:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< Akonadi::Item >(); break;
            }
            break;
        case 51:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< Akonadi::Item >(); break;
            }
            break;
        case 53:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< Akonadi::Item >(); break;
            }
            break;
        case 58:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< Akonadi::Item >(); break;
            }
            break;
        case 72:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< Akonadi::Item >(); break;
            }
            break;
        case 73:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< Akonadi::Item >(); break;
            }
            break;
        case 74:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< Akonadi::Item >(); break;
            }
            break;
        case 75:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< Akonadi::Item >(); break;
            }
            break;
        case 76:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< Akonadi::Item >(); break;
            }
            break;
        case 77:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< Akonadi::Item >(); break;
            }
            break;
        case 83:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 1:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< Akonadi::IncidenceChanger::ChangeType >(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< Akonadi::Item >(); break;
            }
            break;
        case 84:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 2:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< Akonadi::IncidenceChanger::ResultCode >(); break;
            case 1:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< Akonadi::Item >(); break;
            }
            break;
        case 85:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 2:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< Akonadi::IncidenceChanger::ResultCode >(); break;
            case 1:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< Akonadi::Item >(); break;
            }
            break;
        case 86:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 2:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< Akonadi::IncidenceChanger::ResultCode >(); break;
            }
            break;
        case 103:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< Akonadi::Item >(); break;
            }
            break;
        case 105:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< Akonadi::Item >(); break;
            }
            break;
        case 106:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< Akonadi::Item >(); break;
            }
            break;
        case 108:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< Akonadi::Item >(); break;
            }
            break;
        case 110:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< Akonadi::Item >(); break;
            }
            break;
        case 112:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< Akonadi::Item >(); break;
            }
            break;
        case 114:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< Akonadi::Item >(); break;
            }
            break;
        case 116:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< Akonadi::Item >(); break;
            }
            break;
        case 118:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< Akonadi::Item >(); break;
            }
            break;
        case 137:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< Akonadi::Item >(); break;
            }
            break;
        case 138:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< Akonadi::Item >(); break;
            }
            break;
        case 139:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< Akonadi::Item >(); break;
            }
            break;
        case 142:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 1:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< Akonadi::Item >(); break;
            }
            break;
        case 143:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< Akonadi::Item >(); break;
            }
            break;
        case 144:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< Akonadi::Item >(); break;
            }
            break;
        }
    }
    if (_c == QMetaObject::IndexOfMethod) {
        if (QtMocHelpers::indexOfMethod<void (CalendarView::*)()>(_a, &CalendarView::configChanged, 0))
            return;
        if (QtMocHelpers::indexOfMethod<void (CalendarView::*)(bool )>(_a, &CalendarView::modifiedChanged, 1))
            return;
        if (QtMocHelpers::indexOfMethod<void (CalendarView::*)(bool )>(_a, &CalendarView::organizerEventsSelected, 2))
            return;
        if (QtMocHelpers::indexOfMethod<void (CalendarView::*)(bool )>(_a, &CalendarView::groupEventsSelected, 3))
            return;
        if (QtMocHelpers::indexOfMethod<void (CalendarView::*)(const Akonadi::Item & , const QDate & )>(_a, &CalendarView::incidenceSelected, 4))
            return;
        if (QtMocHelpers::indexOfMethod<void (CalendarView::*)(bool )>(_a, &CalendarView::todoSelected, 5))
            return;
        if (QtMocHelpers::indexOfMethod<void (CalendarView::*)(bool )>(_a, &CalendarView::subtodoSelected, 6))
            return;
        if (QtMocHelpers::indexOfMethod<void (CalendarView::*)(const QDate & )>(_a, &CalendarView::dayPassed, 7))
            return;
        if (QtMocHelpers::indexOfMethod<void (CalendarView::*)(bool )>(_a, &CalendarView::pasteEnabled, 8))
            return;
        if (QtMocHelpers::indexOfMethod<void (CalendarView::*)(const QString & )>(_a, &CalendarView::statusMessage, 9))
            return;
        if (QtMocHelpers::indexOfMethod<void (CalendarView::*)(bool )>(_a, &CalendarView::calendarViewExpanded, 10))
            return;
        if (QtMocHelpers::indexOfMethod<void (CalendarView::*)()>(_a, &CalendarView::autoArchivingSettingsModified, 11))
            return;
        if (QtMocHelpers::indexOfMethod<void (CalendarView::*)(const QStringList & , int )>(_a, &CalendarView::filtersUpdated, 12))
            return;
        if (QtMocHelpers::indexOfMethod<void (CalendarView::*)()>(_a, &CalendarView::filterChanged, 13))
            return;
        if (QtMocHelpers::indexOfMethod<void (CalendarView::*)(const Akonadi::CollectionCalendar::Ptr & )>(_a, &CalendarView::calendarAdded, 14))
            return;
        if (QtMocHelpers::indexOfMethod<void (CalendarView::*)(const Akonadi::CollectionCalendar::Ptr & )>(_a, &CalendarView::calendarRemoved, 15))
            return;
    }
}

const QMetaObject *CalendarView::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *CalendarView::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN12CalendarViewE_t>.strings))
        return static_cast<void*>(this);
    if (!strcmp(_clname, "KCalendarCore::Calendar::CalendarObserver"))
        return static_cast< KCalendarCore::Calendar::CalendarObserver*>(this);
    return KOrg::CalendarViewBase::qt_metacast(_clname);
}

int CalendarView::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = KOrg::CalendarViewBase::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 158)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 158;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 158)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 158;
    }
    return _id;
}

// SIGNAL 0
void CalendarView::configChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 0, nullptr);
}

// SIGNAL 1
void CalendarView::modifiedChanged(bool _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 1, nullptr, _t1);
}

// SIGNAL 2
void CalendarView::organizerEventsSelected(bool _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 2, nullptr, _t1);
}

// SIGNAL 3
void CalendarView::groupEventsSelected(bool _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 3, nullptr, _t1);
}

// SIGNAL 4
void CalendarView::incidenceSelected(const Akonadi::Item & _t1, const QDate & _t2)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 4, nullptr, _t1, _t2);
}

// SIGNAL 5
void CalendarView::todoSelected(bool _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 5, nullptr, _t1);
}

// SIGNAL 6
void CalendarView::subtodoSelected(bool _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 6, nullptr, _t1);
}

// SIGNAL 7
void CalendarView::dayPassed(const QDate & _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 7, nullptr, _t1);
}

// SIGNAL 8
void CalendarView::pasteEnabled(bool _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 8, nullptr, _t1);
}

// SIGNAL 9
void CalendarView::statusMessage(const QString & _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 9, nullptr, _t1);
}

// SIGNAL 10
void CalendarView::calendarViewExpanded(bool _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 10, nullptr, _t1);
}

// SIGNAL 11
void CalendarView::autoArchivingSettingsModified()
{
    QMetaObject::activate(this, &staticMetaObject, 11, nullptr);
}

// SIGNAL 12
void CalendarView::filtersUpdated(const QStringList & _t1, int _t2)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 12, nullptr, _t1, _t2);
}

// SIGNAL 13
void CalendarView::filterChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 13, nullptr);
}

// SIGNAL 14
void CalendarView::calendarAdded(const Akonadi::CollectionCalendar::Ptr & _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 14, nullptr, _t1);
}

// SIGNAL 15
void CalendarView::calendarRemoved(const Akonadi::CollectionCalendar::Ptr & _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 15, nullptr, _t1);
}
QT_WARNING_POP
