/********************************************************************************
** Form generated from reading UI file 'quickview.ui'
**
** Created by: Qt User Interface Compiler version 6.11.2
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef UI_QUICKVIEW_H
#define UI_QUICKVIEW_H

#include <QtCore/QVariant>
#include <QtWidgets/QApplication>
#include <QtWidgets/QHBoxLayout>
#include <QtWidgets/QPushButton>
#include <QtWidgets/QSpacerItem>
#include <QtWidgets/QVBoxLayout>
#include <QtWidgets/QWidget>
#include <klocalizedstring.h>

QT_BEGIN_NAMESPACE

class Ui_quickview
{
public:
    QVBoxLayout *verticalLayout;
    QHBoxLayout *horizontalLayout;
    QPushButton *mDayBtn;
    QPushButton *mWeekBtn;
    QPushButton *mMothBtn;
    QPushButton *mAgendaBtn;
    QSpacerItem *horizontalSpacer;
    QPushButton *mPreviousBtn;
    QPushButton *mTodayBtn;
    QPushButton *mNextBtn;
    QHBoxLayout *calendar;

    void setupUi(QWidget *quickview)
    {
        if (quickview->objectName().isEmpty())
            quickview->setObjectName("quickview");
        quickview->resize(644, 566);
        verticalLayout = new QVBoxLayout(quickview);
        verticalLayout->setObjectName("verticalLayout");
        verticalLayout->setContentsMargins(0, 0, 0, 0);
        horizontalLayout = new QHBoxLayout();
        horizontalLayout->setObjectName("horizontalLayout");
        mDayBtn = new QPushButton(quickview);
        mDayBtn->setObjectName("mDayBtn");
        mDayBtn->setEnabled(false);

        horizontalLayout->addWidget(mDayBtn);

        mWeekBtn = new QPushButton(quickview);
        mWeekBtn->setObjectName("mWeekBtn");

        horizontalLayout->addWidget(mWeekBtn);

        mMothBtn = new QPushButton(quickview);
        mMothBtn->setObjectName("mMothBtn");
        mMothBtn->setEnabled(false);

        horizontalLayout->addWidget(mMothBtn);

        mAgendaBtn = new QPushButton(quickview);
        mAgendaBtn->setObjectName("mAgendaBtn");
        mAgendaBtn->setEnabled(false);

        horizontalLayout->addWidget(mAgendaBtn);

        horizontalSpacer = new QSpacerItem(40, 20, QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Minimum);

        horizontalLayout->addItem(horizontalSpacer);

        mPreviousBtn = new QPushButton(quickview);
        mPreviousBtn->setObjectName("mPreviousBtn");
        mPreviousBtn->setEnabled(true);

        horizontalLayout->addWidget(mPreviousBtn);

        mTodayBtn = new QPushButton(quickview);
        mTodayBtn->setObjectName("mTodayBtn");
        mTodayBtn->setEnabled(true);

        horizontalLayout->addWidget(mTodayBtn);

        mNextBtn = new QPushButton(quickview);
        mNextBtn->setObjectName("mNextBtn");
        mNextBtn->setEnabled(true);

        horizontalLayout->addWidget(mNextBtn);


        verticalLayout->addLayout(horizontalLayout);

        calendar = new QHBoxLayout();
        calendar->setObjectName("calendar");
        calendar->setSizeConstraint(QLayout::SetDefaultConstraint);

        verticalLayout->addLayout(calendar);


        retranslateUi(quickview);

        QMetaObject::connectSlotsByName(quickview);
    } // setupUi

    void retranslateUi(QWidget *quickview)
    {
        mDayBtn->setText(tr2i18n("Day", nullptr));
        mWeekBtn->setText(tr2i18n("Week", nullptr));
        mMothBtn->setText(tr2i18n("Month", nullptr));
        mAgendaBtn->setText(tr2i18n("Agenda", nullptr));
        mPreviousBtn->setText(tr2i18n("<", nullptr));
        mTodayBtn->setText(tr2i18n("Today", nullptr));
        mNextBtn->setText(tr2i18n(">", nullptr));
        (void)quickview;
    } // retranslateUi

};

namespace Ui {
    class quickview: public Ui_quickview {};
} // namespace Ui

QT_END_NAMESPACE

#endif // QUICKVIEW_H

