// This file was generated by ecm_qt_declare_logging_category(): DO NOT EDIT!

#include "korganizer_picoftheday_plugin_debug.h"


Q_LOGGING_CATEGORY(KORGANIZERPICOFTHEDAYPLUGIN_LOG, "org.kde.pim.korganizer_picoftheday_plugins", QtInfoMsg)

