/****************************************************************************
** Meta object code from reading C++ file 'calendarinterface.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.11.2)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "calendarinterface.h"
#include <QtCore/qmetatype.h>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'calendarinterface.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.11.2. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN33OrgKdeKorganizerCalendarInterfaceE_t {};
} // unnamed namespace

template <> constexpr inline auto OrgKdeKorganizerCalendarInterface::qt_create_metaobjectdata<qt_meta_tag_ZN33OrgKdeKorganizerCalendarInterfaceE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "OrgKdeKorganizerCalendarInterface",
        "goDate",
        "QDBusPendingReply<>",
        "",
        "date",
        "openEventEditor",
        "summary",
        "description",
        "attachmentUris",
        "attendees",
        "attachmentMimetypes",
        "attachmentIsInline",
        "attachments",
        "uri",
        "file",
        "attachmentMimetype",
        "text",
        "openJournalEditor",
        "openTodoEditor",
        "showDate",
        "showEventView",
        "showJournalView",
        "showTodoView"
    };

    QtMocHelpers::UintData qt_methods {
        // Slot 'goDate'
        QtMocHelpers::SlotData<QDBusPendingReply<>(const QString &)>(1, 3, QMC::AccessPublic, 0x80000000 | 2, {{
            { QMetaType::QString, 4 },
        }}),
        // Slot 'goDate'
        QtMocHelpers::SlotData<QDBusPendingReply<>(const QDate &)>(1, 3, QMC::AccessPublic, 0x80000000 | 2, {{
            { QMetaType::QDate, 4 },
        }}),
        // Slot 'openEventEditor'
        QtMocHelpers::SlotData<QDBusPendingReply<>(const QString &, const QString &, const QStringList &, const QStringList &, const QStringList &, bool)>(5, 3, QMC::AccessPublic, 0x80000000 | 2, {{
            { QMetaType::QString, 6 }, { QMetaType::QString, 7 }, { QMetaType::QStringList, 8 }, { QMetaType::QStringList, 9 },
            { QMetaType::QStringList, 10 }, { QMetaType::Bool, 11 },
        }}),
        // Slot 'openEventEditor'
        QtMocHelpers::SlotData<QDBusPendingReply<>(const QString &, const QString &, const QStringList &, const QStringList &)>(5, 3, QMC::AccessPublic, 0x80000000 | 2, {{
            { QMetaType::QString, 6 }, { QMetaType::QString, 7 }, { QMetaType::QStringList, 12 }, { QMetaType::QStringList, 9 },
        }}),
        // Slot 'openEventEditor'
        QtMocHelpers::SlotData<QDBusPendingReply<>(const QString &, const QString &, const QString &, const QString &, const QStringList &, const QString &)>(5, 3, QMC::AccessPublic, 0x80000000 | 2, {{
            { QMetaType::QString, 6 }, { QMetaType::QString, 7 }, { QMetaType::QString, 13 }, { QMetaType::QString, 14 },
            { QMetaType::QStringList, 9 }, { QMetaType::QString, 15 },
        }}),
        // Slot 'openEventEditor'
        QtMocHelpers::SlotData<QDBusPendingReply<>(const QString &, const QString &, const QStringList &)>(5, 3, QMC::AccessPublic, 0x80000000 | 2, {{
            { QMetaType::QString, 6 }, { QMetaType::QString, 7 }, { QMetaType::QStringList, 12 },
        }}),
        // Slot 'openEventEditor'
        QtMocHelpers::SlotData<QDBusPendingReply<>(const QString &)>(5, 3, QMC::AccessPublic, 0x80000000 | 2, {{
            { QMetaType::QString, 16 },
        }}),
        // Slot 'openEventEditor'
        QtMocHelpers::SlotData<QDBusPendingReply<>()>(5, 3, QMC::AccessPublic, 0x80000000 | 2),
        // Slot 'openJournalEditor'
        QtMocHelpers::SlotData<QDBusPendingReply<>(const QString &)>(17, 3, QMC::AccessPublic, 0x80000000 | 2, {{
            { QMetaType::QString, 16 },
        }}),
        // Slot 'openJournalEditor'
        QtMocHelpers::SlotData<QDBusPendingReply<>(const QString &, const QDate &)>(17, 3, QMC::AccessPublic, 0x80000000 | 2, {{
            { QMetaType::QString, 16 }, { QMetaType::QDate, 4 },
        }}),
        // Slot 'openJournalEditor'
        QtMocHelpers::SlotData<QDBusPendingReply<>(const QDate &)>(17, 3, QMC::AccessPublic, 0x80000000 | 2, {{
            { QMetaType::QDate, 4 },
        }}),
        // Slot 'openTodoEditor'
        QtMocHelpers::SlotData<QDBusPendingReply<>(const QString &, const QString &, const QStringList &, const QStringList &, const QStringList &, bool)>(18, 3, QMC::AccessPublic, 0x80000000 | 2, {{
            { QMetaType::QString, 6 }, { QMetaType::QString, 7 }, { QMetaType::QStringList, 8 }, { QMetaType::QStringList, 9 },
            { QMetaType::QStringList, 10 }, { QMetaType::Bool, 11 },
        }}),
        // Slot 'openTodoEditor'
        QtMocHelpers::SlotData<QDBusPendingReply<>(const QString &, const QString &, const QString &, const QString &, const QStringList &, const QString &)>(18, 3, QMC::AccessPublic, 0x80000000 | 2, {{
            { QMetaType::QString, 6 }, { QMetaType::QString, 7 }, { QMetaType::QString, 13 }, { QMetaType::QString, 14 },
            { QMetaType::QStringList, 9 }, { QMetaType::QString, 15 },
        }}),
        // Slot 'openTodoEditor'
        QtMocHelpers::SlotData<QDBusPendingReply<>(const QString &, const QString &, const QStringList &, const QStringList &)>(18, 3, QMC::AccessPublic, 0x80000000 | 2, {{
            { QMetaType::QString, 6 }, { QMetaType::QString, 7 }, { QMetaType::QStringList, 12 }, { QMetaType::QStringList, 9 },
        }}),
        // Slot 'openTodoEditor'
        QtMocHelpers::SlotData<QDBusPendingReply<>(const QString &, const QString &, const QStringList &)>(18, 3, QMC::AccessPublic, 0x80000000 | 2, {{
            { QMetaType::QString, 6 }, { QMetaType::QString, 7 }, { QMetaType::QStringList, 12 },
        }}),
        // Slot 'openTodoEditor'
        QtMocHelpers::SlotData<QDBusPendingReply<>(const QString &)>(18, 3, QMC::AccessPublic, 0x80000000 | 2, {{
            { QMetaType::QString, 16 },
        }}),
        // Slot 'showDate'
        QtMocHelpers::SlotData<QDBusPendingReply<>(const QDate &)>(19, 3, QMC::AccessPublic, 0x80000000 | 2, {{
            { QMetaType::QDate, 4 },
        }}),
        // Slot 'showEventView'
        QtMocHelpers::SlotData<QDBusPendingReply<>()>(20, 3, QMC::AccessPublic, 0x80000000 | 2),
        // Slot 'showJournalView'
        QtMocHelpers::SlotData<QDBusPendingReply<>()>(21, 3, QMC::AccessPublic, 0x80000000 | 2),
        // Slot 'showTodoView'
        QtMocHelpers::SlotData<QDBusPendingReply<>()>(22, 3, QMC::AccessPublic, 0x80000000 | 2),
    };
    QtMocHelpers::UintData qt_properties {
    };
    QtMocHelpers::UintData qt_enums {
    };
    return QtMocHelpers::metaObjectData<OrgKdeKorganizerCalendarInterface, qt_meta_tag_ZN33OrgKdeKorganizerCalendarInterfaceE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject OrgKdeKorganizerCalendarInterface::staticMetaObject = { {
    QMetaObject::SuperData::link<QDBusAbstractInterface::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN33OrgKdeKorganizerCalendarInterfaceE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN33OrgKdeKorganizerCalendarInterfaceE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN33OrgKdeKorganizerCalendarInterfaceE_t>.metaTypes,
    nullptr
} };

void OrgKdeKorganizerCalendarInterface::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<OrgKdeKorganizerCalendarInterface *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: { QDBusPendingReply<> _r = _t->goDate((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])));
            if (_a[0]) *reinterpret_cast<QDBusPendingReply<>*>(_a[0]) = std::move(_r); }  break;
        case 1: { QDBusPendingReply<> _r = _t->goDate((*reinterpret_cast<std::add_pointer_t<QDate>>(_a[1])));
            if (_a[0]) *reinterpret_cast<QDBusPendingReply<>*>(_a[0]) = std::move(_r); }  break;
        case 2: { QDBusPendingReply<> _r = _t->openEventEditor((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<QStringList>>(_a[3])),(*reinterpret_cast<std::add_pointer_t<QStringList>>(_a[4])),(*reinterpret_cast<std::add_pointer_t<QStringList>>(_a[5])),(*reinterpret_cast<std::add_pointer_t<bool>>(_a[6])));
            if (_a[0]) *reinterpret_cast<QDBusPendingReply<>*>(_a[0]) = std::move(_r); }  break;
        case 3: { QDBusPendingReply<> _r = _t->openEventEditor((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<QStringList>>(_a[3])),(*reinterpret_cast<std::add_pointer_t<QStringList>>(_a[4])));
            if (_a[0]) *reinterpret_cast<QDBusPendingReply<>*>(_a[0]) = std::move(_r); }  break;
        case 4: { QDBusPendingReply<> _r = _t->openEventEditor((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[3])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[4])),(*reinterpret_cast<std::add_pointer_t<QStringList>>(_a[5])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[6])));
            if (_a[0]) *reinterpret_cast<QDBusPendingReply<>*>(_a[0]) = std::move(_r); }  break;
        case 5: { QDBusPendingReply<> _r = _t->openEventEditor((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<QStringList>>(_a[3])));
            if (_a[0]) *reinterpret_cast<QDBusPendingReply<>*>(_a[0]) = std::move(_r); }  break;
        case 6: { QDBusPendingReply<> _r = _t->openEventEditor((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])));
            if (_a[0]) *reinterpret_cast<QDBusPendingReply<>*>(_a[0]) = std::move(_r); }  break;
        case 7: { QDBusPendingReply<> _r = _t->openEventEditor();
            if (_a[0]) *reinterpret_cast<QDBusPendingReply<>*>(_a[0]) = std::move(_r); }  break;
        case 8: { QDBusPendingReply<> _r = _t->openJournalEditor((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])));
            if (_a[0]) *reinterpret_cast<QDBusPendingReply<>*>(_a[0]) = std::move(_r); }  break;
        case 9: { QDBusPendingReply<> _r = _t->openJournalEditor((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QDate>>(_a[2])));
            if (_a[0]) *reinterpret_cast<QDBusPendingReply<>*>(_a[0]) = std::move(_r); }  break;
        case 10: { QDBusPendingReply<> _r = _t->openJournalEditor((*reinterpret_cast<std::add_pointer_t<QDate>>(_a[1])));
            if (_a[0]) *reinterpret_cast<QDBusPendingReply<>*>(_a[0]) = std::move(_r); }  break;
        case 11: { QDBusPendingReply<> _r = _t->openTodoEditor((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<QStringList>>(_a[3])),(*reinterpret_cast<std::add_pointer_t<QStringList>>(_a[4])),(*reinterpret_cast<std::add_pointer_t<QStringList>>(_a[5])),(*reinterpret_cast<std::add_pointer_t<bool>>(_a[6])));
            if (_a[0]) *reinterpret_cast<QDBusPendingReply<>*>(_a[0]) = std::move(_r); }  break;
        case 12: { QDBusPendingReply<> _r = _t->openTodoEditor((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[3])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[4])),(*reinterpret_cast<std::add_pointer_t<QStringList>>(_a[5])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[6])));
            if (_a[0]) *reinterpret_cast<QDBusPendingReply<>*>(_a[0]) = std::move(_r); }  break;
        case 13: { QDBusPendingReply<> _r = _t->openTodoEditor((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<QStringList>>(_a[3])),(*reinterpret_cast<std::add_pointer_t<QStringList>>(_a[4])));
            if (_a[0]) *reinterpret_cast<QDBusPendingReply<>*>(_a[0]) = std::move(_r); }  break;
        case 14: { QDBusPendingReply<> _r = _t->openTodoEditor((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<QStringList>>(_a[3])));
            if (_a[0]) *reinterpret_cast<QDBusPendingReply<>*>(_a[0]) = std::move(_r); }  break;
        case 15: { QDBusPendingReply<> _r = _t->openTodoEditor((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])));
            if (_a[0]) *reinterpret_cast<QDBusPendingReply<>*>(_a[0]) = std::move(_r); }  break;
        case 16: { QDBusPendingReply<> _r = _t->showDate((*reinterpret_cast<std::add_pointer_t<QDate>>(_a[1])));
            if (_a[0]) *reinterpret_cast<QDBusPendingReply<>*>(_a[0]) = std::move(_r); }  break;
        case 17: { QDBusPendingReply<> _r = _t->showEventView();
            if (_a[0]) *reinterpret_cast<QDBusPendingReply<>*>(_a[0]) = std::move(_r); }  break;
        case 18: { QDBusPendingReply<> _r = _t->showJournalView();
            if (_a[0]) *reinterpret_cast<QDBusPendingReply<>*>(_a[0]) = std::move(_r); }  break;
        case 19: { QDBusPendingReply<> _r = _t->showTodoView();
            if (_a[0]) *reinterpret_cast<QDBusPendingReply<>*>(_a[0]) = std::move(_r); }  break;
        default: ;
        }
    }
}

const QMetaObject *OrgKdeKorganizerCalendarInterface::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *OrgKdeKorganizerCalendarInterface::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN33OrgKdeKorganizerCalendarInterfaceE_t>.strings))
        return static_cast<void*>(this);
    return QDBusAbstractInterface::qt_metacast(_clname);
}

int OrgKdeKorganizerCalendarInterface::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QDBusAbstractInterface::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 20)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 20;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 20)
            *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType();
        _id -= 20;
    }
    return _id;
}
QT_WARNING_POP
