/****************************************************************************
** Meta object code from reading C++ file 'akonadicollectionview.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.11.2)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../../korganizer-26.08.0/src/akonadicollectionview.h"
#include <QtCore/qmetatype.h>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'akonadicollectionview.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.11.2. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN21AkonadiCollectionViewE_t {};
} // unnamed namespace

template <> constexpr inline auto AkonadiCollectionView::qt_create_metaobjectdata<qt_meta_tag_ZN21AkonadiCollectionViewE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "AkonadiCollectionView",
        "collectionEnabled",
        "",
        "Akonadi::Collection",
        "collectionDisabled",
        "resourcesChanged",
        "resourcesAddedRemoved",
        "defaultResourceChanged",
        "colorsChanged",
        "updateView",
        "updateMenu",
        "newCalendar",
        "newCalendarDone",
        "KJob*",
        "deleteCalendar",
        "deleteCalendarDone",
        "rowsInserted",
        "QModelIndex",
        "assignColor",
        "setDefaultCalendar",
        "onAction",
        "index",
        "action",
        "selectionChanged",
        "QItemSelection",
        "selected",
        "deselected"
    };

    QtMocHelpers::UintData qt_methods {
        // Signal 'collectionEnabled'
        QtMocHelpers::SignalData<void(const Akonadi::Collection &)>(1, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 3, 2 },
        }}),
        // Signal 'collectionDisabled'
        QtMocHelpers::SignalData<void(const Akonadi::Collection &)>(4, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 3, 2 },
        }}),
        // Signal 'resourcesChanged'
        QtMocHelpers::SignalData<void(bool)>(5, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Bool, 2 },
        }}),
        // Signal 'resourcesAddedRemoved'
        QtMocHelpers::SignalData<void()>(6, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'defaultResourceChanged'
        QtMocHelpers::SignalData<void(const Akonadi::Collection &)>(7, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 3, 2 },
        }}),
        // Signal 'colorsChanged'
        QtMocHelpers::SignalData<void()>(8, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'updateView'
        QtMocHelpers::SlotData<void()>(9, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'updateMenu'
        QtMocHelpers::SlotData<void()>(10, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'newCalendar'
        QtMocHelpers::SlotData<void()>(11, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'newCalendarDone'
        QtMocHelpers::SlotData<void(KJob *)>(12, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { 0x80000000 | 13, 2 },
        }}),
        // Slot 'deleteCalendar'
        QtMocHelpers::SlotData<void()>(14, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'deleteCalendarDone'
        QtMocHelpers::SlotData<void(KJob *)>(15, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { 0x80000000 | 13, 2 },
        }}),
        // Slot 'rowsInserted'
        QtMocHelpers::SlotData<void(const QModelIndex &, int, int)>(16, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { 0x80000000 | 17, 2 }, { QMetaType::Int, 2 }, { QMetaType::Int, 2 },
        }}),
        // Slot 'assignColor'
        QtMocHelpers::SlotData<void()>(18, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'setDefaultCalendar'
        QtMocHelpers::SlotData<void()>(19, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'onAction'
        QtMocHelpers::SlotData<void(const QModelIndex &, int)>(20, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { 0x80000000 | 17, 21 }, { QMetaType::Int, 22 },
        }}),
        // Slot 'selectionChanged'
        QtMocHelpers::SlotData<void(const QItemSelection &, const QItemSelection &)>(23, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { 0x80000000 | 24, 25 }, { 0x80000000 | 24, 26 },
        }}),
    };
    QtMocHelpers::UintData qt_properties {
    };
    QtMocHelpers::UintData qt_enums {
    };
    return QtMocHelpers::metaObjectData<AkonadiCollectionView, qt_meta_tag_ZN21AkonadiCollectionViewE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject AkonadiCollectionView::staticMetaObject = { {
    QMetaObject::SuperData::link<CalendarViewExtension::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN21AkonadiCollectionViewE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN21AkonadiCollectionViewE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN21AkonadiCollectionViewE_t>.metaTypes,
    nullptr
} };

void AkonadiCollectionView::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<AkonadiCollectionView *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->collectionEnabled((*reinterpret_cast<std::add_pointer_t<Akonadi::Collection>>(_a[1]))); break;
        case 1: _t->collectionDisabled((*reinterpret_cast<std::add_pointer_t<Akonadi::Collection>>(_a[1]))); break;
        case 2: _t->resourcesChanged((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 3: _t->resourcesAddedRemoved(); break;
        case 4: _t->defaultResourceChanged((*reinterpret_cast<std::add_pointer_t<Akonadi::Collection>>(_a[1]))); break;
        case 5: _t->colorsChanged(); break;
        case 6: _t->updateView(); break;
        case 7: _t->updateMenu(); break;
        case 8: _t->newCalendar(); break;
        case 9: _t->newCalendarDone((*reinterpret_cast<std::add_pointer_t<KJob*>>(_a[1]))); break;
        case 10: _t->deleteCalendar(); break;
        case 11: _t->deleteCalendarDone((*reinterpret_cast<std::add_pointer_t<KJob*>>(_a[1]))); break;
        case 12: _t->rowsInserted((*reinterpret_cast<std::add_pointer_t<QModelIndex>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[3]))); break;
        case 13: _t->assignColor(); break;
        case 14: _t->setDefaultCalendar(); break;
        case 15: _t->onAction((*reinterpret_cast<std::add_pointer_t<QModelIndex>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[2]))); break;
        case 16: _t->selectionChanged((*reinterpret_cast<std::add_pointer_t<QItemSelection>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QItemSelection>>(_a[2]))); break;
        default: ;
        }
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        switch (_id) {
        default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
        case 9:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< KJob* >(); break;
            }
            break;
        case 11:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< KJob* >(); break;
            }
            break;
        }
    }
    if (_c == QMetaObject::IndexOfMethod) {
        if (QtMocHelpers::indexOfMethod<void (AkonadiCollectionView::*)(const Akonadi::Collection & )>(_a, &AkonadiCollectionView::collectionEnabled, 0))
            return;
        if (QtMocHelpers::indexOfMethod<void (AkonadiCollectionView::*)(const Akonadi::Collection & )>(_a, &AkonadiCollectionView::collectionDisabled, 1))
            return;
        if (QtMocHelpers::indexOfMethod<void (AkonadiCollectionView::*)(bool )>(_a, &AkonadiCollectionView::resourcesChanged, 2))
            return;
        if (QtMocHelpers::indexOfMethod<void (AkonadiCollectionView::*)()>(_a, &AkonadiCollectionView::resourcesAddedRemoved, 3))
            return;
        if (QtMocHelpers::indexOfMethod<void (AkonadiCollectionView::*)(const Akonadi::Collection & )>(_a, &AkonadiCollectionView::defaultResourceChanged, 4))
            return;
        if (QtMocHelpers::indexOfMethod<void (AkonadiCollectionView::*)()>(_a, &AkonadiCollectionView::colorsChanged, 5))
            return;
    }
}

const QMetaObject *AkonadiCollectionView::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *AkonadiCollectionView::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN21AkonadiCollectionViewE_t>.strings))
        return static_cast<void*>(this);
    return CalendarViewExtension::qt_metacast(_clname);
}

int AkonadiCollectionView::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = CalendarViewExtension::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 17)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 17;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 17)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 17;
    }
    return _id;
}

// SIGNAL 0
void AkonadiCollectionView::collectionEnabled(const Akonadi::Collection & _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 0, nullptr, _t1);
}

// SIGNAL 1
void AkonadiCollectionView::collectionDisabled(const Akonadi::Collection & _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 1, nullptr, _t1);
}

// SIGNAL 2
void AkonadiCollectionView::resourcesChanged(bool _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 2, nullptr, _t1);
}

// SIGNAL 3
void AkonadiCollectionView::resourcesAddedRemoved()
{
    QMetaObject::activate(this, &staticMetaObject, 3, nullptr);
}

// SIGNAL 4
void AkonadiCollectionView::defaultResourceChanged(const Akonadi::Collection & _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 4, nullptr, _t1);
}

// SIGNAL 5
void AkonadiCollectionView::colorsChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 5, nullptr);
}
QT_WARNING_POP
