/****************************************************************************
** Meta object code from reading C++ file 'koeventpopupmenu.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.11.2)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../../korganizer-26.08.0/src/koeventpopupmenu.h"
#include <QtCore/qmetatype.h>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'koeventpopupmenu.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.11.2. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN16KOEventPopupMenuE_t {};
} // unnamed namespace

template <> constexpr inline auto KOEventPopupMenu::qt_create_metaobjectdata<qt_meta_tag_ZN16KOEventPopupMenuE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "KOEventPopupMenu",
        "configChanged",
        "",
        "editIncidenceSignal",
        "Akonadi::Item",
        "showIncidenceSignal",
        "showOccurrenceSignal",
        "deleteIncidenceSignal",
        "cutIncidenceSignal",
        "copyIncidenceSignal",
        "pasteIncidenceSignal",
        "toggleAlarmSignal",
        "toggleOccurrenceCompletedSignal",
        "copyIncidenceToResourceSignal",
        "Akonadi::Collection",
        "moveIncidenceToResourceSignal",
        "dissociateOccurrencesSignal",
        "showIncidencePopup",
        "Akonadi::CollectionCalendar::Ptr",
        "calendar",
        "createEvent",
        "item",
        "popupShow",
        "popupEdit",
        "popupPaste",
        "slotPrint",
        "printPreview",
        "popupDelete",
        "popupCut",
        "popupCopy",
        "toggleAlarm",
        "toggleTodoCompleted",
        "dissociateOccurrences",
        "forward",
        "createNewTodo",
        "createTodo",
        "createNewEvent",
        "MenuStyle",
        "NormalView",
        "MiniList"
    };

    QtMocHelpers::UintData qt_methods {
        // Signal 'configChanged'
        QtMocHelpers::SignalData<void()>(1, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'editIncidenceSignal'
        QtMocHelpers::SignalData<void(const Akonadi::Item &)>(3, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 4, 2 },
        }}),
        // Signal 'showIncidenceSignal'
        QtMocHelpers::SignalData<void(const Akonadi::Item &)>(5, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 4, 2 },
        }}),
        // Signal 'showOccurrenceSignal'
        QtMocHelpers::SignalData<void(const Akonadi::Item &, const QDate &)>(6, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 4, 2 }, { QMetaType::QDate, 2 },
        }}),
        // Signal 'deleteIncidenceSignal'
        QtMocHelpers::SignalData<void(const Akonadi::Item &)>(7, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 4, 2 },
        }}),
        // Signal 'cutIncidenceSignal'
        QtMocHelpers::SignalData<void(const Akonadi::Item &)>(8, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 4, 2 },
        }}),
        // Signal 'copyIncidenceSignal'
        QtMocHelpers::SignalData<void(const Akonadi::Item &)>(9, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 4, 2 },
        }}),
        // Signal 'pasteIncidenceSignal'
        QtMocHelpers::SignalData<void()>(10, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'toggleAlarmSignal'
        QtMocHelpers::SignalData<void(const Akonadi::Item &)>(11, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 4, 2 },
        }}),
        // Signal 'toggleOccurrenceCompletedSignal'
        QtMocHelpers::SignalData<void(const Akonadi::Item &, const QDate &)>(12, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 4, 2 }, { QMetaType::QDate, 2 },
        }}),
        // Signal 'copyIncidenceToResourceSignal'
        QtMocHelpers::SignalData<void(const Akonadi::Item &, const Akonadi::Collection &)>(13, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 4, 2 }, { 0x80000000 | 14, 2 },
        }}),
        // Signal 'moveIncidenceToResourceSignal'
        QtMocHelpers::SignalData<void(const Akonadi::Item &, const Akonadi::Collection &)>(15, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 4, 2 }, { 0x80000000 | 14, 2 },
        }}),
        // Signal 'dissociateOccurrencesSignal'
        QtMocHelpers::SignalData<void(const Akonadi::Item &, const QDate &)>(16, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 4, 2 }, { QMetaType::QDate, 2 },
        }}),
        // Slot 'showIncidencePopup'
        QtMocHelpers::SlotData<void(const Akonadi::CollectionCalendar::Ptr &, const Akonadi::Item &, const QDate &)>(17, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 18, 19 }, { 0x80000000 | 4, 2 }, { QMetaType::QDate, 2 },
        }}),
        // Slot 'createEvent'
        QtMocHelpers::SlotData<void(const Akonadi::Item &)>(20, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 4, 21 },
        }}),
        // Slot 'popupShow'
        QtMocHelpers::SlotData<void()>(22, 2, QMC::AccessProtected, QMetaType::Void),
        // Slot 'popupEdit'
        QtMocHelpers::SlotData<void()>(23, 2, QMC::AccessProtected, QMetaType::Void),
        // Slot 'popupPaste'
        QtMocHelpers::SlotData<void()>(24, 2, QMC::AccessProtected, QMetaType::Void),
        // Slot 'slotPrint'
        QtMocHelpers::SlotData<void()>(25, 2, QMC::AccessProtected, QMetaType::Void),
        // Slot 'printPreview'
        QtMocHelpers::SlotData<void()>(26, 2, QMC::AccessProtected, QMetaType::Void),
        // Slot 'popupDelete'
        QtMocHelpers::SlotData<void()>(27, 2, QMC::AccessProtected, QMetaType::Void),
        // Slot 'popupCut'
        QtMocHelpers::SlotData<void()>(28, 2, QMC::AccessProtected, QMetaType::Void),
        // Slot 'popupCopy'
        QtMocHelpers::SlotData<void()>(29, 2, QMC::AccessProtected, QMetaType::Void),
        // Slot 'toggleAlarm'
        QtMocHelpers::SlotData<void()>(30, 2, QMC::AccessProtected, QMetaType::Void),
        // Slot 'toggleTodoCompleted'
        QtMocHelpers::SlotData<void()>(31, 2, QMC::AccessProtected, QMetaType::Void),
        // Slot 'dissociateOccurrences'
        QtMocHelpers::SlotData<void()>(32, 2, QMC::AccessProtected, QMetaType::Void),
        // Slot 'forward'
        QtMocHelpers::SlotData<void()>(33, 2, QMC::AccessProtected, QMetaType::Void),
        // Slot 'createNewTodo'
        QtMocHelpers::SlotData<void()>(34, 2, QMC::AccessProtected, QMetaType::Void),
        // Slot 'createTodo'
        QtMocHelpers::SlotData<void()>(35, 2, QMC::AccessProtected, QMetaType::Void),
        // Slot 'createNewEvent'
        QtMocHelpers::SlotData<void()>(36, 2, QMC::AccessProtected, QMetaType::Void),
        // Slot 'createEvent'
        QtMocHelpers::SlotData<void()>(20, 2, QMC::AccessProtected, QMetaType::Void),
    };
    QtMocHelpers::UintData qt_properties {
    };
    QtMocHelpers::UintData qt_enums {
        // enum 'MenuStyle'
        QtMocHelpers::EnumData<enum MenuStyle>(37, 37, QMC::EnumFlags{}).add({
            {   38, MenuStyle::NormalView },
            {   39, MenuStyle::MiniList },
        }),
    };
    return QtMocHelpers::metaObjectData<KOEventPopupMenu, qt_meta_tag_ZN16KOEventPopupMenuE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject KOEventPopupMenu::staticMetaObject = { {
    QMetaObject::SuperData::link<QMenu::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN16KOEventPopupMenuE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN16KOEventPopupMenuE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN16KOEventPopupMenuE_t>.metaTypes,
    nullptr
} };

void KOEventPopupMenu::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<KOEventPopupMenu *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->configChanged(); break;
        case 1: _t->editIncidenceSignal((*reinterpret_cast<std::add_pointer_t<Akonadi::Item>>(_a[1]))); break;
        case 2: _t->showIncidenceSignal((*reinterpret_cast<std::add_pointer_t<Akonadi::Item>>(_a[1]))); break;
        case 3: _t->showOccurrenceSignal((*reinterpret_cast<std::add_pointer_t<Akonadi::Item>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QDate>>(_a[2]))); break;
        case 4: _t->deleteIncidenceSignal((*reinterpret_cast<std::add_pointer_t<Akonadi::Item>>(_a[1]))); break;
        case 5: _t->cutIncidenceSignal((*reinterpret_cast<std::add_pointer_t<Akonadi::Item>>(_a[1]))); break;
        case 6: _t->copyIncidenceSignal((*reinterpret_cast<std::add_pointer_t<Akonadi::Item>>(_a[1]))); break;
        case 7: _t->pasteIncidenceSignal(); break;
        case 8: _t->toggleAlarmSignal((*reinterpret_cast<std::add_pointer_t<Akonadi::Item>>(_a[1]))); break;
        case 9: _t->toggleOccurrenceCompletedSignal((*reinterpret_cast<std::add_pointer_t<Akonadi::Item>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QDate>>(_a[2]))); break;
        case 10: _t->copyIncidenceToResourceSignal((*reinterpret_cast<std::add_pointer_t<Akonadi::Item>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<Akonadi::Collection>>(_a[2]))); break;
        case 11: _t->moveIncidenceToResourceSignal((*reinterpret_cast<std::add_pointer_t<Akonadi::Item>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<Akonadi::Collection>>(_a[2]))); break;
        case 12: _t->dissociateOccurrencesSignal((*reinterpret_cast<std::add_pointer_t<Akonadi::Item>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QDate>>(_a[2]))); break;
        case 13: _t->showIncidencePopup((*reinterpret_cast<std::add_pointer_t<Akonadi::CollectionCalendar::Ptr>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<Akonadi::Item>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<QDate>>(_a[3]))); break;
        case 14: _t->createEvent((*reinterpret_cast<std::add_pointer_t<Akonadi::Item>>(_a[1]))); break;
        case 15: _t->popupShow(); break;
        case 16: _t->popupEdit(); break;
        case 17: _t->popupPaste(); break;
        case 18: _t->slotPrint(); break;
        case 19: _t->printPreview(); break;
        case 20: _t->popupDelete(); break;
        case 21: _t->popupCut(); break;
        case 22: _t->popupCopy(); break;
        case 23: _t->toggleAlarm(); break;
        case 24: _t->toggleTodoCompleted(); break;
        case 25: _t->dissociateOccurrences(); break;
        case 26: _t->forward(); break;
        case 27: _t->createNewTodo(); break;
        case 28: _t->createTodo(); break;
        case 29: _t->createNewEvent(); break;
        case 30: _t->createEvent(); break;
        default: ;
        }
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        switch (_id) {
        default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
        case 1:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< Akonadi::Item >(); break;
            }
            break;
        case 2:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< Akonadi::Item >(); break;
            }
            break;
        case 3:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< Akonadi::Item >(); break;
            }
            break;
        case 4:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< Akonadi::Item >(); break;
            }
            break;
        case 5:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< Akonadi::Item >(); break;
            }
            break;
        case 6:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< Akonadi::Item >(); break;
            }
            break;
        case 8:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< Akonadi::Item >(); break;
            }
            break;
        case 9:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< Akonadi::Item >(); break;
            }
            break;
        case 10:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< Akonadi::Item >(); break;
            }
            break;
        case 11:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< Akonadi::Item >(); break;
            }
            break;
        case 12:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< Akonadi::Item >(); break;
            }
            break;
        case 13:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 1:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< Akonadi::Item >(); break;
            }
            break;
        case 14:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< Akonadi::Item >(); break;
            }
            break;
        }
    }
    if (_c == QMetaObject::IndexOfMethod) {
        if (QtMocHelpers::indexOfMethod<void (KOEventPopupMenu::*)()>(_a, &KOEventPopupMenu::configChanged, 0))
            return;
        if (QtMocHelpers::indexOfMethod<void (KOEventPopupMenu::*)(const Akonadi::Item & )>(_a, &KOEventPopupMenu::editIncidenceSignal, 1))
            return;
        if (QtMocHelpers::indexOfMethod<void (KOEventPopupMenu::*)(const Akonadi::Item & )>(_a, &KOEventPopupMenu::showIncidenceSignal, 2))
            return;
        if (QtMocHelpers::indexOfMethod<void (KOEventPopupMenu::*)(const Akonadi::Item & , const QDate & )>(_a, &KOEventPopupMenu::showOccurrenceSignal, 3))
            return;
        if (QtMocHelpers::indexOfMethod<void (KOEventPopupMenu::*)(const Akonadi::Item & )>(_a, &KOEventPopupMenu::deleteIncidenceSignal, 4))
            return;
        if (QtMocHelpers::indexOfMethod<void (KOEventPopupMenu::*)(const Akonadi::Item & )>(_a, &KOEventPopupMenu::cutIncidenceSignal, 5))
            return;
        if (QtMocHelpers::indexOfMethod<void (KOEventPopupMenu::*)(const Akonadi::Item & )>(_a, &KOEventPopupMenu::copyIncidenceSignal, 6))
            return;
        if (QtMocHelpers::indexOfMethod<void (KOEventPopupMenu::*)()>(_a, &KOEventPopupMenu::pasteIncidenceSignal, 7))
            return;
        if (QtMocHelpers::indexOfMethod<void (KOEventPopupMenu::*)(const Akonadi::Item & )>(_a, &KOEventPopupMenu::toggleAlarmSignal, 8))
            return;
        if (QtMocHelpers::indexOfMethod<void (KOEventPopupMenu::*)(const Akonadi::Item & , const QDate & )>(_a, &KOEventPopupMenu::toggleOccurrenceCompletedSignal, 9))
            return;
        if (QtMocHelpers::indexOfMethod<void (KOEventPopupMenu::*)(const Akonadi::Item & , const Akonadi::Collection & )>(_a, &KOEventPopupMenu::copyIncidenceToResourceSignal, 10))
            return;
        if (QtMocHelpers::indexOfMethod<void (KOEventPopupMenu::*)(const Akonadi::Item & , const Akonadi::Collection & )>(_a, &KOEventPopupMenu::moveIncidenceToResourceSignal, 11))
            return;
        if (QtMocHelpers::indexOfMethod<void (KOEventPopupMenu::*)(const Akonadi::Item & , const QDate & )>(_a, &KOEventPopupMenu::dissociateOccurrencesSignal, 12))
            return;
    }
}

const QMetaObject *KOEventPopupMenu::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *KOEventPopupMenu::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN16KOEventPopupMenuE_t>.strings))
        return static_cast<void*>(this);
    return QMenu::qt_metacast(_clname);
}

int KOEventPopupMenu::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QMenu::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 31)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 31;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 31)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 31;
    }
    return _id;
}

// SIGNAL 0
void KOEventPopupMenu::configChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 0, nullptr);
}

// SIGNAL 1
void KOEventPopupMenu::editIncidenceSignal(const Akonadi::Item & _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 1, nullptr, _t1);
}

// SIGNAL 2
void KOEventPopupMenu::showIncidenceSignal(const Akonadi::Item & _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 2, nullptr, _t1);
}

// SIGNAL 3
void KOEventPopupMenu::showOccurrenceSignal(const Akonadi::Item & _t1, const QDate & _t2)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 3, nullptr, _t1, _t2);
}

// SIGNAL 4
void KOEventPopupMenu::deleteIncidenceSignal(const Akonadi::Item & _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 4, nullptr, _t1);
}

// SIGNAL 5
void KOEventPopupMenu::cutIncidenceSignal(const Akonadi::Item & _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 5, nullptr, _t1);
}

// SIGNAL 6
void KOEventPopupMenu::copyIncidenceSignal(const Akonadi::Item & _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 6, nullptr, _t1);
}

// SIGNAL 7
void KOEventPopupMenu::pasteIncidenceSignal()
{
    QMetaObject::activate(this, &staticMetaObject, 7, nullptr);
}

// SIGNAL 8
void KOEventPopupMenu::toggleAlarmSignal(const Akonadi::Item & _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 8, nullptr, _t1);
}

// SIGNAL 9
void KOEventPopupMenu::toggleOccurrenceCompletedSignal(const Akonadi::Item & _t1, const QDate & _t2)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 9, nullptr, _t1, _t2);
}

// SIGNAL 10
void KOEventPopupMenu::copyIncidenceToResourceSignal(const Akonadi::Item & _t1, const Akonadi::Collection & _t2)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 10, nullptr, _t1, _t2);
}

// SIGNAL 11
void KOEventPopupMenu::moveIncidenceToResourceSignal(const Akonadi::Item & _t1, const Akonadi::Collection & _t2)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 11, nullptr, _t1, _t2);
}

// SIGNAL 12
void KOEventPopupMenu::dissociateOccurrencesSignal(const Akonadi::Item & _t1, const QDate & _t2)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 12, nullptr, _t1, _t2);
}
QT_WARNING_POP
